CMIP6 Source ID Citation details by experiment details
Author: Paul J. Durack
Description: Controlled vocabulary for CMIP6
Keywords: HTML, CSS, JavaScript

# WCRP-CMIP CMIP6_CVs version: 6.2.60.0

#### Experiment IDs | Institution IDs | Source IDs | Source IDs (incl licenses) | Citations by (Source ID, Institution Id, Activity ID) | Citations by (Source ID, Institution Id, Activity ID, Experiment ID) |

Source ID | Institution ID | Activity ID | Experiment | Data Reference | License | DOI
--- | --- | --- | --- | --- | --- | ---
Source ID | Institution ID | Activity ID | Experiment | Data Reference | License | DOI
4AOP-v1-5 | IPSL | RFMIP | rad-irf | Boucher, Olivier et al. (2020). IPSL 4AOP-v1-5 model output prepared for CMIP6 RFMIP rad-irf. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12369 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12369
ACCESS-CM2 | CSIRO-ARCCSS | CMIP | 1pctCO2 | Dix, Martin et al. (2019). CSIRO-ARCCSS ACCESS-CM2 model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4230 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4230
ACCESS-CM2 | CSIRO-ARCCSS | CMIP | abrupt-4xCO2 | Dix, Martin et al. (2019). CSIRO-ARCCSS ACCESS-CM2 model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4237 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4237
ACCESS-CM2 | CSIRO-ARCCSS | CMIP | amip | Dix, Martin et al. (2019). CSIRO-ARCCSS ACCESS-CM2 model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4239 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4239
ACCESS-CM2 | CSIRO-ARCCSS | CMIP | historical | Dix, Martin et al. (2019). CSIRO-ARCCSS ACCESS-CM2 model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4271 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4271
ACCESS-CM2 | CSIRO-ARCCSS | CMIP | piControl | Dix, Martin et al. (2019). CSIRO-ARCCSS ACCESS-CM2 model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4311 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4311
ACCESS-CM2 | CSIRO-ARCCSS | DAMIP | hist-GHG | Dix, Martin et al. (2020). CSIRO-ARCCSS ACCESS-CM2 model output prepared for CMIP6 DAMIP hist-GHG. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14365 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14365
ACCESS-CM2 | CSIRO-ARCCSS | DAMIP | hist-aer | Dix, Martin et al. (2020). CSIRO-ARCCSS ACCESS-CM2 model output prepared for CMIP6 DAMIP hist-aer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14369 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14369
ACCESS-CM2 | CSIRO-ARCCSS | DAMIP | hist-nat | Dix, Martin et al. (2020). CSIRO-ARCCSS ACCESS-CM2 model output prepared for CMIP6 DAMIP hist-nat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14377 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14377
ACCESS-CM2 | CSIRO-ARCCSS | FAFMIP | faf-all | Savita, Abhishek et al. (2019). CSIRO-ARCCSS ACCESS-CM2 model output prepared for CMIP6 FAFMIP faf-all. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4261 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4261
ACCESS-CM2 | CSIRO-ARCCSS | FAFMIP | faf-heat | Savita, Abhishek et al. (2019). CSIRO-ARCCSS ACCESS-CM2 model output prepared for CMIP6 FAFMIP faf-heat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4262 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4262
ACCESS-CM2 | CSIRO-ARCCSS | FAFMIP | faf-heat-NA0pct | Savita, Abhishek et al. (2020). CSIRO-ARCCSS ACCESS-CM2 model output prepared for CMIP6 FAFMIP faf-heat-NA0pct. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11617 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11617
ACCESS-CM2 | CSIRO-ARCCSS | FAFMIP | faf-heat-NA50pct | Savita, Abhishek et al. (2020). CSIRO-ARCCSS ACCESS-CM2 model output prepared for CMIP6 FAFMIP faf-heat-NA50pct. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11618 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11618
ACCESS-CM2 | CSIRO-ARCCSS | FAFMIP | faf-passiveheat | Savita, Abhishek et al. (2019). CSIRO-ARCCSS ACCESS-CM2 model output prepared for CMIP6 FAFMIP faf-passiveheat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4263 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4263
ACCESS-CM2 | CSIRO-ARCCSS | FAFMIP | faf-stress | Savita, Abhishek et al. (2019). CSIRO-ARCCSS ACCESS-CM2 model output prepared for CMIP6 FAFMIP faf-stress. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4264 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4264
ACCESS-CM2 | CSIRO-ARCCSS | FAFMIP | faf-water | Savita, Abhishek et al. (2019). CSIRO-ARCCSS ACCESS-CM2 model output prepared for CMIP6 FAFMIP faf-water. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4265 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4265
ACCESS-CM2 | CSIRO-ARCCSS | RFMIP | piClim-4xCO2 | Dix, Martin et al. (2020). CSIRO-ARCCSS ACCESS-CM2 model output prepared for CMIP6 RFMIP piClim-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4283 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4283
ACCESS-CM2 | CSIRO-ARCCSS | RFMIP | piClim-aer | Dix, Martin et al. (2020). CSIRO-ARCCSS ACCESS-CM2 model output prepared for CMIP6 RFMIP piClim-aer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4285 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4285
ACCESS-CM2 | CSIRO-ARCCSS | RFMIP | piClim-anthro | Dix, Martin et al. (2020). CSIRO-ARCCSS ACCESS-CM2 model output prepared for CMIP6 RFMIP piClim-anthro. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4287 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4287
ACCESS-CM2 | CSIRO-ARCCSS | RFMIP | piClim-control | Dix, Martin et al. (2020). CSIRO-ARCCSS ACCESS-CM2 model output prepared for CMIP6 RFMIP piClim-control. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4289 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4289
ACCESS-CM2 | CSIRO-ARCCSS | RFMIP | piClim-ghg | Dix, Martin et al. (2020). CSIRO-ARCCSS ACCESS-CM2 model output prepared for CMIP6 RFMIP piClim-ghg. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4291 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4291
ACCESS-CM2 | CSIRO-ARCCSS | ScenarioMIP | ssp126 | Dix, Martin et al. (2019). CSIRO-ARCCSS ACCESS-CM2 model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4319 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4319
ACCESS-CM2 | CSIRO-ARCCSS | ScenarioMIP | ssp245 | Dix, Martin et al. (2019). CSIRO-ARCCSS ACCESS-CM2 model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4321 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4321
ACCESS-CM2 | CSIRO-ARCCSS | ScenarioMIP | ssp370 | Dix, Martin et al. (2019). CSIRO-ARCCSS ACCESS-CM2 model output prepared for CMIP6 ScenarioMIP ssp370. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4323 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4323
ACCESS-CM2 | CSIRO-ARCCSS | ScenarioMIP | ssp534-over | Dix, Martin et al. (2021). CSIRO-ARCCSS ACCESS-CM2 model output prepared for CMIP6 ScenarioMIP ssp534-over. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4329 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4329
ACCESS-CM2 | CSIRO-ARCCSS | ScenarioMIP | ssp585 | Dix, Martin et al. (2019). CSIRO-ARCCSS ACCESS-CM2 model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4332 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4332
ACCESS-ESM1-5 | CSIRO | C4MIP | 1pctCO2-bgc | Ziehn, Tilo et al. (2019). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 C4MIP 1pctCO2-bgc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4232 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4232
ACCESS-ESM1-5 | CSIRO | C4MIP | 1pctCO2-rad | Ziehn, Tilo et al. (2019). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 C4MIP 1pctCO2-rad. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4234 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4234
ACCESS-ESM1-5 | CSIRO | C4MIP | esm-1pct-brch-1000PgC | Ziehn, Tilo et al. (2019). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 C4MIP esm-1pct-brch-1000PgC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10481 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10481
ACCESS-ESM1-5 | CSIRO | C4MIP | esm-1pct-brch-2000PgC | Ziehn, Tilo et al. (2019). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 C4MIP esm-1pct-brch-2000PgC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10483 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10483
ACCESS-ESM1-5 | CSIRO | C4MIP | esm-1pct-brch-750PgC | Ziehn, Tilo et al. (2019). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 C4MIP esm-1pct-brch-750PgC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10485 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10485
ACCESS-ESM1-5 | CSIRO | C4MIP | esm-ssp585 | Ziehn, Tilo et al. (2019). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 C4MIP esm-ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4252 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4252
ACCESS-ESM1-5 | CSIRO | C4MIP | hist-bgc | Ziehn, Tilo et al. (2019). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 C4MIP hist-bgc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4266 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4266
ACCESS-ESM1-5 | CSIRO | C4MIP | ssp585-bgc | Ziehn, Tilo et al. (2020). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 C4MIP ssp585-bgc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4334 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4334
ACCESS-ESM1-5 | CSIRO | CDRMIP | 1pctCO2-cdr | Ziehn, Tilo et al. (2019). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 CDRMIP 1pctCO2-cdr. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4233 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4233
ACCESS-ESM1-5 | CSIRO | CDRMIP | esm-pi-CO2pulse | Ziehn, Tilo et al. (2019). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 CDRMIP esm-pi-cdr-CO2pulse. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4245 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4245
ACCESS-ESM1-5 | CSIRO | CDRMIP | esm-pi-cdr-pulse | Ziehn, Tilo et al. (2019). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 CDRMIP esm-pi-cdr-pulse. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4246 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4246
ACCESS-ESM1-5 | CSIRO | CMIP | 1pctCO2 | Ziehn, Tilo et al. (2019). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4231 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4231
ACCESS-ESM1-5 | CSIRO | CMIP | abrupt-4xCO2 | Ziehn, Tilo et al. (2019). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4238 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4238
ACCESS-ESM1-5 | CSIRO | CMIP | amip | Ziehn, Tilo et al. (2019). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4240 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4240
ACCESS-ESM1-5 | CSIRO | CMIP | esm-hist | Ziehn, Tilo et al. (2019). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 CMIP esm-hist. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4242 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4242
ACCESS-ESM1-5 | CSIRO | CMIP | esm-piControl | Ziehn, Tilo et al. (2019). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 CMIP esm-piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4248 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4248
ACCESS-ESM1-5 | CSIRO | CMIP | historical | Ziehn, Tilo et al. (2019). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4272 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4272
ACCESS-ESM1-5 | CSIRO | CMIP | piControl | Ziehn, Tilo et al. (2019). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4312 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4312
ACCESS-ESM1-5 | CSIRO | DAMIP | hist-GHG | Ziehn, Tilo et al. (2020). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 DAMIP hist-GHG. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14366 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14366
ACCESS-ESM1-5 | CSIRO | DAMIP | hist-aer | Ziehn, Tilo et al. (2020). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 DAMIP hist-aer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14370 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14370
ACCESS-ESM1-5 | CSIRO | DAMIP | hist-nat | Ziehn, Tilo et al. (2020). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 DAMIP hist-nat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14378 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14378
ACCESS-ESM1-5 | CSIRO | DAMIP | hist-sol | Ziehn, Tilo et al. (2023). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 DAMIP hist-sol. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14382 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14382
ACCESS-ESM1-5 | CSIRO | DAMIP | hist-volc | Ziehn, Tilo et al. (2023). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 DAMIP hist-volc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14388 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14388
ACCESS-ESM1-5 | CSIRO | DAMIP | ssp245-cov-fossil | Ziehn, Tilo et al. (2021). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 DAMIP ssp245-cov-fossil. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14931 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14931
ACCESS-ESM1-5 | CSIRO | DAMIP | ssp245-cov-modgreen | Ziehn, Tilo et al. (2021). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 DAMIP ssp245-cov-modgreen. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14933 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14933
ACCESS-ESM1-5 | CSIRO | DAMIP | ssp245-cov-strgreen | Ziehn, Tilo et al. (2021). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 DAMIP ssp245-cov-strgreen. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14935 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14935
ACCESS-ESM1-5 | CSIRO | DAMIP | ssp245-covid | Ziehn, Tilo et al. (2020). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 DAMIP ssp245-covid. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14937 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14937
ACCESS-ESM1-5 | CSIRO | LUMIP | esm-ssp585-ssp126Lu | Ziehn, Tilo et al. (2021). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 LUMIP esm-ssp585-ssp126Lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15743 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15743
ACCESS-ESM1-5 | CSIRO | LUMIP | hist-noLu | Ziehn, Tilo et al. (2021). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 LUMIP hist-noLu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15744 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15744
ACCESS-ESM1-5 | CSIRO | LUMIP | ssp126-ssp370Lu | Ziehn, Tilo et al. (2021). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 LUMIP ssp126-ssp370Lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15760 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15760
ACCESS-ESM1-5 | CSIRO | LUMIP | ssp370-ssp126Lu | Ziehn, Tilo et al. (2021). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 LUMIP ssp370-ssp126Lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15761 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15761
ACCESS-ESM1-5 | CSIRO | PMIP | lig127k | Yeung, Nicholas et al. (2019). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 PMIP lig127k. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13703 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13703
ACCESS-ESM1-5 | CSIRO | PMIP | midHolocene | Brown, Josephine et al. (2021). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 PMIP midHolocene. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13704 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13704
ACCESS-ESM1-5 | CSIRO | PMIP | past1000 | Wright, Nicky et al. (2023). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 PMIP past1000. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13706 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13706
ACCESS-ESM1-5 | CSIRO | RFMIP | piClim-4xCO2 | Ziehn, Tilo et al. (2020). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 RFMIP piClim-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4284 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4284
ACCESS-ESM1-5 | CSIRO | RFMIP | piClim-aer | Ziehn, Tilo et al. (2020). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 RFMIP piClim-aer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4286 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4286
ACCESS-ESM1-5 | CSIRO | RFMIP | piClim-anthro | Ziehn, Tilo et al. (2020). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 RFMIP piClim-anthro. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4288 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4288
ACCESS-ESM1-5 | CSIRO | RFMIP | piClim-control | Ziehn, Tilo et al. (2020). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 RFMIP piClim-control. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4290 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4290
ACCESS-ESM1-5 | CSIRO | RFMIP | piClim-ghg | Ziehn, Tilo et al. (2020). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 RFMIP piClim-ghg. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4292 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4292
ACCESS-ESM1-5 | CSIRO | RFMIP | piClim-lu | Ziehn, Tilo et al. (2020). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 RFMIP piClim-lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4302 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4302
ACCESS-ESM1-5 | CSIRO | ScenarioMIP | ssp126 | Ziehn, Tilo et al. (2019). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4320 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4320
ACCESS-ESM1-5 | CSIRO | ScenarioMIP | ssp245 | Ziehn, Tilo et al. (2019). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4322 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4322
ACCESS-ESM1-5 | CSIRO | ScenarioMIP | ssp370 | Ziehn, Tilo et al. (2019). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 ScenarioMIP ssp370. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4324 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4324
ACCESS-ESM1-5 | CSIRO | ScenarioMIP | ssp534-over | Ziehn, Tilo et al. (2021). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 ScenarioMIP ssp534-over. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4330 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4330
ACCESS-ESM1-5 | CSIRO | ScenarioMIP | ssp585 | Ziehn, Tilo et al. (2019). CSIRO ACCESS-ESM1.5 model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4333 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4333
ACCESS-OM2 | CSIRO-COSIMA | OMIP | omip2 | Hayashida, Hakase et al. (2021). CSIRO-COSIMA ACCESS-OM2 model output prepared for CMIP6 OMIP omip2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14689 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14689
ACCESS-OM2 | CSIRO-COSIMA | OMIP | omip2-spunup | Hayashida, Hakase et al. (2021). CSIRO-COSIMA ACCESS-OM2 model output prepared for CMIP6 OMIP omip2-spunup. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14691 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14691
ACCESS-OM2-025 | CSIRO-COSIMA | OMIP | omip2 | Holmes, Ryan et al. (2021). CSIRO-COSIMA ACCESS-OM2-025 model output prepared for CMIP6 OMIP omip2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14690 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14690
ARTS-2-3 | UHH | RFMIP | rad-irf | Brath, Manfred (2019). UHH ARTS2.3 model output prepared for CMIP6 RFMIP rad-irf. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8919 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8919
AWI-CM-1-1-HR | AWI | HighResMIP | control-1950 | Semmler, Tido et al. (2017). AWI AWI-CM1.1HR model output prepared for CMIP6 HighResMIP control-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2596 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2596
AWI-CM-1-1-HR | AWI | HighResMIP | hist-1950 | Semmler, Tido et al. (2017). AWI AWI-CM1.1HR model output prepared for CMIP6 HighResMIP hist-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2676 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2676
AWI-CM-1-1-HR | AWI | HighResMIP | spinup-1950 | Semmler, Tido et al. (2017). AWI AWI-CM1.1HR model output prepared for CMIP6 HighResMIP spinup-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2790 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2790
AWI-CM-1-1-LR | AWI | HighResMIP | control-1950 | Semmler, Tido et al. (2017). AWI AWI-CM1.1LR model output prepared for CMIP6 HighResMIP control-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2597 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2597
AWI-CM-1-1-LR | AWI | HighResMIP | hist-1950 | Semmler, Tido et al. (2017). AWI AWI-CM1.1LR model output prepared for CMIP6 HighResMIP hist-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2677 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2677
AWI-CM-1-1-LR | AWI | HighResMIP | spinup-1950 | Semmler, Tido et al. (2017). AWI AWI-CM1.1LR model output prepared for CMIP6 HighResMIP spinup-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2791 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2791
AWI-CM-1-1-MR | AWI | CMIP | 1pctCO2 | Semmler, Tido et al. (2018). AWI AWI-CM1.1MR model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2543 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2543
AWI-CM-1-1-MR | AWI | CMIP | abrupt-4xCO2 | Semmler, Tido et al. (2018). AWI AWI-CM1.1MR model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2568 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2568
AWI-CM-1-1-MR | AWI | CMIP | historical | Semmler, Tido et al. (2018). AWI AWI-CM1.1MR model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2686 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2686
AWI-CM-1-1-MR | AWI | CMIP | piControl | Semmler, Tido et al. (2018). AWI AWI-CM1.1MR model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2777 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2777
AWI-CM-1-1-MR | AWI | PAMIP | futSST-pdSIC | Semmler, Tido et al. (2019). AWI AWI-CM1.1MR model output prepared for CMIP6 PAMIP futSST-pdSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12024 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12024
AWI-CM-1-1-MR | AWI | PAMIP | pdSST-futArcSIC | Semmler, Tido et al. (2019). AWI AWI-CM1.1MR model output prepared for CMIP6 PAMIP pdSST-futArcSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12036 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12036
AWI-CM-1-1-MR | AWI | PAMIP | pdSST-futBKSeasSIC | Semmler, Tido et al. (2019). AWI AWI-CM1.1MR model output prepared for CMIP6 PAMIP pdSST-futBKSeasSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12038 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12038
AWI-CM-1-1-MR | AWI | PAMIP | pdSST-futOkhotskSIC | Semmler, Tido et al. (2019). AWI AWI-CM1.1MR model output prepared for CMIP6 PAMIP pdSST-futOkhotskSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12039 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12039
AWI-CM-1-1-MR | AWI | PAMIP | pdSST-pdSIC | Semmler, Tido et al. (2019). AWI AWI-CM1.1MR model output prepared for CMIP6 PAMIP pdSST-pdSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12040 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12040
AWI-CM-1-1-MR | AWI | PAMIP | pdSST-piArcSIC | Semmler, Tido et al. (2019). AWI AWI-CM1.1MR model output prepared for CMIP6 PAMIP pdSST-piArcSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12043 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12043
AWI-CM-1-1-MR | AWI | PAMIP | piSST-pdSIC | Semmler, Tido et al. (2019). AWI AWI-CM1.1MR model output prepared for CMIP6 PAMIP piSST-pdSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12044 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12044
AWI-CM-1-1-MR | AWI | PAMIP | piSST-piSIC | Semmler, Tido et al. (2019). AWI AWI-CM1.1MR model output prepared for CMIP6 PAMIP piSST-piSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12045 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12045
AWI-CM-1-1-MR | AWI | ScenarioMIP | ssp126 | Semmler, Tido et al. (2018). AWI AWI-CM1.1MR model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2796 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2796
AWI-CM-1-1-MR | AWI | ScenarioMIP | ssp245 | Semmler, Tido et al. (2018). AWI AWI-CM1.1MR model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2800 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2800
AWI-CM-1-1-MR | AWI | ScenarioMIP | ssp370 | Semmler, Tido et al. (2019). AWI AWI-CM1.1MR model output prepared for CMIP6 ScenarioMIP ssp370. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2803 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2803
AWI-CM-1-1-MR | AWI | ScenarioMIP | ssp585 | Semmler, Tido et al. (2019). AWI AWI-CM1.1MR model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2817 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2817
AWI-ESM-1-1-LR | AWI | CMIP | 1pctCO2 | Danek, Christopher et al. (2020). AWI AWI-ESM1.1LR model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9321 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9321
AWI-ESM-1-1-LR | AWI | CMIP | historical | Danek, Christopher et al. (2020). AWI AWI-ESM1.1LR model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9328 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9328
AWI-ESM-1-1-LR | AWI | CMIP | piControl | Danek, Christopher et al. (2020). AWI AWI-ESM1.1LR model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9335 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9335
AWI-ESM-1-1-LR | AWI | PMIP | lgm | Shi, Xiaoxu et al. (2020). AWI AWI-ESM1.1LR model output prepared for CMIP6 PMIP lgm. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9330 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9330
AWI-ESM-1-1-LR | AWI | PMIP | lig127k | Shi, Xiaoxu et al. (2020). AWI AWI-ESM1.1LR model output prepared for CMIP6 PMIP lig127k. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9331 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9331
AWI-ESM-1-1-LR | AWI | PMIP | midHolocene | Shi, Xiaoxu et al. (2020). AWI AWI-ESM1.1LR model output prepared for CMIP6 PMIP midHolocene. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9332 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9332
AWI-ESM-1-REcoM | AWI | C4MIP | esm-ssp585 | Danek, Christopher et al. (2023). AWI AWI-ESM1REcoM model output prepared for CMIP6 C4MIP esm-ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17742 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17742
AWI-ESM-1-REcoM | AWI | CDRMIP | esm-ssp534-over | Danek, Christopher et al. (2023). AWI AWI-ESM1REcoM model output prepared for CMIP6 CDRMIP esm-ssp534-over. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17811 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17811
AWI-ESM-1-REcoM | AWI | CMIP | esm-hist | Danek, Christopher et al. (2023). AWI AWI-ESM1REcoM model output prepared for CMIP6 CMIP esm-hist. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17738 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17738
AWI-ESM-1-REcoM | AWI | CMIP | esm-piControl | Danek, Christopher et al. (2023). AWI AWI-ESM1REcoM model output prepared for CMIP6 CMIP esm-piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17740 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17740
AWI-ESM-1-REcoM | AWI | CMIP | historical | Danek, Christopher et al. (2023). AWI AWI-ESM1REcoM model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17744 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17744
AWI-ESM-1-REcoM | AWI | CMIP | piControl | Danek, Christopher et al. (2023). AWI AWI-ESM1REcoM model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17747 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17747
AWI-ESM-1-REcoM | AWI | ScenarioMIP | ssp126 | Danek, Christopher et al. (2023). AWI AWI-ESM1REcoM model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17756 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17756
AWI-ESM-1-REcoM | AWI | ScenarioMIP | ssp245 | Danek, Christopher et al. (2023). AWI AWI-ESM1REcoM model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17757 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17757
AWI-ESM-1-REcoM | AWI | ScenarioMIP | ssp534-over | Danek, Christopher et al. (2023). AWI AWI-ESM1REcoM model output prepared for CMIP6 ScenarioMIP ssp534-over. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17761 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17761
AWI-ESM-1-REcoM | AWI | ScenarioMIP | ssp585 | Danek, Christopher et al. (2023). AWI AWI-ESM1REcoM model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17763 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17763
BCC-CSM2-HR | BCC | HighResMIP | control-1950 | Jie, Weihua et al. (2020). BCC BCC-CSM2HR model output prepared for CMIP6 HighResMIP control-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2872 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2872
BCC-CSM2-HR | BCC | HighResMIP | highresSST-present | Jie, Weihua et al. (2020). BCC BCC-CSM2HR model output prepared for CMIP6 HighResMIP highresSST-present. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2919 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2919
BCC-CSM2-HR | BCC | HighResMIP | hist-1950 | Jie, Weihua et al. (2020). BCC BCC-CSM2HR model output prepared for CMIP6 HighResMIP hist-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2921 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2921
BCC-CSM2-MR | BCC | C4MIP | 1pctCO2-bgc | Wu, Tongwen et al. (2019). BCC BCC-CSM2MR model output prepared for CMIP6 C4MIP 1pctCO2-bgc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2835 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2835
BCC-CSM2-MR | BCC | C4MIP | 1pctCO2-rad | Wu, Tongwen et al. (2019). BCC BCC-CSM2MR model output prepared for CMIP6 C4MIP 1pctCO2-rad. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2836 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2836
BCC-CSM2-MR | BCC | C4MIP | esm-ssp585 | Wu, Tongwen et al. (2019). BCC BCC-CSM2MR model output prepared for CMIP6 C4MIP esm-ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2912 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2912
BCC-CSM2-MR | BCC | CFMIP | amip-4xCO2 | Wu, Tongwen et al. (2019). BCC BCC-CSM2MR model output prepared for CMIP6 CFMIP amip-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2852 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2852
BCC-CSM2-MR | BCC | CFMIP | amip-future4K | Wu, Tongwen et al. (2019). BCC BCC-CSM2MR model output prepared for CMIP6 CFMIP amip-future4K. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2856 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2856
BCC-CSM2-MR | BCC | CFMIP | amip-m4K | Wu, Tongwen et al. (2019). BCC BCC-CSM2MR model output prepared for CMIP6 CFMIP amip-m4K. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2863 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2863
BCC-CSM2-MR | BCC | CFMIP | amip-p4K | Wu, Tongwen et al. (2019). BCC BCC-CSM2MR model output prepared for CMIP6 CFMIP amip-p4K. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2864 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2864
BCC-CSM2-MR | BCC | CMIP | 1pctCO2 | Wu, Tongwen et al. (2018). BCC BCC-CSM2MR model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2833 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2833
BCC-CSM2-MR | BCC | CMIP | abrupt-4xCO2 | Wu, Tongwen et al. (2018). BCC BCC-CSM2MR model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2845 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2845
BCC-CSM2-MR | BCC | CMIP | amip | Wu, Tongwen et al. (2019). BCC BCC-CSM2MR model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2850 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2850
BCC-CSM2-MR | BCC | CMIP | esm-hist | Wu, Tongwen et al. (2018). BCC BCC-CSM2MR model output prepared for CMIP6 CMIP esm-hist. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2901 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2901
BCC-CSM2-MR | BCC | CMIP | esm-piControl | Wu, Tongwen et al. (2018). BCC BCC-CSM2MR model output prepared for CMIP6 CMIP esm-piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2907 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2907
BCC-CSM2-MR | BCC | CMIP | historical | Wu, Tongwen et al. (2018). BCC BCC-CSM2MR model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2948 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2948
BCC-CSM2-MR | BCC | CMIP | piControl | Wu, Tongwen et al. (2018). BCC BCC-CSM2MR model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3016 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3016
BCC-CSM2-MR | BCC | DAMIP | hist-GHG | Wu, Tongwen et al. (2019). BCC BCC-CSM2MR model output prepared for CMIP6 DAMIP hist-GHG. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2924 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2924
BCC-CSM2-MR | BCC | DAMIP | hist-aer | Wu, Tongwen et al. (2019). BCC BCC-CSM2MR model output prepared for CMIP6 DAMIP hist-aer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2925 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2925
BCC-CSM2-MR | BCC | DAMIP | hist-nat | Wu, Tongwen et al. (2019). BCC BCC-CSM2MR model output prepared for CMIP6 DAMIP hist-nat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2929 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2929
BCC-CSM2-MR | BCC | DCPP | dcppA-hindcast | Fang, Yongjie et al. (2019). BCC BCC-CSM2MR model output prepared for CMIP6 DCPP dcppA-hindcast. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2874 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2874
BCC-CSM2-MR | BCC | GMMIP | amip-hist | Zhang, Jie et al. (2019). BCC BCC-CSM2MR model output prepared for CMIP6 GMMIP amip-hist. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2857 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2857
BCC-CSM2-MR | BCC | GMMIP | hist-resAMO | Zhang, Jie et al. (2019). BCC BCC-CSM2MR model output prepared for CMIP6 GMMIP hist-resAMO. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2933 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2933
BCC-CSM2-MR | BCC | GMMIP | hist-resIPO | Zhang, Jie et al. (2019). BCC BCC-CSM2MR model output prepared for CMIP6 GMMIP hist-resIPO. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2934 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2934
BCC-CSM2-MR | BCC | LS3MIP | land-hist-princeton | Li, Weiping et al. (2019). BCC BCC-CSM2MR model output prepared for CMIP6 LS3MIP land-hist-princeton. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2966 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2966
BCC-CSM2-MR | BCC | LUMIP | deforest-globe | Zhang, Yanwu et al. (2019). BCC BCC-CSM2MR model output prepared for CMIP6 LUMIP deforest-globe. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2899 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2899
BCC-CSM2-MR | BCC | LUMIP | esm-ssp585-ssp126Lu | Zhang, Yanwu et al. (2019). BCC BCC-CSM2MR model output prepared for CMIP6 LUMIP esm-ssp585-ssp126Lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2913 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2913
BCC-CSM2-MR | BCC | LUMIP | hist-noLu | Zhang, Yanwu et al. (2019). BCC BCC-CSM2MR model output prepared for CMIP6 LUMIP hist-noLu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2930 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2930
BCC-CSM2-MR | BCC | LUMIP | land-hist | Zhang, Yanwu et al. (2019). BCC BCC-CSM2MR model output prepared for CMIP6 LUMIP land-hist. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2961 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2961
BCC-CSM2-MR | BCC | LUMIP | land-noLu | Zhang, Yanwu et al. (2019). BCC BCC-CSM2MR model output prepared for CMIP6 LUMIP land-noLu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2969 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2969
BCC-CSM2-MR | BCC | LUMIP | ssp126-ssp370Lu | Zhang, Yanwu et al. (2019). BCC BCC-CSM2MR model output prepared for CMIP6 LUMIP ssp126-ssp370Lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3029 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3029
BCC-CSM2-MR | BCC | LUMIP | ssp370-ssp126Lu | Zhang, Yanwu et al. (2019). BCC BCC-CSM2MR model output prepared for CMIP6 LUMIP ssp370-ssp126Lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3038 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3038
BCC-CSM2-MR | BCC | ScenarioMIP | ssp126 | Xin, Xiaoge et al. (2019). BCC BCC-CSM2MR model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3028 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3028
BCC-CSM2-MR | BCC | ScenarioMIP | ssp245 | Xin, Xiaoge et al. (2019). BCC BCC-CSM2MR model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3030 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3030
BCC-CSM2-MR | BCC | ScenarioMIP | ssp370 | Xin, Xiaoge et al. (2019). BCC BCC-CSM2MR model output prepared for CMIP6 ScenarioMIP ssp370. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3035 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3035
BCC-CSM2-MR | BCC | ScenarioMIP | ssp585 | Xin, Xiaoge et al. (2019). BCC BCC-CSM2MR model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3050 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3050
BCC-ESM1 | BCC | AerChemMIP | hist-piAer | Zhang, Jie et al. (2020). BCC BCC-ESM1 model output prepared for CMIP6 AerChemMIP hist-piAer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2931 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2931
BCC-ESM1 | BCC | AerChemMIP | hist-piNTCF | Zhang, Jie et al. (2019). BCC BCC-ESM1 model output prepared for CMIP6 AerChemMIP hist-piNTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2932 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2932
BCC-ESM1 | BCC | AerChemMIP | histSST | Zhang, Jie et al. (2019). BCC BCC-ESM1 model output prepared for CMIP6 AerChemMIP histSST. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2940 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2940
BCC-ESM1 | BCC | AerChemMIP | histSST-piAer | Zhang, Jie et al. (2021). BCC BCC-ESM1 model output prepared for CMIP6 AerChemMIP histSST-piAer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2942 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2942
BCC-ESM1 | BCC | AerChemMIP | histSST-piCH4 | Zhang, Jie et al. (2019). BCC BCC-ESM1 model output prepared for CMIP6 AerChemMIP histSST-piCH4. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2943 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2943
BCC-ESM1 | BCC | AerChemMIP | histSST-piNTCF | Zhang, Jie et al. (2019). BCC BCC-ESM1 model output prepared for CMIP6 AerChemMIP histSST-piNTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2945 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2945
BCC-ESM1 | BCC | AerChemMIP | histSST-piO3 | Zhang, Jie et al. (2021). BCC BCC-ESM1 model output prepared for CMIP6 AerChemMIP histSST-piO3. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2946 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2946
BCC-ESM1 | BCC | AerChemMIP | piClim-BC | Zhang, Jie et al. (2020). BCC BCC-ESM1 model output prepared for CMIP6 AerChemMIP piClim-BC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2989 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2989
BCC-ESM1 | BCC | AerChemMIP | piClim-CH4 | Zhang, Jie et al. (2019). BCC BCC-ESM1 model output prepared for CMIP6 AerChemMIP piClim-CH4. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2990 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2990
BCC-ESM1 | BCC | AerChemMIP | piClim-NOx | Zhang, Jie et al. (2020). BCC BCC-ESM1 model output prepared for CMIP6 AerChemMIP piClim-NOx. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2994 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2994
BCC-ESM1 | BCC | AerChemMIP | piClim-NTCF | Zhang, Jie et al. (2019). BCC BCC-ESM1 model output prepared for CMIP6 AerChemMIP piClim-NTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2995 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2995
BCC-ESM1 | BCC | AerChemMIP | piClim-O3 | Zhang, Jie et al. (2020). BCC BCC-ESM1 model output prepared for CMIP6 AerChemMIP piClim-O3. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2996 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2996
BCC-ESM1 | BCC | AerChemMIP | piClim-SO2 | Zhang, Jie et al. (2020). BCC BCC-ESM1 model output prepared for CMIP6 AerChemMIP piClim-SO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2998 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2998
BCC-ESM1 | BCC | AerChemMIP | piClim-VOC | Zhang, Jie et al. (2020). BCC BCC-ESM1 model output prepared for CMIP6 AerChemMIP piClim-VOC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2999 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2999
BCC-ESM1 | BCC | AerChemMIP | piClim-aer | Zhang, Jie et al. (2020). BCC BCC-ESM1 model output prepared for CMIP6 AerChemMIP piClim-aer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3001 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3001
BCC-ESM1 | BCC | AerChemMIP | piClim-control | Zhang, Jie et al. (2019). BCC BCC-ESM1 model output prepared for CMIP6 AerChemMIP piClim-control. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3004 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3004
BCC-ESM1 | BCC | AerChemMIP | ssp370 | Zhang, Jie et al. (2019). BCC BCC-ESM1 model output prepared for CMIP6 AerChemMIP ssp370. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3036 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3036
BCC-ESM1 | BCC | AerChemMIP | ssp370-lowNTCF | Zhang, Jie et al. (2019). BCC BCC-ESM1 model output prepared for CMIP6 AerChemMIP ssp370-lowNTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3037 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3037
BCC-ESM1 | BCC | AerChemMIP | ssp370SST | Zhang, Jie et al. (2019). BCC BCC-ESM1 model output prepared for CMIP6 AerChemMIP ssp370SST. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3039 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3039
BCC-ESM1 | BCC | AerChemMIP | ssp370SST-lowNTCF | Zhang, Jie et al. (2019). BCC BCC-ESM1 model output prepared for CMIP6 AerChemMIP ssp370SST-lowNTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3043 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3043
BCC-ESM1 | BCC | CMIP | 1pctCO2 | Zhang, Jie et al. (2019). BCC BCC-ESM1 model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2834 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2834
BCC-ESM1 | BCC | CMIP | abrupt-4xCO2 | Zhang, Jie et al. (2019). BCC BCC-ESM1 model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2846 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2846
BCC-ESM1 | BCC | CMIP | amip | Zhang, Jie et al. (2019). BCC BCC-ESM1 model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2851 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2851
BCC-ESM1 | BCC | CMIP | historical | Zhang, Jie et al. (2018). BCC BCC-ESM1 model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2949 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2949
BCC-ESM1 | BCC | CMIP | piControl | Zhang, Jie et al. (2018). BCC BCC-ESM1 model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3017 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3017
CAM-MPAS-HR | PNNL-WACCEM | HighResMIP | highresSST-future | Pacific Northwest National Laboratory (PNNL) (2025). PNNL-WACCEM CAM-MPAS-HR model output prepared for CMIP6 HighResMIP highresSST-future. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14090 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14090
CAM-MPAS-HR | PNNL-WACCEM | HighResMIP | highresSST-present | Pacific Northwest National Laboratory (PNNL) (2025). PNNL-WACCEM CAM-MPAS-HR model output prepared for CMIP6 HighResMIP highresSST-present. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14092 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14092
CAM-MPAS-LR | PNNL-WACCEM | HighResMIP | highresSST-future | Pacific Northwest National Laboratory (PNNL) (2025). PNNL-WACCEM CAM-MPAS-LR model output prepared for CMIP6 HighResMIP highresSST-future. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14767 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14767
CAM-MPAS-LR | PNNL-WACCEM | HighResMIP | highresSST-present | Pacific Northwest National Laboratory (PNNL) (2025). PNNL-WACCEM CAM-MPAS-LR model output prepared for CMIP6 HighResMIP highresSST-present. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14769 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14769
CAMS-CSM1-0 | CAMS | CMIP | 1pctCO2 | Rong, Xinyao (2019). CAMS CAMS_CSM1.0 model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9701 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9701
CAMS-CSM1-0 | CAMS | CMIP | abrupt-4xCO2 | Rong, Xinyao (2019). CAMS CAMS_CSM1.0 model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9708 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9708
CAMS-CSM1-0 | CAMS | CMIP | amip | Rong, Xinyao (2019). CAMS CAMS_CSM1.0 model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9712 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9712
CAMS-CSM1-0 | CAMS | CMIP | historical | Rong, Xinyao (2019). CAMS CAMS_CSM1.0 model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9754 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9754
CAMS-CSM1-0 | CAMS | CMIP | piControl | Rong, Xinyao (2019). CAMS CAMS_CSM1.0 model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9797 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9797
CAMS-CSM1-0 | CAMS | GMMIP | amip-hist | Chinese Academy of Meteorological Sciences (CAMS) (2019). CAMS CAMS-CSM1.0 model output prepared for CMIP6 GMMIP amip-hist. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11017 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11017
CAMS-CSM1-0 | CAMS | HighResMIP | highresSST-present | Rong, Xinyao (2020). CAMS CAMS-CSM1.0 model output prepared for CMIP6 HighResMIP highresSST-present. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11035 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11035
CAMS-CSM1-0 | CAMS | ScenarioMIP | ssp119 | Rong, Xinyao (2019). CAMS CAMS-CSM1.0 model output prepared for CMIP6 ScenarioMIP ssp119. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11045 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11045
CAMS-CSM1-0 | CAMS | ScenarioMIP | ssp126 | Rong, Xinyao (2019). CAMS CAMS-CSM1.0 model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11046 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11046
CAMS-CSM1-0 | CAMS | ScenarioMIP | ssp245 | Rong, Xinyao (2019). CAMS CAMS-CSM1.0 model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11047 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11047
CAMS-CSM1-0 | CAMS | ScenarioMIP | ssp370 | Rong, Xinyao (2019). CAMS CAMS-CSM1.0 model output prepared for CMIP6 ScenarioMIP ssp370. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11048 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11048
CAMS-CSM1-0 | CAMS | ScenarioMIP | ssp585 | Rong, Xinyao (2019). CAMS CAMS-CSM1.0 model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11052 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11052
CAS-ESM2-0 | CAS | CDRMIP | 1pctCO2-cdr | Jin, Jiangbo et al. (2023). CAS CAS-ESM2.0 model output prepared for CMIP6 CDRMIP 1pctCO2-cdr. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17542 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17542
CAS-ESM2-0 | CAS | CMIP | 1pctCO2 | Chai, Zhaoyang (2020). CAS CAS-ESM2.0 model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3052 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3052
CAS-ESM2-0 | CAS | CMIP | abrupt-4xCO2 | Chai, Zhaoyang (2020). CAS CAS-ESM2.0 model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3174 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3174
CAS-ESM2-0 | CAS | CMIP | amip | Chai, Zhaoyang (2020). CAS CAS-ESM1.0 model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3180 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3180
CAS-ESM2-0 | CAS | CMIP | historical | Chai, Zhaoyang (2020). CAS CAS-ESM1.0 model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3353 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3353
CAS-ESM2-0 | CAS | CMIP | piControl | Chai, Zhaoyang (2020). CAS CAS-ESM1.0 model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3445 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3445
CAS-ESM2-0 | CAS | FAFMIP | faf-all | Chai, Zhaoyang (2020). CAS CAS-ESM1.0 model output prepared for CMIP6 FAFMIP faf-all. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3290 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3290
CAS-ESM2-0 | CAS | FAFMIP | faf-heat | Chai, Zhaoyang (2020). CAS CAS-ESM1.0 model output prepared for CMIP6 FAFMIP faf-heat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3292 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3292
CAS-ESM2-0 | CAS | FAFMIP | faf-heat-NA0pct | Chai, Zhaoyang (2020). CAS CAS-ESM1.0 model output prepared for CMIP6 FAFMIP faf-heat-NA0pct. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11606 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11606
CAS-ESM2-0 | CAS | FAFMIP | faf-heat-NA50pct | Chai, Zhaoyang (2020). CAS CAS-ESM1.0 model output prepared for CMIP6 FAFMIP faf-heat-NA50pct. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11608 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11608
CAS-ESM2-0 | CAS | FAFMIP | faf-passiveheat | Chai, Zhaoyang (2020). CAS CAS-ESM1.0 model output prepared for CMIP6 FAFMIP faf-passiveheat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3294 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3294
CAS-ESM2-0 | CAS | FAFMIP | faf-stress | Chai, Zhaoyang (2020). CAS CAS-ESM1.0 model output prepared for CMIP6 FAFMIP faf-stress. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3296 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3296
CAS-ESM2-0 | CAS | FAFMIP | faf-water | Chai, Zhaoyang (2020). CAS CAS-ESM1.0 model output prepared for CMIP6 FAFMIP faf-water. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3298 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3298
CAS-ESM2-0 | CAS | OMIP | omip1 | Chai, Zhaoyang (2020). CAS CAS-ESM1.0 model output prepared for CMIP6 OMIP omip1. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3412 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3412
CAS-ESM2-0 | CAS | ScenarioMIP | ssp126 | Chinese Academy of Sciences (CAS) (2020). CAS CAS-ESM1.0 model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3463 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3463
CAS-ESM2-0 | CAS | ScenarioMIP | ssp245 | Chinese Academy of Sciences (CAS) (2020). CAS CAS-ESM1.0 model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3467 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3467
CAS-ESM2-0 | CAS | ScenarioMIP | ssp370 | Chinese Academy of Sciences (CAS) (2020). CAS CAS-ESM1.0 model output prepared for CMIP6 ScenarioMIP ssp370. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3478 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3478
CAS-ESM2-0 | CAS | ScenarioMIP | ssp585 | Chinese Academy of Sciences (CAS) (2020). CAS CAS-ESM1.0 model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3501 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3501
CESM1-1-CAM5-CMIP5 | NCAR | DCPP | dcppA-hindcast | Danabasoglu, Gokhan (2019). NCAR CESM1-1-CAM5-CMIP5 model output prepared for CMIP6 DCPP dcppA-hindcast. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11552 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11552
CESM1-1-CAM5-CMIP5 | NCAR | DCPP | dcppC-hindcast-noAgung | Danabasoglu, Gokhan (2021). NCAR CESM1-1-CAM5-CMIP5 model output prepared for CMIP6 DCPP dcppC-hindcast-noAgung. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11568 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11568
CESM1-1-CAM5-CMIP5 | NCAR | DCPP | dcppC-hindcast-noElChichon | Danabasoglu, Gokhan (2021). NCAR CESM1-1-CAM5-CMIP5 model output prepared for CMIP6 DCPP dcppC-hindcast-noElChichon. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11569 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11569
CESM1-1-CAM5-CMIP5 | NCAR | DCPP | dcppC-hindcast-noPinatubo | Danabasoglu, Gokhan (2021). NCAR CESM1-1-CAM5-CMIP5 model output prepared for CMIP6 DCPP dcppC-hindcast-noPinatubo. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11570 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11570
CESM1-CAM5-SE-HR | NCAR | HighResMIP | control-1950 | Hurrel, James et al. (2020). NCAR CESM1-CAM5-SE-HR model output prepared for CMIP6 HighResMIP control-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14270 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14270
CESM1-CAM5-SE-HR | NCAR | HighResMIP | highres-future | Hurrel, James et al. (2020). NCAR CESM1-CAM5-SE-HR model output prepared for CMIP6 HighResMIP highres-future. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14280 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14280
CESM1-CAM5-SE-HR | NCAR | HighResMIP | hist-1950 | Hurrel, James et al. (2020). NCAR CESM1-CAM5-SE-HR model output prepared for CMIP6 HighResMIP hist-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14294 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14294
CESM1-CAM5-SE-LR | NCAR | HighResMIP | control-1950 | Hurrel, James et al. (2020). NCAR CESM1-CAM5-SE-LR model output prepared for CMIP6 HighResMIP control-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14271 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14271
CESM1-CAM5-SE-LR | NCAR | HighResMIP | highres-future | Hurrel, James et al. (2020). NCAR CESM1-CAM5-SE-LR model output prepared for CMIP6 HighResMIP highres-future. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14281 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14281
CESM1-CAM5-SE-LR | NCAR | HighResMIP | hist-1950 | Hurrel, James et al. (2020). NCAR CESM1-CAM5-SE-LR model output prepared for CMIP6 HighResMIP hist-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14295 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14295
CESM1-WACCM-SC | NCAR | PAMIP | futSST-pdSIC | Peings, Yannick (2020). UCI CESM1-WACCM-SC model output prepared for CMIP6 PAMIP futSST-pdSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12292 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12292
CESM1-WACCM-SC | NCAR | PAMIP | modelSST-futArcSIC | Peings, Yannick (2021). UCI CESM1-WACCM-SC model output prepared for CMIP6 PAMIP modelSST-futArcSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12295 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12295
CESM1-WACCM-SC | NCAR | PAMIP | modelSST-pdSIC | Peings, Yannick (2021). UCI CESM1-WACCM-SC model output prepared for CMIP6 PAMIP modelSST-pdSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12296 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12296
CESM1-WACCM-SC | NCAR | PAMIP | pa-futAntSIC | Peings, Yannick (2020). UCI CESM1-WACCM-SC model output prepared for CMIP6 PAMIP pa-futAntSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12297 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12297
CESM1-WACCM-SC | NCAR | PAMIP | pa-futArcSIC | Peings, Yannick (2020). UCI CESM1-WACCM-SC model output prepared for CMIP6 PAMIP pa-futArcSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12299 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12299
CESM1-WACCM-SC | NCAR | PAMIP | pa-pdSIC | Peings, Yannick (2020). UCI CESM1-WACCM-SC model output prepared for CMIP6 PAMIP pa-pdSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12301 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12301
CESM1-WACCM-SC | NCAR | PAMIP | pa-piAntSIC | Peings, Yannick (2020). UCI CESM1-WACCM-SC model output prepared for CMIP6 PAMIP pa-piAntSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12303 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12303
CESM1-WACCM-SC | NCAR | PAMIP | pa-piArcSIC | Peings, Yannick (2020). UCI CESM1-WACCM-SC model output prepared for CMIP6 PAMIP pa-piArcSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12304 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12304
CESM1-WACCM-SC | NCAR | PAMIP | pdSST-futAntSIC | Peings, Yannick (2020). UCI CESM1-WACCM-SC model output prepared for CMIP6 PAMIP pdSST-futAntSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12305 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12305
CESM1-WACCM-SC | NCAR | PAMIP | pdSST-futArcSIC | Peings, Yannick (2020). UCI CESM1-WACCM-SC model output prepared for CMIP6 PAMIP pdSST-futArcSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12306 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12306
CESM1-WACCM-SC | NCAR | PAMIP | pdSST-futArcSICSIT | Peings, Yannick (2020). UCI CESM1-WACCM-SC model output prepared for CMIP6 PAMIP pdSST-futArcSICSIT. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12307 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12307
CESM1-WACCM-SC | NCAR | PAMIP | pdSST-futBKSeasSIC | Peings, Yannick (2020). UCI CESM1-WACCM-SC model output prepared for CMIP6 PAMIP pdSST-futBKSeasSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12308 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12308
CESM1-WACCM-SC | NCAR | PAMIP | pdSST-futOkhotskSIC | Peings, Yannick (2020). UCI CESM1-WACCM-SC model output prepared for CMIP6 PAMIP pdSST-futOkhotskSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12309 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12309
CESM1-WACCM-SC | NCAR | PAMIP | pdSST-pdSIC | Peings, Yannick (2020). UCI CESM1-WACCM-SC model output prepared for CMIP6 PAMIP pdSST-pdSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12310 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12310
CESM1-WACCM-SC | NCAR | PAMIP | pdSST-pdSICSIT | Peings, Yannick (2020). UCI CESM1-WACCM-SC model output prepared for CMIP6 PAMIP pdSST-pdSICSIT. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12311 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12311
CESM1-WACCM-SC | NCAR | PAMIP | pdSST-piAntSIC | Peings, Yannick (2020). UCI CESM1-WACCM-SC model output prepared for CMIP6 PAMIP pdSST-piAntSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12312 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12312
CESM1-WACCM-SC | NCAR | PAMIP | pdSST-piArcSIC | Peings, Yannick (2020). UCI CESM1-WACCM-SC model output prepared for CMIP6 PAMIP pdSST-piArcSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12313 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12313
CESM1-WACCM-SC | NCAR | PAMIP | piSST-pdSIC | Peings, Yannick (2020). UCI CESM1-WACCM-SC model output prepared for CMIP6 PAMIP piSST-pdSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12316 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12316
CESM1-WACCM-SC | NCAR | PAMIP | piSST-piSIC | Peings, Yannick (2020). UCI CESM1-WACCM-SC model output prepared for CMIP6 PAMIP piSST-piSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12317 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12317
CESM2 | NCAR | AerChemMIP | piClim-HC | Danabasoglu, Gokhan (2020). NCAR CESM2 model output prepared for CMIP6 AerChemMIP piClim-HC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7709 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7709
CESM2 | NCAR | AerChemMIP | ssp370-lowNTCF | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 AerChemMIP ssp370-lowNTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7755 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7755
CESM2 | NCAR | C4MIP | 1pctCO2-bgc | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 C4MIP 1pctCO2-bgc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7499 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7499
CESM2 | NCAR | C4MIP | 1pctCO2-rad | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 C4MIP 1pctCO2-rad. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7501 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7501
CESM2 | NCAR | C4MIP | esm-1pct-brch-1000PgC | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 C4MIP esm-1pct-brch-1000PgC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10542 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10542
CESM2 | NCAR | C4MIP | esm-ssp585 | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 C4MIP esm-ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7582 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7582
CESM2 | NCAR | CDRMIP | 1pctCO2-cdr | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 CDRMIP 1pctCO2-cdr. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7500 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7500
CESM2 | NCAR | CFMIP | a4SST | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 CFMIP a4SST. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7514 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7514
CESM2 | NCAR | CFMIP | a4SSTice | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 CFMIP a4SSTice. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7515 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7515
CESM2 | NCAR | CFMIP | a4SSTice-4xCO2 | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 CFMIP a4SSTice-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7516 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7516
CESM2 | NCAR | CFMIP | abrupt-0p5xCO2 | Danabasoglu, Gokhan (2020). NCAR CESM2 model output prepared for CMIP6 CFMIP abrupt-0p5xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7517 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7517
CESM2 | NCAR | CFMIP | abrupt-2xCO2 | Danabasoglu, Gokhan (2020). NCAR CESM2 model output prepared for CMIP6 CFMIP abrupt-2xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7518 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7518
CESM2 | NCAR | CFMIP | abrupt-solm4p | Danabasoglu, Gokhan (2020). NCAR CESM2 model output prepared for CMIP6 CFMIP abrupt-solm4p. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7520 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7520
CESM2 | NCAR | CFMIP | abrupt-solp4p | Danabasoglu, Gokhan (2020). NCAR CESM2 model output prepared for CMIP6 CFMIP abrupt-solp4p. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7521 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7521
CESM2 | NCAR | CFMIP | amip-4xCO2 | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 CFMIP amip-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7523 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7523
CESM2 | NCAR | CFMIP | amip-a4SST-4xCO2 | Danabasoglu, Gokhan (2020). NCAR CESM2 model output prepared for CMIP6 CFMIP amip-a4SST-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7526 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7526
CESM2 | NCAR | CFMIP | amip-future4K | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 CFMIP amip-future4K. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7529 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7529
CESM2 | NCAR | CFMIP | amip-lwoff | Danabasoglu, Gokhan (2020). NCAR CESM2 model output prepared for CMIP6 CFMIP amip-lwoff. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7535 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7535
CESM2 | NCAR | CFMIP | amip-m4K | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 CFMIP amip-m4K. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7536 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7536
CESM2 | NCAR | CFMIP | amip-p4K | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 CFMIP amip-p4K. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7537 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7537
CESM2 | NCAR | CFMIP | amip-p4K-lwoff | Danabasoglu, Gokhan (2020). NCAR CESM2 model output prepared for CMIP6 CFMIP amip-p4K-lwoff. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7538 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7538
CESM2 | NCAR | CFMIP | amip-piForcing | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 CFMIP amip-piForcing. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7539 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7539
CESM2 | NCAR | CFMIP | aqua-4xCO2 | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 CFMIP aqua-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7540 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7540
CESM2 | NCAR | CFMIP | aqua-control | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 CFMIP aqua-control. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7541 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7541
CESM2 | NCAR | CFMIP | aqua-control-lwoff | Danabasoglu, Gokhan (2020). NCAR CESM2 model output prepared for CMIP6 CFMIP aqua-control-lwoff. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7542 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7542
CESM2 | NCAR | CFMIP | aqua-p4K | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 CFMIP aqua-p4K. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7543 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7543
CESM2 | NCAR | CFMIP | aqua-p4K-lwoff | Danabasoglu, Gokhan (2020). NCAR CESM2 model output prepared for CMIP6 CFMIP aqua-p4K-lwoff. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7544 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7544
CESM2 | NCAR | CFMIP | piSST | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 CFMIP piSST. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7736 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7736
CESM2 | NCAR | CFMIP | piSST-4xCO2 | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 CFMIP piSST-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7737 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7737
CESM2 | NCAR | CFMIP | piSST-4xCO2-rad | Danabasoglu, Gokhan (2020). NCAR CESM2 model output prepared for CMIP6 CFMIP piSST-4xCO2-rad. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7738 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7738
CESM2 | NCAR | CFMIP | piSST-pxK | Danabasoglu, Gokhan (2020). NCAR CESM2 model output prepared for CMIP6 CFMIP piSST-pxK. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7742 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7742
CESM2 | NCAR | CMIP | 1pctCO2 | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7497 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7497
CESM2 | NCAR | CMIP | abrupt-4xCO2 | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7519 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7519
CESM2 | NCAR | CMIP | amip | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7522 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7522
CESM2 | NCAR | CMIP | esm-hist | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 CMIP esm-hist. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7575 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7575
CESM2 | NCAR | CMIP | esm-piControl | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 CMIP esm-piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7579 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7579
CESM2 | NCAR | CMIP | historical | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7627 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7627
CESM2 | NCAR | CMIP | piControl | Danabasoglu, Gokhan et al. (2019). NCAR CESM2 model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7733 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7733
CESM2 | NCAR | DAMIP | hist-GHG | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 DAMIP hist-GHG. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7604 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7604
CESM2 | NCAR | DAMIP | hist-aer | Danabasoglu, Gokhan (2020). NCAR CESM2 model output prepared for CMIP6 DAMIP hist-aer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7605 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7605
CESM2 | NCAR | DAMIP | hist-nat | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 DAMIP hist-nat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7609 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7609
CESM2 | NCAR | DAMIP | ssp245-GHG | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 DAMIP ssp245-GHG. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7749 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7749
CESM2 | NCAR | DAMIP | ssp245-aer | Danabasoglu, Gokhan (2020). NCAR CESM2 model output prepared for CMIP6 DAMIP ssp245-aer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7750 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7750
CESM2 | NCAR | DAMIP | ssp245-covid | Danabasoglu, Gokhan (2021). NCAR CESM2 model output prepared for CMIP6 DAMIP ssp245-covid. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14979 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14979
CESM2 | NCAR | DAMIP | ssp245-nat | Danabasoglu, Gokhan (2020). NCAR CESM2 model output prepared for CMIP6 DAMIP ssp245-nat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7751 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7751
CESM2 | NCAR | FAFMIP | faf-all | Danabasoglu, Gokhan (2020). NCAR CESM2 model output prepared for CMIP6 FAFMIP faf-all. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14054 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14054
CESM2 | NCAR | FAFMIP | faf-heat | Danabasoglu, Gokhan (2020). NCAR CESM2 model output prepared for CMIP6 FAFMIP faf-heat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14056 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14056
CESM2 | NCAR | FAFMIP | faf-passiveheat | Danabasoglu, Gokhan (2020). NCAR CESM2 model output prepared for CMIP6 FAFMIP faf-passiveheat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14059 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14059
CESM2 | NCAR | FAFMIP | faf-stress | Danabasoglu, Gokhan (2020). NCAR CESM2 model output prepared for CMIP6 FAFMIP faf-stress. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14060 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14060
CESM2 | NCAR | FAFMIP | faf-water | Danabasoglu, Gokhan (2020). NCAR CESM2 model output prepared for CMIP6 FAFMIP faf-water. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14061 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14061
CESM2 | NCAR | GMMIP | amip-hist | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 GMMIP amip-hist. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7530 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7530
CESM2 | NCAR | ISMIP6 | 1pctCO2-4xext | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 ISMIP6 1pctCO2-4xext. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7498 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7498
CESM2 | NCAR | ISMIP6 | 1pctCO2to4x-withism | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 ISMIP6 1pctCO2to4x-withism. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7504 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7504
CESM2 | NCAR | ISMIP6 | historical-withism | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 ISMIP6 historical-withism. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7629 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7629
CESM2 | NCAR | ISMIP6 | piControl-withism | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 ISMIP6 piControl-withism. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7735 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7735
CESM2 | NCAR | ISMIP6 | ssp585-withism | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 ISMIP6 ssp585-withism. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7770 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7770
CESM2 | NCAR | LS3MIP | amip-lfmip-pdLC | Danabasoglu, Gokhan (2020). NCAR CESM2 model output prepared for CMIP6 LS3MIP amip-lfmip-pdLC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7533 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7533
CESM2 | NCAR | LS3MIP | amip-lfmip-rmLC | Danabasoglu, Gokhan (2020). NCAR CESM2 model output prepared for CMIP6 LS3MIP amip-lfmip-rmLC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7534 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7534
CESM2 | NCAR | LS3MIP | land-hist | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 LS3MIP land-hist. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7650 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7650
CESM2 | NCAR | LS3MIP | land-hist-cruNcep | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 LS3MIP land-hist-cruNcep. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7655 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7655
CESM2 | NCAR | LS3MIP | land-hist-princeton | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 LS3MIP land-hist-princeton. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7656 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7656
CESM2 | NCAR | LS3MIP | lfmip-pdLC | Danabasoglu, Gokhan (2020). NCAR CESM2 model output prepared for CMIP6 LS3MIP lfmip-pdLC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7664 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7664
CESM2 | NCAR | LS3MIP | lfmip-rmLC | Danabasoglu, Gokhan (2020). NCAR CESM2 model output prepared for CMIP6 LS3MIP lfmip-rmLC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7668 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7668
CESM2 | NCAR | LUMIP | deforest-globe | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 LUMIP deforest-globe. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7574 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7574
CESM2 | NCAR | LUMIP | esm-ssp585-ssp126Lu | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 LUMIP esm-ssp585-ssp126Lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7585 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7585
CESM2 | NCAR | LUMIP | hist-noLu | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 LUMIP hist-noLu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7610 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7610
CESM2 | NCAR | LUMIP | land-cCO2 | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 LUMIP land-cCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7643 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7643
CESM2 | NCAR | LUMIP | land-cClim | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 LUMIP land-cClim. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7644 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7644
CESM2 | NCAR | LUMIP | land-crop-grass | Danabasoglu, Gokhan (2020). NCAR CESM2 model output prepared for CMIP6 LUMIP land-crop-grass. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7645 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7645
CESM2 | NCAR | LUMIP | land-crop-noFert | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 LUMIP land-crop-noFert. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7646 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7646
CESM2 | NCAR | LUMIP | land-crop-noIrrig | Danabasoglu, Gokhan (2020). NCAR CESM2 model output prepared for CMIP6 LUMIP land-crop-noIrrig. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7647 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7647
CESM2 | NCAR | LUMIP | land-crop-noIrrigFert | Danabasoglu, Gokhan (2020). NCAR CESM2 model output prepared for CMIP6 LUMIP land-crop-noIrrigFert. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7648 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7648
CESM2 | NCAR | LUMIP | land-hist-altStartYear | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 LUMIP land-hist-altStartYear. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7654 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7654
CESM2 | NCAR | LUMIP | land-noFire | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 LUMIP land-noFire. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7658 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7658
CESM2 | NCAR | LUMIP | land-noLu | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 LUMIP land-noLu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7659 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7659
CESM2 | NCAR | LUMIP | land-noWoodHarv | Danabasoglu, Gokhan (2020). NCAR CESM2 model output prepared for CMIP6 LUMIP land-noWoodHarv. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7662 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7662
CESM2 | NCAR | LUMIP | ssp126-ssp370Lu | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 LUMIP ssp126-ssp370Lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7747 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7747
CESM2 | NCAR | LUMIP | ssp370-ssp126Lu | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 LUMIP ssp370-ssp126Lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7756 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7756
CESM2 | NCAR | OMIP | omip1 | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 OMIP omip1. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7678 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7678
CESM2 | NCAR | OMIP | omip2 | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 OMIP omip2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7680 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7680
CESM2 | NCAR | PAMIP | futSST-pdSIC | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 PAMIP futSST-pdSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7592 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7592
CESM2 | NCAR | PAMIP | pdSST-futAntSIC | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 PAMIP pdSST-futAntSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7691 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7691
CESM2 | NCAR | PAMIP | pdSST-futArcSIC | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 PAMIP pdSST-futArcSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7692 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7692
CESM2 | NCAR | PAMIP | pdSST-pdSIC | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 PAMIP pdSST-pdSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7696 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7696
CESM2 | NCAR | PAMIP | pdSST-piAntSIC | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 PAMIP pdSST-piAntSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7698 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7698
CESM2 | NCAR | PAMIP | pdSST-piArcSIC | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 PAMIP pdSST-piArcSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7699 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7699
CESM2 | NCAR | PAMIP | piSST-pdSIC | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 PAMIP piSST-pdSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7740 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7740
CESM2 | NCAR | PAMIP | piSST-piSIC | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 PAMIP piSST-piSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7741 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7741
CESM2 | NCAR | PMIP | lig127k | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 PMIP lig127k. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7673 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7673
CESM2 | NCAR | PMIP | midHolocene | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 PMIP midHolocene. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7674 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7674
CESM2 | NCAR | PMIP | midPliocene-eoi400 | Danabasoglu, Gokhan (2020). NCAR CESM2 model output prepared for CMIP6 PMIP midPliocene-eoi400. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7675 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7675
CESM2 | NCAR | RFMIP | piClim-4xCO2 | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 RFMIP piClim-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7706 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7706
CESM2 | NCAR | RFMIP | piClim-aer | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 RFMIP piClim-aer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7718 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7718
CESM2 | NCAR | RFMIP | piClim-anthro | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 RFMIP piClim-anthro. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7720 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7720
CESM2 | NCAR | RFMIP | piClim-control | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 RFMIP piClim-control. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7721 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7721
CESM2 | NCAR | RFMIP | piClim-ghg | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 RFMIP piClim-ghg. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7723 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7723
CESM2 | NCAR | RFMIP | piClim-lu | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 RFMIP piClim-lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7728 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7728
CESM2 | NCAR | ScenarioMIP | ssp126 | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7746 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7746
CESM2 | NCAR | ScenarioMIP | ssp245 | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7748 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7748
CESM2 | NCAR | ScenarioMIP | ssp370 | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 ScenarioMIP ssp370. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7753 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7753
CESM2 | NCAR | ScenarioMIP | ssp585 | Danabasoglu, Gokhan (2019). NCAR CESM2 model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7768 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7768
CESM2-FV2 | NCAR | CMIP | 1pctCO2 | Danabasoglu, Gokhan (2020). NCAR CESM2-FV2 model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11283 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11283
CESM2-FV2 | NCAR | CMIP | abrupt-4xCO2 | Danabasoglu, Gokhan (2020). NCAR CESM2-FV2 model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11285 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11285
CESM2-FV2 | NCAR | CMIP | amip | Danabasoglu, Gokhan (2020). NCAR CESM2-FV2 model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11287 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11287
CESM2-FV2 | NCAR | CMIP | historical | Danabasoglu, Gokhan (2019). NCAR CESM2-FV2 model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11297 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11297
CESM2-FV2 | NCAR | CMIP | piControl | Danabasoglu, Gokhan (2019). NCAR CESM2-FV2 model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11301 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11301
CESM2-FV2 | NCAR | PMIP | lgm | National Center for Atmospheric Research (NCAR) (2022). NCAR CESM2-FV2 model output prepared for CMIP6 PMIP lgm. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17642 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17642
CESM2-FV2 | NCAR | ScenarioMIP | ssp370 | National Center for Atmospheric Research (NCAR) (2022). NCAR CESM2-FV2 model output prepared for CMIP6 ScenarioMIP ssp370. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17665 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17665
CESM2-FV2 | NCAR | ScenarioMIP | ssp585 | National Center for Atmospheric Research (NCAR) (2022). NCAR CESM2-FV2 model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17669 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17669
CESM2-WACCM | NCAR | AerChemMIP | hist-1950HC | Danabasoglu, Gokhan (2019). NCAR CESM2-WACCM model output prepared for CMIP6 AerChemMIP hist-1950HC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10060 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10060
CESM2-WACCM | NCAR | AerChemMIP | hist-piNTCF | Danabasoglu, Gokhan (2019). NCAR CESM2-WACCM model output prepared for CMIP6 AerChemMIP hist-piNTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10062 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10062
CESM2-WACCM | NCAR | AerChemMIP | histSST | Danabasoglu, Gokhan (2019). NCAR CESM2-WACCM model output prepared for CMIP6 AerChemMIP histSST. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10063 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10063
CESM2-WACCM | NCAR | AerChemMIP | histSST-1950HC | Danabasoglu, Gokhan (2019). NCAR CESM2-WACCM model output prepared for CMIP6 AerChemMIP histSST-1950HC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10064 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10064
CESM2-WACCM | NCAR | AerChemMIP | histSST-piCH4 | Danabasoglu, Gokhan (2020). NCAR CESM2-WACCM model output prepared for CMIP6 AerChemMIP histSST-piCH4. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10066 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10066
CESM2-WACCM | NCAR | AerChemMIP | histSST-piNTCF | Danabasoglu, Gokhan (2019). NCAR CESM2-WACCM model output prepared for CMIP6 AerChemMIP histSST-piNTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10068 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10068
CESM2-WACCM | NCAR | AerChemMIP | piClim-2xNOx | Danabasoglu, Gokhan (2020). NCAR CESM2-WACCM model output prepared for CMIP6 AerChemMIP piClim-2xNOx. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10075 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10075
CESM2-WACCM | NCAR | AerChemMIP | piClim-2xVOC | Danabasoglu, Gokhan (2020). NCAR CESM2-WACCM model output prepared for CMIP6 AerChemMIP piClim-2xVOC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10076 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10076
CESM2-WACCM | NCAR | AerChemMIP | piClim-CH4 | Danabasoglu, Gokhan (2020). NCAR CESM2-WACCM model output prepared for CMIP6 AerChemMIP piClim-CH4. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10081 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10081
CESM2-WACCM | NCAR | AerChemMIP | piClim-HC | Danabasoglu, Gokhan (2020). NCAR CESM2-WACCM model output prepared for CMIP6 AerChemMIP piClim-HC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10082 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10082
CESM2-WACCM | NCAR | AerChemMIP | piClim-N2O | Danabasoglu, Gokhan (2020). NCAR CESM2-WACCM model output prepared for CMIP6 AerChemMIP piClim-N2O. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10083 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10083
CESM2-WACCM | NCAR | AerChemMIP | piClim-NOx | Danabasoglu, Gokhan (2020). NCAR CESM2-WACCM model output prepared for CMIP6 AerChemMIP piClim-NOx. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10085 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10085
CESM2-WACCM | NCAR | AerChemMIP | piClim-NTCF | Danabasoglu, Gokhan (2019). NCAR CESM2-WACCM model output prepared for CMIP6 AerChemMIP piClim-NTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10086 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10086
CESM2-WACCM | NCAR | AerChemMIP | piClim-VOC | Danabasoglu, Gokhan (2020). NCAR CESM2-WACCM model output prepared for CMIP6 AerChemMIP piClim-VOC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10090 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10090
CESM2-WACCM | NCAR | AerChemMIP | ssp370-lowNTCF | Danabasoglu, Gokhan (2019). NCAR CESM2-WACCM model output prepared for CMIP6 AerChemMIP ssp370-lowNTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10104 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10104
CESM2-WACCM | NCAR | AerChemMIP | ssp370SST | Danabasoglu, Gokhan (2019). NCAR CESM2-WACCM model output prepared for CMIP6 AerChemMIP ssp370SST. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10105 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10105
CESM2-WACCM | NCAR | AerChemMIP | ssp370SST-lowNTCF | Danabasoglu, Gokhan (2019). NCAR CESM2-WACCM model output prepared for CMIP6 AerChemMIP ssp370SST-lowNTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10109 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10109
CESM2-WACCM | NCAR | CMIP | 1pctCO2 | Danabasoglu, Gokhan (2019). NCAR CESM2-WACCM model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10028 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10028
CESM2-WACCM | NCAR | CMIP | abrupt-4xCO2 | Danabasoglu, Gokhan (2019). NCAR CESM2-WACCM model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10039 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10039
CESM2-WACCM | NCAR | CMIP | amip | Danabasoglu, Gokhan (2019). NCAR CESM2-WACCM model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10041 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10041
CESM2-WACCM | NCAR | CMIP | historical | Danabasoglu, Gokhan (2019). NCAR CESM2-WACCM model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10071 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10071
CESM2-WACCM | NCAR | CMIP | piControl | Danabasoglu, Gokhan (2019). NCAR CESM2-WACCM model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10094 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10094
CESM2-WACCM | NCAR | GeoMIP | G1 | Danabasoglu, Gokhan (2019). NCAR CESM2-WACCM model output prepared for CMIP6 GeoMIP G1. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10029 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10029
CESM2-WACCM | NCAR | GeoMIP | G6solar | Danabasoglu, Gokhan (2019). NCAR CESM2-WACCM model output prepared for CMIP6 GeoMIP G6solar. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10033 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10033
CESM2-WACCM | NCAR | GeoMIP | G6sulfur | Danabasoglu, Gokhan (2019). NCAR CESM2-WACCM model output prepared for CMIP6 GeoMIP G6sulfur. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10034 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10034
CESM2-WACCM | NCAR | RFMIP | piClim-control | Danabasoglu, Gokhan (2019). NCAR CESM2-WACCM model output prepared for CMIP6 RFMIP piClim-control. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14067 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14067
CESM2-WACCM | NCAR | ScenarioMIP | ssp126 | Danabasoglu, Gokhan (2019). NCAR CESM2-WACCM model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10100 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10100
CESM2-WACCM | NCAR | ScenarioMIP | ssp245 | Danabasoglu, Gokhan (2019). NCAR CESM2-WACCM model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10101 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10101
CESM2-WACCM | NCAR | ScenarioMIP | ssp370 | Danabasoglu, Gokhan (2019). NCAR CESM2-WACCM model output prepared for CMIP6 ScenarioMIP ssp370. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10102 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10102
CESM2-WACCM | NCAR | ScenarioMIP | ssp534-over | Danabasoglu, Gokhan (2019). NCAR CESM2-WACCM model output prepared for CMIP6 ScenarioMIP ssp534-over. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10114 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10114
CESM2-WACCM | NCAR | ScenarioMIP | ssp585 | Danabasoglu, Gokhan (2019). NCAR CESM2-WACCM model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10115 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10115
CESM2-WACCM-FV2 | NCAR | CMIP | 1pctCO2 | Danabasoglu, Gokhan (2020). NCAR CESM2-WACCM-FV2 model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11284 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11284
CESM2-WACCM-FV2 | NCAR | CMIP | abrupt-4xCO2 | Danabasoglu, Gokhan (2020). NCAR CESM2-WACCM-FV2 model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11286 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11286
CESM2-WACCM-FV2 | NCAR | CMIP | amip | Danabasoglu, Gokhan (2020). NCAR CESM2-WACCM-FV2 model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11288 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11288
CESM2-WACCM-FV2 | NCAR | CMIP | historical | Danabasoglu, Gokhan (2019). NCAR CESM2-WACCM-FV2 model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11298 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11298
CESM2-WACCM-FV2 | NCAR | CMIP | piControl | Danabasoglu, Gokhan (2019). NCAR CESM2-WACCM-FV2 model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11302 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11302
CESM2-WACCM-FV2 | NCAR | PMIP | lgm | National Center for Atmospheric Research (NCAR) (2022). NCAR CESM2-WACCM-FV2 model output prepared for CMIP6 PMIP lgm. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17643 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17643
CIESM | THU | CMIP | 1pctCO2 | Huang, Wenyu (2020). THU CIESM model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8801 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8801
CIESM | THU | CMIP | abrupt-4xCO2 | Huang, Wenyu (2020). THU CIESM model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8807 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8807
CIESM | THU | CMIP | amip | Huang, Wenyu (2020). THU CIESM model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8810 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8810
CIESM | THU | CMIP | historical | Huang, Wenyu (2019). THU CIESM model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8843 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8843
CIESM | THU | CMIP | piControl | Huang, Wenyu (2019). THU CIESM model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8849 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8849
CIESM | THU | GMMIP | amip-hist | Xue, Wei (2020). THU CIESM model output prepared for CMIP6 GMMIP amip-hist. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8816 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8816
CIESM | THU | ScenarioMIP | ssp126 | Huang, Wenyu (2019). THU CIESM model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8857 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8857
CIESM | THU | ScenarioMIP | ssp245 | Huang, Wenyu (2020). THU CIESM model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8858 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8858
CIESM | THU | ScenarioMIP | ssp585 | Huang, Wenyu (2020). THU CIESM model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8863 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8863
CMCC-CM2-HR4 | CMCC | CMIP | 1pctCO2 | Scoccimarro, Enrico et al. (2021). CMCC CMCC-CM2-HR4 model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3699 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3699
CMCC-CM2-HR4 | CMCC | CMIP | abrupt-4xCO2 | Scoccimarro, Enrico et al. (2021). CMCC CMCC-CM2-HR4 model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3729 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3729
CMCC-CM2-HR4 | CMCC | CMIP | amip | Scoccimarro, Enrico et al. (2021). CMCC CMCC-CM2-HR4 model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3735 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3735
CMCC-CM2-HR4 | CMCC | CMIP | historical | Scoccimarro, Enrico et al. (2020). CMCC CMCC-CM2-HR4 model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3823 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3823
CMCC-CM2-HR4 | CMCC | HighResMIP | control-1950 | Scoccimarro, Enrico et al. (2018). CMCC CMCC-CM2-HR4 model output prepared for CMIP6 HighResMIP control-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3748 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3748
CMCC-CM2-HR4 | CMCC | HighResMIP | highres-future | Scoccimarro, Enrico et al. (2019). CMCC CMCC-CM2-HR4 model output prepared for CMIP6 HighResMIP highres-future. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3803 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3803
CMCC-CM2-HR4 | CMCC | HighResMIP | highresSST-future | Scoccimarro, Enrico et al. (2019). CMCC CMCC-CM2-HR4 model output prepared for CMIP6 HighResMIP highresSST-future. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3809 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3809
CMCC-CM2-HR4 | CMCC | HighResMIP | highresSST-present | Scoccimarro, Enrico et al. (2017). CMCC CMCC-CM2-HR4 model output prepared for CMIP6 HighResMIP highresSST-present. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3813 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3813
CMCC-CM2-HR4 | CMCC | HighResMIP | hist-1950 | Scoccimarro, Enrico et al. (2019). CMCC CMCC-CM2-HR4 model output prepared for CMIP6 HighResMIP hist-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3817 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3817
CMCC-CM2-HR4 | CMCC | OMIP | omip2 | Fogli, Pier Giuseppe et al. (2020). CMCC CMCC-CM2-HR4 model output prepared for CMIP6 OMIP omip2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13235 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13235
CMCC-CM2-SR5 | CMCC | CMIP | 1pctCO2 | Lovato, Tomas; Peano, Daniele (2020). CMCC CMCC-CM2-SR5 model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3721 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3721
CMCC-CM2-SR5 | CMCC | CMIP | abrupt-4xCO2 | Lovato, Tomas; Peano, Daniele (2020). CMCC CMCC-CM2-SR5 model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3731 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3731
CMCC-CM2-SR5 | CMCC | CMIP | amip | Lovato, Tomas; Peano, Daniele (2020). CMCC CMCC-CM2-SR5 model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3737 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3737
CMCC-CM2-SR5 | CMCC | CMIP | historical | Lovato, Tomas; Peano, Daniele (2020). CMCC CMCC-CM2-SR5 model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3825 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3825
CMCC-CM2-SR5 | CMCC | CMIP | piControl | Lovato, Tomas; Peano, Daniele (2020). CMCC CMCC-CM2-SR5 model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3874 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3874
CMCC-CM2-SR5 | CMCC | DAMIP | hist-GHG | Lovato, Tomas; Peano, Daniele (2024). CMCC CMCC-CM2-SR5 model output prepared for CMIP6 DAMIP hist-GHG. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17945 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17945
CMCC-CM2-SR5 | CMCC | DAMIP | hist-aer | Lovato, Tomas; Peano, Daniele (2024). CMCC CMCC-CM2-SR5 model output prepared for CMIP6 DAMIP hist-aer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17947 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17947
CMCC-CM2-SR5 | CMCC | DAMIP | hist-volc | Lovato, Tomas; Peano, Daniele (2024). CMCC CMCC-CM2-SR5 model output prepared for CMIP6 DAMIP hist-volc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17958 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17958
CMCC-CM2-SR5 | CMCC | DCPP | dcppA-hindcast | Nicolì, Dario (2020). CMCC CMCC-CM2-SR5 model output prepared for CMIP6 DCPP dcppA-hindcast. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3751 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3751
CMCC-CM2-SR5 | CMCC | DCPP | dcppB-forecast | Nicolì, Dario (2021). CMCC CMCC-CM2-SR5 model output prepared for CMIP6 DCPP dcppB-forecast. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3754 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3754
CMCC-CM2-SR5 | CMCC | DCPP | dcppC-hindcast-noAgung | Nicolì, Dario (2022). CMCC CMCC-CM2-SR5 model output prepared for CMIP6 DCPP dcppC-hindcast-noAgung. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3767 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3767
CMCC-CM2-SR5 | CMCC | DCPP | dcppC-hindcast-noElChichon | Nicolì, Dario (2022). CMCC CMCC-CM2-SR5 model output prepared for CMIP6 DCPP dcppC-hindcast-noElChichon. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3768 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3768
CMCC-CM2-SR5 | CMCC | DCPP | dcppC-hindcast-noPinatubo | Nicolì, Dario (2022). CMCC CMCC-CM2-SR5 model output prepared for CMIP6 DCPP dcppC-hindcast-noPinatubo. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3769 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3769
CMCC-CM2-SR5 | CMCC | OMIP | omip1 | Fogli, Pier Giuseppe et al. (2020). CMCC CMCC-CM2-SR5 model output prepared for CMIP6 OMIP omip1. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13230 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13230
CMCC-CM2-SR5 | CMCC | OMIP | omip2 | Fogli, Pier Giuseppe et al. (2020). CMCC CMCC-CM2-SR5 model output prepared for CMIP6 OMIP omip2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13236 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13236
CMCC-CM2-SR5 | CMCC | ScenarioMIP | ssp126 | Lovato, Tomas; Peano, Daniele (2020). CMCC CMCC-CM2-SR5 model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3887 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3887
CMCC-CM2-SR5 | CMCC | ScenarioMIP | ssp245 | Lovato, Tomas; Peano, Daniele (2020). CMCC CMCC-CM2-SR5 model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3889 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3889
CMCC-CM2-SR5 | CMCC | ScenarioMIP | ssp370 | Lovato, Tomas; Peano, Daniele (2020). CMCC CMCC-CM2-SR5 model output prepared for CMIP6 ScenarioMIP ssp370. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3890 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3890
CMCC-CM2-SR5 | CMCC | ScenarioMIP | ssp585 | Lovato, Tomas; Peano, Daniele (2020). CMCC CMCC-CM2-SR5 model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3896 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3896
CMCC-CM2-VHR4 | CMCC | HighResMIP | control-1950 | Scoccimarro, Enrico et al. (2018). CMCC CMCC-CM2-VHR4 model output prepared for CMIP6 HighResMIP control-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3749 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3749
CMCC-CM2-VHR4 | CMCC | HighResMIP | highres-future | Scoccimarro, Enrico et al. (2019). CMCC CMCC-CM2-VHR4 model output prepared for CMIP6 HighResMIP highres-future. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3804 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3804
CMCC-CM2-VHR4 | CMCC | HighResMIP | highresSST-future | Scoccimarro, Enrico et al. (2019). CMCC CMCC-CM2-VHR4 model output prepared for CMIP6 HighResMIP highresSST-future. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3810 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3810
CMCC-CM2-VHR4 | CMCC | HighResMIP | highresSST-present | Scoccimarro, Enrico et al. (2017). CMCC CMCC-CM2-VHR4 model output prepared for CMIP6 HighResMIP highresSST-present. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3814 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3814
CMCC-CM2-VHR4 | CMCC | HighResMIP | hist-1950 | Scoccimarro, Enrico et al. (2018). CMCC CMCC-CM2-VHR4 model output prepared for CMIP6 HighResMIP hist-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3818 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3818
CMCC-ESM2 | CMCC | C4MIP | 1pctCO2-bgc | Lovato, Tomas et al. (2021). CMCC CMCC-ESM2 model output prepared for CMIP6 C4MIP 1pctCO2-bgc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13170 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13170
CMCC-ESM2 | CMCC | C4MIP | 1pctCO2-rad | Lovato, Tomas et al. (2021). CMCC CMCC-ESM2 model output prepared for CMIP6 C4MIP 1pctCO2-rad. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13171 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13171
CMCC-ESM2 | CMCC | CMIP | 1pctCO2 | Lovato, Tomas et al. (2021). CMCC CMCC-ESM2 model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13169 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13169
CMCC-ESM2 | CMCC | CMIP | abrupt-4xCO2 | Lovato, Tomas et al. (2021). CMCC CMCC-ESM2 model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13174 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13174
CMCC-ESM2 | CMCC | CMIP | historical | Lovato, Tomas et al. (2021). CMCC CMCC-ESM2 model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13195 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13195
CMCC-ESM2 | CMCC | CMIP | piControl | Lovato, Tomas et al. (2021). CMCC CMCC-ESM2 model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13241 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13241
CMCC-ESM2 | CMCC | LS3MIP | amip-lfmip-pdLC | Peano, Daniele et al. (2021). CMCC CMCC-ESM2 model output prepared for CMIP6 LS3MIP amip-lfmip-pdLC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13177 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13177
CMCC-ESM2 | CMCC | LS3MIP | amip-lfmip-rmLC | Peano, Daniele et al. (2021). CMCC CMCC-ESM2 model output prepared for CMIP6 LS3MIP amip-lfmip-rmLC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13178 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13178
CMCC-ESM2 | CMCC | LS3MIP | land-hist | Peano, Daniele et al. (2020). CMCC CMCC-ESM2 model output prepared for CMIP6 LS3MIP land-hist. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13204 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13204
CMCC-ESM2 | CMCC | LUMIP | deforest-globe | Peano, Daniele et al. (2021). CMCC CMCC-ESM2 model output prepared for CMIP6 LUMIP deforest-globe. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13179 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13179
CMCC-ESM2 | CMCC | LUMIP | hist-noLu | Peano, Daniele et al. (2021). CMCC CMCC-ESM2 model output prepared for CMIP6 LUMIP hist-noLu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13194 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13194
CMCC-ESM2 | CMCC | LUMIP | land-cCO2 | Peano, Daniele et al. (2020). CMCC CMCC-ESM2 model output prepared for CMIP6 LUMIP land-cCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13198 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13198
CMCC-ESM2 | CMCC | LUMIP | land-cClim | Peano, Daniele et al. (2020). CMCC CMCC-ESM2 model output prepared for CMIP6 LUMIP land-cClim. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13199 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13199
CMCC-ESM2 | CMCC | LUMIP | land-hist-altStartYear | Peano, Daniele et al. (2020). CMCC CMCC-ESM2 model output prepared for CMIP6 LUMIP land-hist-altStartYear. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13208 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13208
CMCC-ESM2 | CMCC | LUMIP | land-noLu | Peano, Daniele et al. (2020). CMCC CMCC-ESM2 model output prepared for CMIP6 LUMIP land-noLu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13213 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13213
CMCC-ESM2 | CMCC | LUMIP | ssp126-ssp370Lu | Peano, Daniele et al. (2021). CMCC CMCC-ESM2 model output prepared for CMIP6 LUMIP ssp126-ssp370Lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13251 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13251
CMCC-ESM2 | CMCC | LUMIP | ssp370-ssp126Lu | Peano, Daniele et al. (2021). CMCC CMCC-ESM2 model output prepared for CMIP6 LUMIP ssp370-ssp126Lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13254 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13254
CMCC-ESM2 | CMCC | OMIP | omip1 | Lovato, Tomas; Butenschön, Momme (2021). CMCC CMCC-ESM2 model output prepared for CMIP6 OMIP omip1. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13231 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13231
CMCC-ESM2 | CMCC | ScenarioMIP | ssp126 | Lovato, Tomas et al. (2021). CMCC CMCC-ESM2 model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13250 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13250
CMCC-ESM2 | CMCC | ScenarioMIP | ssp245 | Lovato, Tomas et al. (2021). CMCC CMCC-ESM2 model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13252 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13252
CMCC-ESM2 | CMCC | ScenarioMIP | ssp370 | Lovato, Tomas et al. (2021). CMCC CMCC-ESM2 model output prepared for CMIP6 ScenarioMIP ssp370. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13253 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13253
CMCC-ESM2 | CMCC | ScenarioMIP | ssp534-over | Lovato, Tomas et al. (2021). CMCC CMCC-ESM2 model output prepared for CMIP6 ScenarioMIP ssp534-over. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13257 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13257
CMCC-ESM2 | CMCC | ScenarioMIP | ssp585 | Lovato, Tomas et al. (2021). CMCC CMCC-ESM2 model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13259 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13259
CNRM-CM6-1 | CNRM-CERFACS | CFMIP | a4SST | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 CFMIP a4SST. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3911 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3911
CNRM-CM6-1 | CNRM-CERFACS | CFMIP | a4SSTice | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 CFMIP a4SSTice. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3912 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3912
CNRM-CM6-1 | CNRM-CERFACS | CFMIP | a4SSTice-4xCO2 | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 CFMIP a4SSTice-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3913 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3913
CNRM-CM6-1 | CNRM-CERFACS | CFMIP | abrupt-0p5xCO2 | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 CFMIP abrupt-0p5xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3914 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3914
CNRM-CM6-1 | CNRM-CERFACS | CFMIP | abrupt-2xCO2 | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 CFMIP abrupt-2xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3915 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3915
CNRM-CM6-1 | CNRM-CERFACS | CFMIP | amip-4xCO2 | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 CFMIP amip-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3926 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3926
CNRM-CM6-1 | CNRM-CERFACS | CFMIP | amip-a4SST-4xCO2 | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 CFMIP amip-a4SST-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3929 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3929
CNRM-CM6-1 | CNRM-CERFACS | CFMIP | amip-future4K | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 CFMIP amip-future4K. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3930 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3930
CNRM-CM6-1 | CNRM-CERFACS | CFMIP | amip-lwoff | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 CFMIP amip-lwoff. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3936 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3936
CNRM-CM6-1 | CNRM-CERFACS | CFMIP | amip-m4K | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 CFMIP amip-m4K. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3937 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3937
CNRM-CM6-1 | CNRM-CERFACS | CFMIP | amip-p4K | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 CFMIP amip-p4K. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3938 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3938
CNRM-CM6-1 | CNRM-CERFACS | CFMIP | amip-p4K-lwoff | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 CFMIP amip-p4K-lwoff. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3939 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3939
CNRM-CM6-1 | CNRM-CERFACS | CFMIP | amip-piForcing | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 CFMIP amip-piForcing. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3940 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3940
CNRM-CM6-1 | CNRM-CERFACS | CFMIP | aqua-4xCO2 | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 CFMIP aqua-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3941 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3941
CNRM-CM6-1 | CNRM-CERFACS | CFMIP | aqua-control | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 CFMIP aqua-control. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3942 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3942
CNRM-CM6-1 | CNRM-CERFACS | CFMIP | aqua-control-lwoff | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 CFMIP aqua-control-lwoff. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3943 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3943
CNRM-CM6-1 | CNRM-CERFACS | CFMIP | aqua-p4K | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 CFMIP aqua-p4K. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3944 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3944
CNRM-CM6-1 | CNRM-CERFACS | CFMIP | aqua-p4K-lwoff | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 CFMIP aqua-p4K-lwoff. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3945 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3945
CNRM-CM6-1 | CNRM-CERFACS | CFMIP | piSST | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 CFMIP piSST. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4172 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4172
CNRM-CM6-1 | CNRM-CERFACS | CFMIP | piSST-4xCO2 | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 CFMIP piSST-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4173 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4173
CNRM-CM6-1 | CNRM-CERFACS | CFMIP | piSST-4xCO2-rad | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 CFMIP piSST-4xCO2-rad. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4174 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4174
CNRM-CM6-1 | CNRM-CERFACS | CFMIP | piSST-pxK | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 CFMIP piSST-pxK. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4176 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4176
CNRM-CM6-1 | CNRM-CERFACS | CMIP | 1pctCO2 | Voldoire, Aurore (2018). CMIP6 simulations of the CNRM-CERFACS based on CNRM-CM6-1 model for CMIP experiment 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3712 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3712
CNRM-CM6-1 | CNRM-CERFACS | CMIP | abrupt-4xCO2 | Voldoire, Aurore (2018). CMIP6 simulations of the CNRM-CERFACS based on CNRM-CM6-1 model for CMIP experiment abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3916 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3916
CNRM-CM6-1 | CNRM-CERFACS | CMIP | amip | Voldoire, Aurore (2018). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3922 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3922
CNRM-CM6-1 | CNRM-CERFACS | CMIP | historical | Voldoire, Aurore (2018). CMIP6 simulations of the CNRM-CERFACS based on CNRM-CM6-1 model for CMIP experiment historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4066 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4066
CNRM-CM6-1 | CNRM-CERFACS | CMIP | piControl | Voldoire, Aurore (2018). CMIP6 simulations of the CNRM-CERFACS based on CNRM-CM6-1 model for CMIP experiment piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4163 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4163
CNRM-CM6-1 | CNRM-CERFACS | DAMIP | hist-GHG | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 DAMIP hist-GHG. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4043 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4043
CNRM-CM6-1 | CNRM-CERFACS | DAMIP | hist-aer | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 DAMIP hist-aer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4044 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4044
CNRM-CM6-1 | CNRM-CERFACS | DAMIP | hist-nat | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 DAMIP hist-nat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4048 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4048
CNRM-CM6-1 | CNRM-CERFACS | DCPP | dcppC-amv-ExTrop-neg | Voldoire, Aurore (2020). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 DCPP dcppC-amv-ExTrop-neg. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3958 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3958
CNRM-CM6-1 | CNRM-CERFACS | DCPP | dcppC-amv-ExTrop-pos | Voldoire, Aurore (2020). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 DCPP dcppC-amv-ExTrop-pos. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3960 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3960
CNRM-CM6-1 | CNRM-CERFACS | DCPP | dcppC-amv-Trop-neg | Voldoire, Aurore (2020). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 DCPP dcppC-amv-Trop-neg. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3962 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3962
CNRM-CM6-1 | CNRM-CERFACS | DCPP | dcppC-amv-Trop-pos | Voldoire, Aurore (2020). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 DCPP dcppC-amv-Trop-pos. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3964 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3964
CNRM-CM6-1 | CNRM-CERFACS | DCPP | dcppC-amv-neg | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 DCPP dcppC-amv-neg. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3966 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3966
CNRM-CM6-1 | CNRM-CERFACS | DCPP | dcppC-amv-pos | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 DCPP dcppC-amv-pos. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3968 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3968
CNRM-CM6-1 | CNRM-CERFACS | DCPP | dcppC-atl-control | Voldoire, Aurore (2020). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 DCPP dcppC-atl-control. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3970 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3970
CNRM-CM6-1 | CNRM-CERFACS | DCPP | dcppC-ipv-NexTrop-neg | Voldoire, Aurore (2020). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 DCPP dcppC-ipv-NexTrop-neg. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3988 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3988
CNRM-CM6-1 | CNRM-CERFACS | DCPP | dcppC-ipv-NexTrop-pos | Voldoire, Aurore (2020). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 DCPP dcppC-ipv-NexTrop-pos. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3990 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3990
CNRM-CM6-1 | CNRM-CERFACS | DCPP | dcppC-ipv-neg | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 DCPP dcppC-ipv-neg. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3992 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3992
CNRM-CM6-1 | CNRM-CERFACS | DCPP | dcppC-ipv-pos | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 DCPP dcppC-ipv-pos. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3994 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3994
CNRM-CM6-1 | CNRM-CERFACS | DCPP | dcppC-pac-control | Voldoire, Aurore (2020). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 DCPP dcppC-pac-control. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3996 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3996
CNRM-CM6-1 | CNRM-CERFACS | GMMIP | amip-hist | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 GMMIP amip-hist. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3931 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3931
CNRM-CM6-1 | CNRM-CERFACS | HighResMIP | control-1950 | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 HighResMIP control-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3946 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3946
CNRM-CM6-1 | CNRM-CERFACS | HighResMIP | highres-future | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 HighResMIP highres-future. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4025 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4025
CNRM-CM6-1 | CNRM-CERFACS | HighResMIP | highresSST-future | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 HighResMIP highresSST-future. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4031 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4031
CNRM-CM6-1 | CNRM-CERFACS | HighResMIP | highresSST-present | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 HighResMIP highresSST-present. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4035 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4035
CNRM-CM6-1 | CNRM-CERFACS | HighResMIP | hist-1950 | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 HighResMIP hist-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4039 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4039
CNRM-CM6-1 | CNRM-CERFACS | HighResMIP | spinup-1950 | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 HighResMIP spinup-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4178 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4178
CNRM-CM6-1 | CNRM-CERFACS | LS3MIP | amip-lfmip-pObs | Voldoire, Aurore (2020). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 LS3MIP amip-lfmip-pObs. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3933 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3933
CNRM-CM6-1 | CNRM-CERFACS | LS3MIP | amip-lfmip-pdLC | Voldoire, Aurore (2020). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 LS3MIP amip-lfmip-pdLC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3934 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3934
CNRM-CM6-1 | CNRM-CERFACS | LS3MIP | amip-lfmip-rmLC | Voldoire, Aurore (2020). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 LS3MIP amip-lfmip-rmLC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3935 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3935
CNRM-CM6-1 | CNRM-CERFACS | LS3MIP | land-hist | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 LS3MIP land-hist. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4095 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4095
CNRM-CM6-1 | CNRM-CERFACS | LS3MIP | land-hist-cruNcep | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 LS3MIP land-hist-cruNcep. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4100 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4100
CNRM-CM6-1 | CNRM-CERFACS | LS3MIP | land-hist-princeton | Voldoire, Aurore (2020). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 LS3MIP land-hist-princeton. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4101 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4101
CNRM-CM6-1 | CNRM-CERFACS | LS3MIP | land-hist-wfdei | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 LS3MIP land-hist-wfdei. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4102 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4102
CNRM-CM6-1 | CNRM-CERFACS | OMIP | omip1 | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 OMIP omip1. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10341 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10341
CNRM-CM6-1 | CNRM-CERFACS | OMIP | omip2 | Voldoire, Aurore (2020). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 OMIP omip2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10345 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10345
CNRM-CM6-1 | CNRM-CERFACS | PAMIP | futSST-pdSIC | Voldoire, Aurore (2022). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 PAMIP futSST-pdSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9598 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9598
CNRM-CM6-1 | CNRM-CERFACS | PAMIP | pa-futArcSIC-ext | Voldoire, Aurore (2021). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 PAMIP pa-futArcSIC-ext. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9620 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9620
CNRM-CM6-1 | CNRM-CERFACS | PAMIP | pa-pdSIC-ext | Voldoire, Aurore (2021). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 PAMIP pa-pdSIC-ext. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9622 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9622
CNRM-CM6-1 | CNRM-CERFACS | PAMIP | pdSST-futArcSIC | Voldoire, Aurore (2021). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 PAMIP pdSST-futArcSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9626 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9626
CNRM-CM6-1 | CNRM-CERFACS | PAMIP | pdSST-futBKSeasSIC | Voldoire, Aurore (2021). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 PAMIP pdSST-futBKSeasSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9628 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9628
CNRM-CM6-1 | CNRM-CERFACS | PAMIP | pdSST-futOkhotskSIC | Voldoire, Aurore (2022). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 PAMIP pdSST-futOkhotskSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9629 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9629
CNRM-CM6-1 | CNRM-CERFACS | PAMIP | pdSST-pdSIC | Voldoire, Aurore (2021). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 PAMIP pdSST-pdSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9630 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9630
CNRM-CM6-1 | CNRM-CERFACS | PAMIP | pdSST-piArcSIC | Voldoire, Aurore (2022). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 PAMIP pdSST-piArcSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9633 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9633
CNRM-CM6-1 | CNRM-CERFACS | PAMIP | piSST-pdSIC | Voldoire, Aurore (2022). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 PAMIP piSST-pdSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9634 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9634
CNRM-CM6-1 | CNRM-CERFACS | PAMIP | piSST-piSIC | Voldoire, Aurore (2022). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 PAMIP piSST-piSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9635 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9635
CNRM-CM6-1 | CNRM-CERFACS | PMIP | lig127k | Voldoire, Aurore (2020). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 PMIP lig127k. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4118 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4118
CNRM-CM6-1 | CNRM-CERFACS | RFMIP | piClim-4xCO2 | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 RFMIP piClim-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4136 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4136
CNRM-CM6-1 | CNRM-CERFACS | RFMIP | piClim-aer | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 RFMIP piClim-aer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4148 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4148
CNRM-CM6-1 | CNRM-CERFACS | RFMIP | piClim-anthro | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 RFMIP piClim-anthro. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4150 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4150
CNRM-CM6-1 | CNRM-CERFACS | RFMIP | piClim-control | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 RFMIP piClim-control. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4151 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4151
CNRM-CM6-1 | CNRM-CERFACS | RFMIP | piClim-ghg | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 RFMIP piClim-ghg. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4153 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4153
CNRM-CM6-1 | CNRM-CERFACS | RFMIP | piClim-histaer | Voldoire, Aurore (2020). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 RFMIP piClim-histaer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4154 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4154
CNRM-CM6-1 | CNRM-CERFACS | RFMIP | piClim-histall | Voldoire, Aurore (2020). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 RFMIP piClim-histall. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4155 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4155
CNRM-CM6-1 | CNRM-CERFACS | RFMIP | piClim-histghg | Voldoire, Aurore (2020). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 RFMIP piClim-histghg. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4156 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4156
CNRM-CM6-1 | CNRM-CERFACS | RFMIP | piClim-histnat | Voldoire, Aurore (2020). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 RFMIP piClim-histnat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4157 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4157
CNRM-CM6-1 | CNRM-CERFACS | ScenarioMIP | ssp126 | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4184 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4184
CNRM-CM6-1 | CNRM-CERFACS | ScenarioMIP | ssp245 | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4189 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4189
CNRM-CM6-1 | CNRM-CERFACS | ScenarioMIP | ssp370 | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 ScenarioMIP ssp370. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4197 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4197
CNRM-CM6-1 | CNRM-CERFACS | ScenarioMIP | ssp585 | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1 model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4224 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4224
CNRM-CM6-1-HR | CNRM-CERFACS | CMIP | 1pctCO2 | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1-HR model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3713 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3713
CNRM-CM6-1-HR | CNRM-CERFACS | CMIP | abrupt-4xCO2 | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1-HR model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3917 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3917
CNRM-CM6-1-HR | CNRM-CERFACS | CMIP | amip | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1-HR model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3923 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3923
CNRM-CM6-1-HR | CNRM-CERFACS | CMIP | historical | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1-HR model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4067 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4067
CNRM-CM6-1-HR | CNRM-CERFACS | CMIP | piControl | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1-HR model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4164 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4164
CNRM-CM6-1-HR | CNRM-CERFACS | GMMIP | amip-hist | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1-HR model output prepared for CMIP6 GMMIP amip-hist. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13927 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13927
CNRM-CM6-1-HR | CNRM-CERFACS | HighResMIP | control-1950 | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1-HR model output prepared for CMIP6 HighResMIP control-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3947 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3947
CNRM-CM6-1-HR | CNRM-CERFACS | HighResMIP | highres-future | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1-HR model output prepared for CMIP6 HighResMIP highres-future. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4026 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4026
CNRM-CM6-1-HR | CNRM-CERFACS | HighResMIP | highresSST-future | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1-HR model output prepared for CMIP6 HighResMIP highresSST-future. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4032 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4032
CNRM-CM6-1-HR | CNRM-CERFACS | HighResMIP | highresSST-present | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1-HR model output prepared for CMIP6 HighResMIP highresSST-present. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4036 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4036
CNRM-CM6-1-HR | CNRM-CERFACS | HighResMIP | hist-1950 | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1-HR model output prepared for CMIP6 HighResMIP hist-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4040 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4040
CNRM-CM6-1-HR | CNRM-CERFACS | OMIP | omip2 | Voldoire, Aurore (2021). CNRM-CERFACS CNRM-CM6-1-HR model output prepared for CMIP6 OMIP omip2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10346 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10346
CNRM-CM6-1-HR | CNRM-CERFACS | ScenarioMIP | ssp126 | Voldoire, Aurore (2020). CNRM-CERFACS CNRM-CM6-1-HR model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4185 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4185
CNRM-CM6-1-HR | CNRM-CERFACS | ScenarioMIP | ssp245 | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1-HR model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4190 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4190
CNRM-CM6-1-HR | CNRM-CERFACS | ScenarioMIP | ssp370 | Voldoire, Aurore (2020). CNRM-CERFACS CNRM-CM6-1-HR model output prepared for CMIP6 ScenarioMIP ssp370. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4198 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4198
CNRM-CM6-1-HR | CNRM-CERFACS | ScenarioMIP | ssp585 | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-CM6-1-HR model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4225 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4225
CNRM-ESM2-1 | CNRM-CERFACS | AerChemMIP | hist-1950HC | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 AerChemMIP hist-1950HC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4041 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4041
CNRM-ESM2-1 | CNRM-CERFACS | AerChemMIP | hist-piNTCF | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 AerChemMIP hist-piNTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4051 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4051
CNRM-ESM2-1 | CNRM-CERFACS | AerChemMIP | histSST | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 AerChemMIP histSST. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4059 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4059
CNRM-ESM2-1 | CNRM-CERFACS | AerChemMIP | histSST-1950HC | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 AerChemMIP histSST-1950HC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4060 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4060
CNRM-ESM2-1 | CNRM-CERFACS | AerChemMIP | histSST-piCH4 | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 AerChemMIP histSST-piCH4. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4062 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4062
CNRM-ESM2-1 | CNRM-CERFACS | AerChemMIP | histSST-piN2O | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 AerChemMIP histSST-piN2O. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4063 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4063
CNRM-ESM2-1 | CNRM-CERFACS | AerChemMIP | histSST-piNTCF | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 AerChemMIP histSST-piNTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4064 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4064
CNRM-ESM2-1 | CNRM-CERFACS | AerChemMIP | piClim-2xDMS | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 AerChemMIP piClim-2xDMS. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4130 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4130
CNRM-ESM2-1 | CNRM-CERFACS | AerChemMIP | piClim-2xdust | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 AerChemMIP piClim-2xdust. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4133 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4133
CNRM-ESM2-1 | CNRM-CERFACS | AerChemMIP | piClim-2xfire | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 AerChemMIP piClim-2xfire. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4134 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4134
CNRM-ESM2-1 | CNRM-CERFACS | AerChemMIP | piClim-2xss | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 AerChemMIP piClim-2xss. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4135 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4135
CNRM-ESM2-1 | CNRM-CERFACS | AerChemMIP | piClim-BC | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 AerChemMIP piClim-BC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4137 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4137
CNRM-ESM2-1 | CNRM-CERFACS | AerChemMIP | piClim-CH4 | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 AerChemMIP piClim-CH4. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4138 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4138
CNRM-ESM2-1 | CNRM-CERFACS | AerChemMIP | piClim-HC | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 AerChemMIP piClim-HC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4139 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4139
CNRM-ESM2-1 | CNRM-CERFACS | AerChemMIP | piClim-N2O | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 AerChemMIP piClim-N2O. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4140 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4140
CNRM-ESM2-1 | CNRM-CERFACS | AerChemMIP | piClim-NTCF | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 AerChemMIP piClim-NTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4143 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4143
CNRM-ESM2-1 | CNRM-CERFACS | AerChemMIP | piClim-OC | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 AerChemMIP piClim-OC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4145 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4145
CNRM-ESM2-1 | CNRM-CERFACS | AerChemMIP | piClim-SO2 | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 AerChemMIP piClim-SO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4146 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4146
CNRM-ESM2-1 | CNRM-CERFACS | AerChemMIP | ssp370-lowNTCF | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 AerChemMIP ssp370-lowNTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4202 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4202
CNRM-ESM2-1 | CNRM-CERFACS | AerChemMIP | ssp370SST | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 AerChemMIP ssp370SST. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4204 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4204
CNRM-ESM2-1 | CNRM-CERFACS | AerChemMIP | ssp370SST-lowBC | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 AerChemMIP ssp370SST-lowBC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4206 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4206
CNRM-ESM2-1 | CNRM-CERFACS | AerChemMIP | ssp370SST-lowNTCF | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 AerChemMIP ssp370SST-lowNTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4208 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4208
CNRM-ESM2-1 | CNRM-CERFACS | AerChemMIP | ssp370SST-ssp126Lu | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 AerChemMIP ssp370SST-ssp126Lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4210 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4210
CNRM-ESM2-1 | CNRM-CERFACS | AerChemMIP | ssp370pdSST | Seferian, Roland (2020). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 AerChemMIP ssp370pdSST. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11385 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11385
CNRM-ESM2-1 | CNRM-CERFACS | C4MIP | 1pctCO2-bgc | Seferian, Roland (2018). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 C4MIP 1pctCO2-bgc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3717 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3717
CNRM-ESM2-1 | CNRM-CERFACS | C4MIP | 1pctCO2-rad | Seferian, Roland (2018). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 C4MIP 1pctCO2-rad. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3718 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3718
CNRM-ESM2-1 | CNRM-CERFACS | C4MIP | esm-ssp585 | Seferian, Roland (2020). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 C4MIP esm-ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4017 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4017
CNRM-ESM2-1 | CNRM-CERFACS | C4MIP | hist-bgc | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 C4MIP hist-bgc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4047 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4047
CNRM-ESM2-1 | CNRM-CERFACS | C4MIP | ssp534-over-bgc | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 C4MIP ssp534-over-bgc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4223 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4223
CNRM-ESM2-1 | CNRM-CERFACS | C4MIP | ssp585-bgc | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 C4MIP ssp585-bgc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4228 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4228
CNRM-ESM2-1 | CNRM-CERFACS | CDRMIP | 1pctCO2-cdr | Seferian, Roland (2021). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 CDRMIP 1pctCO2-cdr. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9581 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9581
CNRM-ESM2-1 | CNRM-CERFACS | CDRMIP | esm-ssp534-over | Seferian, Roland (2021). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 CDRMIP esm-ssp534-over. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9589 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9589
CNRM-ESM2-1 | CNRM-CERFACS | CMIP | 1pctCO2 | Seferian, Roland (2018). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 CMIP for experiment 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3714 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3714
CNRM-ESM2-1 | CNRM-CERFACS | CMIP | abrupt-4xCO2 | Seferian, Roland (2018). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 CMIP for experiment abrupt-4xCO2 . Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3918 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3918
CNRM-ESM2-1 | CNRM-CERFACS | CMIP | amip | Seferian, Roland (2018). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3924 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3924
CNRM-ESM2-1 | CNRM-CERFACS | CMIP | esm-hist | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 CMIP esm-hist. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4003 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4003
CNRM-ESM2-1 | CNRM-CERFACS | CMIP | esm-piControl | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 CMIP esm-piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4011 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4011
CNRM-ESM2-1 | CNRM-CERFACS | CMIP | esm-piControl-spinup | Seferian, Roland (2018). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 CMIP for experiment esm-piControl-spinup . Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4015 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4015
CNRM-ESM2-1 | CNRM-CERFACS | CMIP | historical | Seferian, Roland (2018). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4068 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4068
CNRM-ESM2-1 | CNRM-CERFACS | CMIP | piControl | Seferian, Roland (2018). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4165 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4165
CNRM-ESM2-1 | CNRM-CERFACS | CMIP | piControl-spinup | Seferian, Roland (2018). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 CMIP for experiment piControl-spinup . Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4169 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4169
CNRM-ESM2-1 | CNRM-CERFACS | DCPP | dcppA-hindcast | Voldoire, Aurore (2022). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 DCPP dcppA-hindcast. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17672 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17672
CNRM-ESM2-1 | CNRM-CERFACS | GMMIP | amip-hist | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 GMMIP amip-hist. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13928 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13928
CNRM-ESM2-1 | CNRM-CERFACS | GeoMIP | G1 | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 GeoMIP G1. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3902 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3902
CNRM-ESM2-1 | CNRM-CERFACS | GeoMIP | G6solar | Seferian, Roland (2020). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 GeoMIP G6solar. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3906 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3906
CNRM-ESM2-1 | CNRM-CERFACS | GeoMIP | G6sulfur | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 GeoMIP G6sulfur. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3907 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3907
CNRM-ESM2-1 | CNRM-CERFACS | LS3MIP | land-hist | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 LS3MIP land-hist. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9599 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9599
CNRM-ESM2-1 | CNRM-CERFACS | LS3MIP | land-hist-cruNcep | Voldoire, Aurore (2020). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 LS3MIP land-hist-cruNcep. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9600 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9600
CNRM-ESM2-1 | CNRM-CERFACS | LS3MIP | land-hist-princeton | Voldoire, Aurore (2020). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 LS3MIP land-hist-princeton. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9601 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9601
CNRM-ESM2-1 | CNRM-CERFACS | LS3MIP | land-hist-wfdei | Voldoire, Aurore (2020). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 LS3MIP land-hist-wfdei. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9602 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9602
CNRM-ESM2-1 | CNRM-CERFACS | LUMIP | deforest-globe | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 LUMIP deforest-globe. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4000 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4000
CNRM-ESM2-1 | CNRM-CERFACS | LUMIP | hist-noLu | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 LUMIP hist-noLu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4049 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4049
CNRM-ESM2-1 | CNRM-CERFACS | LUMIP | land-cCO2 | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 LUMIP land-cCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4088 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4088
CNRM-ESM2-1 | CNRM-CERFACS | LUMIP | land-cClim | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 LUMIP land-cClim. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4089 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4089
CNRM-ESM2-1 | CNRM-CERFACS | LUMIP | land-hist-altStartYear | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 LUMIP land-hist-altStartYear. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4099 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4099
CNRM-ESM2-1 | CNRM-CERFACS | LUMIP | land-noLu | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 LUMIP land-noLu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4104 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4104
CNRM-ESM2-1 | CNRM-CERFACS | LUMIP | ssp126-ssp370Lu | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 LUMIP ssp126-ssp370Lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4188 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4188
CNRM-ESM2-1 | CNRM-CERFACS | LUMIP | ssp370-ssp126Lu | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 LUMIP ssp370-ssp126Lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4203 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4203
CNRM-ESM2-1 | CNRM-CERFACS | OMIP | omip1 | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 OMIP omip1. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4121 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4121
CNRM-ESM2-1 | CNRM-CERFACS | RFMIP | piClim-4xCO2 | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 RFMIP piClim-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9643 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9643
CNRM-ESM2-1 | CNRM-CERFACS | RFMIP | piClim-aer | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 RFMIP piClim-aer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9644 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9644
CNRM-ESM2-1 | CNRM-CERFACS | RFMIP | piClim-anthro | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 RFMIP piClim-anthro. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9645 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9645
CNRM-ESM2-1 | CNRM-CERFACS | RFMIP | piClim-control | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 RFMIP piClim-control. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9646 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9646
CNRM-ESM2-1 | CNRM-CERFACS | RFMIP | piClim-ghg | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 RFMIP piClim-ghg. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9647 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9647
CNRM-ESM2-1 | CNRM-CERFACS | RFMIP | piClim-lu | Seferian, Roland (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 RFMIP piClim-lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9652 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9652
CNRM-ESM2-1 | CNRM-CERFACS | ScenarioMIP | ssp119 | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 ScenarioMIP ssp119. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4182 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4182
CNRM-ESM2-1 | CNRM-CERFACS | ScenarioMIP | ssp126 | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4186 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4186
CNRM-ESM2-1 | CNRM-CERFACS | ScenarioMIP | ssp245 | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4191 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4191
CNRM-ESM2-1 | CNRM-CERFACS | ScenarioMIP | ssp370 | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 ScenarioMIP ssp370. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4199 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4199
CNRM-ESM2-1 | CNRM-CERFACS | ScenarioMIP | ssp434 | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 ScenarioMIP ssp434. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4213 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4213
CNRM-ESM2-1 | CNRM-CERFACS | ScenarioMIP | ssp460 | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 ScenarioMIP ssp460. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4217 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4217
CNRM-ESM2-1 | CNRM-CERFACS | ScenarioMIP | ssp534-over | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 ScenarioMIP ssp534-over. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4221 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4221
CNRM-ESM2-1 | CNRM-CERFACS | ScenarioMIP | ssp585 | Voldoire, Aurore (2019). CNRM-CERFACS CNRM-ESM2-1 model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4226 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4226
CanESM5 | CCCma | C4MIP | 1pctCO2-bgc | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 C4MIP 1pctCO2-bgc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3153 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3153
CanESM5 | CCCma | C4MIP | 1pctCO2-rad | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 C4MIP 1pctCO2-rad. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3154 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3154
CanESM5 | CCCma | C4MIP | esm-1pct-brch-1000PgC | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 C4MIP esm-1pct-brch-1000PgC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10563 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10563
CanESM5 | CCCma | C4MIP | esm-1pct-brch-2000PgC | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 C4MIP esm-1pct-brch-2000PgC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10567 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10567
CanESM5 | CCCma | C4MIP | esm-ssp585 | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 C4MIP esm-ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3587 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3587
CanESM5 | CCCma | C4MIP | hist-bgc | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 C4MIP hist-bgc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3600 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3600
CanESM5 | CCCma | C4MIP | ssp534-over-bgc | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 C4MIP ssp534-over-bgc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3695 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3695
CanESM5 | CCCma | C4MIP | ssp585-bgc | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 C4MIP ssp585-bgc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3697 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3697
CanESM5 | CCCma | CDRMIP | 1pctCO2-cdr | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 CDRMIP 1pctCO2-cdr. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10223 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10223
CanESM5 | CCCma | CDRMIP | esm-pi-CO2pulse | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 CDRMIP esm-pi-CO2pulse. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10234 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10234
CanESM5 | CCCma | CDRMIP | esm-pi-cdr-pulse | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 CDRMIP esm-pi-cdr-pulse. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10236 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10236
CanESM5 | CCCma | CFMIP | abrupt-0p5xCO2 | Cole, Jason N.S. et al. (2019). CCCma CanESM5 model output prepared for CMIP6 CFMIP abrupt-0p5xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3530 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3530
CanESM5 | CCCma | CFMIP | abrupt-2xCO2 | Cole, Jason N.S. et al. (2019). CCCma CanESM5 model output prepared for CMIP6 CFMIP abrupt-2xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3531 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3531
CanESM5 | CCCma | CFMIP | abrupt-solm4p | Cole, Jason N.S. et al. (2019). CCCma CanESM5 model output prepared for CMIP6 CFMIP abrupt-solm4p. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3533 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3533
CanESM5 | CCCma | CFMIP | abrupt-solp4p | Cole, Jason N.S. et al. (2019). CCCma CanESM5 model output prepared for CMIP6 CFMIP abrupt-solp4p. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3534 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3534
CanESM5 | CCCma | CFMIP | amip-4xCO2 | Cole, Jason N.S. et al. (2019). CCCma CanESM5 model output prepared for CMIP6 CFMIP amip-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3536 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3536
CanESM5 | CCCma | CFMIP | amip-future4K | Cole, Jason N.S. et al. (2019). CCCma CanESM5 model output prepared for CMIP6 CFMIP amip-future4K. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3540 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3540
CanESM5 | CCCma | CFMIP | amip-m4K | Cole, Jason N.S. et al. (2019). CCCma CanESM5 model output prepared for CMIP6 CFMIP amip-m4K. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3547 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3547
CanESM5 | CCCma | CFMIP | amip-p4K | Cole, Jason N.S. et al. (2019). CCCma CanESM5 model output prepared for CMIP6 CFMIP amip-p4K. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3548 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3548
CanESM5 | CCCma | CFMIP | amip-piForcing | Cole, Jason N.S. et al. (2019). CCCma CanESM5 model output prepared for CMIP6 CFMIP amip-piForcing. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3550 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3550
CanESM5 | CCCma | CMIP | 1pctCO2 | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3151 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3151
CanESM5 | CCCma | CMIP | abrupt-4xCO2 | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3532 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3532
CanESM5 | CCCma | CMIP | amip | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3535 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3535
CanESM5 | CCCma | CMIP | esm-hist | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 CMIP esm-hist. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3583 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3583
CanESM5 | CCCma | CMIP | esm-piControl | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 CMIP esm-piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3585 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3585
CanESM5 | CCCma | CMIP | historical | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3610 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3610
CanESM5 | CCCma | CMIP | historical-cmip5 | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 CMIP historical-cmip5. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12553 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12553
CanESM5 | CCCma | CMIP | piControl | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3673 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3673
CanESM5 | CCCma | CMIP | piControl-cmip5 | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 CMIP piControl-cmip5. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12555 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12555
CanESM5 | CCCma | DAMIP | hist-CO2 | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 DAMIP hist-CO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3595 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3595
CanESM5 | CCCma | DAMIP | hist-GHG | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 DAMIP hist-GHG. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3596 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3596
CanESM5 | CCCma | DAMIP | hist-GHG-cmip5 | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 DAMIP hist-GHG-cmip5. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12550 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12550
CanESM5 | CCCma | DAMIP | hist-aer | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 DAMIP hist-aer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3597 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3597
CanESM5 | CCCma | DAMIP | hist-aer-cmip5 | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 DAMIP hist-aer-cmip5. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12551 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12551
CanESM5 | CCCma | DAMIP | hist-nat | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 DAMIP hist-nat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3601 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3601
CanESM5 | CCCma | DAMIP | hist-nat-cmip5 | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 DAMIP hist-nat-cmip5. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12552 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12552
CanESM5 | CCCma | DAMIP | hist-sol | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 DAMIP hist-sol. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3605 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3605
CanESM5 | CCCma | DAMIP | hist-stratO3 | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 DAMIP hist-stratO3. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3608 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3608
CanESM5 | CCCma | DAMIP | hist-totalO3 | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 DAMIP hist-totalO3. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12405 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12405
CanESM5 | CCCma | DAMIP | hist-volc | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 DAMIP hist-volc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3609 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3609
CanESM5 | CCCma | DAMIP | ssp245-GHG | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 DAMIP ssp245-GHG. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3686 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3686
CanESM5 | CCCma | DAMIP | ssp245-aer | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 DAMIP ssp245-aer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3687 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3687
CanESM5 | CCCma | DAMIP | ssp245-cov-GHG | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 DAMIP ssp245-cov-GHG. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14908 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14908
CanESM5 | CCCma | DAMIP | ssp245-cov-aer | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 DAMIP ssp245-cov-aer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14909 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14909
CanESM5 | CCCma | DAMIP | ssp245-cov-fossil | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 DAMIP ssp245-cov-fossil. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14910 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14910
CanESM5 | CCCma | DAMIP | ssp245-cov-modgreen | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 DAMIP ssp245-cov-modgreen. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14911 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14911
CanESM5 | CCCma | DAMIP | ssp245-cov-strgreen | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 DAMIP ssp245-cov-strgreen. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14912 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14912
CanESM5 | CCCma | DAMIP | ssp245-covid | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 DAMIP ssp245-covid. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14913 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14913
CanESM5 | CCCma | DAMIP | ssp245-nat | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 DAMIP ssp245-nat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3688 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3688
CanESM5 | CCCma | DAMIP | ssp245-stratO3 | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 DAMIP ssp245-stratO3. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3689 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3689
CanESM5 | CCCma | DCPP | dcppA-assim | Sospedra-Alfonso, Reinel et al. (2019). CCCma CanESM5 model output prepared for CMIP6 DCPP dcppA-assim. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3556 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3556
CanESM5 | CCCma | DCPP | dcppA-hindcast | Sospedra-Alfonso, Reinel et al. (2019). CCCma CanESM5 model output prepared for CMIP6 DCPP dcppA-hindcast. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3557 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3557
CanESM5 | CCCma | DCPP | dcppB-forecast | Sospedra-Alfonso, Reinel et al. (2019). CCCma CanESM5 model output prepared for CMIP6 DCPP dcppB-forecast. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3560 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3560
CanESM5 | CCCma | DCPP | dcppC-atl-spg | Sospedra-Alfonso, Reinel et al. (2019). CCCma CanESM5 model output prepared for CMIP6 DCPP dcppC-atl-spg. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3569 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3569
CanESM5 | CCCma | DCPP | dcppC-forecast-addAgung | Sospedra-Alfonso, Reinel et al. (2019). CCCma CanESM5 model output prepared for CMIP6 DCPP dcppC-forecast-addAgung. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3570 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3570
CanESM5 | CCCma | DCPP | dcppC-forecast-addElChichon | Sospedra-Alfonso, Reinel et al. (2019). CCCma CanESM5 model output prepared for CMIP6 DCPP dcppC-forecast-addElChichon. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3571 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3571
CanESM5 | CCCma | DCPP | dcppC-forecast-addPinatubo | Sospedra-Alfonso, Reinel et al. (2019). CCCma CanESM5 model output prepared for CMIP6 DCPP dcppC-forecast-addPinatubo. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3572 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3572
CanESM5 | CCCma | DCPP | dcppC-hindcast-noAgung | Sospedra-Alfonso, Reinel et al. (2019). CCCma CanESM5 model output prepared for CMIP6 DCPP dcppC-hindcast-noAgung. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3573 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3573
CanESM5 | CCCma | DCPP | dcppC-hindcast-noElChichon | Sospedra-Alfonso, Reinel et al. (2019). CCCma CanESM5 model output prepared for CMIP6 DCPP dcppC-hindcast-noElChichon. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3574 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3574
CanESM5 | CCCma | DCPP | dcppC-hindcast-noPinatubo | Sospedra-Alfonso, Reinel et al. (2019). CCCma CanESM5 model output prepared for CMIP6 DCPP dcppC-hindcast-noPinatubo. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3575 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3575
CanESM5 | CCCma | FAFMIP | faf-all | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 FAFMIP faf-all. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3589 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3589
CanESM5 | CCCma | FAFMIP | faf-antwater-stress | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 FAFMIP faf-antwater-stress. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11610 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11610
CanESM5 | CCCma | FAFMIP | faf-heat | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 FAFMIP faf-heat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3590 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3590
CanESM5 | CCCma | FAFMIP | faf-heat-NA0pct | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 FAFMIP faf-heat-NA0pct. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11611 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11611
CanESM5 | CCCma | FAFMIP | faf-heat-NA50pct | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 FAFMIP faf-heat-NA50pct. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11612 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11612
CanESM5 | CCCma | FAFMIP | faf-passiveheat | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 FAFMIP faf-passiveheat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3591 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3591
CanESM5 | CCCma | FAFMIP | faf-stress | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 FAFMIP faf-stress. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3592 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3592
CanESM5 | CCCma | FAFMIP | faf-water | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 FAFMIP faf-water. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3593 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3593
CanESM5 | CCCma | GMMIP | amip-hist | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 GMMIP amip-hist. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3541 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3541
CanESM5 | CCCma | GeoMIP | G1 | Cole, Jason N.S. et al. (2019). CCCma CanESM5 model output prepared for CMIP6 GeoMIP G1. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3158 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3158
CanESM5 | CCCma | LUMIP | deforest-globe | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 LUMIP deforest-globe. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3582 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3582
CanESM5 | CCCma | LUMIP | esm-ssp585-ssp126Lu | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 LUMIP esm-ssp585-ssp126Lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3588 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3588
CanESM5 | CCCma | LUMIP | hist-noLu | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 LUMIP hist-noLu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3602 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3602
CanESM5 | CCCma | LUMIP | ssp126-ssp370Lu | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 LUMIP ssp126-ssp370Lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3684 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3684
CanESM5 | CCCma | LUMIP | ssp370-ssp126Lu | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 LUMIP ssp370-ssp126Lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3691 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3691
CanESM5 | CCCma | OMIP | omip1 | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 OMIP omip1. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3655 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3655
CanESM5 | CCCma | OMIP | omip1-spunup | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 OMIP omip1-spunup. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3656 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3656
CanESM5 | CCCma | PAMIP | futSST-pdSIC | Sigmond, Michael et al. (2019). CCCma CanESM5 model output prepared for CMIP6 PAMIP futSST-pdSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13945 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13945
CanESM5 | CCCma | PAMIP | pdSST-futAntSIC | Sigmond, Michael et al. (2019). CCCma CanESM5 model output prepared for CMIP6 PAMIP pdSST-futAntSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13956 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13956
CanESM5 | CCCma | PAMIP | pdSST-futArcSIC | Sigmond, Michael et al. (2019). CCCma CanESM5 model output prepared for CMIP6 PAMIP pdSST-futArcSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13957 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13957
CanESM5 | CCCma | PAMIP | pdSST-futBKSeasSIC | Sigmond, Michael et al. (2019). CCCma CanESM5 model output prepared for CMIP6 PAMIP pdSST-futBKSeasSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13959 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13959
CanESM5 | CCCma | PAMIP | pdSST-futOkhotskSIC | Sigmond, Michael et al. (2019). CCCma CanESM5 model output prepared for CMIP6 PAMIP pdSST-futOkhotskSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13960 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13960
CanESM5 | CCCma | PAMIP | pdSST-pdSIC | Sigmond, Michael et al. (2019). CCCma CanESM5 model output prepared for CMIP6 PAMIP pdSST-pdSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14001 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14001
CanESM5 | CCCma | PAMIP | pdSST-piAntSIC | Sigmond, Michael et al. (2019). CCCma CanESM5 model output prepared for CMIP6 PAMIP pdSST-piAntSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14003 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14003
CanESM5 | CCCma | PAMIP | pdSST-piArcSIC | Sigmond, Michael et al. (2019). CCCma CanESM5 model output prepared for CMIP6 PAMIP pdSST-piArcSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14004 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14004
CanESM5 | CCCma | PAMIP | piSST-pdSIC | Sigmond, Michael et al. (2019). CCCma CanESM5 model output prepared for CMIP6 PAMIP piSST-pdSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14005 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14005
CanESM5 | CCCma | PAMIP | piSST-piSIC | Sigmond, Michael et al. (2019). CCCma CanESM5 model output prepared for CMIP6 PAMIP piSST-piSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14006 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14006
CanESM5 | CCCma | RFMIP | piClim-4xCO2 | Cole, Jason N.S. et al. (2019). CCCma CanESM5 model output prepared for CMIP6 RFMIP piClim-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3659 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3659
CanESM5 | CCCma | RFMIP | piClim-aer | Cole, Jason N.S. et al. (2019). CCCma CanESM5 model output prepared for CMIP6 RFMIP piClim-aer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3660 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3660
CanESM5 | CCCma | RFMIP | piClim-anthro | Cole, Jason N.S. et al. (2019). CCCma CanESM5 model output prepared for CMIP6 RFMIP piClim-anthro. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3661 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3661
CanESM5 | CCCma | RFMIP | piClim-control | Cole, Jason N.S. et al. (2019). CCCma CanESM5 model output prepared for CMIP6 RFMIP piClim-control. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3662 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3662
CanESM5 | CCCma | RFMIP | piClim-ghg | Cole, Jason N.S. et al. (2019). CCCma CanESM5 model output prepared for CMIP6 RFMIP piClim-ghg. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3663 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3663
CanESM5 | CCCma | RFMIP | piClim-histaer | Cole, Jason N.S. et al. (2019). CCCma CanESM5 model output prepared for CMIP6 RFMIP piClim-histaer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3664 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3664
CanESM5 | CCCma | RFMIP | piClim-histall | Cole, Jason N.S. et al. (2019). CCCma CanESM5 model output prepared for CMIP6 RFMIP piClim-histall. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3665 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3665
CanESM5 | CCCma | RFMIP | piClim-histghg | Cole, Jason N.S. et al. (2019). CCCma CanESM5 model output prepared for CMIP6 RFMIP piClim-histghg. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3666 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3666
CanESM5 | CCCma | RFMIP | piClim-histnat | Cole, Jason N.S. et al. (2019). CCCma CanESM5 model output prepared for CMIP6 RFMIP piClim-histnat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3667 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3667
CanESM5 | CCCma | RFMIP | piClim-lu | Cole, Jason N.S. et al. (2019). CCCma CanESM5 model output prepared for CMIP6 RFMIP piClim-lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3668 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3668
CanESM5 | CCCma | RFMIP | rad-irf | Cole, Jason N.S. et al. (2019). CCCma CanESM5 model output prepared for CMIP6 RFMIP rad-irf. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3681 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3681
CanESM5 | CCCma | ScenarioMIP | rcp26-cmip5 | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 ScenarioMIP rcp26-cmip5. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12559 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12559
CanESM5 | CCCma | ScenarioMIP | rcp45-cmip5 | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 ScenarioMIP rcp45-cmip5. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12561 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12561
CanESM5 | CCCma | ScenarioMIP | rcp85-cmip5 | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 ScenarioMIP rcp85-cmip5. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12565 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12565
CanESM5 | CCCma | ScenarioMIP | ssp119 | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 ScenarioMIP ssp119. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3682 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3682
CanESM5 | CCCma | ScenarioMIP | ssp126 | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3683 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3683
CanESM5 | CCCma | ScenarioMIP | ssp245 | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3685 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3685
CanESM5 | CCCma | ScenarioMIP | ssp370 | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 ScenarioMIP ssp370. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3690 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3690
CanESM5 | CCCma | ScenarioMIP | ssp434 | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 ScenarioMIP ssp434. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3692 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3692
CanESM5 | CCCma | ScenarioMIP | ssp460 | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 ScenarioMIP ssp460. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3693 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3693
CanESM5 | CCCma | ScenarioMIP | ssp534-over | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 ScenarioMIP ssp534-over. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3694 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3694
CanESM5 | CCCma | ScenarioMIP | ssp585 | Swart, Neil Cameron et al. (2019). CCCma CanESM5 model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3696 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3696
CanESM5 | CCCma | VolMIP | volc-long-eq | Cole, Jason N.S. et al. (2019). CCCma CanESM5 model output prepared for CMIP6 VolMIP volc-long-eq. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10281 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10281
CanESM5 | CCCma | VolMIP | volc-pinatubo-full | Cole, Jason N.S. et al. (2019). CCCma CanESM5 model output prepared for CMIP6 VolMIP volc-pinatubo-full. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10284 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10284
CanESM5-1 | CCCma | CMIP | 1pctCO2 | Swart, Neil Cameron et al. (2019). CCCma CanESM5.1 model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17202 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17202
CanESM5-1 | CCCma | CMIP | abrupt-4xCO2 | Swart, Neil Cameron et al. (2019). CCCma CanESM5.1 model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17224 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17224
CanESM5-1 | CCCma | CMIP | historical | Swart, Neil Cameron et al. (2019). CCCma CanESM5.1 model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17339 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17339
CanESM5-1 | CCCma | CMIP | piControl | Swart, Neil Cameron et al. (2019). CCCma CanESM5.1 model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17424 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17424
CanESM5-1 | CCCma | ScenarioMIP | ssp119 | Swart, Neil Cameron et al. (2019). CCCma CanESM5.1 model output prepared for CMIP6 ScenarioMIP ssp119. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17441 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17441
CanESM5-1 | CCCma | ScenarioMIP | ssp126 | Swart, Neil Cameron et al. (2019). CCCma CanESM5.1 model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17442 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17442
CanESM5-1 | CCCma | ScenarioMIP | ssp245 | Swart, Neil Cameron et al. (2019). CCCma CanESM5.1 model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17444 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17444
CanESM5-1 | CCCma | ScenarioMIP | ssp370 | Swart, Neil Cameron et al. (2019). CCCma CanESM5.1 model output prepared for CMIP6 ScenarioMIP ssp370. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17455 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17455
CanESM5-1 | CCCma | ScenarioMIP | ssp460 | Swart, Neil Cameron et al. (2019). CCCma CanESM5.1 model output prepared for CMIP6 ScenarioMIP ssp460. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17458 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17458
CanESM5-1 | CCCma | ScenarioMIP | ssp585 | Swart, Neil Cameron et al. (2019). CCCma CanESM5.1 model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17461 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17461
CanESM5-CanOE | CCCma | C4MIP | 1pctCO2-bgc | Swart, Neil Cameron et al. (2019). CCCma CanESM5-CanOE model output prepared for CMIP6 C4MIP 1pctCO2-bgc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10222 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10222
CanESM5-CanOE | CCCma | C4MIP | 1pctCO2-rad | Swart, Neil Cameron et al. (2019). CCCma CanESM5-CanOE model output prepared for CMIP6 C4MIP 1pctCO2-rad. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10225 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10225
CanESM5-CanOE | CCCma | C4MIP | esm-ssp585 | Swart, Neil Cameron et al. (2019). CCCma CanESM5-CanOE model output prepared for CMIP6 C4MIP esm-ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10242 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10242
CanESM5-CanOE | CCCma | CDRMIP | esm-pi-CO2pulse | Swart, Neil Cameron et al. (2019). CCCma CanESM5-CanOE model output prepared for CMIP6 CDRMIP esm-pi-CO2pulse. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10235 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10235
CanESM5-CanOE | CCCma | CDRMIP | esm-pi-cdr-pulse | Swart, Neil Cameron et al. (2019). CCCma CanESM5-CanOE model output prepared for CMIP6 CDRMIP esm-pi-cdr-pulse. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10237 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10237
CanESM5-CanOE | CCCma | CMIP | 1pctCO2 | Swart, Neil Cameron et al. (2019). CCCma CanESM5-CanOE model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10221 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10221
CanESM5-CanOE | CCCma | CMIP | esm-hist | Swart, Neil Cameron et al. (2019). CCCma CanESM5-CanOE model output prepared for CMIP6 CMIP esm-hist. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10232 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10232
CanESM5-CanOE | CCCma | CMIP | esm-piControl | Swart, Neil Cameron et al. (2019). CCCma CanESM5-CanOE model output prepared for CMIP6 CMIP esm-piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10238 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10238
CanESM5-CanOE | CCCma | CMIP | historical | Swart, Neil Cameron et al. (2019). CCCma CanESM5-CanOE model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10260 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10260
CanESM5-CanOE | CCCma | CMIP | piControl | Swart, Neil Cameron et al. (2019). CCCma CanESM5-CanOE model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10266 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10266
CanESM5-CanOE | CCCma | OMIP | omip1 | Swart, Neil Cameron et al. (2019). CCCma CanESM5-CanOE model output prepared for CMIP6 OMIP omip1. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10262 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10262
CanESM5-CanOE | CCCma | ScenarioMIP | ssp126 | Swart, Neil Cameron et al. (2019). CCCma CanESM5-CanOE model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10269 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10269
CanESM5-CanOE | CCCma | ScenarioMIP | ssp245 | Swart, Neil Cameron et al. (2019). CCCma CanESM5-CanOE model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10270 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10270
CanESM5-CanOE | CCCma | ScenarioMIP | ssp370 | Swart, Neil Cameron et al. (2019). CCCma CanESM5-CanOE model output prepared for CMIP6 ScenarioMIP ssp370. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10271 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10271
CanESM5-CanOE | CCCma | ScenarioMIP | ssp585 | Swart, Neil Cameron et al. (2019). CCCma CanESM5-CanOE model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10276 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10276
E3SM-1-0 | E3SM-Project | CMIP | 1pctCO2 | Bader, David C. et al. (2019). E3SM-Project E3SM1.0 model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4490 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4490
E3SM-1-0 | E3SM-Project | CMIP | abrupt-4xCO2 | Bader, David C. et al. (2019). E3SM-Project E3SM1.0 model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4491 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4491
E3SM-1-0 | E3SM-Project | CMIP | amip | Bader, David C. et al. (2019). E3SM-Project E3SM1.0 model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4492 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4492
E3SM-1-0 | E3SM-Project | CMIP | historical | Bader, David C. et al. (2019). E3SM-Project E3SM1.0 model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4497 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4497
E3SM-1-0 | E3SM-Project | CMIP | piControl | Bader, David C. et al. (2018). E3SM-Project E3SM1.0 model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4499 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4499
E3SM-1-0 | E3SM-Project | DAMIP | hist-GHG | Bader, David C. et al. (2022). E3SM-Project E3SM1.0 model output prepared for CMIP6 DAMIP hist-GHG. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16643 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16643
E3SM-1-0 | E3SM-Project | ScenarioMIP | ssp585 | Bader, David C. et al. (2022). E3SM-Project E3SM1.0 model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15178 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15178
E3SM-1-0 | LLNL | CFMIP | amip-4xCO2 | Qin, Yi et al. (2021). LLNL E3SM1.0 model output prepared for CMIP6 CFMIP amip-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15125 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15125
E3SM-1-0 | LLNL | CFMIP | amip-future4K | Qin, Yi et al. (2021). LLNL E3SM1.0 model output prepared for CMIP6 CFMIP amip-future4K. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15127 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15127
E3SM-1-0 | LLNL | CFMIP | amip-p4K | Qin, Yi et al. (2021). LLNL E3SM1.0 model output prepared for CMIP6 CFMIP amip-p4K. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15130 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15130
E3SM-1-0 | UCI | PAMIP | futSST-pdSIC | University of California Irvine (UCI) (2021). UCI E3SM1.0 model output prepared for CMIP6 PAMIP futSST-pdSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16530 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16530
E3SM-1-0 | UCI | PAMIP | pdSST-futAntSIC | University of California Irvine (UCI) (2021). UCI E3SM1.0 model output prepared for CMIP6 PAMIP pdSST-futAntSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16544 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16544
E3SM-1-0 | UCI | PAMIP | pdSST-futArcSIC | University of California Irvine (UCI) (2021). UCI E3SM1.0 model output prepared for CMIP6 PAMIP pdSST-futArcSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16545 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16545
E3SM-1-0 | UCI | PAMIP | pdSST-futArcSICSIT | University of California Irvine (UCI) (2022). UCI E3SM1.0 model output prepared for CMIP6 PAMIP pdSST-futArcSICSIT. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16546 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16546
E3SM-1-0 | UCI | PAMIP | pdSST-futBKSeasSIC | University of California Irvine (UCI) (2021). UCI E3SM1.0 model output prepared for CMIP6 PAMIP pdSST-futBKSeasSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16547 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16547
E3SM-1-0 | UCI | PAMIP | pdSST-futOkhotskSIC | University of California Irvine (UCI) (2021). UCI E3SM1.0 model output prepared for CMIP6 PAMIP pdSST-futOkhotskSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16548 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16548
E3SM-1-0 | UCI | PAMIP | pdSST-pdSIC | University of California Irvine (UCI) (2021). UCI E3SM1.0 model output prepared for CMIP6 PAMIP pdSST-pdSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16549 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16549
E3SM-1-0 | UCI | PAMIP | pdSST-pdSICSIT | University of California Irvine (UCI) (2021). UCI E3SM1.0 model output prepared for CMIP6 PAMIP pdSST-pdSICSIT. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16550 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16550
E3SM-1-0 | UCI | PAMIP | pdSST-piAntSIC | University of California Irvine (UCI) (2021). UCI E3SM1.0 model output prepared for CMIP6 PAMIP pdSST-piAntSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16551 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16551
E3SM-1-0 | UCI | PAMIP | pdSST-piArcSIC | University of California Irvine (UCI) (2021). UCI E3SM1.0 model output prepared for CMIP6 PAMIP pdSST-piArcSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16552 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16552
E3SM-1-0 | UCI | PAMIP | piSST-pdSIC | University of California Irvine (UCI) (2021). UCI E3SM1.0 model output prepared for CMIP6 PAMIP piSST-pdSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16560 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16560
E3SM-1-0 | UCI | PAMIP | piSST-piSIC | University of California Irvine (UCI) (2021). UCI E3SM1.0 model output prepared for CMIP6 PAMIP piSST-piSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16561 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16561
E3SM-1-0 | UCSB | CMIP | historical | Stevenson, Samantha et al. (2023). UCSB E3SM1.0 model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17109 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17109
E3SM-1-0 | UCSB | ScenarioMIP | ssp370 | Stevenson, Samantha et al. (2023). UCSB E3SM1.0 model output prepared for CMIP6 ScenarioMIP ssp370. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17161 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17161
E3SM-1-1 | E3SM-Project | C4MIP | hist-bgc | Bader, David C. et al. (2019). E3SM-Project E3SM1.1 model output prepared for CMIP6 C4MIP hist-bgc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11483 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11483
E3SM-1-1 | E3SM-Project | C4MIP | ssp585-bgc | Bader, David C. et al. (2020). E3SM-Project E3SM1.1 model output prepared for CMIP6 C4MIP ssp585-bgc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11495 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11495
E3SM-1-1 | E3SM-Project | CMIP | historical | Bader, David C. et al. (2019). E3SM-Project E3SM1.1 model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11485 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11485
E3SM-1-1 | E3SM-Project | CMIP | piControl | Bader, David C. et al. (2019). E3SM-Project E3SM1.1 model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11489 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11489
E3SM-1-1 | E3SM-Project | DAMIP | ssp245-covid | Bader, David C. et al. (2020). E3SM-Project E3SM1.1 model output prepared for CMIP6 DAMIP ssp245-covid. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15802 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15802
E3SM-1-1 | E3SM-Project | ScenarioMIP | ssp245 | Bader, David C. et al. (2020). E3SM-Project E3SM1.1 model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15164 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15164
E3SM-1-1 | E3SM-Project | ScenarioMIP | ssp585 | Bader, David C. et al. (2020). E3SM-Project E3SM1.1 model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15179 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15179
E3SM-1-1 | RUBISCO | LS3MIP | land-hist | Oak Ridge National Laboratory (ORNL) et al. (2020). RUBISCO E3SM1.1 model output prepared for CMIP6 LS3MIP land-hist. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11921 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11921
E3SM-1-1 | RUBISCO | LS3MIP | land-hist-cruNcep | Oak Ridge National Laboratory (ORNL) et al. (2021). RUBISCO E3SM1.1 model output prepared for CMIP6 LS3MIP land-hist-cruNcep. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11923 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11923
E3SM-1-1 | RUBISCO | LS3MIP | land-hist-princeton | Oak Ridge National Laboratory (ORNL) et al. (2021). RUBISCO E3SM1.1 model output prepared for CMIP6 LS3MIP land-hist-princeton. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11925 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11925
E3SM-1-1-ECA | E3SM-Project | C4MIP | hist-bgc | Bader, David C. et al. (2020). E3SM-Project E3SM1.1ECA model output prepared for CMIP6 C4MIP hist-bgc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11484 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11484
E3SM-1-1-ECA | E3SM-Project | C4MIP | ssp585-bgc | Bader, David C. et al. (2020). E3SM-Project E3SM1.1ECA model output prepared for CMIP6 C4MIP ssp585-bgc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11496 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11496
E3SM-1-1-ECA | E3SM-Project | CMIP | historical | Bader, David C. et al. (2020). E3SM-Project E3SM1.1ECA model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11486 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11486
E3SM-1-1-ECA | E3SM-Project | CMIP | piControl | Bader, David C. et al. (2019). E3SM-Project E3SM1.1ECA model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11490 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11490
E3SM-1-1-ECA | E3SM-Project | ScenarioMIP | ssp585 | Bader, David C. et al. (2022). E3SM-Project E3SM1.1ECA model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15180 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15180
E3SM-2-0 | E3SM-Project | CMIP | 1pctCO2 | Bader, David C. et al. (2022). E3SM-Project E3SM2.0 model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16944 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16944
E3SM-2-0 | E3SM-Project | CMIP | abrupt-4xCO2 | Bader, David C. et al. (2022). E3SM-Project E3SM2.0 model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16945 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16945
E3SM-2-0 | E3SM-Project | CMIP | amip | Bader, David C. et al. (2022). E3SM-Project E3SM2.0 model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16946 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16946
E3SM-2-0 | E3SM-Project | CMIP | historical | Bader, David C. et al. (2022). E3SM-Project E3SM2.0 model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16953 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16953
E3SM-2-0 | E3SM-Project | CMIP | piControl | Bader, David C. et al. (2022). E3SM-Project E3SM2.0 model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16970 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16970
E3SM-2-0 | E3SM-Project | DAMIP | hist-GHG | Bader, David C. et al. (2022). E3SM-Project E3SM2.0 model output prepared for CMIP6 DAMIP hist-GHG. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17024 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17024
E3SM-2-0 | E3SM-Project | DAMIP | hist-aer | Bader, David C. et al. (2022). E3SM-Project E3SM2.0 model output prepared for CMIP6 DAMIP hist-aer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17026 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17026
E3SM-2-0 | E3SM-Project | DAMIP | hist-nat | Bader, David C. et al. (2022). E3SM-Project E3SM2.0 model output prepared for CMIP6 DAMIP hist-nat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17030 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17030
E3SM-2-0 | E3SM-Project | RFMIP | piClim-control | Bader, David C. et al. (2022). E3SM-Project E3SM2.0 model output prepared for CMIP6 RFMIP piClim-control. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16959 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16959
E3SM-2-0 | E3SM-Project | RFMIP | piClim-histaer | Bader, David C. et al. (2022). E3SM-Project E3SM2.0 model output prepared for CMIP6 RFMIP piClim-histaer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16961 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16961
E3SM-2-0 | E3SM-Project | RFMIP | piClim-histall | Bader, David C. et al. (2022). E3SM-Project E3SM2.0 model output prepared for CMIP6 RFMIP piClim-histall. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16962 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16962
E3SM-2-0 | E3SM-Project | ScenarioMIP | ssp370 | Bader, David C. et al. (2023). E3SM-Project E3SM2.0 model output prepared for CMIP6 ScenarioMIP ssp370. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16982 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16982
E3SM-2-0-NARRM | E3SM-Project | CMIP | 1pctCO2 | Bader, David C. et al. (2023). E3SM-Project E3SM2.0NARRM model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17501 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17501
E3SM-2-0-NARRM | E3SM-Project | CMIP | abrupt-4xCO2 | Bader, David C. et al. (2023). E3SM-Project E3SM2.0NARRM model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17502 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17502
E3SM-2-0-NARRM | E3SM-Project | CMIP | amip | Bader, David C. et al. (2023). E3SM-Project E3SM2.0NARRM model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17503 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17503
E3SM-2-0-NARRM | E3SM-Project | CMIP | historical | Bader, David C. et al. (2023). E3SM-Project E3SM2.0NARRM model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17508 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17508
E3SM-2-0-NARRM | E3SM-Project | CMIP | piControl | Bader, David C. et al. (2023). E3SM-Project E3SM2.0NARRM model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17511 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17511
E3SM-2-1 | E3SM-Project | CMIP | 1pctCO2 | Bader, David C. et al. (2024). E3SM-Project E3SM2.1 model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17783 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17783
E3SM-2-1 | E3SM-Project | CMIP | abrupt-4xCO2 | Bader, David C. et al. (2024). E3SM-Project E3SM2.1 model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17784 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17784
E3SM-2-1 | E3SM-Project | CMIP | amip | Bader, David C. et al. (2024). E3SM-Project E3SM2.1 model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17785 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17785
E3SM-2-1 | E3SM-Project | CMIP | historical | Bader, David C. et al. (2024). E3SM-Project E3SM2.1 model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17790 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17790
E3SM-2-1 | E3SM-Project | CMIP | piControl | Bader, David C. et al. (2024). E3SM-Project E3SM2.1 model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17793 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17793
EC-Earth3 | EC-Earth-Consortium | CMIP | 1pctCO2 | EC-Earth Consortium (EC-Earth) (2019). EC-Earth-Consortium EC-Earth3 model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4501 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4501
EC-Earth3 | EC-Earth-Consortium | CMIP | abrupt-4xCO2 | EC-Earth Consortium (EC-Earth) (2019). EC-Earth-Consortium EC-Earth3 model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4518 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4518
EC-Earth3 | EC-Earth-Consortium | CMIP | amip | EC-Earth Consortium (EC-Earth) (2019). EC-Earth-Consortium EC-Earth3 model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4529 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4529
EC-Earth3 | EC-Earth-Consortium | CMIP | historical | EC-Earth Consortium (EC-Earth) (2019). EC-Earth-Consortium EC-Earth3 model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4700 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4700
EC-Earth3 | EC-Earth-Consortium | CMIP | piControl | EC-Earth Consortium (EC-Earth) (2019). EC-Earth-Consortium EC-Earth3 model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4842 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4842
EC-Earth3 | EC-Earth-Consortium | DAMIP | ssp245-cov-fossil | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3 model output prepared for CMIP6 DAMIP ssp245-cov-fossil. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14940 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14940
EC-Earth3 | EC-Earth-Consortium | DAMIP | ssp245-cov-modgreen | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3 model output prepared for CMIP6 DAMIP ssp245-cov-modgreen. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14941 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14941
EC-Earth3 | EC-Earth-Consortium | DAMIP | ssp245-cov-strgreen | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3 model output prepared for CMIP6 DAMIP ssp245-cov-strgreen. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14942 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14942
EC-Earth3 | EC-Earth-Consortium | DAMIP | ssp245-covid | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3 model output prepared for CMIP6 DAMIP ssp245-covid. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14943 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14943
EC-Earth3 | EC-Earth-Consortium | DCPP | dcppA-hindcast | EC-Earth Consortium (EC-Earth) (2019). EC-Earth-Consortium EC-Earth3 model output prepared for CMIP6 DCPP dcppA-hindcast. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4553 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4553
EC-Earth3 | EC-Earth-Consortium | DCPP | dcppB-forecast | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3 model output prepared for CMIP6 DCPP dcppB-forecast. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4559 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4559
EC-Earth3 | EC-Earth-Consortium | DCPP | dcppC-amv-neg | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3 model output prepared for CMIP6 DCPP dcppC-amv-neg. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4569 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4569
EC-Earth3 | EC-Earth-Consortium | DCPP | dcppC-amv-pos | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3 model output prepared for CMIP6 DCPP dcppC-amv-pos. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4571 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4571
EC-Earth3 | EC-Earth-Consortium | DCPP | dcppC-hindcast-noAgung | EC-Earth Consortium (EC-Earth) (2022). EC-Earth-Consortium EC-Earth3 model output prepared for CMIP6 DCPP dcppC-hindcast-noAgung. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4586 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4586
EC-Earth3 | EC-Earth-Consortium | DCPP | dcppC-hindcast-noElChichon | EC-Earth Consortium (EC-Earth) (2022). EC-Earth-Consortium EC-Earth3 model output prepared for CMIP6 DCPP dcppC-hindcast-noElChichon. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4588 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4588
EC-Earth3 | EC-Earth-Consortium | DCPP | dcppC-hindcast-noPinatubo | EC-Earth Consortium (EC-Earth) (2022). EC-Earth-Consortium EC-Earth3 model output prepared for CMIP6 DCPP dcppC-hindcast-noPinatubo. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4590 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4590
EC-Earth3 | EC-Earth-Consortium | LS3MIP | amip-lfmip-pdLC | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3 model output prepared for CMIP6 LS3MIP amip-lfmip-pdLC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4542 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4542
EC-Earth3 | EC-Earth-Consortium | LS3MIP | amip-lfmip-rmLC | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3 model output prepared for CMIP6 LS3MIP amip-lfmip-rmLC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4544 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4544
EC-Earth3 | EC-Earth-Consortium | OMIP | omip1 | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3 model output prepared for CMIP6 OMIP omip1. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14716 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14716
EC-Earth3 | EC-Earth-Consortium | OMIP | omip2 | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3 model output prepared for CMIP6 OMIP omip2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14718 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14718
EC-Earth3 | EC-Earth-Consortium | PAMIP | pa-futArcSIC-ext | EC-Earth Consortium (EC-Earth) (2022). EC-Earth-Consortium EC-Earth3 model output prepared for CMIP6 PAMIP pa-futArcSIC-ext. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9921 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9921
EC-Earth3 | EC-Earth-Consortium | PAMIP | pa-pdSIC-ext | EC-Earth Consortium (EC-Earth) (2022). EC-Earth-Consortium EC-Earth3 model output prepared for CMIP6 PAMIP pa-pdSIC-ext. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9923 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9923
EC-Earth3 | EC-Earth-Consortium | PAMIP | pdSST-futArcSIC | EC-Earth Consortium (EC-Earth) (2021). EC-Earth-Consortium EC-Earth3 model output prepared for CMIP6 PAMIP pdSST-futArcSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9927 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9927
EC-Earth3 | EC-Earth-Consortium | PAMIP | pdSST-futOkhotskSIC | EC-Earth Consortium (EC-Earth) (2021). EC-Earth-Consortium EC-Earth3 model output prepared for CMIP6 PAMIP pdSST-futOkhotskSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9930 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9930
EC-Earth3 | EC-Earth-Consortium | PAMIP | pdSST-pdSIC | EC-Earth Consortium (EC-Earth) (2021). EC-Earth-Consortium EC-Earth3 model output prepared for CMIP6 PAMIP pdSST-pdSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9931 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9931
EC-Earth3 | EC-Earth-Consortium | PMIP | lig127k | EC-Earth Stockholm group (EC-Earth-S) (2023). EC-Earth-Consortium EC-Earth3 model output prepared for CMIP6 PMIP lig127k. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11223 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11223
EC-Earth3 | EC-Earth-Consortium | PMIP | midHolocene | EC-Earth Stockholm group (EC-Earth-S) (2023). EC-Earth-Consortium EC-Earth3 model output prepared for CMIP6 PMIP midHolocene. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11224 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11224
EC-Earth3 | EC-Earth-Consortium | RFMIP | piClim-4xCO2 | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3 model output prepared for CMIP6 RFMIP piClim-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4815 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4815
EC-Earth3 | EC-Earth-Consortium | RFMIP | piClim-aer | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3 model output prepared for CMIP6 RFMIP piClim-aer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4827 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4827
EC-Earth3 | EC-Earth-Consortium | RFMIP | piClim-anthro | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3 model output prepared for CMIP6 RFMIP piClim-anthro. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4829 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4829
EC-Earth3 | EC-Earth-Consortium | RFMIP | piClim-control | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3 model output prepared for CMIP6 RFMIP piClim-control. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4830 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4830
EC-Earth3 | EC-Earth-Consortium | RFMIP | piClim-ghg | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3 model output prepared for CMIP6 RFMIP piClim-ghg. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4832 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4832
EC-Earth3 | EC-Earth-Consortium | RFMIP | piClim-histaer | EC-Earth Consortium (EC-Earth) (2021). EC-Earth-Consortium EC-Earth3 model output prepared for CMIP6 RFMIP piClim-histaer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4833 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4833
EC-Earth3 | EC-Earth-Consortium | RFMIP | piClim-histall | EC-Earth Consortium (EC-Earth) (2021). EC-Earth-Consortium EC-Earth3 model output prepared for CMIP6 RFMIP piClim-histall. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4834 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4834
EC-Earth3 | EC-Earth-Consortium | RFMIP | piClim-lu | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3 model output prepared for CMIP6 RFMIP piClim-lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4837 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4837
EC-Earth3 | EC-Earth-Consortium | ScenarioMIP | ssp119 | EC-Earth Consortium (EC-Earth) (2019). EC-Earth-Consortium EC-Earth3 model output prepared for CMIP6 ScenarioMIP ssp119. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4870 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4870
EC-Earth3 | EC-Earth-Consortium | ScenarioMIP | ssp126 | EC-Earth Consortium (EC-Earth) (2019). EC-Earth-Consortium EC-Earth3 model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4874 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4874
EC-Earth3 | EC-Earth-Consortium | ScenarioMIP | ssp245 | EC-Earth Consortium (EC-Earth) (2019). EC-Earth-Consortium EC-Earth3 model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4880 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4880
EC-Earth3 | EC-Earth-Consortium | ScenarioMIP | ssp370 | EC-Earth Consortium (EC-Earth) (2019). EC-Earth-Consortium EC-Earth3 model output prepared for CMIP6 ScenarioMIP ssp370. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4884 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4884
EC-Earth3 | EC-Earth-Consortium | ScenarioMIP | ssp434 | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3 model output prepared for CMIP6 ScenarioMIP ssp434. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4899 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4899
EC-Earth3 | EC-Earth-Consortium | ScenarioMIP | ssp460 | EC-Earth Consortium (EC-Earth) (2021). EC-Earth-Consortium EC-Earth3 model output prepared for CMIP6 ScenarioMIP ssp460. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4903 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4903
EC-Earth3 | EC-Earth-Consortium | ScenarioMIP | ssp534-over | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3 model output prepared for CMIP6 ScenarioMIP ssp534-over. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4907 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4907
EC-Earth3 | EC-Earth-Consortium | ScenarioMIP | ssp585 | EC-Earth Consortium (EC-Earth) (2019). EC-Earth-Consortium EC-Earth3 model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4912 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4912
EC-Earth3-AerChem | EC-Earth-Consortium | AerChemMIP | hist-piAer | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3-AerChem model output prepared for CMIP6 AerChemMIP hist-piAer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4689 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4689
EC-Earth3-AerChem | EC-Earth-Consortium | AerChemMIP | hist-piNTCF | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3-AerChem model output prepared for CMIP6 AerChemMIP hist-piNTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4690 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4690
EC-Earth3-AerChem | EC-Earth-Consortium | AerChemMIP | histSST-piAer | EC-Earth Consortium (EC-Earth) (2021). EC-Earth-Consortium EC-Earth3-AerChem model output prepared for CMIP6 AerChemMIP histSST-piAer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4695 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4695
EC-Earth3-AerChem | EC-Earth-Consortium | AerChemMIP | histSST-piCH4 | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3-AerChem model output prepared for CMIP6 AerChemMIP histSST-piCH4. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4696 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4696
EC-Earth3-AerChem | EC-Earth-Consortium | AerChemMIP | piClim-2xdust | EC-Earth Consortium (EC-Earth) (2021). EC-Earth-Consortium EC-Earth3-AerChem model output prepared for CMIP6 AerChemMIP piClim-2xdust. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4812 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4812
EC-Earth3-AerChem | EC-Earth-Consortium | AerChemMIP | piClim-CH4 | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3-AerChem model output prepared for CMIP6 AerChemMIP piClim-CH4. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4817 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4817
EC-Earth3-AerChem | EC-Earth-Consortium | AerChemMIP | piClim-NTCF | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3-AerChem model output prepared for CMIP6 AerChemMIP piClim-NTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4822 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4822
EC-Earth3-AerChem | EC-Earth-Consortium | AerChemMIP | ssp370-lowNTCF | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3-AerChem model output prepared for CMIP6 AerChemMIP ssp370-lowNTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4889 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4889
EC-Earth3-AerChem | EC-Earth-Consortium | AerChemMIP | ssp370-lowNTCFCH4 | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3-AerChem model output prepared for CMIP6 AerChemMIP ssp370-lowNTCFCH4. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13515 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13515
EC-Earth3-AerChem | EC-Earth-Consortium | AerChemMIP | ssp370SST | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3-AerChem model output prepared for CMIP6 AerChemMIP ssp370SST. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4892 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4892
EC-Earth3-AerChem | EC-Earth-Consortium | AerChemMIP | ssp370SST-lowNTCF | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3-AerChem model output prepared for CMIP6 AerChemMIP ssp370SST-lowNTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4896 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4896
EC-Earth3-AerChem | EC-Earth-Consortium | AerChemMIP | ssp370SST-lowNTCFCH4 | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3-AerChem model output prepared for CMIP6 AerChemMIP ssp370SST-lowNTCFCH4. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13516 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13516
EC-Earth3-AerChem | EC-Earth-Consortium | AerChemMIP | ssp370pdSST | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3-AerChem model output prepared for CMIP6 AerChemMIP ssp370pdSST. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11386 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11386
EC-Earth3-AerChem | EC-Earth-Consortium | CMIP | 1pctCO2 | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3-AerChem model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4502 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4502
EC-Earth3-AerChem | EC-Earth-Consortium | CMIP | abrupt-4xCO2 | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3-AerChem model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4519 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4519
EC-Earth3-AerChem | EC-Earth-Consortium | CMIP | amip | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3-AerChem model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4530 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4530
EC-Earth3-AerChem | EC-Earth-Consortium | CMIP | historical | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3-AerChem model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4701 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4701
EC-Earth3-AerChem | EC-Earth-Consortium | CMIP | piControl | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3-AerChem model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4843 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4843
EC-Earth3-AerChem | EC-Earth-Consortium | RFMIP | piClim-aer | EC-Earth Consortium (EC-Earth) (2021). EC-Earth-Consortium EC-Earth3-AerChem model output prepared for CMIP6 RFMIP piClim-aer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15331 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15331
EC-Earth3-AerChem | EC-Earth-Consortium | RFMIP | piClim-control | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3-AerChem model output prepared for CMIP6 RFMIP piClim-control. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15333 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15333
EC-Earth3-AerChem | EC-Earth-Consortium | ScenarioMIP | ssp245 | EC-Earth Consortium (EC-Earth) (2023). EC-Earth-Consortium EC-Earth3-AerChem model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4881 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4881
EC-Earth3-AerChem | EC-Earth-Consortium | ScenarioMIP | ssp370 | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3-AerChem model output prepared for CMIP6 ScenarioMIP ssp370. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4885 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4885
EC-Earth3-CC | EC-Earth-Consortium | C4MIP | 1pctCO2-bgc | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth-3-CC model output prepared for CMIP6 C4MIP 1pctCO2-bgc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4513 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4513
EC-Earth3-CC | EC-Earth-Consortium | C4MIP | 1pctCO2-rad | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth-3-CC model output prepared for CMIP6 C4MIP 1pctCO2-rad. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4514 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4514
EC-Earth3-CC | EC-Earth-Consortium | C4MIP | esm-ssp585 | EC-Earth Consortium (EC-Earth) (2021). EC-Earth-Consortium EC-Earth-3-CC model output prepared for CMIP6 C4MIP esm-ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4650 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4650
EC-Earth3-CC | EC-Earth-Consortium | CMIP | 1pctCO2 | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth-3-CC model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4503 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4503
EC-Earth3-CC | EC-Earth-Consortium | CMIP | abrupt-4xCO2 | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth-3-CC model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4520 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4520
EC-Earth3-CC | EC-Earth-Consortium | CMIP | amip | EC-Earth Consortium (EC-Earth) (2021). EC-Earth-Consortium EC-Earth-3-CC model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4531 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4531
EC-Earth3-CC | EC-Earth-Consortium | CMIP | esm-hist | EC-Earth Consortium (EC-Earth) (2021). EC-Earth-Consortium EC-Earth-3-CC model output prepared for CMIP6 CMIP esm-hist. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4608 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4608
EC-Earth3-CC | EC-Earth-Consortium | CMIP | esm-piControl | EC-Earth Consortium (EC-Earth) (2021). EC-Earth-Consortium EC-Earth-3-CC model output prepared for CMIP6 CMIP esm-piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4630 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4630
EC-Earth3-CC | EC-Earth-Consortium | CMIP | historical | EC-Earth Consortium (EC-Earth) (2021). EC-Earth-Consortium EC-Earth-3-CC model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4702 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4702
EC-Earth3-CC | EC-Earth-Consortium | CMIP | piControl | EC-Earth Consortium (EC-Earth) (2021). EC-Earth-Consortium EC-Earth-3-CC model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4844 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4844
EC-Earth3-CC | EC-Earth-Consortium | DCPP | dcppA-hindcast | EC-Earth BSC group (EC-Earth-BSC) (2022). EC-Earth-Consortium EC-Earth3-CC model output prepared for CMIP6 DCPP dcppA-hindcast. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16743 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16743
EC-Earth3-CC | EC-Earth-Consortium | DCPP | dcppB-forecast | EC-Earth BSC group (EC-Earth-BSC) (2022). EC-Earth-Consortium EC-Earth3-CC model output prepared for CMIP6 DCPP dcppB-forecast. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16746 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16746
EC-Earth3-CC | EC-Earth-Consortium | ScenarioMIP | ssp245 | EC-Earth Consortium (EC-Earth) (2021). EC-Earth-Consortium EC-Earth3-CC model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15631 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15631
EC-Earth3-CC | EC-Earth-Consortium | ScenarioMIP | ssp585 | EC-Earth Consortium (EC-Earth) (2021). EC-Earth-Consortium EC-Earth3-CC model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15636 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15636
EC-Earth3-ESM-1 | EC-Earth-Consortium | CMIP | 1pctCO2 | EC-Earth OptimESM partners (EC-Earth-OptimESM) (2024). EC-Earth-Consortium EC-Earth3-ESM-1 model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17828 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17828
EC-Earth3-ESM-1 | EC-Earth-Consortium | CMIP | abrupt-4xCO2 | EC-Earth OptimESM partners (EC-Earth-OptimESM) (2024). EC-Earth-Consortium EC-Earth3-ESM-1 model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17834 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17834
EC-Earth3-ESM-1 | EC-Earth-Consortium | CMIP | amip | EC-Earth OptimESM partners (EC-Earth-OptimESM) (2024). EC-Earth-Consortium EC-Earth3-ESM-1 model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17835 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17835
EC-Earth3-ESM-1 | EC-Earth-Consortium | CMIP | historical | EC-Earth OptimESM partners (EC-Earth-OptimESM) (2024). EC-Earth-Consortium EC-Earth3-ESM-1 model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17896 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17896
EC-Earth3-ESM-1 | EC-Earth-Consortium | CMIP | piControl | EC-Earth OptimESM partners (EC-Earth-OptimESM) (2024). EC-Earth-Consortium EC-Earth3-ESM-1 model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17918 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17918
EC-Earth3-HR | EC-Earth-Consortium | CMIP | historical | EC-Earth Consortium (EC-Earth) (2025). EC-Earth-Consortium EC-Earth3-HR model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4704 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4704
EC-Earth3-HR | EC-Earth-Consortium | DCPP | dcppA-hindcast | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3-HR model output prepared for CMIP6 DCPP dcppA-hindcast. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4554 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4554
EC-Earth3-HR | EC-Earth-Consortium | ScenarioMIP | ssp245 | EC-Earth Consortium (EC-Earth) (2025). EC-Earth-Consortium EC-Earth3-HR model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.18140 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.18140
EC-Earth3-LR | EC-Earth-Consortium | CMIP | piControl | EC-Earth Consortium (EC-Earth) (2019). EC-Earth-Consortium EC-Earth3-LR model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4847 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4847
EC-Earth3-LR | EC-Earth-Consortium | PMIP | lig127k | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3-LR model output prepared for CMIP6 PMIP lig127k. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4798 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4798
EC-Earth3-LR | EC-Earth-Consortium | PMIP | midHolocene | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3-LR model output prepared for CMIP6 PMIP midHolocene. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4801 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4801
EC-Earth3-LR | EC-Earth-Consortium | PMIP | midPliocene-eoi400 | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3-LR model output prepared for CMIP6 PMIP midPliocene-eoi400. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4804 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4804
EC-Earth3-LR | EC-Earth-Consortium | PMIP | past1000 | EC-Earth Consortium (EC-Earth) (2024). EC-Earth-Consortium EC-Earth3-LR model output prepared for CMIP6 PMIP past1000. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4807 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4807
EC-Earth3-Veg | EC-Earth-Consortium | CMIP | 1pctCO2 | EC-Earth Consortium (EC-Earth) (2019). EC-Earth-Consortium EC-Earth3-Veg model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4507 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4507
EC-Earth3-Veg | EC-Earth-Consortium | CMIP | abrupt-4xCO2 | EC-Earth Consortium (EC-Earth) (2019). EC-Earth-Consortium EC-Earth3-Veg model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4524 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4524
EC-Earth3-Veg | EC-Earth-Consortium | CMIP | amip | EC-Earth Consortium (EC-Earth) (2019). EC-Earth-Consortium EC-Earth3-Veg model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4535 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4535
EC-Earth3-Veg | EC-Earth-Consortium | CMIP | historical | EC-Earth Consortium (EC-Earth) (2019). EC-Earth-Consortium EC-Earth3-Veg model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4706 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4706
EC-Earth3-Veg | EC-Earth-Consortium | CMIP | piControl | EC-Earth Consortium (EC-Earth) (2019). EC-Earth-Consortium EC-Earth3-Veg model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4848 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4848
EC-Earth3-Veg | EC-Earth-Consortium | LS3MIP | land-hist | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3-Veg model output prepared for CMIP6 LS3MIP land-hist. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4751 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4751
EC-Earth3-Veg | EC-Earth-Consortium | LUMIP | deforest-globe | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3-Veg model output prepared for CMIP6 LUMIP deforest-globe. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4605 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4605
EC-Earth3-Veg | EC-Earth-Consortium | LUMIP | hist-noLu | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3-Veg model output prepared for CMIP6 LUMIP hist-noLu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4688 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4688
EC-Earth3-Veg | EC-Earth-Consortium | LUMIP | land-noLu | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3-Veg model output prepared for CMIP6 LUMIP land-noLu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4769 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4769
EC-Earth3-Veg | EC-Earth-Consortium | LUMIP | land-noShiftCultivate | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3-Veg model output prepared for CMIP6 LUMIP land-noShiftCultivate. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4773 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4773
EC-Earth3-Veg | EC-Earth-Consortium | PMIP | lig127k | EC-Earth Stockholm group (EC-Earth-S) (2023). EC-Earth-Consortium EC-Earth3-Veg model output prepared for CMIP6 PMIP lig127k. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.18104 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.18104
EC-Earth3-Veg | EC-Earth-Consortium | PMIP | midHolocene | EC-Earth Stockholm group (EC-Earth-S) (2023). EC-Earth-Consortium EC-Earth3-Veg model output prepared for CMIP6 PMIP midHolocene. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.18105 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.18105
EC-Earth3-Veg | EC-Earth-Consortium | ScenarioMIP | ssp119 | EC-Earth Consortium (EC-Earth) (2019). EC-Earth-Consortium EC-Earth3-Veg model output prepared for CMIP6 ScenarioMIP ssp119. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4872 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4872
EC-Earth3-Veg | EC-Earth-Consortium | ScenarioMIP | ssp126 | EC-Earth Consortium (EC-Earth) (2019). EC-Earth-Consortium EC-Earth3-Veg model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4876 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4876
EC-Earth3-Veg | EC-Earth-Consortium | ScenarioMIP | ssp245 | EC-Earth Consortium (EC-Earth) (2019). EC-Earth-Consortium EC-Earth3-Veg model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4882 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4882
EC-Earth3-Veg | EC-Earth-Consortium | ScenarioMIP | ssp370 | EC-Earth Consortium (EC-Earth) (2019). EC-Earth-Consortium EC-Earth3-Veg model output prepared for CMIP6 ScenarioMIP ssp370. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4886 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4886
EC-Earth3-Veg | EC-Earth-Consortium | ScenarioMIP | ssp434 | EC-Earth Consortium (EC-Earth) (2022). EC-Earth-Consortium EC-Earth3-Veg model output prepared for CMIP6 ScenarioMIP ssp434. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4901 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4901
EC-Earth3-Veg | EC-Earth-Consortium | ScenarioMIP | ssp460 | EC-Earth Consortium (EC-Earth) (2022). EC-Earth-Consortium EC-Earth3-Veg model output prepared for CMIP6 ScenarioMIP ssp460. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4905 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4905
EC-Earth3-Veg | EC-Earth-Consortium | ScenarioMIP | ssp534-over | EC-Earth Consortium (EC-Earth) (2022). EC-Earth-Consortium EC-Earth3-Veg model output prepared for CMIP6 ScenarioMIP ssp534-over. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4909 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4909
EC-Earth3-Veg | EC-Earth-Consortium | ScenarioMIP | ssp585 | EC-Earth Consortium (EC-Earth) (2019). EC-Earth-Consortium EC-Earth3-Veg model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4914 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4914
EC-Earth3-Veg-LR | EC-Earth-Consortium | CMIP | 1pctCO2 | EC-Earth Consortium (EC-Earth) (2022). EC-Earth-Consortium EC-Earth3-Veg-LR model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4508 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4508
EC-Earth3-Veg-LR | EC-Earth-Consortium | CMIP | abrupt-4xCO2 | EC-Earth Consortium (EC-Earth) (2022). EC-Earth-Consortium EC-Earth3-Veg-LR model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4525 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4525
EC-Earth3-Veg-LR | EC-Earth-Consortium | CMIP | amip | EC-Earth Consortium (EC-Earth) (2022). EC-Earth-Consortium EC-Earth3-Veg-LR model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4536 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4536
EC-Earth3-Veg-LR | EC-Earth-Consortium | CMIP | historical | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3-Veg-LR model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4707 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4707
EC-Earth3-Veg-LR | EC-Earth-Consortium | CMIP | piControl | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3-Veg-LR model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4849 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4849
EC-Earth3-Veg-LR | EC-Earth-Consortium | PMIP | past1000 | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3-Veg-LR model output prepared for CMIP6 PMIP past1000. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4808 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4808
EC-Earth3-Veg-LR | EC-Earth-Consortium | ScenarioMIP | ssp119 | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3-Veg-LR model output prepared for CMIP6 ScenarioMIP ssp119. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4873 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4873
EC-Earth3-Veg-LR | EC-Earth-Consortium | ScenarioMIP | ssp126 | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3-Veg-LR model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4877 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4877
EC-Earth3-Veg-LR | EC-Earth-Consortium | ScenarioMIP | ssp245 | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3-Veg-LR model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4883 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4883
EC-Earth3-Veg-LR | EC-Earth-Consortium | ScenarioMIP | ssp370 | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3-Veg-LR model output prepared for CMIP6 ScenarioMIP ssp370. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4887 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4887
EC-Earth3-Veg-LR | EC-Earth-Consortium | ScenarioMIP | ssp585 | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3-Veg-LR model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4915 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4915
EC-Earth3P | EC-Earth-Consortium | HighResMIP | control-1950 | EC-Earth Consortium (EC-Earth) (2019). EC-Earth-Consortium EC-Earth3P model output prepared for CMIP6 HighResMIP control-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4547 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4547
EC-Earth3P | EC-Earth-Consortium | HighResMIP | highres-future | EC-Earth Consortium (EC-Earth) (2019). EC-Earth-Consortium EC-Earth3P model output prepared for CMIP6 HighResMIP highres-future. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4654 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4654
EC-Earth3P | EC-Earth-Consortium | HighResMIP | highresSST-future | EC-Earth Consortium (EC-Earth) (2019). EC-Earth-Consortium EC-Earth3P model output prepared for CMIP6 HighResMIP highresSST-future. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4666 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4666
EC-Earth3P | EC-Earth-Consortium | HighResMIP | highresSST-present | EC-Earth Consortium (EC-Earth) (2017). EC-Earth-Consortium EC-Earth3P model output prepared for CMIP6 HighResMIP highresSST-present. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4674 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4674
EC-Earth3P | EC-Earth-Consortium | HighResMIP | hist-1950 | EC-Earth Consortium (EC-Earth) (2019). EC-Earth-Consortium EC-Earth3P model output prepared for CMIP6 HighResMIP hist-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4682 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4682
EC-Earth3P | EC-Earth-Consortium | HighResMIP | spinup-1950 | EC-Earth Consortium (EC-Earth) (2019). EC-Earth-Consortium EC-Earth3P model output prepared for CMIP6 HighResMIP spinup-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4867 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4867
EC-Earth3P-HR | EC-Earth-Consortium | HighResMIP | control-1950 | EC-Earth Consortium (EC-Earth) (2018). EC-Earth-Consortium EC-Earth3P-HR model output prepared for CMIP6 HighResMIP control-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4548 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4548
EC-Earth3P-HR | EC-Earth-Consortium | HighResMIP | highres-future | EC-Earth Consortium (EC-Earth) (2019). EC-Earth-Consortium EC-Earth3P-HR model output prepared for CMIP6 HighResMIP highres-future. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4655 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4655
EC-Earth3P-HR | EC-Earth-Consortium | HighResMIP | highresSST-future | EC-Earth Consortium (EC-Earth) (2019). EC-Earth-Consortium EC-Earth3P-HR model output prepared for CMIP6 HighResMIP highresSST-future. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4667 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4667
EC-Earth3P-HR | EC-Earth-Consortium | HighResMIP | highresSST-present | EC-Earth Consortium (EC-Earth) (2017). EC-Earth-Consortium EC-Earth3P-HR model output prepared for CMIP6 HighResMIP highresSST-present. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4675 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4675
EC-Earth3P-HR | EC-Earth-Consortium | HighResMIP | hist-1950 | EC-Earth Consortium (EC-Earth) (2018). EC-Earth-Consortium EC-Earth3P-HR model output prepared for CMIP6 HighResMIP hist-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4683 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4683
EC-Earth3P-VHR | EC-Earth-Consortium | CMIP | historical | EC-Earth Consortium (EC-Earth) (2020). EC-Earth-Consortium EC-Earth3P-VHR model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4710 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4710
EC-Earth3P-VHR | EC-Earth-Consortium | HighResMIP | control-1950 | EC-Earth Consortium (EC-Earth) (2024). EC-Earth-Consortium EC-Earth3P-VHR model output prepared for CMIP6 HighResMIP control-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4549 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4549
EC-Earth3P-VHR | EC-Earth-Consortium | HighResMIP | highres-future | EC-Earth Consortium (EC-Earth) (2024). EC-Earth-Consortium EC-Earth3P-VHR model output prepared for CMIP6 HighResMIP highres-future. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4656 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4656
EC-Earth3P-VHR | EC-Earth-Consortium | HighResMIP | hist-1950 | EC-Earth Consortium (EC-Earth) (2024). EC-Earth-Consortium EC-Earth3P-VHR model output prepared for CMIP6 HighResMIP hist-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4684 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4684
ECMWF-IFS-HR | ECMWF | HighResMIP | control-1950 | Roberts, Christopher David et al. (2017). ECMWF ECMWF-IFS-HR model output prepared for CMIP6 HighResMIP control-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4945 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4945
ECMWF-IFS-HR | ECMWF | HighResMIP | highresSST-present | Roberts, Christopher David et al. (2017). ECMWF ECMWF-IFS-HR model output prepared for CMIP6 HighResMIP highresSST-present. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4975 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4975
ECMWF-IFS-HR | ECMWF | HighResMIP | hist-1950 | Roberts, Christopher David et al. (2017). ECMWF ECMWF-IFS-HR model output prepared for CMIP6 HighResMIP hist-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4981 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4981
ECMWF-IFS-HR | ECMWF | HighResMIP | spinup-1950 | Roberts, Christopher David et al. (2017). ECMWF ECMWF-IFS-HR model output prepared for CMIP6 HighResMIP spinup-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4996 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4996
ECMWF-IFS-LR | ECMWF | HighResMIP | control-1950 | Roberts, Christopher David et al. (2018). ECMWF ECMWF-IFS-LR model output prepared for CMIP6 HighResMIP control-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4946 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4946
ECMWF-IFS-LR | ECMWF | HighResMIP | highresSST-present | Roberts, Christopher David et al. (2017). ECMWF ECMWF-IFS-LR model output prepared for CMIP6 HighResMIP highresSST-present. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4976 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4976
ECMWF-IFS-LR | ECMWF | HighResMIP | hist-1950 | Roberts, Christopher David et al. (2018). ECMWF ECMWF-IFS-LR model output prepared for CMIP6 HighResMIP hist-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4982 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4982
ECMWF-IFS-LR | ECMWF | HighResMIP | spinup-1950 | Roberts, Christopher David et al. (2018). ECMWF ECMWF-IFS-LR model output prepared for CMIP6 HighResMIP spinup-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4997 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4997
ECMWF-IFS-MR | ECMWF | HighResMIP | control-1950 | Roberts, Christopher David et al. (2018). ECMWF ECMWF-IFS-MR model output prepared for CMIP6 HighResMIP control-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4947 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4947
ECMWF-IFS-MR | ECMWF | HighResMIP | hist-1950 | Roberts, Christopher David et al. (2018). ECMWF ECMWF-IFS-MR model output prepared for CMIP6 HighResMIP hist-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4983 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4983
ECMWF-IFS-MR | ECMWF | HighResMIP | spinup-1950 | Roberts, Christopher David et al. (2018). ECMWF ECMWF-IFS-MR model output prepared for CMIP6 HighResMIP spinup-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4998 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4998
FGOALS-f3-H | CAS | HighResMIP | control-1950 | YU, Yongqiang (2021). CAS FGOALS-f3-H model output prepared for CMIP6 HighResMIP control-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3216 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3216
FGOALS-f3-H | CAS | HighResMIP | highres-future | YU, Yongqiang (2020). CAS FGOALS-f3-H model output prepared for CMIP6 HighResMIP highres-future. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3302 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3302
FGOALS-f3-H | CAS | HighResMIP | highresSST-future | Bao, Qing; He, Bian (2020). CAS FGOALS-f3-H model output prepared for CMIP6 HighResMIP highresSST-future. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3308 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3308
FGOALS-f3-H | CAS | HighResMIP | highresSST-present | Bao, Qing; He, Bian (2019). CAS FGOALS-f3-H model output prepared for CMIP6 HighResMIP highresSST-present. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3312 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3312
FGOALS-f3-H | CAS | HighResMIP | hist-1950 | YU, Yongqiang (2020). CAS FGOALS-f3-H model output prepared for CMIP6 HighResMIP hist-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3316 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3316
FGOALS-f3-H | CAS | OMIP | omip2 | Lin, Pengfei (2020). CAS FGOALS-f3-H model output prepared for CMIP6 OMIP omip2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13283 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13283
FGOALS-f3-L | CAS | CMIP | 1pctCO2 | YU, Yongqiang (2019). CAS FGOALS-f3-L model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3054 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3054
FGOALS-f3-L | CAS | CMIP | abrupt-4xCO2 | YU, Yongqiang (2019). CAS FGOALS-f3-L model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3176 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3176
FGOALS-f3-L | CAS | CMIP | amip | YU, Yongqiang (2018). CAS FGOALS-f3-L model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3182 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3182
FGOALS-f3-L | CAS | CMIP | historical | YU, Yongqiang (2019). CAS FGOALS-f3-L model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3355 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3355
FGOALS-f3-L | CAS | CMIP | piControl | YU, Yongqiang (2019). CAS FGOALS-f3-L model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3447 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3447
FGOALS-f3-L | CAS | DCPP | dcppA-hindcast | Hu, Shuai et al. (2022). CAS FGOALS-f3-L model output prepared for CMIP6 DCPP dcppA-hindcast. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3220 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3220
FGOALS-f3-L | CAS | DCPP | dcppB-forecast | Hu, Shuai et al. (2022). CAS FGOALS-f3-L model output prepared for CMIP6 DCPP dcppB-forecast. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3226 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3226
FGOALS-f3-L | CAS | GMMIP | amip-TIP | He, Bian; Bao, Qing (2019). CAS FGOALS-f3-L model output prepared for CMIP6 GMMIP amip-TIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3186 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3186
FGOALS-f3-L | CAS | GMMIP | amip-TIP-nosh | He, Bian; Bao, Qing (2019). CAS FGOALS-f3-L model output prepared for CMIP6 GMMIP amip-TIP-nosh. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3189 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3189
FGOALS-f3-L | CAS | GMMIP | amip-hist | He, Bian; Bao, Qing (2019). CAS FGOALS-f3-L model output prepared for CMIP6 GMMIP amip-hist. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3194 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3194
FGOALS-f3-L | CAS | GMMIP | amip-hld | He, Bian; Bao, Qing (2019). CAS FGOALS-f3-L model output prepared for CMIP6 GMMIP amip-hld. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3197 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3197
FGOALS-f3-L | CAS | GMMIP | hist-resIPO | He, Bian; Bao, Qing (2020). CAS FGOALS-f3-L model output prepared for CMIP6 GMMIP hist-resIPO. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3338 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3338
FGOALS-f3-L | CAS | HighResMIP | highresSST-future | Bao, Qing; He, Bian (2019). CAS FGOALS-f3-L model output prepared for CMIP6 HighResMIP highresSST-future. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12007 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12007
FGOALS-f3-L | CAS | HighResMIP | highresSST-present | Bao, Qing; He, Bian (2019). CAS FGOALS-f3-L model output prepared for CMIP6 HighResMIP highresSST-present. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12009 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12009
FGOALS-f3-L | CAS | OMIP | omip1 | Lin, Pengfei (2019). CAS FGOALS-f3-L model output prepared for CMIP6 OMIP omip1. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3413 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3413
FGOALS-f3-L | CAS | OMIP | omip2 | Lin, Pengfei (2019). CAS FGOALS-f3-L model output prepared for CMIP6 OMIP omip2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3419 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3419
FGOALS-f3-L | CAS | PAMIP | futSST-pdSIC | He, Bian; Bao, Qing (2019). CAS FGOALS-f3-L model output prepared for CMIP6 PAMIP futSST-pdSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11500 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11500
FGOALS-f3-L | CAS | PAMIP | pdSST-futAntSIC | He, Bian; Bao, Qing (2019). CAS FGOALS-f3-L model output prepared for CMIP6 PAMIP pdSST-futAntSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11511 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11511
FGOALS-f3-L | CAS | PAMIP | pdSST-futArcSIC | He, Bian; Bao, Qing (2019). CAS FGOALS-f3-L model output prepared for CMIP6 PAMIP pdSST-futArcSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11512 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11512
FGOALS-f3-L | CAS | PAMIP | pdSST-pdSIC | He, Bian; Bao, Qing (2019). CAS FGOALS-f3-L model output prepared for CMIP6 PAMIP pdSST-pdSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11516 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11516
FGOALS-f3-L | CAS | PAMIP | pdSST-piAntSIC | He, Bian; Bao, Qing (2019). CAS FGOALS-f3-L model output prepared for CMIP6 PAMIP pdSST-piAntSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11518 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11518
FGOALS-f3-L | CAS | PAMIP | pdSST-piArcSIC | He, Bian; Bao, Qing (2019). CAS FGOALS-f3-L model output prepared for CMIP6 PAMIP pdSST-piArcSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11519 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11519
FGOALS-f3-L | CAS | PAMIP | piSST-pdSIC | He, Bian; Bao, Qing (2019). CAS FGOALS-f3-L model output prepared for CMIP6 PAMIP piSST-pdSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11520 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11520
FGOALS-f3-L | CAS | PAMIP | piSST-piSIC | He, Bian; Bao, Qing (2019). CAS FGOALS-f3-L model output prepared for CMIP6 PAMIP piSST-piSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11521 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11521
FGOALS-f3-L | CAS | PMIP | lig127k | Zheng, Weipeng; He, Bian (2019). CAS FGOALS-f3-L model output prepared for CMIP6 PMIP lig127k. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12013 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12013
FGOALS-f3-L | CAS | PMIP | midHolocene | Zheng, Weipeng; He, Bian (2019). CAS FGOALS-f3-L model output prepared for CMIP6 PMIP midHolocene. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12014 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12014
FGOALS-f3-L | CAS | ScenarioMIP | ssp126 | YU, Yongqiang (2019). CAS FGOALS-f3-L model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3464 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3464
FGOALS-f3-L | CAS | ScenarioMIP | ssp245 | YU, Yongqiang (2019). CAS FGOALS-f3-L model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3468 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3468
FGOALS-f3-L | CAS | ScenarioMIP | ssp370 | YU, Yongqiang (2019). CAS FGOALS-f3-L model output prepared for CMIP6 ScenarioMIP ssp370. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3479 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3479
FGOALS-f3-L | CAS | ScenarioMIP | ssp585 | YU, Yongqiang (2019). CAS FGOALS-f3-L model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3502 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3502
FGOALS-g3 | CAS | CMIP | 1pctCO2 | Li, Lijuan (2019). CAS FGOALS-g3 model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3055 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3055
FGOALS-g3 | CAS | CMIP | abrupt-4xCO2 | Li, Lijuan (2019). CAS FGOALS-g3 model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3177 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3177
FGOALS-g3 | CAS | CMIP | amip | Li, Lijuan (2019). CAS FGOALS-g3 model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3183 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3183
FGOALS-g3 | CAS | CMIP | historical | Li, Lijuan (2019). CAS FGOALS-g3 model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3356 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3356
FGOALS-g3 | CAS | CMIP | piControl | Li, Lijuan (2019). CAS FGOALS-g3 model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3448 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3448
FGOALS-g3 | CAS | DAMIP | hist-GHG | Li, Lijuan (2020). CAS FGOALS-g3 model output prepared for CMIP6 DAMIP hist-GHG. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3321 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3321
FGOALS-g3 | CAS | DAMIP | hist-aer | Li, Lijuan (2020). CAS FGOALS-g3 model output prepared for CMIP6 DAMIP hist-aer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3323 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3323
FGOALS-g3 | CAS | DAMIP | hist-nat | Li, Lijuan (2020). CAS FGOALS-g3 model output prepared for CMIP6 DAMIP hist-nat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3330 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3330
FGOALS-g3 | CAS | FAFMIP | faf-all | Lin, Pengfei (2020). CAS FGOALS-g3 model output prepared for CMIP6 FAFMIP faf-all. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3291 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3291
FGOALS-g3 | CAS | FAFMIP | faf-heat | Lin, Pengfei (2020). CAS FGOALS-g3 model output prepared for CMIP6 FAFMIP faf-heat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3293 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3293
FGOALS-g3 | CAS | FAFMIP | faf-heat-NA0pct | Lin, Pengfei (2020). CAS FGOALS-g3 model output prepared for CMIP6 FAFMIP faf-heat-NA0pct. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11607 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11607
FGOALS-g3 | CAS | FAFMIP | faf-heat-NA50pct | Lin, Pengfei (2020). CAS FGOALS-g3 model output prepared for CMIP6 FAFMIP faf-heat-NA50pct. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11609 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11609
FGOALS-g3 | CAS | FAFMIP | faf-passiveheat | Lin, Pengfei (2020). CAS FGOALS-g3 model output prepared for CMIP6 FAFMIP faf-passiveheat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3295 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3295
FGOALS-g3 | CAS | FAFMIP | faf-stress | Lin, Pengfei (2020). CAS FGOALS-g3 model output prepared for CMIP6 FAFMIP faf-stress. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3297 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3297
FGOALS-g3 | CAS | FAFMIP | faf-water | Lin, Pengfei (2020). CAS FGOALS-g3 model output prepared for CMIP6 FAFMIP faf-water. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3299 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3299
FGOALS-g3 | CAS | GMMIP | amip-hist | Li, Lijuan (2020). CAS FGOALS-g3 model output prepared for CMIP6 GMMIP amip-hist. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3195 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3195
FGOALS-g3 | CAS | LS3MIP | land-hist | Jia, Binghao et al. (2020). CAS FGOALS-g3 model output prepared for CMIP6 LS3MIP land-hist. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3370 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3370
FGOALS-g3 | CAS | LS3MIP | land-hist-cruNcep | Jia, Binghao et al. (2020). CAS FGOALS-g3 model output prepared for CMIP6 LS3MIP land-hist-cruNcep. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3376 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3376
FGOALS-g3 | CAS | LS3MIP | land-hist-princeton | Jia, Binghao et al. (2020). CAS FGOALS-g3 model output prepared for CMIP6 LS3MIP land-hist-princeton. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3378 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3378
FGOALS-g3 | CAS | LS3MIP | land-hist-wfdei | Jia, Binghao et al. (2020). CAS FGOALS-g3 model output prepared for CMIP6 LS3MIP land-hist-wfdei. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3380 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3380
FGOALS-g3 | CAS | PMIP | lig127k | Zheng, Weipeng; Dong, Li (2019). CAS FGOALS-g3 model output prepared for CMIP6 PMIP lig127k. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3407 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3407
FGOALS-g3 | CAS | PMIP | midHolocene | Zheng, Weipeng; Dong, Li (2019). CAS FGOALS-g3 model output prepared for CMIP6 PMIP midHolocene. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3409 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3409
FGOALS-g3 | CAS | ScenarioMIP | ssp119 | Li, Lijuan (2019). CAS FGOALS-g3 model output prepared for CMIP6 ScenarioMIP ssp119. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3462 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3462
FGOALS-g3 | CAS | ScenarioMIP | ssp126 | Li, Lijuan (2019). CAS FGOALS-g3 model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3465 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3465
FGOALS-g3 | CAS | ScenarioMIP | ssp245 | Li, Lijuan (2019). CAS FGOALS-g3 model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3469 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3469
FGOALS-g3 | CAS | ScenarioMIP | ssp370 | Li, Lijuan (2019). CAS FGOALS-g3 model output prepared for CMIP6 ScenarioMIP ssp370. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3480 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3480
FGOALS-g3 | CAS | ScenarioMIP | ssp434 | Li, Lijuan (2019). CAS FGOALS-g3 model output prepared for CMIP6 ScenarioMIP ssp434. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3493 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3493
FGOALS-g3 | CAS | ScenarioMIP | ssp460 | Li, Lijuan (2019). CAS FGOALS-g3 model output prepared for CMIP6 ScenarioMIP ssp460. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3496 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3496
FGOALS-g3 | CAS | ScenarioMIP | ssp534-over | Li, Lijuan (2020). CAS FGOALS-g3 model output prepared for CMIP6 ScenarioMIP ssp534-over. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3499 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3499
FGOALS-g3 | CAS | ScenarioMIP | ssp585 | Li, Lijuan (2019). CAS FGOALS-g3 model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3503 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3503
FIO-ESM-2-0 | FIO-QLNM | CMIP | 1pctCO2 | Song, Zhenya et al. (2020). FIO-QLNM FIO-ESM2.0 model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9160 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9160
FIO-ESM-2-0 | FIO-QLNM | CMIP | abrupt-4xCO2 | Song, Zhenya et al. (2020). FIO-QLNM FIO-ESM2.0 model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9161 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9161
FIO-ESM-2-0 | FIO-QLNM | CMIP | amip | Song, Zhenya et al. (2020). FIO-QLNM FIO-ESM2.0 model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9162 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9162
FIO-ESM-2-0 | FIO-QLNM | CMIP | historical | Song, Zhenya et al. (2019). FIO-QLNM FIO-ESM2.0 model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9199 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9199
FIO-ESM-2-0 | FIO-QLNM | CMIP | piControl | Song, Zhenya et al. (2019). FIO-QLNM FIO-ESM2.0 model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9205 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9205
FIO-ESM-2-0 | FIO-QLNM | GMMIP | amip-TIP | Song, Zhenya et al. (2019). FIO-QLNM FIO-ESM2.0 model output prepared for CMIP6 GMMIP amip-TIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9163 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9163
FIO-ESM-2-0 | FIO-QLNM | GMMIP | amip-TIP-nosh | Song, Zhenya et al. (2019). FIO-QLNM FIO-ESM2.0 model output prepared for CMIP6 GMMIP amip-TIP-nosh. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9164 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9164
FIO-ESM-2-0 | FIO-QLNM | GMMIP | amip-hist | Song, Zhenya et al. (2019). FIO-QLNM FIO-ESM2.0 model output prepared for CMIP6 GMMIP amip-hist. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9165 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9165
FIO-ESM-2-0 | FIO-QLNM | GMMIP | amip-hld | Song, Zhenya et al. (2019). FIO-QLNM FIO-ESM2.0 model output prepared for CMIP6 GMMIP amip-hld. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9166 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9166
FIO-ESM-2-0 | FIO-QLNM | GMMIP | hist-resAMO | Song, Zhenya et al. (2019). FIO-QLNM FIO-ESM2.0 model output prepared for CMIP6 GMMIP hist-resAMO. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9197 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9197
FIO-ESM-2-0 | FIO-QLNM | GMMIP | hist-resIPO | Song, Zhenya et al. (2019). FIO-QLNM FIO-ESM2.0 model output prepared for CMIP6 GMMIP hist-resIPO. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9198 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9198
FIO-ESM-2-0 | FIO-QLNM | OMIP | omip1 | Song, Zhenya et al. (2020). FIO-QLNM FIO-ESM2.0 model output prepared for CMIP6 OMIP omip1. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9201 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9201
FIO-ESM-2-0 | FIO-QLNM | ScenarioMIP | ssp126 | Song, Zhenya et al. (2019). FIO-QLNM FIO-ESM2.0 model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9208 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9208
FIO-ESM-2-0 | FIO-QLNM | ScenarioMIP | ssp245 | Song, Zhenya et al. (2019). FIO-QLNM FIO-ESM2.0 model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9209 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9209
FIO-ESM-2-0 | FIO-QLNM | ScenarioMIP | ssp585 | Song, Zhenya et al. (2019). FIO-QLNM FIO-ESM2.0 model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9214 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9214
GFDL-AM4 | NOAA-GFDL | CMIP | amip | Zhao, Ming et al. (2018). NOAA-GFDL GFDL-AM4 model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8493 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8493
GFDL-CM4 | NOAA-GFDL | CFMIP | amip-4xCO2 | Silvers, Levi et al. (2018). NOAA-GFDL GFDL-CM4 model output prepared for CMIP6 CFMIP amip-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8499 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8499
GFDL-CM4 | NOAA-GFDL | CFMIP | amip-future4K | Silvers, Levi et al. (2018). NOAA-GFDL GFDL-CM4 model output prepared for CMIP6 CFMIP amip-future4K. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8503 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8503
GFDL-CM4 | NOAA-GFDL | CFMIP | amip-lwoff | Silvers, Levi et al. (2018). NOAA-GFDL GFDL-CM4 model output prepared for CMIP6 CFMIP amip-lwoff. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8506 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8506
GFDL-CM4 | NOAA-GFDL | CFMIP | amip-m4K | Silvers, Levi et al. (2018). NOAA-GFDL GFDL-CM4 model output prepared for CMIP6 CFMIP amip-m4K. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8507 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8507
GFDL-CM4 | NOAA-GFDL | CFMIP | amip-p4K | Silvers, Levi et al. (2018). NOAA-GFDL GFDL-CM4 model output prepared for CMIP6 CFMIP amip-p4K. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8508 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8508
GFDL-CM4 | NOAA-GFDL | CFMIP | amip-p4K-lwoff | Silvers, Levi et al. (2018). NOAA-GFDL GFDL-CM4 model output prepared for CMIP6 CFMIP amip-p4K-lwoff. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8509 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8509
GFDL-CM4 | NOAA-GFDL | CFMIP | aqua-4xCO2 | Silvers, Levi et al. (2018). NOAA-GFDL GFDL-CM4 model output prepared for CMIP6 CFMIP aqua-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8511 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8511
GFDL-CM4 | NOAA-GFDL | CFMIP | aqua-control | Silvers, Levi et al. (2018). NOAA-GFDL GFDL-CM4 model output prepared for CMIP6 CFMIP aqua-control. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8512 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8512
GFDL-CM4 | NOAA-GFDL | CFMIP | aqua-control-lwoff | Silvers, Levi et al. (2018). NOAA-GFDL GFDL-CM4 model output prepared for CMIP6 CFMIP aqua-control-lwoff. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8513 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8513
GFDL-CM4 | NOAA-GFDL | CFMIP | aqua-p4K | Silvers, Levi et al. (2018). NOAA-GFDL GFDL-CM4 model output prepared for CMIP6 CFMIP aqua-p4K. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8514 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8514
GFDL-CM4 | NOAA-GFDL | CMIP | 1pctCO2 | Guo, Huan et al. (2018). NOAA-GFDL GFDL-CM4 model output 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8470 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8470
GFDL-CM4 | NOAA-GFDL | CMIP | abrupt-4xCO2 | Guo, Huan et al. (2018). NOAA-GFDL GFDL-CM4 model output abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8486 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8486
GFDL-CM4 | NOAA-GFDL | CMIP | amip | Guo, Huan et al. (2018). NOAA-GFDL GFDL-CM4 model output amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8494 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8494
GFDL-CM4 | NOAA-GFDL | CMIP | historical | Guo, Huan et al. (2018). NOAA-GFDL GFDL-CM4 model output historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8594 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8594
GFDL-CM4 | NOAA-GFDL | CMIP | piControl | Guo, Huan et al. (2018). NOAA-GFDL GFDL-CM4 model output piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8666 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8666
GFDL-CM4 | NOAA-GFDL | DAMIP | hist-nat | Ploshay, Jeffrey et al. (2018). NOAA-GFDL GFDL-CM4 model output prepared for CMIP6 DAMIP hist-nat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11330 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11330
GFDL-CM4 | NOAA-GFDL | GMMIP | amip-hist | Xiang, Baoqiang et al. (2018). NOAA-GFDL GFDL-CM4 model output prepared for CMIP6 GMMIP amip-hist. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8504 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8504
GFDL-CM4 | NOAA-GFDL | OMIP | omip1 | Adcroft, Alistair et al. (2018). NOAA-GFDL GFDL-CM4 model output prepared for CMIP6 OMIP omip1. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8620 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8620
GFDL-CM4 | NOAA-GFDL | OMIP | omip2 | Hurlin, William et al. (2018). NOAA-GFDL GFDL-CM4 model output prepared for CMIP6 OMIP omip2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8626 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8626
GFDL-CM4 | NOAA-GFDL | RFMIP | piClim-4xCO2 | Paynter, David J et al. (2018). NOAA-GFDL GFDL-CM4 model output prepared for CMIP6 RFMIP piClim-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8638 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8638
GFDL-CM4 | NOAA-GFDL | RFMIP | piClim-aer | Paynter, David J et al. (2018). NOAA-GFDL GFDL-CM4 model output prepared for CMIP6 RFMIP piClim-aer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8650 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8650
GFDL-CM4 | NOAA-GFDL | RFMIP | piClim-anthro | Paynter, David J et al. (2018). NOAA-GFDL GFDL-CM4 model output prepared for CMIP6 RFMIP piClim-anthro. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8652 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8652
GFDL-CM4 | NOAA-GFDL | RFMIP | piClim-control | Paynter, David J et al. (2018). NOAA-GFDL GFDL-CM4 model output prepared for CMIP6 RFMIP piClim-control. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8653 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8653
GFDL-CM4 | NOAA-GFDL | RFMIP | piClim-ghg | Paynter, David J et al. (2018). NOAA-GFDL GFDL-CM4 model output prepared for CMIP6 RFMIP piClim-ghg. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8655 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8655
GFDL-CM4 | NOAA-GFDL | RFMIP | piClim-histaer | Paynter, David J et al. (2018). NOAA-GFDL GFDL-CM4 model output prepared for CMIP6 RFMIP piClim-histaer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8656 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8656
GFDL-CM4 | NOAA-GFDL | RFMIP | piClim-histall | Paynter, David J et al. (2018). NOAA-GFDL GFDL-CM4 model output prepared for CMIP6 RFMIP piClim-histall. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8657 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8657
GFDL-CM4 | NOAA-GFDL | RFMIP | piClim-histghg | Paynter, David J et al. (2018). NOAA-GFDL GFDL-CM4 model output prepared for CMIP6 RFMIP piClim-histghg. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8658 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8658
GFDL-CM4 | NOAA-GFDL | RFMIP | piClim-histnat | Paynter, David J et al. (2018). NOAA-GFDL GFDL-CM4 model output prepared for CMIP6 RFMIP piClim-histnat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8659 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8659
GFDL-CM4 | NOAA-GFDL | RFMIP | piClim-lu | Paynter, David J et al. (2018). NOAA-GFDL GFDL-CM4 model output prepared for CMIP6 RFMIP piClim-lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8660 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8660
GFDL-CM4 | NOAA-GFDL | RFMIP | rad-irf | Paynter, David J et al. (2018). NOAA-GFDL GFDL-CM4 model output prepared for CMIP6 RFMIP rad-irf. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8681 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8681
GFDL-CM4 | NOAA-GFDL | ScenarioMIP | ssp245 | Guo, Huan et al. (2018). NOAA-GFDL GFDL-CM4 model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9263 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9263
GFDL-CM4 | NOAA-GFDL | ScenarioMIP | ssp585 | Guo, Huan et al. (2018). NOAA-GFDL GFDL-CM4 model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9268 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9268
GFDL-CM4C192 | NOAA-GFDL | HighResMIP | control-1950 | Zhao, Ming et al. (2018). NOAA-GFDL GFDL-CM4C192 model output prepared for CMIP6 HighResMIP control-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8516 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8516
GFDL-CM4C192 | NOAA-GFDL | HighResMIP | highresSST-future | Zhao, Ming et al. (2018). NOAA-GFDL GFDL-CM4C192 model output prepared for CMIP6 HighResMIP highresSST-future. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8563 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8563
GFDL-CM4C192 | NOAA-GFDL | HighResMIP | highresSST-present | Zhao, Ming et al. (2018). NOAA-GFDL GFDL-CM4C192 model output prepared for CMIP6 HighResMIP highresSST-present. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8565 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8565
GFDL-CM4C192 | NOAA-GFDL | HighResMIP | hist-1950 | Zhao, Ming et al. (2018). NOAA-GFDL GFDL-CM4C192 model output prepared for CMIP6 HighResMIP hist-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8567 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8567
GFDL-ESM2M | NOAA-GFDL | FAFMIP | faf-all | Hurlin, William et al. (2018). NOAA-GFDL GFDL-ESM2M model output prepared for CMIP6 FAFMIP faf-all. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8555 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8555
GFDL-ESM2M | NOAA-GFDL | FAFMIP | faf-heat | Hurlin, William et al. (2018). NOAA-GFDL GFDL-ESM2M model output prepared for CMIP6 FAFMIP faf-heat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8556 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8556
GFDL-ESM2M | NOAA-GFDL | FAFMIP | faf-heat-NA0pct | Hurlin, William et al. (2018). NOAA-GFDL GFDL-ESM2M model output prepared for CMIP6 FAFMIP faf-heat-NA0pct. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11635 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11635
GFDL-ESM2M | NOAA-GFDL | FAFMIP | faf-heat-NA50pct | Hurlin, William et al. (2018). NOAA-GFDL GFDL-ESM2M model output prepared for CMIP6 FAFMIP faf-heat-NA50pct. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11636 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11636
GFDL-ESM2M | NOAA-GFDL | FAFMIP | faf-passiveheat | Hurlin, William et al. (2018). NOAA-GFDL GFDL-ESM2M model output prepared for CMIP6 FAFMIP faf-passiveheat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8557 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8557
GFDL-ESM2M | NOAA-GFDL | FAFMIP | faf-stress | Hurlin, William et al. (2018). NOAA-GFDL GFDL-ESM2M model output prepared for CMIP6 FAFMIP faf-stress. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8558 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8558
GFDL-ESM2M | NOAA-GFDL | FAFMIP | faf-water | Hurlin, William et al. (2018). NOAA-GFDL GFDL-ESM2M model output prepared for CMIP6 FAFMIP faf-water. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8559 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8559
GFDL-ESM4 | NOAA-GFDL | AerChemMIP | hist-1950HC | Horowitz, Larry W. et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 AerChemMIP hist-1950HC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8568 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8568
GFDL-ESM4 | NOAA-GFDL | AerChemMIP | hist-piAer | Horowitz, Larry W. et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 AerChemMIP hist-piAer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8577 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8577
GFDL-ESM4 | NOAA-GFDL | AerChemMIP | hist-piNTCF | Horowitz, Larry W. et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 AerChemMIP hist-piNTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8578 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8578
GFDL-ESM4 | NOAA-GFDL | AerChemMIP | histSST | Horowitz, Larry W. et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 AerChemMIP histSST. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8586 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8586
GFDL-ESM4 | NOAA-GFDL | AerChemMIP | histSST-1950HC | Horowitz, Larry W. et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 AerChemMIP histSST-1950HC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8587 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8587
GFDL-ESM4 | NOAA-GFDL | AerChemMIP | histSST-piAer | Horowitz, Larry W. et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 AerChemMIP histSST-piAer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8588 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8588
GFDL-ESM4 | NOAA-GFDL | AerChemMIP | histSST-piCH4 | Horowitz, Larry W. et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 AerChemMIP histSST-piCH4. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8589 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8589
GFDL-ESM4 | NOAA-GFDL | AerChemMIP | histSST-piNTCF | Horowitz, Larry W. et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 AerChemMIP histSST-piNTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8591 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8591
GFDL-ESM4 | NOAA-GFDL | AerChemMIP | histSST-piO3 | Horowitz, Larry W. et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 AerChemMIP histSST-piO3. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8592 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8592
GFDL-ESM4 | NOAA-GFDL | AerChemMIP | piClim-2xNOx | Horowitz, Larry W. et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 AerChemMIP piClim-2xNOx. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8633 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8633
GFDL-ESM4 | NOAA-GFDL | AerChemMIP | piClim-2xVOC | Horowitz, Larry W. et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 AerChemMIP piClim-2xVOC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8634 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8634
GFDL-ESM4 | NOAA-GFDL | AerChemMIP | piClim-2xdust | Horowitz, Larry W. et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 AerChemMIP piClim-2xdust. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8635 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8635
GFDL-ESM4 | NOAA-GFDL | AerChemMIP | piClim-2xss | Horowitz, Larry W. et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 AerChemMIP piClim-2xss. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8637 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8637
GFDL-ESM4 | NOAA-GFDL | AerChemMIP | piClim-BC | Horowitz, Larry W. et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 AerChemMIP piClim-BC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8639 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8639
GFDL-ESM4 | NOAA-GFDL | AerChemMIP | piClim-CH4 | Horowitz, Larry W. et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 AerChemMIP piClim-CH4. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8640 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8640
GFDL-ESM4 | NOAA-GFDL | AerChemMIP | piClim-HC | Horowitz, Larry W. et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 AerChemMIP piClim-HC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8641 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8641
GFDL-ESM4 | NOAA-GFDL | AerChemMIP | piClim-NOx | Horowitz, Larry W. et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 AerChemMIP piClim-NOx. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8644 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8644
GFDL-ESM4 | NOAA-GFDL | AerChemMIP | piClim-NTCF | Horowitz, Larry W. et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 AerChemMIP piClim-NTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8645 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8645
GFDL-ESM4 | NOAA-GFDL | AerChemMIP | piClim-O3 | Horowitz, Larry W. et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 AerChemMIP piClim-O3. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8646 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8646
GFDL-ESM4 | NOAA-GFDL | AerChemMIP | piClim-OC | Horowitz, Larry W. et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 AerChemMIP piClim-OC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8647 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8647
GFDL-ESM4 | NOAA-GFDL | AerChemMIP | piClim-SO2 | Horowitz, Larry W. et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 AerChemMIP piClim-SO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8648 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8648
GFDL-ESM4 | NOAA-GFDL | AerChemMIP | piClim-VOC | Horowitz, Larry W. et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 AerChemMIP piClim-VOC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8649 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8649
GFDL-ESM4 | NOAA-GFDL | AerChemMIP | piClim-aer | Horowitz, Larry W. et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 AerChemMIP piClim-aer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8651 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8651
GFDL-ESM4 | NOAA-GFDL | AerChemMIP | piClim-control | Horowitz, Larry W. et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 AerChemMIP piClim-control. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8654 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8654
GFDL-ESM4 | NOAA-GFDL | AerChemMIP | ssp370-lowNTCF | Horowitz, Larry W. et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 AerChemMIP ssp370-lowNTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8693 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8693
GFDL-ESM4 | NOAA-GFDL | AerChemMIP | ssp370-lowNTCFCH4 | Horowitz, Larry W. et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 AerChemMIP ssp370-lowNTCFCH4. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13561 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13561
GFDL-ESM4 | NOAA-GFDL | AerChemMIP | ssp370SST | Horowitz, Larry W. et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 AerChemMIP ssp370SST. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8695 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8695
GFDL-ESM4 | NOAA-GFDL | AerChemMIP | ssp370SST-lowCH4 | Horowitz, Larry W. et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 AerChemMIP ssp370SST-lowCH4. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8698 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8698
GFDL-ESM4 | NOAA-GFDL | AerChemMIP | ssp370SST-lowNTCF | Horowitz, Larry W. et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 AerChemMIP ssp370SST-lowNTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8699 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8699
GFDL-ESM4 | NOAA-GFDL | AerChemMIP | ssp370SST-lowNTCFCH4 | Horowitz, Larry W. et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 AerChemMIP ssp370SST-lowNTCFCH4. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13562 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13562
GFDL-ESM4 | NOAA-GFDL | AerChemMIP | ssp370SST-ssp126Lu | Horowitz, Larry W. et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 AerChemMIP ssp370SST-ssp126Lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8701 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8701
GFDL-ESM4 | NOAA-GFDL | AerChemMIP | ssp370pdSST | Horowitz, Larry W. et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 AerChemMIP ssp370pdSST. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11338 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11338
GFDL-ESM4 | NOAA-GFDL | C4MIP | 1pctCO2-bgc | Krasting, John P. et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 C4MIP 1pctCO2-bgc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8475 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8475
GFDL-ESM4 | NOAA-GFDL | C4MIP | 1pctCO2-rad | Krasting, John P. et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 C4MIP 1pctCO2-rad. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8477 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8477
GFDL-ESM4 | NOAA-GFDL | C4MIP | esm-1pct-brch-1000PgC | John, Jasmin G. et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 C4MIP esm-1pct-brch-1000PgC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10621 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10621
GFDL-ESM4 | NOAA-GFDL | C4MIP | esm-ssp585 | Krasting, John P. et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 C4MIP esm-ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8545 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8545
GFDL-ESM4 | NOAA-GFDL | CDRMIP | 1pctCO2-cdr | John, Jasmin G et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 CDRMIP 1pctCO2-cdr. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8476 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8476
GFDL-ESM4 | NOAA-GFDL | CDRMIP | esm-pi-CO2pulse | John, Jasmin G et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 CDRMIP esm-pi-CO2pulse. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8530 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8530
GFDL-ESM4 | NOAA-GFDL | CDRMIP | esm-pi-cdr-pulse | John, Jasmin G et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 CDRMIP esm-pi-cdr-pulse. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8531 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8531
GFDL-ESM4 | NOAA-GFDL | CMIP | 1pctCO2 | Krasting, John P. et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8473 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8473
GFDL-ESM4 | NOAA-GFDL | CMIP | abrupt-4xCO2 | Krasting, John P. et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8489 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8489
GFDL-ESM4 | NOAA-GFDL | CMIP | amip | Krasting, John P. et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8497 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8497
GFDL-ESM4 | NOAA-GFDL | CMIP | esm-hist | Krasting, John P. et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 CMIP esm-hist. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8522 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8522
GFDL-ESM4 | NOAA-GFDL | CMIP | esm-piControl | Krasting, John P. et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 CMIP esm-piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8536 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8536
GFDL-ESM4 | NOAA-GFDL | CMIP | historical | Krasting, John P. et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8597 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8597
GFDL-ESM4 | NOAA-GFDL | CMIP | piControl | Krasting, John P. et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8669 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8669
GFDL-ESM4 | NOAA-GFDL | DAMIP | hist-GHG | Horowitz, Larry W. et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 DAMIP hist-GHG. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8570 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8570
GFDL-ESM4 | NOAA-GFDL | DAMIP | hist-aer | Horowitz, Larry W. et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 DAMIP hist-aer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8571 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8571
GFDL-ESM4 | NOAA-GFDL | DAMIP | hist-nat | Horowitz, Larry W. et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 DAMIP hist-nat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8575 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8575
GFDL-ESM4 | NOAA-GFDL | LUMIP | esm-ssp585-ssp126Lu | Malyshev, Sergey et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 LUMIP esm-ssp585-ssp126Lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8548 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8548
GFDL-ESM4 | NOAA-GFDL | LUMIP | hist-noLu | Malyshev, Sergey et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 LUMIP hist-noLu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8576 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8576
GFDL-ESM4 | NOAA-GFDL | LUMIP | land-hist | Malyshev, Sergey et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 LUMIP land-hist. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8611 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8611
GFDL-ESM4 | NOAA-GFDL | LUMIP | land-hist-altStartYear | Malyshev, Sergey et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 LUMIP land-hist-altStartYear. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8614 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8614
GFDL-ESM4 | NOAA-GFDL | LUMIP | land-noLu | Malyshev, Sergey et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 LUMIP land-noLu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8616 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8616
GFDL-ESM4 | NOAA-GFDL | LUMIP | ssp126-ssp370Lu | Malyshev, Sergey et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 LUMIP ssp126-ssp370Lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8685 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8685
GFDL-ESM4 | NOAA-GFDL | LUMIP | ssp370-ssp126Lu | Malyshev, Sergey et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 LUMIP ssp370-ssp126Lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8694 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8694
GFDL-ESM4 | NOAA-GFDL | RFMIP | piClim-4xCO2 | Paynter, David J et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 RFMIP piClim-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11964 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11964
GFDL-ESM4 | NOAA-GFDL | RFMIP | piClim-anthro | Paynter, David J et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 RFMIP piClim-anthro. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11966 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11966
GFDL-ESM4 | NOAA-GFDL | RFMIP | piClim-ghg | Paynter, David J et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 RFMIP piClim-ghg. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11968 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11968
GFDL-ESM4 | NOAA-GFDL | RFMIP | piClim-lu | Paynter, David J et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 RFMIP piClim-lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11973 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11973
GFDL-ESM4 | NOAA-GFDL | ScenarioMIP | ssp119 | John, Jasmin G et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 ScenarioMIP ssp119. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8683 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8683
GFDL-ESM4 | NOAA-GFDL | ScenarioMIP | ssp126 | John, Jasmin G et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8684 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8684
GFDL-ESM4 | NOAA-GFDL | ScenarioMIP | ssp245 | John, Jasmin G et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8686 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8686
GFDL-ESM4 | NOAA-GFDL | ScenarioMIP | ssp370 | John, Jasmin G et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 ScenarioMIP ssp370. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8691 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8691
GFDL-ESM4 | NOAA-GFDL | ScenarioMIP | ssp585 | John, Jasmin G et al. (2018). NOAA-GFDL GFDL-ESM4 model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8706 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8706
GFDL-GRTCODE | NOAA-GFDL | RFMIP | rad-irf | Paynter, David J et al. (2018). NOAA-GFDL GFDL-GRTCODE model output prepared for CMIP6 RFMIP rad-irf. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10708 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10708
GFDL-OM4p5B | NOAA-GFDL | OMIP | omip1 | Zadeh, Niki T. et al. (2018). NOAA-GFDL GFDL-OM4p5B model output prepared for CMIP6 OMIP omip1. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8622 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8622
GFDL-RFM-DISORT | NOAA-GFDL | RFMIP | rad-irf | Paynter, David J et al. (2018). NOAA-GFDL GFDL-RFM-DISORT model output prepared for CMIP6 RFMIP rad-irf. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10709 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10709
GISS-E2-1-G | NASA-GISS | AerChemMIP | hist-1950HC | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 AerChemMIP hist-1950HC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7075 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7075
GISS-E2-1-G | NASA-GISS | AerChemMIP | hist-piAer | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 AerChemMIP hist-piAer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7093 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7093
GISS-E2-1-G | NASA-GISS | AerChemMIP | hist-piNTCF | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 AerChemMIP hist-piNTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7095 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7095
GISS-E2-1-G | NASA-GISS | AerChemMIP | histSST | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 AerChemMIP histSST. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7113 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7113
GISS-E2-1-G | NASA-GISS | AerChemMIP | histSST-1950HC | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 AerChemMIP histSST-1950HC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7115 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7115
GISS-E2-1-G | NASA-GISS | AerChemMIP | histSST-noLu | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 AerChemMIP histSST-noLu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11161 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.11161
GISS-E2-1-G | NASA-GISS | AerChemMIP | histSST-piAer | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 AerChemMIP histSST-piAer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7117 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7117
GISS-E2-1-G | NASA-GISS | AerChemMIP | histSST-piCH4 | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 AerChemMIP histSST-piCH4. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7119 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7119
GISS-E2-1-G | NASA-GISS | AerChemMIP | histSST-piN2O | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 AerChemMIP histSST-piN2O. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7121 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7121
GISS-E2-1-G | NASA-GISS | AerChemMIP | histSST-piNTCF | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 AerChemMIP histSST-piNTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7123 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7123
GISS-E2-1-G | NASA-GISS | AerChemMIP | histSST-piO3 | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 AerChemMIP histSST-piO3. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7125 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7125
GISS-E2-1-G | NASA-GISS | AerChemMIP | piClim-2xDMS | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 AerChemMIP piClim-2xDMS. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7300 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7300
GISS-E2-1-G | NASA-GISS | AerChemMIP | piClim-2xNOx | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 AerChemMIP piClim-2xNOx. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7302 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7302
GISS-E2-1-G | NASA-GISS | AerChemMIP | piClim-2xVOC | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 AerChemMIP piClim-2xVOC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7304 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7304
GISS-E2-1-G | NASA-GISS | AerChemMIP | piClim-2xdust | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 AerChemMIP piClim-2xdust. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7306 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7306
GISS-E2-1-G | NASA-GISS | AerChemMIP | piClim-2xfire | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 AerChemMIP piClim-2xfire. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7308 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7308
GISS-E2-1-G | NASA-GISS | AerChemMIP | piClim-2xss | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 AerChemMIP piClim-2xss. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7310 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7310
GISS-E2-1-G | NASA-GISS | AerChemMIP | piClim-BC | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 AerChemMIP piClim-BC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7315 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7315
GISS-E2-1-G | NASA-GISS | AerChemMIP | piClim-CH4 | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 AerChemMIP piClim-CH4. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7317 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7317
GISS-E2-1-G | NASA-GISS | AerChemMIP | piClim-HC | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 AerChemMIP piClim-HC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7319 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7319
GISS-E2-1-G | NASA-GISS | AerChemMIP | piClim-N2O | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 AerChemMIP piClim-N2O. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7321 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7321
GISS-E2-1-G | NASA-GISS | AerChemMIP | piClim-NH3 | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 AerChemMIP piClim-NH3. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7323 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7323
GISS-E2-1-G | NASA-GISS | AerChemMIP | piClim-NOx | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 AerChemMIP piClim-NOx. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7325 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7325
GISS-E2-1-G | NASA-GISS | AerChemMIP | piClim-NTCF | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 AerChemMIP piClim-NTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7327 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7327
GISS-E2-1-G | NASA-GISS | AerChemMIP | piClim-O3 | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 AerChemMIP piClim-O3. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7329 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7329
GISS-E2-1-G | NASA-GISS | AerChemMIP | piClim-OC | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 AerChemMIP piClim-OC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7331 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7331
GISS-E2-1-G | NASA-GISS | AerChemMIP | piClim-SO2 | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 AerChemMIP piClim-SO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7333 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7333
GISS-E2-1-G | NASA-GISS | AerChemMIP | piClim-VOC | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 AerChemMIP piClim-VOC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7335 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7335
GISS-E2-1-G | NASA-GISS | AerChemMIP | ssp370-lowNTCF | NASA Goddard Institute for Space Studies (NASA/GISS) (2020). NASA-GISS GISS-E2.1G model output prepared for CMIP6 AerChemMIP ssp370-lowNTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7431 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7431
GISS-E2-1-G | NASA-GISS | AerChemMIP | ssp370-lowNTCFCH4 | NASA Goddard Institute for Space Studies (NASA/GISS) (2020). NASA-GISS GISS-E2.1G model output prepared for CMIP6 AerChemMIP ssp370-lowNTCFCH4. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13531 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.13531
GISS-E2-1-G | NASA-GISS | AerChemMIP | ssp370SST | NASA Goddard Institute for Space Studies (NASA/GISS) (2020). NASA-GISS GISS-E2.1G model output prepared for CMIP6 AerChemMIP ssp370SST. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7435 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7435
GISS-E2-1-G | NASA-GISS | AerChemMIP | ssp370SST-lowAer | NASA Goddard Institute for Space Studies (NASA/GISS) (2020). NASA-GISS GISS-E2.1G model output prepared for CMIP6 AerChemMIP ssp370SST-lowAer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7437 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7437
GISS-E2-1-G | NASA-GISS | AerChemMIP | ssp370SST-lowBC | NASA Goddard Institute for Space Studies (NASA/GISS) (2020). NASA-GISS GISS-E2.1G model output prepared for CMIP6 AerChemMIP ssp370SST-lowBC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7439 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7439
GISS-E2-1-G | NASA-GISS | AerChemMIP | ssp370SST-lowCH4 | NASA Goddard Institute for Space Studies (NASA/GISS) (2020). NASA-GISS GISS-E2.1G model output prepared for CMIP6 AerChemMIP ssp370SST-lowCH4. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7441 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7441
GISS-E2-1-G | NASA-GISS | AerChemMIP | ssp370SST-lowNTCF | NASA Goddard Institute for Space Studies (NASA/GISS) (2020). NASA-GISS GISS-E2.1G model output prepared for CMIP6 AerChemMIP ssp370SST-lowNTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7443 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7443
GISS-E2-1-G | NASA-GISS | AerChemMIP | ssp370SST-lowNTCFCH4 | NASA Goddard Institute for Space Studies (NASA/GISS) (2020). NASA-GISS GISS-E2.1G model output prepared for CMIP6 AerChemMIP ssp370SST-lowNTCFCH4. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13534 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.13534
GISS-E2-1-G | NASA-GISS | AerChemMIP | ssp370SST-lowO3 | NASA Goddard Institute for Space Studies (NASA/GISS) (2020). NASA-GISS GISS-E2.1G model output prepared for CMIP6 AerChemMIP ssp370SST-lowO3. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7445 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7445
GISS-E2-1-G | NASA-GISS | AerChemMIP | ssp370pdSST | NASA Goddard Institute for Space Studies (NASA/GISS) (2020). NASA-GISS GISS-E2.1G model output prepared for CMIP6 AerChemMIP ssp370pdSST. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11387 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.11387
GISS-E2-1-G | NASA-GISS | C4MIP | 1pctCO2-bgc | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 C4MIP 1pctCO2-bgc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6956 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.6956
GISS-E2-1-G | NASA-GISS | C4MIP | 1pctCO2-rad | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 C4MIP 1pctCO2-rad. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6958 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.6958
GISS-E2-1-G | NASA-GISS | C4MIP | hist-bgc | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 C4MIP hist-bgc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7087 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7087
GISS-E2-1-G | NASA-GISS | CFMIP | abrupt-0p5xCO2 | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 CFMIP abrupt-0p5xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6972 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.6972
GISS-E2-1-G | NASA-GISS | CFMIP | abrupt-2xCO2 | NASA Goddard Institute for Space Studies (NASA/GISS) (2018). NASA-GISS GISS-E2.1G model output prepared for CMIP6 CFMIP abrupt-2xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6974 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.6974
GISS-E2-1-G | NASA-GISS | CFMIP | amip-4xCO2 | NASA Goddard Institute for Space Studies (NASA/GISS) (2020). NASA-GISS GISS-E2.1G model output prepared for CMIP6 CFMIP amip-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6988 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.6988
GISS-E2-1-G | NASA-GISS | CFMIP | amip-p4K | NASA Goddard Institute for Space Studies (NASA/GISS) (2020). NASA-GISS GISS-E2.1G model output prepared for CMIP6 CFMIP amip-p4K. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7018 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7018
GISS-E2-1-G | NASA-GISS | CFMIP | amip-piForcing | NASA Goddard Institute for Space Studies (NASA/GISS) (2021). NASA-GISS GISS-E2.1G model output prepared for CMIP6 CFMIP amip-piForcing. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7022 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7022
GISS-E2-1-G | NASA-GISS | CMIP | 1pctCO2 | NASA Goddard Institute for Space Studies (NASA/GISS) (2018). NASA-GISS GISS-E2.1G model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6950 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.6950
GISS-E2-1-G | NASA-GISS | CMIP | abrupt-4xCO2 | NASA Goddard Institute for Space Studies (NASA/GISS) (2018). NASA-GISS GISS-E2.1G model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6976 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.6976
GISS-E2-1-G | NASA-GISS | CMIP | amip | NASA Goddard Institute for Space Studies (NASA/GISS) (2018). NASA-GISS GISS-E2.1G model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6984 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.6984
GISS-E2-1-G | NASA-GISS | CMIP | historical | NASA Goddard Institute for Space Studies (NASA/GISS) (2018). NASA-GISS GISS-E2.1G model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7127 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7127
GISS-E2-1-G | NASA-GISS | CMIP | piControl | NASA Goddard Institute for Space Studies (NASA/GISS) (2018). NASA-GISS GISS-E2.1G model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7380 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7380
GISS-E2-1-G | NASA-GISS | DAMIP | hist-GHG | NASA Goddard Institute for Space Studies (NASA/GISS) (2018). NASA-GISS GISS-E2.1G model output prepared for CMIP6 DAMIP hist-GHG. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7079 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7079
GISS-E2-1-G | NASA-GISS | DAMIP | hist-aer | NASA Goddard Institute for Space Studies (NASA/GISS) (2018). NASA-GISS GISS-E2.1G model output prepared for CMIP6 DAMIP hist-aer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7081 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7081
GISS-E2-1-G | NASA-GISS | DAMIP | hist-nat | NASA Goddard Institute for Space Studies (NASA/GISS) (2018). NASA-GISS GISS-E2.1G model output prepared for CMIP6 DAMIP hist-nat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7089 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7089
GISS-E2-1-G | NASA-GISS | DAMIP | hist-sol | NASA Goddard Institute for Space Studies (NASA/GISS) (2018). NASA-GISS GISS-E2.1G model output prepared for CMIP6 DAMIP hist-sol. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7101 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7101
GISS-E2-1-G | NASA-GISS | DAMIP | hist-stratO3 | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 DAMIP hist-stratO3. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7109 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7109
GISS-E2-1-G | NASA-GISS | DAMIP | hist-totalO3 | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 DAMIP hist-totalO3. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12412 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.12412
GISS-E2-1-G | NASA-GISS | DAMIP | hist-volc | NASA Goddard Institute for Space Studies (NASA/GISS) (2018). NASA-GISS GISS-E2.1G model output prepared for CMIP6 DAMIP hist-volc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7111 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7111
GISS-E2-1-G | NASA-GISS | DAMIP | ssp245-GHG | NASA Goddard Institute for Space Studies (NASA/GISS) (2020). NASA-GISS GISS-E2.1G model output prepared for CMIP6 DAMIP ssp245-GHG. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7418 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7418
GISS-E2-1-G | NASA-GISS | DAMIP | ssp245-aer | NASA Goddard Institute for Space Studies (NASA/GISS) (2020). NASA-GISS GISS-E2.1G model output prepared for CMIP6 DAMIP ssp245-aer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7420 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7420
GISS-E2-1-G | NASA-GISS | DAMIP | ssp245-covid | NASA Goddard Institute for Space Studies (NASA/GISS) (2020). NASA-GISS GISS-E2.1G model output prepared for CMIP6 DAMIP ssp245-covid. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14971 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.14971
GISS-E2-1-G | NASA-GISS | DAMIP | ssp245-nat | NASA Goddard Institute for Space Studies (NASA/GISS) (2020). NASA-GISS GISS-E2.1G model output prepared for CMIP6 DAMIP ssp245-nat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7422 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7422
GISS-E2-1-G | NASA-GISS | DAMIP | ssp245-stratO3 | NASA Goddard Institute for Space Studies (NASA/GISS) (2020). NASA-GISS GISS-E2.1G model output prepared for CMIP6 DAMIP ssp245-stratO3. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7424 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7424
GISS-E2-1-G | NASA-GISS | ISMIP6 | 1pctCO2-4xext | NASA Goddard Institute for Space Studies (NASA/GISS) (2018). NASA-GISS GISS-E2.1G model output prepared for CMIP6 ISMIP6 1pctCO2-4xext. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6954 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.6954
GISS-E2-1-G | NASA-GISS | LS3MIP | land-hist | NASA Goddard Institute for Space Studies (NASA/GISS) (2018). NASA-GISS GISS-E2.1G model output prepared for CMIP6 LS3MIP land-hist. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7177 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7177
GISS-E2-1-G | NASA-GISS | LUMIP | deforest-globe | NASA Goddard Institute for Space Studies (NASA/GISS) (2020). NASA-GISS GISS-E2.1G model output prepared for CMIP6 LUMIP deforest-globe. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7040 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7040
GISS-E2-1-G | NASA-GISS | LUMIP | land-hist | NASA Goddard Institute for Space Studies (NASA/GISS) (2018). NASA-GISS GISS-E2.1G model output prepared for CMIP6 LUMIP land-hist. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7179 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7179
GISS-E2-1-G | NASA-GISS | PMIP | lig127k | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 PMIP lig127k. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7223 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7223
GISS-E2-1-G | NASA-GISS | PMIP | midHolocene | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 PMIP midHolocene. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7225 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7225
GISS-E2-1-G | NASA-GISS | PMIP | midPliocene-eoi400 | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 PMIP midPliocene-eoi400. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7227 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7227
GISS-E2-1-G | NASA-GISS | RFMIP | piClim-4xCO2 | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 RFMIP piClim-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7312 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7312
GISS-E2-1-G | NASA-GISS | RFMIP | piClim-aer | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 RFMIP piClim-aer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7337 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7337
GISS-E2-1-G | NASA-GISS | RFMIP | piClim-anthro | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 RFMIP piClim-anthro. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7342 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7342
GISS-E2-1-G | NASA-GISS | RFMIP | piClim-control | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 RFMIP piClim-control. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7345 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7345
GISS-E2-1-G | NASA-GISS | RFMIP | piClim-ghg | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 RFMIP piClim-ghg. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7350 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7350
GISS-E2-1-G | NASA-GISS | RFMIP | piClim-histaer | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 RFMIP piClim-histaer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7353 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7353
GISS-E2-1-G | NASA-GISS | RFMIP | piClim-histall | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 RFMIP piClim-histall. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7356 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7356
GISS-E2-1-G | NASA-GISS | RFMIP | piClim-histghg | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 RFMIP piClim-histghg. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7359 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7359
GISS-E2-1-G | NASA-GISS | RFMIP | piClim-histnat | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 RFMIP piClim-histnat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7362 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7362
GISS-E2-1-G | NASA-GISS | RFMIP | piClim-lu | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 RFMIP piClim-lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7365 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7365
GISS-E2-1-G | NASA-GISS | RFMIP | rad-irf | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 RFMIP rad-irf. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7404 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7404
GISS-E2-1-G | NASA-GISS | ScenarioMIP | ssp119 | NASA Goddard Institute for Space Studies (NASA/GISS) (2020). NASA-GISS GISS-E2.1G model output prepared for CMIP6 ScenarioMIP ssp119. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7407 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7407
GISS-E2-1-G | NASA-GISS | ScenarioMIP | ssp126 | NASA Goddard Institute for Space Studies (NASA/GISS) (2020). NASA-GISS GISS-E2.1G model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7410 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7410
GISS-E2-1-G | NASA-GISS | ScenarioMIP | ssp245 | NASA Goddard Institute for Space Studies (NASA/GISS) (2020). NASA-GISS GISS-E2.1G model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7415 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7415
GISS-E2-1-G | NASA-GISS | ScenarioMIP | ssp370 | NASA Goddard Institute for Space Studies (NASA/GISS) (2020). NASA-GISS GISS-E2.1G model output prepared for CMIP6 ScenarioMIP ssp370. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7426 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7426
GISS-E2-1-G | NASA-GISS | ScenarioMIP | ssp434 | NASA Goddard Institute for Space Studies (NASA/GISS) (2020). NASA-GISS GISS-E2.1G model output prepared for CMIP6 ScenarioMIP ssp434. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7449 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7449
GISS-E2-1-G | NASA-GISS | ScenarioMIP | ssp460 | NASA Goddard Institute for Space Studies (NASA/GISS) (2020). NASA-GISS GISS-E2.1G model output prepared for CMIP6 ScenarioMIP ssp460. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7452 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7452
GISS-E2-1-G | NASA-GISS | ScenarioMIP | ssp534-over | NASA Goddard Institute for Space Studies (NASA/GISS) (2020). NASA-GISS GISS-E2.1G model output prepared for CMIP6 ScenarioMIP ssp534-over. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7455 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7455
GISS-E2-1-G | NASA-GISS | ScenarioMIP | ssp585 | NASA Goddard Institute for Space Studies (NASA/GISS) (2020). NASA-GISS GISS-E2.1G model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7460 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7460
GISS-E2-1-G | NASA-GISS | VolMIP | volc-pinatubo-full | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1G model output prepared for CMIP6 VolMIP volc-pinatubo-full. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7485 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7485
GISS-E2-1-G-CC | NASA-GISS | C4MIP | esm-1pct-brch-1000PgC | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2-1-G-CC model output prepared for CMIP6 C4MIP esm-1pct-brch-1000PgC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11716 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.11716
GISS-E2-1-G-CC | NASA-GISS | C4MIP | esm-1pctCO2 | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2-1-G-CC model output prepared for CMIP6 C4MIP esm-1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11719 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.11719
GISS-E2-1-G-CC | NASA-GISS | C4MIP | esm-ssp585 | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2-1-G-CC model output prepared for CMIP6 C4MIP esm-ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11727 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.11727
GISS-E2-1-G-CC | NASA-GISS | C4MIP | ssp585-bgc | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2-1-G-CC model output prepared for CMIP6 C4MIP ssp585-bgc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11890 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.11890
GISS-E2-1-G-CC | NASA-GISS | CMIP | esm-hist | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2-1-G-CC model output prepared for CMIP6 CMIP esm-hist. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11723 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.11723
GISS-E2-1-G-CC | NASA-GISS | CMIP | esm-piControl | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2-1-G-CC model output prepared for CMIP6 CMIP esm-piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11725 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.11725
GISS-E2-1-G-CC | NASA-GISS | CMIP | historical | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2-1-G-CC model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11762 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.11762
GISS-E2-1-G-CC | NASA-GISS | CMIP | piControl | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2-1-G-CC model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11856 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.11856
GISS-E2-1-G-CC | NASA-GISS | ScenarioMIP | ssp126 | NASA Goddard Institute for Space Studies (NASA/GISS) (2022). NASA-GISS GISS-E2-1-G-CC model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17630 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.17630
GISS-E2-1-G-CC | NASA-GISS | ScenarioMIP | ssp245 | NASA Goddard Institute for Space Studies (NASA/GISS) (2022). NASA-GISS GISS-E2-1-G-CC model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17631 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.17631
GISS-E2-1-G-CC | NASA-GISS | ScenarioMIP | ssp460 | NASA Goddard Institute for Space Studies (NASA/GISS) (2022). NASA-GISS GISS-E2-1-G-CC model output prepared for CMIP6 ScenarioMIP ssp460. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17634 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.17634
GISS-E2-1-G-CC | NASA-GISS | ScenarioMIP | ssp585 | NASA Goddard Institute for Space Studies (NASA/GISS) (2024). NASA-GISS GISS-E2-1-G-CC model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17636 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.17636
GISS-E2-1-H | NASA-GISS | AerChemMIP | ssp370-lowNTCF | NASA Goddard Institute for Space Studies (NASA/GISS) (2020). NASA-GISS GISS-E2.1H model output prepared for CMIP6 AerChemMIP ssp370-lowNTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.18079 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.18079
GISS-E2-1-H | NASA-GISS | CFMIP | abrupt-2xCO2 | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1H model output prepared for CMIP6 CFMIP abrupt-2xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13965 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.13965
GISS-E2-1-H | NASA-GISS | CMIP | 1pctCO2 | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1H model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6951 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.6951
GISS-E2-1-H | NASA-GISS | CMIP | abrupt-4xCO2 | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1H model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6977 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.6977
GISS-E2-1-H | NASA-GISS | CMIP | historical | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.1H model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7128 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7128
GISS-E2-1-H | NASA-GISS | CMIP | piControl | NASA Goddard Institute for Space Studies (NASA/GISS) (2018). NASA-GISS GISS-E2.1H model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7381 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7381
GISS-E2-1-H | NASA-GISS | ScenarioMIP | ssp119 | NASA Goddard Institute for Space Studies (NASA/GISS) (2020). NASA-GISS GISS-E2.1H model output prepared for CMIP6 ScenarioMIP ssp119. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7408 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7408
GISS-E2-1-H | NASA-GISS | ScenarioMIP | ssp126 | NASA Goddard Institute for Space Studies (NASA/GISS) (2020). NASA-GISS GISS-E2.1H model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7411 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7411
GISS-E2-1-H | NASA-GISS | ScenarioMIP | ssp245 | NASA Goddard Institute for Space Studies (NASA/GISS) (2020). NASA-GISS GISS-E2.1H model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7416 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7416
GISS-E2-1-H | NASA-GISS | ScenarioMIP | ssp370 | NASA Goddard Institute for Space Studies (NASA/GISS) (2020). NASA-GISS GISS-E2.1H model output prepared for CMIP6 ScenarioMIP ssp370. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7427 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7427
GISS-E2-1-H | NASA-GISS | ScenarioMIP | ssp434 | NASA Goddard Institute for Space Studies (NASA/GISS) (2020). NASA-GISS GISS-E2.1H model output prepared for CMIP6 ScenarioMIP ssp434. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7450 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7450
GISS-E2-1-H | NASA-GISS | ScenarioMIP | ssp460 | NASA Goddard Institute for Space Studies (NASA/GISS) (2020). NASA-GISS GISS-E2.1H model output prepared for CMIP6 ScenarioMIP ssp460. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7453 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7453
GISS-E2-1-H | NASA-GISS | ScenarioMIP | ssp534-over | NASA Goddard Institute for Space Studies (NASA/GISS) (2020). NASA-GISS GISS-E2.1H model output prepared for CMIP6 ScenarioMIP ssp534-over. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7456 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7456
GISS-E2-1-H | NASA-GISS | ScenarioMIP | ssp585 | NASA Goddard Institute for Space Studies (NASA/GISS) (2020). NASA-GISS GISS-E2.1H model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7461 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7461
GISS-E2-2-G | NASA-GISS | CFMIP | abrupt-2xCO2 | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2-2-G model output prepared for CMIP6 CFMIP abrupt-2xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11688 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.11688
GISS-E2-2-G | NASA-GISS | CMIP | 1pctCO2 | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2-2-G model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6952 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.6952
GISS-E2-2-G | NASA-GISS | CMIP | abrupt-4xCO2 | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2-2-G model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6978 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.6978
GISS-E2-2-G | NASA-GISS | CMIP | amip | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2-2-G model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6986 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.6986
GISS-E2-2-G | NASA-GISS | CMIP | historical | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2-2-G model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7129 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7129
GISS-E2-2-G | NASA-GISS | CMIP | piControl | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2-2-G model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7382 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7382
GISS-E2-2-G | NASA-GISS | DAMIP | hist-sol | NASA Goddard Institute for Space Studies (NASA/GISS) (2021). NASA-GISS GISS-E2-2-G model output prepared for CMIP6 DAMIP hist-sol. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11751 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.11751
GISS-E2-2-G | NASA-GISS | ScenarioMIP | ssp126 | NASA Goddard Institute for Space Studies (NASA/GISS) (2021). NASA-GISS GISS-E2-2-G model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11866 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.11866
GISS-E2-2-G | NASA-GISS | ScenarioMIP | ssp245 | NASA Goddard Institute for Space Studies (NASA/GISS) (2022). NASA-GISS GISS-E2-2-G model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11868 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.11868
GISS-E2-2-G | NASA-GISS | ScenarioMIP | ssp370 | NASA Goddard Institute for Space Studies (NASA/GISS) (2021). NASA-GISS GISS-E2-2-G model output prepared for CMIP6 ScenarioMIP ssp370. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11873 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.11873
GISS-E2-2-G | NASA-GISS | ScenarioMIP | ssp534-over | NASA Goddard Institute for Space Studies (NASA/GISS) (2022). NASA-GISS GISS-E2-2-G model output prepared for CMIP6 ScenarioMIP ssp534-over. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11887 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.11887
GISS-E2-2-G | NASA-GISS | ScenarioMIP | ssp585 | NASA Goddard Institute for Space Studies (NASA/GISS) (2021). NASA-GISS GISS-E2-2-G model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11889 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.11889
GISS-E2-2-H | NASA-GISS | CFMIP | abrupt-2xCO2 | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.2H model output prepared for CMIP6 CFMIP abrupt-2xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17605 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.17605
GISS-E2-2-H | NASA-GISS | CMIP | 1pctCO2 | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.2H model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15864 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.15864
GISS-E2-2-H | NASA-GISS | CMIP | abrupt-4xCO2 | NASA Goddard Institute for Space Studies (NASA/GISS) (2020). NASA-GISS GISS-E2.2H model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15865 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.15865
GISS-E2-2-H | NASA-GISS | CMIP | historical | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.2H model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15871 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.15871
GISS-E2-2-H | NASA-GISS | CMIP | piControl | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E2.2H model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15874 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.15874
GISS-E3-G | NASA-GISS | CMIP | 1pctCO2 | NASA Goddard Institute for Space Studies (NASA/GISS) (2022). NASA-GISS GISS-E3-G model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6953 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.6953
GISS-E3-G | NASA-GISS | CMIP | abrupt-4xCO2 | NASA Goddard Institute for Space Studies (NASA/GISS) (2022). NASA-GISS GISS-E3-G model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6979 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.6979
GISS-E3-G | NASA-GISS | CMIP | amip | NASA Goddard Institute for Space Studies (NASA/GISS) (2022). NASA-GISS GISS-E3-G model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6987 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.6987
GISS-E3-G | NASA-GISS | CMIP | historical | NASA Goddard Institute for Space Studies (NASA/GISS) (2022). NASA-GISS GISS-E3-G model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7130 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7130
GISS-E3-G | NASA-GISS | CMIP | piControl | NASA Goddard Institute for Space Studies (NASA/GISS) (2023). NASA-GISS GISS-E3-G model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7383 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7383
GISS-E3-G | NASA-GISS | RFMIP | rad-irf | NASA Goddard Institute for Space Studies (NASA/GISS) (2019). NASA-GISS GISS-E3-G model output prepared for CMIP6 RFMIP rad-irf. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7406 | CC0 1.0 | https://doi.org/10.22033/ESGF/CMIP6.7406
HadGEM3-GC31-HH | MOHC | HighResMIP | control-1950 | Roberts, Malcolm (2018). MOHC HadGEM3-GC31-HH model output prepared for CMIP6 HighResMIP control-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5881 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5881
HadGEM3-GC31-HH | MOHC | HighResMIP | highres-future | Roberts, Malcolm (2019). MOHC HadGEM3-GC31-HH model output prepared for CMIP6 HighResMIP highres-future. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5982 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5982
HadGEM3-GC31-HH | MOHC | HighResMIP | hist-1950 | Roberts, Malcolm (2021). MOHC HadGEM3-GC31-HH model output prepared for CMIP6 HighResMIP hist-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6038 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6038
HadGEM3-GC31-HH | NERC | HighResMIP | hist-1950 | Coward, Andrew; Roberts, Malcolm (2018). NERC HadGEM3-GC31-HH model output prepared for CMIP6 HighResMIP hist-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6039 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6039
HadGEM3-GC31-HM | MOHC | HighResMIP | control-1950 | Roberts, Malcolm (2018). MOHC HadGEM3-GC31-HM model output prepared for CMIP6 HighResMIP control-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5883 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5883
HadGEM3-GC31-HM | MOHC | HighResMIP | highres-future | Roberts, Malcolm (2019). MOHC HadGEM3-GC31-HM model output prepared for CMIP6 HighResMIP highres-future. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5984 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5984
HadGEM3-GC31-HM | MOHC | HighResMIP | highresSST-future | Roberts, Malcolm (2019). MOHC HadGEM3-GC31-HM model output prepared for CMIP6 HighResMIP highresSST-future. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6008 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6008
HadGEM3-GC31-HM | MOHC | HighResMIP | highresSST-present | Roberts, Malcolm (2017). MOHC HadGEM3-GC31-HM model output prepared for CMIP6 HighResMIP highresSST-present. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6024 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6024
HadGEM3-GC31-HM | MOHC | HighResMIP | hist-1950 | Roberts, Malcolm (2018). MOHC HadGEM3-GC31-HM model output prepared for CMIP6 HighResMIP hist-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6040 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6040
HadGEM3-GC31-HM | NERC | HighResMIP | highres-future | Schiemann, Reinhard et al. (2019). NERC HadGEM3-GC31-HM model output prepared for CMIP6 HighResMIP highres-future. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5985 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5985
HadGEM3-GC31-HM | NERC | HighResMIP | hist-1950 | Schiemann, Reinhard et al. (2019). NERC HadGEM3-GC31-HM model output prepared for CMIP6 HighResMIP hist-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6041 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6041
HadGEM3-GC31-LL | MOHC | CFMIP | a4SST | Webb, Mark (2020). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 CFMIP a4SST. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5830 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5830
HadGEM3-GC31-LL | MOHC | CFMIP | a4SSTice | Webb, Mark (2020). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 CFMIP a4SSTice. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5831 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5831
HadGEM3-GC31-LL | MOHC | CFMIP | a4SSTice-4xCO2 | Webb, Mark (2020). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 CFMIP a4SSTice-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5832 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5832
HadGEM3-GC31-LL | MOHC | CFMIP | abrupt-0p5xCO2 | Webb, Mark (2020). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 CFMIP abrupt-0p5xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5833 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5833
HadGEM3-GC31-LL | MOHC | CFMIP | abrupt-2xCO2 | Webb, Mark (2020). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 CFMIP abrupt-2xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5834 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5834
HadGEM3-GC31-LL | MOHC | CFMIP | abrupt-solp4p | Webb, Mark (2020). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 CFMIP abrupt-solp4p. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5848 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5848
HadGEM3-GC31-LL | MOHC | CFMIP | amip-4xCO2 | Webb, Mark (2019). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 CFMIP amip-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5861 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5861
HadGEM3-GC31-LL | MOHC | CFMIP | amip-a4SST-4xCO2 | Webb, Mark (2020). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 CFMIP amip-a4SST-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5864 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5864
HadGEM3-GC31-LL | MOHC | CFMIP | amip-future4K | Webb, Mark (2019). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 CFMIP amip-future4K. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5865 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5865
HadGEM3-GC31-LL | MOHC | CFMIP | amip-lwoff | Webb, Mark (2020). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 CFMIP amip-lwoff. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5871 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5871
HadGEM3-GC31-LL | MOHC | CFMIP | amip-m4K | Webb, Mark (2019). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 CFMIP amip-m4K. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5872 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5872
HadGEM3-GC31-LL | MOHC | CFMIP | amip-p4K | Webb, Mark (2019). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 CFMIP amip-p4K. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5873 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5873
HadGEM3-GC31-LL | MOHC | CFMIP | amip-p4K-lwoff | Webb, Mark (2020). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 CFMIP amip-p4K-lwoff. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5874 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5874
HadGEM3-GC31-LL | MOHC | CFMIP | amip-piForcing | Webb, Mark (2019). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 CFMIP amip-piForcing. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5875 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5875
HadGEM3-GC31-LL | MOHC | CFMIP | aqua-4xCO2 | Webb, Mark (2020). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 CFMIP aqua-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5876 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5876
HadGEM3-GC31-LL | MOHC | CFMIP | aqua-control | Webb, Mark (2020). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 CFMIP aqua-control. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5877 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5877
HadGEM3-GC31-LL | MOHC | CFMIP | aqua-control-lwoff | Webb, Mark (2020). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 CFMIP aqua-control-lwoff. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5878 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5878
HadGEM3-GC31-LL | MOHC | CFMIP | aqua-p4K | Webb, Mark (2020). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 CFMIP aqua-p4K. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5879 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5879
HadGEM3-GC31-LL | MOHC | CFMIP | aqua-p4K-lwoff | Webb, Mark (2020). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 CFMIP aqua-p4K-lwoff. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5880 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5880
HadGEM3-GC31-LL | MOHC | CFMIP | piSST | Webb, Mark (2020). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 CFMIP piSST. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6314 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6314
HadGEM3-GC31-LL | MOHC | CFMIP | piSST-4xCO2 | Webb, Mark (2020). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 CFMIP piSST-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6315 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6315
HadGEM3-GC31-LL | MOHC | CFMIP | piSST-4xCO2-rad | Webb, Mark (2020). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 CFMIP piSST-4xCO2-rad. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6316 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6316
HadGEM3-GC31-LL | MOHC | CFMIP | piSST-pxK | Webb, Mark (2020). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 CFMIP piSST-pxK. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6319 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6319
HadGEM3-GC31-LL | MOHC | CMIP | 1pctCO2 | Ridley, Jeff et al. (2019). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5788 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5788
HadGEM3-GC31-LL | MOHC | CMIP | abrupt-4xCO2 | Ridley, Jeff et al. (2019). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5839 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5839
HadGEM3-GC31-LL | MOHC | CMIP | amip | Ridley, Jeff et al. (2019). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5853 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5853
HadGEM3-GC31-LL | MOHC | CMIP | historical | Ridley, Jeff et al. (2019). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6109 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6109
HadGEM3-GC31-LL | MOHC | CMIP | piControl | Ridley, Jeff et al. (2018). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6294 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6294
HadGEM3-GC31-LL | MOHC | DAMIP | hist-GHG | Jones, Gareth (2019). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 DAMIP hist-GHG. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6051 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6051
HadGEM3-GC31-LL | MOHC | DAMIP | hist-aer | Jones, Gareth (2019). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 DAMIP hist-aer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6052 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6052
HadGEM3-GC31-LL | MOHC | DAMIP | hist-nat | Jones, Gareth (2019). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 DAMIP hist-nat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6059 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6059
HadGEM3-GC31-LL | MOHC | DAMIP | hist-sol | Jones, Gareth (2023). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 DAMIP hist-sol. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6072 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6072
HadGEM3-GC31-LL | MOHC | DAMIP | hist-totalO3 | Jones, Gareth (2023). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 DAMIP hist-totalO3. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12409 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12409
HadGEM3-GC31-LL | MOHC | DAMIP | hist-volc | Jones, Gareth (2023). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 DAMIP hist-volc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6076 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6076
HadGEM3-GC31-LL | MOHC | DAMIP | ssp245-GHG | Jones, Gareth (2020). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 DAMIP ssp245-GHG. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6343 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6343
HadGEM3-GC31-LL | MOHC | HighResMIP | control-1950 | Roberts, Malcolm (2017). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 HighResMIP control-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5885 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5885
HadGEM3-GC31-LL | MOHC | HighResMIP | highres-future | Roberts, Malcolm (2018). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 HighResMIP highres-future. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5986 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5986
HadGEM3-GC31-LL | MOHC | HighResMIP | hist-1950 | Roberts, Malcolm (2017). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 HighResMIP hist-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6042 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6042
HadGEM3-GC31-LL | MOHC | HighResMIP | spinup-1950 | Roberts, Malcolm (2017). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 HighResMIP spinup-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6325 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6325
HadGEM3-GC31-LL | MOHC | LS3MIP | land-hist-cruNcep | Wiltshire, Andy et al. (2020). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 LS3MIP land-hist-cruNcep. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14504 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14504
HadGEM3-GC31-LL | MOHC | LUMIP | land-hist | Wiltshire, Andy et al. (2020). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 LUMIP land-hist. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14496 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14496
HadGEM3-GC31-LL | MOHC | LUMIP | land-noLu | Wiltshire, Andy et al. (2020). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 LUMIP land-noLu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14518 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14518
HadGEM3-GC31-LL | MOHC | RFMIP | piClim-4xCO2 | Andrews, Tim (2019). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 RFMIP piClim-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6224 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6224
HadGEM3-GC31-LL | MOHC | RFMIP | piClim-aer | Andrews, Tim (2019). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 RFMIP piClim-aer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6269 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6269
HadGEM3-GC31-LL | MOHC | RFMIP | piClim-anthro | Andrews, Tim (2019). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 RFMIP piClim-anthro. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6274 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6274
HadGEM3-GC31-LL | MOHC | RFMIP | piClim-control | Andrews, Tim (2019). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 RFMIP piClim-control. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6275 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6275
HadGEM3-GC31-LL | MOHC | RFMIP | piClim-ghg | Andrews, Tim (2019). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 RFMIP piClim-ghg. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6280 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6280
HadGEM3-GC31-LL | MOHC | RFMIP | piClim-histaer | Andrews, Tim (2020). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 RFMIP piClim-histaer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6281 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6281
HadGEM3-GC31-LL | MOHC | RFMIP | piClim-histall | Andrews, Tim (2020). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 RFMIP piClim-histall. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6282 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6282
HadGEM3-GC31-LL | MOHC | RFMIP | piClim-histghg | Andrews, Tim (2020). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 RFMIP piClim-histghg. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6283 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6283
HadGEM3-GC31-LL | MOHC | RFMIP | piClim-histnat | Andrews, Tim (2020). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 RFMIP piClim-histnat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6284 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6284
HadGEM3-GC31-LL | MOHC | RFMIP | piClim-lu | Andrews, Tim (2019). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 RFMIP piClim-lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6285 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6285
HadGEM3-GC31-LL | MOHC | RFMIP | rad-irf | Andrews, Tim (2019). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 RFMIP rad-irf. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6320 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6320
HadGEM3-GC31-LL | MOHC | ScenarioMIP | ssp126 | Good, Peter (2020). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10849 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10849
HadGEM3-GC31-LL | MOHC | ScenarioMIP | ssp245 | Good, Peter (2019). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10851 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10851
HadGEM3-GC31-LL | MOHC | ScenarioMIP | ssp585 | Good, Peter (2020). MOHC HadGEM3-GC31-LL model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10901 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10901
HadGEM3-GC31-LL | NERC | FAFMIP | faf-all | Gregory, Jonathan M. (2021). NERC HadGEM3-GC31-LL model output prepared for CMIP6 FAFMIP faf-all. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12098 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12098
HadGEM3-GC31-LL | NERC | FAFMIP | faf-heat | Gregory, Jonathan M. (2021). NERC HadGEM3-GC31-LL model output prepared for CMIP6 FAFMIP faf-heat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12100 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12100
HadGEM3-GC31-LL | NERC | FAFMIP | faf-heat-NA0pct | Gregory, Jonathan M. (2021). NERC HadGEM3-GC31-LL model output prepared for CMIP6 FAFMIP faf-heat-NA0pct. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12101 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12101
HadGEM3-GC31-LL | NERC | FAFMIP | faf-heat-NA50pct | Gregory, Jonathan M. (2021). NERC HadGEM3-GC31-LL model output prepared for CMIP6 FAFMIP faf-heat-NA50pct. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12102 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12102
HadGEM3-GC31-LL | NERC | FAFMIP | faf-passiveheat | Gregory, Jonathan M. (2021). NERC HadGEM3-GC31-LL model output prepared for CMIP6 FAFMIP faf-passiveheat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12103 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12103
HadGEM3-GC31-LL | NERC | FAFMIP | faf-stress | Gregory, Jonathan M. (2021). NERC HadGEM3-GC31-LL model output prepared for CMIP6 FAFMIP faf-stress. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12104 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12104
HadGEM3-GC31-LL | NERC | FAFMIP | faf-water | Gregory, Jonathan M. (2021). NERC HadGEM3-GC31-LL model output prepared for CMIP6 FAFMIP faf-water. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12105 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12105
HadGEM3-GC31-LL | NERC | PMIP | lig127k | Williams, Charlie et al. (2021). NERC HadGEM3-GC31-LL model output prepared for CMIP6 PMIP lig127k. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12128 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12128
HadGEM3-GC31-LL | NERC | PMIP | midHolocene | Williams, Charlie et al. (2021). NERC HadGEM3-GC31-LL model output prepared for CMIP6 PMIP midHolocene. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12129 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12129
HadGEM3-GC31-LL | NERC | PMIP | midPliocene-eoi400 | Williams, Charlie et al. (2020). NERC HadGEM3-GC31-LL model output prepared for CMIP6 PMIP midPliocene-eoi400. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12130 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12130
HadGEM3-GC31-LM | MOHC | HighResMIP | highresSST-future | Roberts, Malcolm (2019). MOHC HadGEM3-GC31-LM model output prepared for CMIP6 HighResMIP highresSST-future. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6011 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6011
HadGEM3-GC31-LM | MOHC | HighResMIP | highresSST-present | Roberts, Malcolm (2017). MOHC HadGEM3-GC31-LM model output prepared for CMIP6 HighResMIP highresSST-present. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6027 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6027
HadGEM3-GC31-MH | MOHC | HighResMIP | hist-1950 | Roberts, Malcolm (2021). MOHC HadGEM3-GC31-MH model output prepared for CMIP6 HighResMIP hist-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6044 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6044
HadGEM3-GC31-MH | MOHC | HighResMIP | spinup-1950 | Roberts, Malcolm (2017). MOHC HadGEM3-GC31-MH model output prepared for CMIP6 HighResMIP spinup-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6327 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6327
HadGEM3-GC31-MM | MOHC | CMIP | 1pctCO2 | Ridley, Jeff et al. (2020). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5791 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5791
HadGEM3-GC31-MM | MOHC | CMIP | abrupt-4xCO2 | Ridley, Jeff et al. (2020). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5842 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5842
HadGEM3-GC31-MM | MOHC | CMIP | amip | Ridley, Jeff et al. (2019). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5856 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5856
HadGEM3-GC31-MM | MOHC | CMIP | historical | Ridley, Jeff et al. (2019). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6112 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6112
HadGEM3-GC31-MM | MOHC | CMIP | piControl | Ridley, Jeff et al. (2019). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6297 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6297
HadGEM3-GC31-MM | MOHC | DCPP | dcppA-assim | Hermanson, Leon (2022). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 DCPP dcppA-assim. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5891 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5891
HadGEM3-GC31-MM | MOHC | DCPP | dcppA-hindcast | Hermanson, Leon (2020). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 DCPP dcppA-hindcast. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5892 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5892
HadGEM3-GC31-MM | MOHC | DCPP | dcppB-forecast | Hermanson, Leon (2020). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 DCPP dcppB-forecast. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5895 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5895
HadGEM3-GC31-MM | MOHC | DCPP | dcppC-amv-ExTrop-neg | Hermanson, Leon (2021). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 DCPP dcppC-amv-ExTrop-neg. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5896 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5896
HadGEM3-GC31-MM | MOHC | DCPP | dcppC-amv-ExTrop-pos | Hermanson, Leon (2021). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 DCPP dcppC-amv-ExTrop-pos. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5897 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5897
HadGEM3-GC31-MM | MOHC | DCPP | dcppC-amv-Trop-neg | Hermanson, Leon (2021). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 DCPP dcppC-amv-Trop-neg. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5898 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5898
HadGEM3-GC31-MM | MOHC | DCPP | dcppC-amv-Trop-pos | Hermanson, Leon (2021). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 DCPP dcppC-amv-Trop-pos. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5899 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5899
HadGEM3-GC31-MM | MOHC | DCPP | dcppC-amv-neg | Hermanson, Leon (2020). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 DCPP dcppC-amv-neg. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5900 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5900
HadGEM3-GC31-MM | MOHC | DCPP | dcppC-amv-pos | Hermanson, Leon (2020). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 DCPP dcppC-amv-pos. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5901 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5901
HadGEM3-GC31-MM | MOHC | DCPP | dcppC-atl-control | Hermanson, Leon (2020). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 DCPP dcppC-atl-control. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5902 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5902
HadGEM3-GC31-MM | MOHC | DCPP | dcppC-forecast-addAgung | Hermanson, Leon (2020). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 DCPP dcppC-forecast-addAgung. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5905 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5905
HadGEM3-GC31-MM | MOHC | DCPP | dcppC-forecast-addElChichon | Hermanson, Leon (2020). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 DCPP dcppC-forecast-addElChichon. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5906 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5906
HadGEM3-GC31-MM | MOHC | DCPP | dcppC-forecast-addPinatubo | Hermanson, Leon (2020). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 DCPP dcppC-forecast-addPinatubo. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5907 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5907
HadGEM3-GC31-MM | MOHC | DCPP | dcppC-hindcast-noAgung | Hermanson, Leon (2020). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 DCPP dcppC-hindcast-noAgung. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5910 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5910
HadGEM3-GC31-MM | MOHC | DCPP | dcppC-hindcast-noElChichon | Hermanson, Leon (2020). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 DCPP dcppC-hindcast-noElChichon. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5911 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5911
HadGEM3-GC31-MM | MOHC | DCPP | dcppC-hindcast-noPinatubo | Hermanson, Leon (2020). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 DCPP dcppC-hindcast-noPinatubo. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5912 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5912
HadGEM3-GC31-MM | MOHC | DCPP | dcppC-ipv-NexTrop-neg | Hermanson, Leon (2021). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 DCPP dcppC-ipv-NexTrop-neg. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5913 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5913
HadGEM3-GC31-MM | MOHC | DCPP | dcppC-ipv-NexTrop-pos | Hermanson, Leon (2021). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 DCPP dcppC-ipv-NexTrop-pos. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5914 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5914
HadGEM3-GC31-MM | MOHC | DCPP | dcppC-ipv-neg | Hermanson, Leon (2021). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 DCPP dcppC-ipv-neg. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5915 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5915
HadGEM3-GC31-MM | MOHC | DCPP | dcppC-ipv-pos | Hermanson, Leon (2021). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 DCPP dcppC-ipv-pos. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5916 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5916
HadGEM3-GC31-MM | MOHC | DCPP | dcppC-pac-control | Hermanson, Leon (2021). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 DCPP dcppC-pac-control. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5917 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5917
HadGEM3-GC31-MM | MOHC | HighResMIP | control-1950 | Roberts, Malcolm (2017). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 HighResMIP control-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5888 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5888
HadGEM3-GC31-MM | MOHC | HighResMIP | highres-future | Roberts, Malcolm (2019). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 HighResMIP highres-future. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5989 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5989
HadGEM3-GC31-MM | MOHC | HighResMIP | highresSST-future | Roberts, Malcolm (2019). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 HighResMIP highresSST-future. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6013 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6013
HadGEM3-GC31-MM | MOHC | HighResMIP | highresSST-present | Roberts, Malcolm (2017). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 HighResMIP highresSST-present. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6029 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6029
HadGEM3-GC31-MM | MOHC | HighResMIP | hist-1950 | Roberts, Malcolm (2017). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 HighResMIP hist-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6045 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6045
HadGEM3-GC31-MM | MOHC | HighResMIP | spinup-1950 | Roberts, Malcolm (2017). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 HighResMIP spinup-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6328 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6328
HadGEM3-GC31-MM | MOHC | PAMIP | futSST-pdSIC | Eade, Rosie (2020). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 PAMIP futSST-pdSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14630 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14630
HadGEM3-GC31-MM | MOHC | PAMIP | modelSST-futArcSIC | Eade, Rosie (2021). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 PAMIP modelSST-futArcSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14631 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14631
HadGEM3-GC31-MM | MOHC | PAMIP | modelSST-pdSIC | Eade, Rosie (2021). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 PAMIP modelSST-pdSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14632 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14632
HadGEM3-GC31-MM | MOHC | PAMIP | pa-futAntSIC | Eade, Rosie (2021). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 PAMIP pa-futAntSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14633 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14633
HadGEM3-GC31-MM | MOHC | PAMIP | pa-futArcSIC | Eade, Rosie (2020). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 PAMIP pa-futArcSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14635 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14635
HadGEM3-GC31-MM | MOHC | PAMIP | pa-pdSIC | Eade, Rosie (2020). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 PAMIP pa-pdSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14637 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14637
HadGEM3-GC31-MM | MOHC | PAMIP | pa-piAntSIC | Eade, Rosie (2021). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 PAMIP pa-piAntSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14639 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14639
HadGEM3-GC31-MM | MOHC | PAMIP | pa-piArcSIC | Eade, Rosie (2021). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 PAMIP pa-piArcSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14640 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14640
HadGEM3-GC31-MM | MOHC | PAMIP | pdSST-futAntSIC | Eade, Rosie (2021). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 PAMIP pdSST-futAntSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14641 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14641
HadGEM3-GC31-MM | MOHC | PAMIP | pdSST-futArcSIC | Eade, Rosie (2020). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 PAMIP pdSST-futArcSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14642 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14642
HadGEM3-GC31-MM | MOHC | PAMIP | pdSST-futBKSeasSIC | Eade, Rosie (2020). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 PAMIP pdSST-futBKSeasSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14644 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14644
HadGEM3-GC31-MM | MOHC | PAMIP | pdSST-futOkhotskSIC | Eade, Rosie (2020). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 PAMIP pdSST-futOkhotskSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14645 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14645
HadGEM3-GC31-MM | MOHC | PAMIP | pdSST-pdSIC | Eade, Rosie (2020). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 PAMIP pdSST-pdSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14646 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14646
HadGEM3-GC31-MM | MOHC | PAMIP | pdSST-piAntSIC | Eade, Rosie (2021). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 PAMIP pdSST-piAntSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14648 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14648
HadGEM3-GC31-MM | MOHC | PAMIP | pdSST-piArcSIC | Eade, Rosie (2020). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 PAMIP pdSST-piArcSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14649 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14649
HadGEM3-GC31-MM | MOHC | PAMIP | piSST-pdSIC | Eade, Rosie (2021). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 PAMIP piSST-pdSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14650 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14650
HadGEM3-GC31-MM | MOHC | PAMIP | piSST-piSIC | Eade, Rosie (2021). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 PAMIP piSST-piSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14651 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14651
HadGEM3-GC31-MM | MOHC | ScenarioMIP | ssp126 | Jackson, Laura (2020). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10850 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10850
HadGEM3-GC31-MM | MOHC | ScenarioMIP | ssp585 | Jackson, Laura (2020). MOHC HadGEM3-GC31-MM model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10902 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10902
HiRAM-SIT-HR | AS-RCEC | HighResMIP | highres-future | Tu, Chia-Ying (2021). AS-RCEC HiRAM-SIT-HR model output prepared for CMIP6 HighResMIP highres-future. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13337 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13337
HiRAM-SIT-HR | AS-RCEC | HighResMIP | highresSST-future | Tu, Chia-Ying (2021). AS-RCEC HiRAM-SIT-HR model output prepared for CMIP6 HighResMIP highresSST-future. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13343 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13343
HiRAM-SIT-HR | AS-RCEC | HighResMIP | highresSST-present | Tu, Chia-Ying (2020). AS-RCEC HiRAM-SIT-HR model output prepared for CMIP6 HighResMIP highresSST-present. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13347 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13347
HiRAM-SIT-HR | AS-RCEC | HighResMIP | hist-1950 | Tu, Chia-Ying (2021). AS-RCEC HiRAM-SIT-HR model output prepared for CMIP6 HighResMIP hist-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13351 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13351
HiRAM-SIT-LR | AS-RCEC | HighResMIP | highres-future | Tu, Chia-Ying (2021). AS-RCEC HiRAM-SIT-LR model output prepared for CMIP6 HighResMIP highres-future. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13338 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13338
HiRAM-SIT-LR | AS-RCEC | HighResMIP | highresSST-future | Tu, Chia-Ying (2021). AS-RCEC HiRAM-SIT-LR model output prepared for CMIP6 HighResMIP highresSST-future. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13344 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13344
HiRAM-SIT-LR | AS-RCEC | HighResMIP | highresSST-present | Tu, Chia-Ying (2020). AS-RCEC HiRAM-SIT-LR model output prepared for CMIP6 HighResMIP highresSST-present. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13348 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13348
HiRAM-SIT-LR | AS-RCEC | HighResMIP | hist-1950 | Tu, Chia-Ying (2021). AS-RCEC HiRAM-SIT-LR model output prepared for CMIP6 HighResMIP hist-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13352 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13352
ICON-ESM-LR | MPI-M | CMIP | 1pctCO2 | Lorenz, Stephan et al. (2021). MPI-M ICON-ESM-LR model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6433 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6433
ICON-ESM-LR | MPI-M | CMIP | abrupt-4xCO2 | Lorenz, Stephan et al. (2021). MPI-M ICON-ESM-LR model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6457 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6457
ICON-ESM-LR | MPI-M | CMIP | amip | Lorenz, Stephan et al. (2022). MPI-M ICON-ESM-LR model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6462 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6462
ICON-ESM-LR | MPI-M | CMIP | historical | Lorenz, Stephan et al. (2021). MPI-M ICON-ESM-LR model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6593 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6593
ICON-ESM-LR | MPI-M | CMIP | piControl | Lorenz, Stephan et al. (2021). MPI-M ICON-ESM-LR model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6673 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6673
IITM-ESM | CCCR-IITM | CMIP | 1pctCO2 | Narayanasetti, Sandeep et al. (2019). CCCR-IITM IITM-ESM model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3515 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3515
IITM-ESM | CCCR-IITM | CMIP | abrupt-4xCO2 | Gopinathan, Prajeesh A. et al. (2019). CCCR-IITM IITM-ESM model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3516 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3516
IITM-ESM | CCCR-IITM | CMIP | amip | Raghavan, Krishnan et al. (2020). CCCR-IITM IITM-ESM model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3517 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3517
IITM-ESM | CCCR-IITM | CMIP | historical | Choudhury, Ayantika Dey et al. (2019). CCCR-IITM IITM-ESM model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3708 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3708
IITM-ESM | CCCR-IITM | CMIP | piControl | Narayanasetti, Sandeep et al. (2019). CCCR-IITM IITM-ESM model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3710 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3710
IITM-ESM | CCCR-IITM | GMMIP | amip-hist | Modi, Aditi et al. (2019). CCCR-IITM IITM-ESM model output prepared for CMIP6 GMMIP amip-hist. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.3520 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.3520
IITM-ESM | CCCR-IITM | ScenarioMIP | ssp126 | Narayanasetti, Sandeep et al. (2020). CCCR-IITM IITM-ESM model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14747 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14747
IITM-ESM | CCCR-IITM | ScenarioMIP | ssp245 | Singh, Manmeet et al. (2020). CCCR-IITM IITM-ESM model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14748 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14748
IITM-ESM | CCCR-IITM | ScenarioMIP | ssp370 | Gopinathan, Prajeesh A. et al. (2020). CCCR-IITM IITM-ESM model output prepared for CMIP6 ScenarioMIP ssp370. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14749 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14749
IITM-ESM | CCCR-IITM | ScenarioMIP | ssp585 | Panickal, Swapna et al. (2020). CCCR-IITM IITM-ESM model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14753 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14753
INM-CM4-8 | INM | CMIP | 1pctCO2 | Volodin, Evgeny et al. (2019). INM INM-CM4-8 model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4928 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4928
INM-CM4-8 | INM | CMIP | abrupt-4xCO2 | Volodin, Evgeny et al. (2019). INM INM-CM4-8 model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4931 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4931
INM-CM4-8 | INM | CMIP | amip | Volodin, Evgeny et al. (2019). INM INM-CM4-8 model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4934 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4934
INM-CM4-8 | INM | CMIP | historical | Volodin, Evgeny et al. (2019). INM INM-CM4-8 model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5069 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5069
INM-CM4-8 | INM | CMIP | piControl | Volodin, Evgeny et al. (2019). INM INM-CM4-8 model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5080 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5080
INM-CM4-8 | INM | PMIP | lgm | Volodin, Evgeny et al. (2019). INM INM-CM4-8 model output prepared for CMIP6 PMIP lgm. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5075 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5075
INM-CM4-8 | INM | PMIP | lig127k | Volodin, Evgeny et al. (2019). INM INM-CM4-8 model output prepared for CMIP6 PMIP lig127k. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5076 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5076
INM-CM4-8 | INM | PMIP | midHolocene | Volodin, Evgeny et al. (2019). INM INM-CM4-8 model output prepared for CMIP6 PMIP midHolocene. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5077 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5077
INM-CM4-8 | INM | PMIP | past1000 | Volodin, Evgeny et al. (2022). INM INM-CM4-8 model output prepared for CMIP6 PMIP past1000. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5079 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5079
INM-CM4-8 | INM | ScenarioMIP | ssp126 | Volodin, Evgeny et al. (2019). INM INM-CM4-8 model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12325 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12325
INM-CM4-8 | INM | ScenarioMIP | ssp245 | Volodin, Evgeny et al. (2019). INM INM-CM4-8 model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12327 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12327
INM-CM4-8 | INM | ScenarioMIP | ssp370 | Volodin, Evgeny et al. (2019). INM INM-CM4-8 model output prepared for CMIP6 ScenarioMIP ssp370. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12329 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12329
INM-CM4-8 | INM | ScenarioMIP | ssp585 | Volodin, Evgeny et al. (2019). INM INM-CM4-8 model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12337 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12337
INM-CM5-0 | INM | CMIP | 1pctCO2 | Volodin, Evgeny et al. (2019). INM INM-CM5-0 model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4929 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4929
INM-CM5-0 | INM | CMIP | abrupt-4xCO2 | Volodin, Evgeny et al. (2019). INM INM-CM5-0 model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4932 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4932
INM-CM5-0 | INM | CMIP | amip | Volodin, Evgeny et al. (2019). INM INM-CM5-0 model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4935 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4935
INM-CM5-0 | INM | CMIP | historical | Volodin, Evgeny et al. (2019). INM INM-CM5-0 model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5070 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5070
INM-CM5-0 | INM | CMIP | piControl | Volodin, Evgeny et al. (2019). INM INM-CM5-0 model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5081 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5081
INM-CM5-0 | INM | ScenarioMIP | ssp126 | Volodin, Evgeny et al. (2019). INM INM-CM5-0 model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12326 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12326
INM-CM5-0 | INM | ScenarioMIP | ssp245 | Volodin, Evgeny et al. (2019). INM INM-CM5-0 model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12328 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12328
INM-CM5-0 | INM | ScenarioMIP | ssp370 | Volodin, Evgeny et al. (2019). INM INM-CM5-0 model output prepared for CMIP6 ScenarioMIP ssp370. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12330 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12330
INM-CM5-0 | INM | ScenarioMIP | ssp585 | Volodin, Evgeny et al. (2019). INM INM-CM5-0 model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12338 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12338
INM-CM5-H | INM | HighResMIP | control-1950 | Volodin, Evgeny et al. (2019). INM INM-CM5-H model output prepared for CMIP6 HighResMIP control-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14042 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14042
INM-CM5-H | INM | HighResMIP | highresSST-present | Volodin, Evgeny et al. (2019). INM INM-CM5-H model output prepared for CMIP6 HighResMIP highresSST-present. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14048 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14048
INM-CM5-H | INM | HighResMIP | hist-1950 | Volodin, Evgeny et al. (2019). INM INM-CM5-H model output prepared for CMIP6 HighResMIP hist-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14050 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14050
IPSL-CM5A2-INCA | IPSL | AerChemMIP | ssp370-lowNTCF | Boucher, Olivier et al. (2021). IPSL IPSL-CM5A2-INCA model output prepared for CMIP6 AerChemMIP ssp370-lowNTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13688 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13688
IPSL-CM5A2-INCA | IPSL | AerChemMIP | ssp370-lowNTCFCH4 | Boucher, Olivier et al. (2021). IPSL IPSL-CM5A2-INCA model output prepared for CMIP6 AerChemMIP ssp370-lowNTCFCH4. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13689 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13689
IPSL-CM5A2-INCA | IPSL | CMIP | 1pctCO2 | Boucher, Olivier et al. (2020). IPSL IPSL-CM5A2-INCA model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13643 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13643
IPSL-CM5A2-INCA | IPSL | CMIP | abrupt-4xCO2 | Boucher, Olivier et al. (2020). IPSL IPSL-CM5A2-INCA model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13644 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13644
IPSL-CM5A2-INCA | IPSL | CMIP | historical | Boucher, Olivier et al. (2020). IPSL IPSL-CM5A2-INCA model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13661 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13661
IPSL-CM5A2-INCA | IPSL | CMIP | piControl | Boucher, Olivier et al. (2021). IPSL IPSL-CM5A2-INCA model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13683 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13683
IPSL-CM5A2-INCA | IPSL | LUMIP | ssp370-ssp126Lu | Boucher, Olivier et al. (2020). IPSL IPSL-CM5A2-INCA model output prepared for CMIP6 LUMIP ssp370-ssp126Lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15715 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15715
IPSL-CM5A2-INCA | IPSL | ScenarioMIP | ssp126 | Boucher, Olivier et al. (2020). IPSL IPSL-CM5A2-INCA model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15711 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15711
IPSL-CM5A2-INCA | IPSL | ScenarioMIP | ssp370 | Boucher, Olivier et al. (2020). IPSL IPSL-CM5A2-INCA model output prepared for CMIP6 ScenarioMIP ssp370. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15714 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15714
IPSL-CM6A-ATM-HR | IPSL | HighResMIP | highresSST-present | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-ATM-HR model output prepared for CMIP6 HighResMIP highresSST-present. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5185 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5185
IPSL-CM6A-ATM-ICO-HR | IPSL | HighResMIP | highresSST-present | Boucher, Olivier et al. (2022). IPSL IPSL-CM6A-ATM-ICO-HR model output prepared for CMIP6 HighResMIP highresSST-present. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16433 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16433
IPSL-CM6A-ATM-ICO-LR | IPSL | HighResMIP | highresSST-present | Boucher, Olivier et al. (2022). IPSL IPSL-CM6A-ATM-ICO-LR model output prepared for CMIP6 HighResMIP highresSST-present. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16434 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16434
IPSL-CM6A-ATM-ICO-MR | IPSL | HighResMIP | highresSST-present | Boucher, Olivier et al. (2022). IPSL IPSL-CM6A-ATM-ICO-MR model output prepared for CMIP6 HighResMIP highresSST-present. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16435 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16435
IPSL-CM6A-ATM-ICO-VHR | IPSL | HighResMIP | highresSST-present | Boucher, Olivier et al. (2022). IPSL IPSL-CM6A-ATM-ICO-VHR model output prepared for CMIP6 HighResMIP highresSST-present. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16436 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16436
IPSL-CM6A-ATM-LR-REPROBUS | IPSL | AerChemMIP | histSST-piNTCF | Boucher, Olivier et al. (2024). IPSL IPSL-CM6A-ATM-LR-REPROBUS model output prepared for CMIP6 AerChemMIP histSST-piNTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16599 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16599
IPSL-CM6A-LR | IPSL | AerChemMIP | hist-piAer | Boucher, Olivier et al. (2021). IPSL IPSL-CM6A-LR model output prepared for CMIP6 AerChemMIP hist-piAer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17799 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17799
IPSL-CM6A-LR | IPSL | C4MIP | 1pctCO2-bgc | Boucher, Olivier et al. (2018). IPSL IPSL-CM6A-LR model output prepared for CMIP6 C4MIP 1pctCO2-bgc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5050 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5050
IPSL-CM6A-LR | IPSL | C4MIP | 1pctCO2-rad | Boucher, Olivier et al. (2018). IPSL IPSL-CM6A-LR model output prepared for CMIP6 C4MIP 1pctCO2-rad. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5051 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5051
IPSL-CM6A-LR | IPSL | CFMIP | a4SST | Boucher, Olivier et al. (2020). IPSL IPSL-CM6A-LR model output prepared for CMIP6 CFMIP a4SST. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5103 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5103
IPSL-CM6A-LR | IPSL | CFMIP | a4SSTice | Boucher, Olivier et al. (2020). IPSL IPSL-CM6A-LR model output prepared for CMIP6 CFMIP a4SSTice. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5104 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5104
IPSL-CM6A-LR | IPSL | CFMIP | a4SSTice-4xCO2 | Boucher, Olivier et al. (2020). IPSL IPSL-CM6A-LR model output prepared for CMIP6 CFMIP a4SSTice-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5105 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5105
IPSL-CM6A-LR | IPSL | CFMIP | abrupt-0p5xCO2 | Boucher, Olivier et al. (2018). IPSL IPSL-CM6A-LR model output prepared for CMIP6 CFMIP abrupt-0p5xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5106 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5106
IPSL-CM6A-LR | IPSL | CFMIP | abrupt-2xCO2 | Boucher, Olivier et al. (2018). IPSL IPSL-CM6A-LR model output prepared for CMIP6 CFMIP abrupt-2xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5107 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5107
IPSL-CM6A-LR | IPSL | CFMIP | abrupt-solm4p | Boucher, Olivier et al. (2018). IPSL IPSL-CM6A-LR model output prepared for CMIP6 CFMIP abrupt-solm4p. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5110 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5110
IPSL-CM6A-LR | IPSL | CFMIP | abrupt-solp4p | Boucher, Olivier et al. (2018). IPSL IPSL-CM6A-LR model output prepared for CMIP6 CFMIP abrupt-solp4p. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5111 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5111
IPSL-CM6A-LR | IPSL | CFMIP | amip-4xCO2 | Boucher, Olivier et al. (2018). IPSL IPSL-CM6A-LR model output prepared for CMIP6 CFMIP amip-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5114 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5114
IPSL-CM6A-LR | IPSL | CFMIP | amip-a4SST-4xCO2 | Boucher, Olivier et al. (2020). IPSL IPSL-CM6A-LR model output prepared for CMIP6 CFMIP amip-a4SST-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5117 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5117
IPSL-CM6A-LR | IPSL | CFMIP | amip-future4K | Boucher, Olivier et al. (2018). IPSL IPSL-CM6A-LR model output prepared for CMIP6 CFMIP amip-future4K. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5118 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5118
IPSL-CM6A-LR | IPSL | CFMIP | amip-lwoff | Boucher, Olivier et al. (2018). IPSL IPSL-CM6A-LR model output prepared for CMIP6 CFMIP amip-lwoff. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5124 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5124
IPSL-CM6A-LR | IPSL | CFMIP | amip-m4K | Boucher, Olivier et al. (2018). IPSL IPSL-CM6A-LR model output prepared for CMIP6 CFMIP amip-m4K. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5125 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5125
IPSL-CM6A-LR | IPSL | CFMIP | amip-p4K | Boucher, Olivier et al. (2018). IPSL IPSL-CM6A-LR model output prepared for CMIP6 CFMIP amip-p4K. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5126 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5126
IPSL-CM6A-LR | IPSL | CFMIP | amip-p4K-lwoff | Boucher, Olivier et al. (2018). IPSL IPSL-CM6A-LR model output prepared for CMIP6 CFMIP amip-p4K-lwoff. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5127 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5127
IPSL-CM6A-LR | IPSL | CFMIP | amip-piForcing | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 CFMIP amip-piForcing. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5128 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5128
IPSL-CM6A-LR | IPSL | CFMIP | aqua-4xCO2 | Boucher, Olivier et al. (2018). IPSL IPSL-CM6A-LR model output prepared for CMIP6 CFMIP aqua-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5129 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5129
IPSL-CM6A-LR | IPSL | CFMIP | aqua-control | Boucher, Olivier et al. (2018). IPSL IPSL-CM6A-LR model output prepared for CMIP6 CFMIP aqua-control. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5130 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5130
IPSL-CM6A-LR | IPSL | CFMIP | aqua-control-lwoff | Boucher, Olivier et al. (2018). IPSL IPSL-CM6A-LR model output prepared for CMIP6 CFMIP aqua-control-lwoff. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5131 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5131
IPSL-CM6A-LR | IPSL | CFMIP | aqua-p4K | Boucher, Olivier et al. (2018). IPSL IPSL-CM6A-LR model output prepared for CMIP6 CFMIP aqua-p4K. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5132 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5132
IPSL-CM6A-LR | IPSL | CFMIP | aqua-p4K-lwoff | Boucher, Olivier et al. (2018). IPSL IPSL-CM6A-LR model output prepared for CMIP6 CFMIP aqua-p4K-lwoff. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5133 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5133
IPSL-CM6A-LR | IPSL | CFMIP | piSST | Boucher, Olivier et al. (2020). IPSL IPSL-CM6A-LR model output prepared for CMIP6 CFMIP piSST. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5254 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5254
IPSL-CM6A-LR | IPSL | CFMIP | piSST-4xCO2 | Boucher, Olivier et al. (2020). IPSL IPSL-CM6A-LR model output prepared for CMIP6 CFMIP piSST-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5255 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5255
IPSL-CM6A-LR | IPSL | CFMIP | piSST-4xCO2-rad | Boucher, Olivier et al. (2020). IPSL IPSL-CM6A-LR model output prepared for CMIP6 CFMIP piSST-4xCO2-rad. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5256 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5256
IPSL-CM6A-LR | IPSL | CFMIP | piSST-pxK | Boucher, Olivier et al. (2020). IPSL IPSL-CM6A-LR model output prepared for CMIP6 CFMIP piSST-pxK. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5258 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5258
IPSL-CM6A-LR | IPSL | CMIP | 1pctCO2 | Boucher, Olivier et al. (2018). IPSL IPSL-CM6A-LR model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5049 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5049
IPSL-CM6A-LR | IPSL | CMIP | abrupt-4xCO2 | Boucher, Olivier et al. (2018). IPSL IPSL-CM6A-LR model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5109 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5109
IPSL-CM6A-LR | IPSL | CMIP | amip | Boucher, Olivier et al. (2018). IPSL IPSL-CM6A-LR model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5113 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5113
IPSL-CM6A-LR | IPSL | CMIP | historical | Boucher, Olivier et al. (2018). IPSL IPSL-CM6A-LR model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5195 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5195
IPSL-CM6A-LR | IPSL | CMIP | piControl | Boucher, Olivier et al. (2018). IPSL IPSL-CM6A-LR model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5251 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5251
IPSL-CM6A-LR | IPSL | CMIP | piControl-spinup | Boucher, Olivier et al. (2018). IPSL IPSL-CM6A-LR model output prepared for CMIP6 CMIP piControl-spinup. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5253 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5253
IPSL-CM6A-LR | IPSL | DAMIP | hist-GHG | Boucher, Olivier et al. (2018). IPSL IPSL-CM6A-LR model output prepared for CMIP6 DAMIP hist-GHG. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13825 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13825
IPSL-CM6A-LR | IPSL | DAMIP | hist-aer | Boucher, Olivier et al. (2018). IPSL IPSL-CM6A-LR model output prepared for CMIP6 DAMIP hist-aer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13827 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13827
IPSL-CM6A-LR | IPSL | DAMIP | hist-nat | Boucher, Olivier et al. (2018). IPSL IPSL-CM6A-LR model output prepared for CMIP6 DAMIP hist-nat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13831 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13831
IPSL-CM6A-LR | IPSL | DAMIP | hist-stratO3 | Boucher, Olivier et al. (2018). IPSL IPSL-CM6A-LR model output prepared for CMIP6 DAMIP hist-stratO3. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13834 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13834
IPSL-CM6A-LR | IPSL | DAMIP | ssp245-GHG | Boucher, Olivier et al. (2018). IPSL IPSL-CM6A-LR model output prepared for CMIP6 DAMIP ssp245-GHG. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13858 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13858
IPSL-CM6A-LR | IPSL | DAMIP | ssp245-nat | Boucher, Olivier et al. (2018). IPSL IPSL-CM6A-LR model output prepared for CMIP6 DAMIP ssp245-nat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13860 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13860
IPSL-CM6A-LR | IPSL | DCPP | dcppA-hindcast | Boucher, Olivier et al. (2020). IPSL IPSL-CM6A-LR model output prepared for CMIP6 DCPP dcppA-hindcast. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5137 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5137
IPSL-CM6A-LR | IPSL | DCPP | dcppC-amv-ExTrop-neg | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 DCPP dcppC-amv-ExTrop-neg. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5141 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5141
IPSL-CM6A-LR | IPSL | DCPP | dcppC-amv-ExTrop-pos | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 DCPP dcppC-amv-ExTrop-pos. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5142 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5142
IPSL-CM6A-LR | IPSL | DCPP | dcppC-amv-Trop-neg | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 DCPP dcppC-amv-Trop-neg. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5143 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5143
IPSL-CM6A-LR | IPSL | DCPP | dcppC-amv-Trop-pos | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 DCPP dcppC-amv-Trop-pos. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5144 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5144
IPSL-CM6A-LR | IPSL | DCPP | dcppC-amv-neg | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 DCPP dcppC-amv-neg. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5145 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5145
IPSL-CM6A-LR | IPSL | DCPP | dcppC-amv-pos | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 DCPP dcppC-amv-pos. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5146 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5146
IPSL-CM6A-LR | IPSL | DCPP | dcppC-atl-control | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 DCPP dcppC-atl-control. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5147 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5147
IPSL-CM6A-LR | IPSL | DCPP | dcppC-atl-pacemaker | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 DCPP dcppC-atl-pacemaker. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5148 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5148
IPSL-CM6A-LR | IPSL | DCPP | dcppC-ipv-NexTrop-neg | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 DCPP dcppC-ipv-NexTrop-neg. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5157 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5157
IPSL-CM6A-LR | IPSL | DCPP | dcppC-ipv-NexTrop-pos | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 DCPP dcppC-ipv-NexTrop-pos. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5158 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5158
IPSL-CM6A-LR | IPSL | DCPP | dcppC-ipv-neg | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 DCPP dcppC-ipv-neg. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5159 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5159
IPSL-CM6A-LR | IPSL | DCPP | dcppC-ipv-pos | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 DCPP dcppC-ipv-pos. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5160 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5160
IPSL-CM6A-LR | IPSL | DCPP | dcppC-pac-control | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 DCPP dcppC-pac-control. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5161 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5161
IPSL-CM6A-LR | IPSL | DCPP | dcppC-pac-pacemaker | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 DCPP dcppC-pac-pacemaker. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5162 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5162
IPSL-CM6A-LR | IPSL | GMMIP | amip-TIP | Boucher, Olivier et al. (2020). IPSL IPSL-CM6A-LR model output prepared for CMIP6 GMMIP amip-TIP. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5115 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5115
IPSL-CM6A-LR | IPSL | GMMIP | amip-hist | Boucher, Olivier et al. (2018). IPSL IPSL-CM6A-LR model output prepared for CMIP6 GMMIP amip-hist. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5119 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5119
IPSL-CM6A-LR | IPSL | GeoMIP | G1 | Boucher, Olivier et al. (2018). IPSL IPSL-CM6A-LR model output prepared for CMIP6 GeoMIP G1. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5054 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5054
IPSL-CM6A-LR | IPSL | GeoMIP | G6solar | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 GeoMIP G6solar. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5058 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5058
IPSL-CM6A-LR | IPSL | GeoMIP | G6sulfur | Boucher, Olivier et al. (2020). IPSL IPSL-CM6A-LR model output prepared for CMIP6 GeoMIP G6sulfur. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5059 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5059
IPSL-CM6A-LR | IPSL | GeoMIP | G7cirrus | Boucher, Olivier et al. (2021). IPSL IPSL-CM6A-LR model output prepared for CMIP6 GeoMIP G7cirrus. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5102 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5102
IPSL-CM6A-LR | IPSL | HighResMIP | highresSST-present | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 HighResMIP highresSST-present. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13810 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13810
IPSL-CM6A-LR | IPSL | LS3MIP | amip-lfmip-pObs | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 LS3MIP amip-lfmip-pObs. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5121 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5121
IPSL-CM6A-LR | IPSL | LS3MIP | amip-lfmip-pdLC | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 LS3MIP amip-lfmip-pdLC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5122 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5122
IPSL-CM6A-LR | IPSL | LS3MIP | amip-lfmip-rmLC | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 LS3MIP amip-lfmip-rmLC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5123 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5123
IPSL-CM6A-LR | IPSL | LS3MIP | land-hist | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 LS3MIP land-hist. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5205 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5205
IPSL-CM6A-LR | IPSL | LS3MIP | land-hist-cruNcep | Boucher, Olivier et al. (2020). IPSL IPSL-CM6A-LR model output prepared for CMIP6 LS3MIP land-hist-cruNcep. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5210 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5210
IPSL-CM6A-LR | IPSL | LUMIP | deforest-globe | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 LUMIP deforest-globe. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5163 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5163
IPSL-CM6A-LR | IPSL | LUMIP | hist-noLu | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 LUMIP hist-noLu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5189 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5189
IPSL-CM6A-LR | IPSL | LUMIP | land-cCO2 | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 LUMIP land-cCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5198 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5198
IPSL-CM6A-LR | IPSL | LUMIP | land-noLu | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 LUMIP land-noLu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5214 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5214
IPSL-CM6A-LR | IPSL | LUMIP | ssp126-ssp370Lu | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 LUMIP ssp126-ssp370Lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5263 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5263
IPSL-CM6A-LR | IPSL | LUMIP | ssp370-ssp126Lu | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 LUMIP ssp370-ssp126Lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5266 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5266
IPSL-CM6A-LR | IPSL | OMIP | omip1 | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 OMIP omip1. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5231 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5231
IPSL-CM6A-LR | IPSL | PAMIP | futSST-pdSIC | Boucher, Olivier et al. (2020). IPSL IPSL-CM6A-LR model output prepared for CMIP6 PAMIP futSST-pdSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13823 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13823
IPSL-CM6A-LR | IPSL | PAMIP | pa-futArcSIC | Boucher, Olivier et al. (2022). IPSL IPSL-CM6A-LR model output prepared for CMIP6 PAMIP pa-futArcSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13841 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13841
IPSL-CM6A-LR | IPSL | PAMIP | pa-futArcSIC-ext | Boucher, Olivier et al. (2022). IPSL IPSL-CM6A-LR model output prepared for CMIP6 PAMIP pa-futArcSIC-ext. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13842 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13842
IPSL-CM6A-LR | IPSL | PAMIP | pa-pdSIC | Boucher, Olivier et al. (2022). IPSL IPSL-CM6A-LR model output prepared for CMIP6 PAMIP pa-pdSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13843 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13843
IPSL-CM6A-LR | IPSL | PAMIP | pa-pdSIC-ext | Boucher, Olivier et al. (2022). IPSL IPSL-CM6A-LR model output prepared for CMIP6 PAMIP pa-pdSIC-ext. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13844 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13844
IPSL-CM6A-LR | IPSL | PAMIP | pa-piArcSIC | Boucher, Olivier et al. (2022). IPSL IPSL-CM6A-LR model output prepared for CMIP6 PAMIP pa-piArcSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13846 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13846
IPSL-CM6A-LR | IPSL | PAMIP | pdSST-futAntSIC | Boucher, Olivier et al. (2020). IPSL IPSL-CM6A-LR model output prepared for CMIP6 PAMIP pdSST-futAntSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13847 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13847
IPSL-CM6A-LR | IPSL | PAMIP | pdSST-futArcSIC | Boucher, Olivier et al. (2020). IPSL IPSL-CM6A-LR model output prepared for CMIP6 PAMIP pdSST-futArcSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13848 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13848
IPSL-CM6A-LR | IPSL | PAMIP | pdSST-futBKSeasSIC | Boucher, Olivier et al. (2020). IPSL IPSL-CM6A-LR model output prepared for CMIP6 PAMIP pdSST-futBKSeasSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13850 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13850
IPSL-CM6A-LR | IPSL | PAMIP | pdSST-futOkhotskSIC | Boucher, Olivier et al. (2020). IPSL IPSL-CM6A-LR model output prepared for CMIP6 PAMIP pdSST-futOkhotskSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13851 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13851
IPSL-CM6A-LR | IPSL | PAMIP | pdSST-pdSIC | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 PAMIP pdSST-pdSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13852 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13852
IPSL-CM6A-LR | IPSL | PAMIP | pdSST-piAntSIC | Boucher, Olivier et al. (2020). IPSL IPSL-CM6A-LR model output prepared for CMIP6 PAMIP pdSST-piAntSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13854 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13854
IPSL-CM6A-LR | IPSL | PAMIP | pdSST-piArcSIC | Boucher, Olivier et al. (2020). IPSL IPSL-CM6A-LR model output prepared for CMIP6 PAMIP pdSST-piArcSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13855 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13855
IPSL-CM6A-LR | IPSL | PAMIP | piSST-pdSIC | Boucher, Olivier et al. (2020). IPSL IPSL-CM6A-LR model output prepared for CMIP6 PAMIP piSST-pdSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13856 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13856
IPSL-CM6A-LR | IPSL | PAMIP | piSST-piSIC | Boucher, Olivier et al. (2020). IPSL IPSL-CM6A-LR model output prepared for CMIP6 PAMIP piSST-piSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13857 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13857
IPSL-CM6A-LR | IPSL | PMIP | lig127k | Boucher, Olivier et al. (2018). IPSL IPSL-CM6A-LR model output prepared for CMIP6 PMIP lig127k. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5228 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5228
IPSL-CM6A-LR | IPSL | PMIP | midHolocene | Boucher, Olivier et al. (2018). IPSL IPSL-CM6A-LR model output prepared for CMIP6 PMIP midHolocene. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5229 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5229
IPSL-CM6A-LR | IPSL | PMIP | midPliocene-eoi400 | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 PMIP midPliocene-eoi400. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5230 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5230
IPSL-CM6A-LR | IPSL | RFMIP | hist-spAer-all | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 RFMIP hist-spAer-all. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5193 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5193
IPSL-CM6A-LR | IPSL | RFMIP | piClim-4xCO2 | Boucher, Olivier et al. (2018). IPSL IPSL-CM6A-LR model output prepared for CMIP6 RFMIP piClim-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5236 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5236
IPSL-CM6A-LR | IPSL | RFMIP | piClim-aer | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 RFMIP piClim-aer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5237 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5237
IPSL-CM6A-LR | IPSL | RFMIP | piClim-anthro | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 RFMIP piClim-anthro. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5238 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5238
IPSL-CM6A-LR | IPSL | RFMIP | piClim-control | Boucher, Olivier et al. (2018). IPSL IPSL-CM6A-LR model output prepared for CMIP6 RFMIP piClim-control. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5239 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5239
IPSL-CM6A-LR | IPSL | RFMIP | piClim-ghg | Boucher, Olivier et al. (2018). IPSL IPSL-CM6A-LR model output prepared for CMIP6 RFMIP piClim-ghg. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5240 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5240
IPSL-CM6A-LR | IPSL | RFMIP | piClim-histaer | Boucher, Olivier et al. (2020). IPSL IPSL-CM6A-LR model output prepared for CMIP6 RFMIP piClim-histaer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5241 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5241
IPSL-CM6A-LR | IPSL | RFMIP | piClim-histall | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 RFMIP piClim-histall. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5242 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5242
IPSL-CM6A-LR | IPSL | RFMIP | piClim-histghg | Boucher, Olivier et al. (2020). IPSL IPSL-CM6A-LR model output prepared for CMIP6 RFMIP piClim-histghg. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5243 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5243
IPSL-CM6A-LR | IPSL | RFMIP | piClim-histnat | Boucher, Olivier et al. (2020). IPSL IPSL-CM6A-LR model output prepared for CMIP6 RFMIP piClim-histnat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5244 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5244
IPSL-CM6A-LR | IPSL | RFMIP | piClim-lu | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 RFMIP piClim-lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5245 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5245
IPSL-CM6A-LR | IPSL | RFMIP | piClim-spAer-aer | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 RFMIP piClim-spAer-aer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5246 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5246
IPSL-CM6A-LR | IPSL | RFMIP | piClim-spAer-anthro | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 RFMIP piClim-spAer-anthro. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5247 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5247
IPSL-CM6A-LR | IPSL | RFMIP | piClim-spAer-histall | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 RFMIP piClim-spAer-histall. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5249 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5249
IPSL-CM6A-LR | IPSL | ScenarioMIP | ssp119 | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 ScenarioMIP ssp119. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5261 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5261
IPSL-CM6A-LR | IPSL | ScenarioMIP | ssp126 | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5262 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5262
IPSL-CM6A-LR | IPSL | ScenarioMIP | ssp245 | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5264 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5264
IPSL-CM6A-LR | IPSL | ScenarioMIP | ssp370 | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 ScenarioMIP ssp370. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5265 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5265
IPSL-CM6A-LR | IPSL | ScenarioMIP | ssp434 | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 ScenarioMIP ssp434. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5267 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5267
IPSL-CM6A-LR | IPSL | ScenarioMIP | ssp460 | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 ScenarioMIP ssp460. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5268 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5268
IPSL-CM6A-LR | IPSL | ScenarioMIP | ssp534-over | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 ScenarioMIP ssp534-over. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5269 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5269
IPSL-CM6A-LR | IPSL | ScenarioMIP | ssp585 | Boucher, Olivier et al. (2019). IPSL IPSL-CM6A-LR model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5271 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5271
IPSL-CM6A-LR-INCA | IPSL | AerChemMIP | piClim-2xdust | Boucher, Olivier et al. (2020). IPSL IPSL-CM6A-LR-INCA model output prepared for CMIP6 AerChemMIP piClim-2xdust. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13607 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13607
IPSL-CM6A-LR-INCA | IPSL | AerChemMIP | piClim-2xss | Boucher, Olivier et al. (2020). IPSL IPSL-CM6A-LR-INCA model output prepared for CMIP6 AerChemMIP piClim-2xss. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13609 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13609
IPSL-CM6A-LR-INCA | IPSL | AerChemMIP | piClim-BC | Boucher, Olivier et al. (2020). IPSL IPSL-CM6A-LR-INCA model output prepared for CMIP6 AerChemMIP piClim-BC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13610 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13610
IPSL-CM6A-LR-INCA | IPSL | AerChemMIP | piClim-NH3 | Boucher, Olivier et al. (2020). IPSL IPSL-CM6A-LR-INCA model output prepared for CMIP6 AerChemMIP piClim-NH3. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13614 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13614
IPSL-CM6A-LR-INCA | IPSL | AerChemMIP | piClim-OC | Boucher, Olivier et al. (2020). IPSL IPSL-CM6A-LR-INCA model output prepared for CMIP6 AerChemMIP piClim-OC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13618 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13618
IPSL-CM6A-LR-INCA | IPSL | AerChemMIP | piClim-SO2 | Boucher, Olivier et al. (2020). IPSL IPSL-CM6A-LR-INCA model output prepared for CMIP6 AerChemMIP piClim-SO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13619 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13619
IPSL-CM6A-LR-INCA | IPSL | CMIP | abrupt-4xCO2 | Boucher, Olivier et al. (2021). IPSL IPSL-CM6A-LR-INCA model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13584 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13584
IPSL-CM6A-LR-INCA | IPSL | CMIP | historical | Boucher, Olivier et al. (2021). IPSL IPSL-CM6A-LR-INCA model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13601 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13601
IPSL-CM6A-LR-INCA | IPSL | RFMIP | piClim-aer | Boucher, Olivier et al. (2020). IPSL IPSL-CM6A-LR-INCA model output prepared for CMIP6 RFMIP piClim-aer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14604 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14604
IPSL-CM6A-LR-INCA | IPSL | RFMIP | piClim-control | Boucher, Olivier et al. (2020). IPSL IPSL-CM6A-LR-INCA model output prepared for CMIP6 RFMIP piClim-control. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14606 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14606
IPSL-CM6A-MR1 | IPSL | CMIP | 1pctCO2 | Boucher, Olivier et al. (2023). IPSL IPSL-CM6A-MR1 model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15924 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15924
IPSL-CM6A-MR1 | IPSL | CMIP | abrupt-4xCO2 | Boucher, Olivier et al. (2023). IPSL IPSL-CM6A-MR1 model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15926 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15926
IPSL-CM6A-MR1 | IPSL | CMIP | amip | Boucher, Olivier et al. (2023). IPSL IPSL-CM6A-MR1 model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15928 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15928
IPSL-CM6A-MR1 | IPSL | CMIP | piControl | Boucher, Olivier et al. (2023). IPSL IPSL-CM6A-MR1 model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15944 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15944
KACE-1-0-G | NIMS-KMA | CMIP | 1pctCO2 | Byun, Young-Hwa et al. (2019). NIMS-KMA KACE1.0-G model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8333 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8333
KACE-1-0-G | NIMS-KMA | CMIP | abrupt-4xCO2 | Byun, Young-Hwa et al. (2019). NIMS-KMA KACE1.0-G model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8348 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8348
KACE-1-0-G | NIMS-KMA | CMIP | amip | Byun, Young-Hwa et al. (2019). NIMS-KMA KACE1.0-G model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8350 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8350
KACE-1-0-G | NIMS-KMA | CMIP | historical | Byun, Young-Hwa et al. (2019). NIMS-KMA KACE1.0-G model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8378 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8378
KACE-1-0-G | NIMS-KMA | CMIP | piControl | Byun, Young-Hwa et al. (2019). NIMS-KMA KACE1.0-G model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8425 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8425
KACE-1-0-G | NIMS-KMA | ScenarioMIP | ssp126 | Byun, Young-Hwa et al. (2019). NIMS-KMA KACE1.0-G model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8432 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8432
KACE-1-0-G | NIMS-KMA | ScenarioMIP | ssp245 | Byun, Young-Hwa et al. (2019). NIMS-KMA KACE1.0-G model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8435 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8435
KACE-1-0-G | NIMS-KMA | ScenarioMIP | ssp370 | Byun, Young-Hwa et al. (2019). NIMS-KMA KACE1.0-G model output prepared for CMIP6 ScenarioMIP ssp370. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8437 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8437
KACE-1-0-G | NIMS-KMA | ScenarioMIP | ssp585 | Byun, Young-Hwa et al. (2019). NIMS-KMA KACE1.0-G model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8456 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8456
KIOST-ESM | KIOST | CMIP | 1pctCO2 | Kim, YoungHo et al. (2019). KIOST KIOST-ESM model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5283 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5283
KIOST-ESM | KIOST | CMIP | abrupt-4xCO2 | Kim, YoungHo et al. (2019). KIOST KIOST-ESM model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5288 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5288
KIOST-ESM | KIOST | CMIP | amip | Kim, YoungHo et al. (2019). KIOST KIOST-ESM model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5289 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5289
KIOST-ESM | KIOST | CMIP | historical | Kim, YoungHo et al. (2019). KIOST KIOST-ESM model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5296 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5296
KIOST-ESM | KIOST | CMIP | piControl | Kim, YoungHo et al. (2019). KIOST KIOST-ESM model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5303 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5303
KIOST-ESM | KIOST | ScenarioMIP | ssp126 | Kim, YoungHo et al. (2019). KIOST KIOST-ESM model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11243 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11243
KIOST-ESM | KIOST | ScenarioMIP | ssp245 | Kim, YoungHo et al. (2019). KIOST KIOST-ESM model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11244 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11244
KIOST-ESM | KIOST | ScenarioMIP | ssp585 | Kim, YoungHo et al. (2019). KIOST KIOST-ESM model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11249 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11249
LBLRTM-12-8 | AER | RFMIP | rad-irf | Mlawer, Eli; Pernak, Richard (2019). AER LBLRTM model output prepared for CMIP6 RFMIP rad-irf. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.2528 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.2528
MCM-UA-1-0 | UA | CMIP | 1pctCO2 | Stouffer, Ronald (2019). UA MCM-UA-1-0 model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8881 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8881
MCM-UA-1-0 | UA | CMIP | abrupt-4xCO2 | Stouffer, Ronald (2019). UA MCM-UA-1-0 model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8882 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8882
MCM-UA-1-0 | UA | CMIP | historical | Stouffer, Ronald (2019). UA MCM-UA-1-0 model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8888 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8888
MCM-UA-1-0 | UA | CMIP | piControl | Stouffer, Ronald (2019). UA MCM-UA-1-0 model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8890 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8890
MCM-UA-1-0 | UA | ScenarioMIP | ssp126 | Stouffer, Ronald (2019). UA MCM-UA-1-0 model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13895 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13895
MCM-UA-1-0 | UA | ScenarioMIP | ssp245 | Stouffer, Ronald (2019). UA MCM-UA-1-0 model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13896 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13896
MCM-UA-1-0 | UA | ScenarioMIP | ssp370 | Stouffer, Ronald (2019). UA MCM-UA-1-0 model output prepared for CMIP6 ScenarioMIP ssp370. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13897 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13897
MCM-UA-1-0 | UA | ScenarioMIP | ssp585 | Stouffer, Ronald (2019). UA MCM-UA-1-0 model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13901 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13901
MIROC-ES2H | MIROC | CMIP | abrupt-4xCO2 | Watanabe, Shingo et al. (2021). MIROC MIROC-ES2H model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5409 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5409
MIROC-ES2H | MIROC | CMIP | historical | Watanabe, Shingo et al. (2021). MIROC MIROC-ES2H model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5601 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5601
MIROC-ES2H | MIROC | CMIP | piControl | Watanabe, Shingo et al. (2021). MIROC MIROC-ES2H model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5709 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5709
MIROC-ES2H | MIROC | GeoMIP | G1 | Watanabe, Shingo et al. (2021). MIROC MIROC-ES2H model output prepared for CMIP6 GeoMIP G1. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5381 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5381
MIROC-ES2H | MIROC | ScenarioMIP | ssp119 | Watanabe, Shingo et al. (2023). MIROC MIROC-ES2H model output prepared for CMIP6 ScenarioMIP ssp119. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15656 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15656
MIROC-ES2H | MIROC | ScenarioMIP | ssp126 | Watanabe, Shingo et al. (2023). MIROC MIROC-ES2H model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15657 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15657
MIROC-ES2H | MIROC | ScenarioMIP | ssp245 | Watanabe, Shingo et al. (2023). MIROC MIROC-ES2H model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15658 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15658
MIROC-ES2H | MIROC | ScenarioMIP | ssp370 | Watanabe, Shingo et al. (2023). MIROC MIROC-ES2H model output prepared for CMIP6 ScenarioMIP ssp370. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15659 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15659
MIROC-ES2H | MIROC | ScenarioMIP | ssp585 | Watanabe, Shingo et al. (2023). MIROC MIROC-ES2H model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15664 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15664
MIROC-ES2H-NB | MIROC | AerChemMIP | histSST | Sudo, Kengo et al. (2020). MIROC MIROC-ES2H-NB model output prepared for CMIP6 AerChemMIP histSST. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13317 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13317
MIROC-ES2H-NB | MIROC | AerChemMIP | histSST-1950HC | Sudo, Kengo et al. (2020). MIROC MIROC-ES2H-NB model output prepared for CMIP6 AerChemMIP histSST-1950HC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13318 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13318
MIROC-ES2H-NB | MIROC | AerChemMIP | histSST-piCH4 | Sudo, Kengo et al. (2020). MIROC MIROC-ES2H-NB model output prepared for CMIP6 AerChemMIP histSST-piCH4. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13381 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13381
MIROC-ES2H-NB | MIROC | AerChemMIP | histSST-piN2O | Sudo, Kengo et al. (2020). MIROC MIROC-ES2H-NB model output prepared for CMIP6 AerChemMIP histSST-piN2O. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13382 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13382
MIROC-ES2H-NB | MIROC | AerChemMIP | histSST-piNTCF | Sudo, Kengo et al. (2020). MIROC MIROC-ES2H-NB model output prepared for CMIP6 AerChemMIP histSST-piNTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13383 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13383
MIROC-ES2H-NB | MIROC | AerChemMIP | histSST-piO3 | Sudo, Kengo et al. (2020). MIROC MIROC-ES2H-NB model output prepared for CMIP6 AerChemMIP histSST-piO3. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13384 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13384
MIROC-ES2H-NB | MIROC | AerChemMIP | piClim-CH4 | Sudo, Kengo et al. (2020). MIROC MIROC-ES2H-NB model output prepared for CMIP6 AerChemMIP piClim-CH4. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13395 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13395
MIROC-ES2H-NB | MIROC | AerChemMIP | piClim-HC | Sudo, Kengo et al. (2020). MIROC MIROC-ES2H-NB model output prepared for CMIP6 AerChemMIP piClim-HC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13396 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13396
MIROC-ES2H-NB | MIROC | AerChemMIP | piClim-N2O | Sudo, Kengo et al. (2020). MIROC MIROC-ES2H-NB model output prepared for CMIP6 AerChemMIP piClim-N2O. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13397 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13397
MIROC-ES2H-NB | MIROC | AerChemMIP | piClim-NTCF | Sudo, Kengo et al. (2020). MIROC MIROC-ES2H-NB model output prepared for CMIP6 AerChemMIP piClim-NTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13400 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13400
MIROC-ES2H-NB | MIROC | AerChemMIP | piClim-control | Sudo, Kengo et al. (2020). MIROC MIROC-ES2H-NB model output prepared for CMIP6 AerChemMIP piClim-control. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13406 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13406
MIROC-ES2L | MIROC | C4MIP | 1pctCO2-bgc | Hajima, Tomohiro et al. (2019). MIROC MIROC-ES2L model output prepared for CMIP6 C4MIP 1pctCO2-bgc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5376 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5376
MIROC-ES2L | MIROC | C4MIP | 1pctCO2-rad | Hajima, Tomohiro et al. (2019). MIROC MIROC-ES2L model output prepared for CMIP6 C4MIP 1pctCO2-rad. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5378 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5378
MIROC-ES2L | MIROC | C4MIP | 1pctCO2Ndep | Hajima, Tomohiro et al. (2019). MIROC MIROC-ES2L model output prepared for CMIP6 C4MIP 1pctCO2Ndep. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5379 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5379
MIROC-ES2L | MIROC | C4MIP | 1pctCO2Ndep-bgc | Hajima, Tomohiro et al. (2019). MIROC MIROC-ES2L model output prepared for CMIP6 C4MIP 1pctCO2Ndep-bgc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5380 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5380
MIROC-ES2L | MIROC | C4MIP | esm-1pct-brch-1000PgC | Hajima, Tomohiro et al. (2020). MIROC MIROC-ES2L model output prepared for CMIP6 C4MIP esm-1pct-brch-1000PgC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10744 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10744
MIROC-ES2L | MIROC | C4MIP | esm-1pct-brch-2000PgC | Hajima, Tomohiro et al. (2020). MIROC MIROC-ES2L model output prepared for CMIP6 C4MIP esm-1pct-brch-2000PgC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10746 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10746
MIROC-ES2L | MIROC | C4MIP | esm-1pct-brch-750PgC | Hajima, Tomohiro et al. (2020). MIROC MIROC-ES2L model output prepared for CMIP6 C4MIP esm-1pct-brch-750PgC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10748 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10748
MIROC-ES2L | MIROC | C4MIP | esm-1pctCO2 | Hajima, Tomohiro et al. (2020). MIROC MIROC-ES2L model output prepared for CMIP6 C4MIP esm-1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10750 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10750
MIROC-ES2L | MIROC | C4MIP | esm-ssp585 | Hajima, Tomohiro et al. (2020). MIROC MIROC-ES2L model output prepared for CMIP6 C4MIP esm-ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5526 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5526
MIROC-ES2L | MIROC | C4MIP | hist-bgc | Hajima, Tomohiro et al. (2019). MIROC MIROC-ES2L model output prepared for CMIP6 C4MIP hist-bgc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5582 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5582
MIROC-ES2L | MIROC | C4MIP | ssp534-over-bgc | Hajima, Tomohiro et al. (2019). MIROC MIROC-ES2L model output prepared for CMIP6 C4MIP ssp534-over-bgc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5769 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5769
MIROC-ES2L | MIROC | C4MIP | ssp585-bgc | Hajima, Tomohiro et al. (2019). MIROC MIROC-ES2L model output prepared for CMIP6 C4MIP ssp585-bgc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5772 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5772
MIROC-ES2L | MIROC | CDRMIP | 1pctCO2-cdr | Hajima, Tomohiro et al. (2020). MIROC MIROC-ES2L model output prepared for CMIP6 CDRMIP 1pctCO2-cdr. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5377 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5377
MIROC-ES2L | MIROC | CDRMIP | esm-pi-CO2pulse | Hajima, Tomohiro et al. (2020). MIROC MIROC-ES2L model output prepared for CMIP6 CDRMIP esm-pi-CO2pulse. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5509 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5509
MIROC-ES2L | MIROC | CDRMIP | esm-pi-cdr-pulse | Hajima, Tomohiro et al. (2020). MIROC MIROC-ES2L model output prepared for CMIP6 CDRMIP esm-pi-cdr-pulse. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5510 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5510
MIROC-ES2L | MIROC | CDRMIP | esm-ssp534-over | Hajima, Tomohiro et al. (2020). MIROC MIROC-ES2L model output prepared for CMIP6 CDRMIP esm-ssp534-over. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5525 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5525
MIROC-ES2L | MIROC | CMIP | 1pctCO2 | Hajima, Tomohiro et al. (2019). MIROC MIROC-ES2L model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5370 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5370
MIROC-ES2L | MIROC | CMIP | abrupt-4xCO2 | Hajima, Tomohiro et al. (2019). MIROC MIROC-ES2L model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5410 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5410
MIROC-ES2L | MIROC | CMIP | amip | Hajima, Tomohiro et al. (2020). MIROC MIROC-ES2L model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5421 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5421
MIROC-ES2L | MIROC | CMIP | esm-hist | Hajima, Tomohiro et al. (2020). MIROC MIROC-ES2L model output prepared for CMIP6 CMIP esm-hist. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5496 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5496
MIROC-ES2L | MIROC | CMIP | esm-piControl | Hajima, Tomohiro et al. (2020). MIROC MIROC-ES2L model output prepared for CMIP6 CMIP esm-piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5512 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5512
MIROC-ES2L | MIROC | CMIP | historical | Hajima, Tomohiro et al. (2019). MIROC MIROC-ES2L model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5602 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5602
MIROC-ES2L | MIROC | CMIP | piControl | Hajima, Tomohiro et al. (2019). MIROC MIROC-ES2L model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5710 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5710
MIROC-ES2L | MIROC | DAMIP | ssp245-cov-fossil | Ohgaito, Rumi et al. (2021). MIROC MIROC-ES2L model output prepared for CMIP6 DAMIP ssp245-cov-fossil. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15259 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15259
MIROC-ES2L | MIROC | DAMIP | ssp245-cov-modgreen | Ohgaito, Rumi et al. (2021). MIROC MIROC-ES2L model output prepared for CMIP6 DAMIP ssp245-cov-modgreen. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15260 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15260
MIROC-ES2L | MIROC | DAMIP | ssp245-cov-strgreen | Ohgaito, Rumi et al. (2021). MIROC MIROC-ES2L model output prepared for CMIP6 DAMIP ssp245-cov-strgreen. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15261 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15261
MIROC-ES2L | MIROC | DAMIP | ssp245-covid | Ohgaito, Rumi et al. (2020). MIROC MIROC-ES2L model output prepared for CMIP6 DAMIP ssp245-covid. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15262 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15262
MIROC-ES2L | MIROC | LUMIP | deforest-globe | Ito, Akihiko; Hajima, Tomohiro (2020). MIROC MIROC-ES2L model output prepared for CMIP6 LUMIP deforest-globe. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5494 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5494
MIROC-ES2L | MIROC | LUMIP | esm-ssp585-ssp126Lu | Hajima, Tomohiro et al. (2020). MIROC MIROC-ES2L model output prepared for CMIP6 LUMIP esm-ssp585-ssp126Lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5529 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5529
MIROC-ES2L | MIROC | LUMIP | hist-noLu | Hajima, Tomohiro et al. (2020). MIROC MIROC-ES2L model output prepared for CMIP6 LUMIP hist-noLu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5584 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5584
MIROC-ES2L | MIROC | LUMIP | ssp126-ssp370Lu | Hajima, Tomohiro et al. (2019). MIROC MIROC-ES2L model output prepared for CMIP6 LUMIP ssp126-ssp370Lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5744 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5744
MIROC-ES2L | MIROC | LUMIP | ssp370-ssp126Lu | Hajima, Tomohiro et al. (2019). MIROC MIROC-ES2L model output prepared for CMIP6 LUMIP ssp370-ssp126Lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5755 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5755
MIROC-ES2L | MIROC | OMIP | omip1 | Watanabe, Michio et al. (2020). MIROC MIROC-ES2L model output prepared for CMIP6 OMIP omip1. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5650 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5650
MIROC-ES2L | MIROC | OMIP | omip1-spunup | Watanabe, Michio et al. (2020). MIROC MIROC-ES2L model output prepared for CMIP6 OMIP omip1-spunup. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5652 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5652
MIROC-ES2L | MIROC | PMIP | lgm | Ohgaito, Rumi et al. (2019). MIROC MIROC-ES2L model output prepared for CMIP6 PMIP lgm. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5644 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5644
MIROC-ES2L | MIROC | PMIP | lig127k | O'ishi, Ryouta et al. (2019). MIROC MIROC-ES2L model output prepared for CMIP6 PMIP lig127k. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5645 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5645
MIROC-ES2L | MIROC | PMIP | midHolocene | Ohgaito, Rumi et al. (2019). MIROC MIROC-ES2L model output prepared for CMIP6 PMIP midHolocene. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5646 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5646
MIROC-ES2L | MIROC | PMIP | past1000 | Ohgaito, Rumi et al. (2020). MIROC MIROC-ES2L model output prepared for CMIP6 PMIP past1000. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5666 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5666
MIROC-ES2L | MIROC | ScenarioMIP | ssp119 | Tachiiri, Kaoru et al. (2019). MIROC MIROC-ES2L model output prepared for CMIP6 ScenarioMIP ssp119. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5740 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5740
MIROC-ES2L | MIROC | ScenarioMIP | ssp126 | Tachiiri, Kaoru et al. (2019). MIROC MIROC-ES2L model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5742 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5742
MIROC-ES2L | MIROC | ScenarioMIP | ssp245 | Tachiiri, Kaoru et al. (2019). MIROC MIROC-ES2L model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5745 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5745
MIROC-ES2L | MIROC | ScenarioMIP | ssp370 | Tachiiri, Kaoru et al. (2019). MIROC MIROC-ES2L model output prepared for CMIP6 ScenarioMIP ssp370. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5751 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5751
MIROC-ES2L | MIROC | ScenarioMIP | ssp534-over | Tachiiri, Kaoru; Kawamiya, Michio (2020). MIROC MIROC-ES2L model output prepared for CMIP6 ScenarioMIP ssp534-over. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5767 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5767
MIROC-ES2L | MIROC | ScenarioMIP | ssp585 | Tachiiri, Kaoru et al. (2019). MIROC MIROC-ES2L model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5770 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5770
MIROC-ES2L | MIROC | VolMIP | volc-long-eq | Abe, Manabu et al. (2021). MIROC MIROC-ES2L model output prepared for CMIP6 VolMIP volc-long-eq. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5776 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5776
MIROC-ES2L | MIROC | VolMIP | volc-pinatubo-full | Abe, Manabu et al. (2021). MIROC MIROC-ES2L model output prepared for CMIP6 VolMIP volc-pinatubo-full. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5779 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5779
MIROC-ES2L | MIROC | VolMIP | volc-pinatubo-strat | Abe, Manabu et al. (2021). MIROC MIROC-ES2L model output prepared for CMIP6 VolMIP volc-pinatubo-strat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5781 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5781
MIROC-ES2L | MIROC | VolMIP | volc-pinatubo-surf | Abe, Manabu et al. (2021). MIROC MIROC-ES2L model output prepared for CMIP6 VolMIP volc-pinatubo-surf. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5782 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5782
MIROC6 | MIROC | AerChemMIP | hist-piAer | Takemura, Toshihiko (2019). MIROC MIROC6 model output prepared for CMIP6 AerChemMIP hist-piAer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9123 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9123
MIROC6 | MIROC | AerChemMIP | hist-piNTCF | Takemura, Toshihiko (2019). MIROC MIROC6 model output prepared for CMIP6 AerChemMIP hist-piNTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9124 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9124
MIROC6 | MIROC | AerChemMIP | histSST | Takemura, Toshihiko (2019). MIROC MIROC6 model output prepared for CMIP6 AerChemMIP histSST. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9125 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9125
MIROC6 | MIROC | AerChemMIP | histSST-piAer | Takemura, Toshihiko (2019). MIROC MIROC6 model output prepared for CMIP6 AerChemMIP histSST-piAer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9127 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9127
MIROC6 | MIROC | AerChemMIP | histSST-piNTCF | Takemura, Toshihiko (2019). MIROC MIROC6 model output prepared for CMIP6 AerChemMIP histSST-piNTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9130 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9130
MIROC6 | MIROC | AerChemMIP | piClim-2xdust | Takemura, Toshihiko (2019). MIROC MIROC6 model output prepared for CMIP6 AerChemMIP piClim-2xdust. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9135 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9135
MIROC6 | MIROC | AerChemMIP | piClim-2xfire | Takemura, Toshihiko (2019). MIROC MIROC6 model output prepared for CMIP6 AerChemMIP piClim-2xfire. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9136 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9136
MIROC6 | MIROC | AerChemMIP | piClim-2xss | Takemura, Toshihiko (2019). MIROC MIROC6 model output prepared for CMIP6 AerChemMIP piClim-2xss. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9137 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9137
MIROC6 | MIROC | AerChemMIP | piClim-BC | Takemura, Toshihiko (2019). MIROC MIROC6 model output prepared for CMIP6 AerChemMIP piClim-BC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9138 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9138
MIROC6 | MIROC | AerChemMIP | piClim-NTCF | Takemura, Toshihiko (2019). MIROC MIROC6 model output prepared for CMIP6 AerChemMIP piClim-NTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9144 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9144
MIROC6 | MIROC | AerChemMIP | piClim-OC | Takemura, Toshihiko (2019). MIROC MIROC6 model output prepared for CMIP6 AerChemMIP piClim-OC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9146 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9146
MIROC6 | MIROC | AerChemMIP | piClim-SO2 | Takemura, Toshihiko (2019). MIROC MIROC6 model output prepared for CMIP6 AerChemMIP piClim-SO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9147 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9147
MIROC6 | MIROC | AerChemMIP | ssp370-lowNTCF | Takemura, Toshihiko (2019). MIROC MIROC6 model output prepared for CMIP6 AerChemMIP ssp370-lowNTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9152 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9152
MIROC6 | MIROC | AerChemMIP | ssp370SST | Takemura, Toshihiko (2019). MIROC MIROC6 model output prepared for CMIP6 AerChemMIP ssp370SST. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9153 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9153
MIROC6 | MIROC | AerChemMIP | ssp370SST-lowAer | Takemura, Toshihiko (2019). MIROC MIROC6 model output prepared for CMIP6 AerChemMIP ssp370SST-lowAer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9154 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9154
MIROC6 | MIROC | AerChemMIP | ssp370SST-lowBC | Takemura, Toshihiko (2019). MIROC MIROC6 model output prepared for CMIP6 AerChemMIP ssp370SST-lowBC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9155 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9155
MIROC6 | MIROC | AerChemMIP | ssp370pdSST | Takemura, Toshihiko (2020). MIROC MIROC6 model output prepared for CMIP6 AerChemMIP ssp370pdSST. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11404 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11404
MIROC6 | MIROC | CFMIP | abrupt-0p5xCO2 | Ogura, Tomoo et al. (2019). MIROC MIROC6 model output prepared for CMIP6 CFMIP abrupt-0p5xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5405 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5405
MIROC6 | MIROC | CFMIP | abrupt-2xCO2 | Ogura, Tomoo et al. (2019). MIROC MIROC6 model output prepared for CMIP6 CFMIP abrupt-2xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5407 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5407
MIROC6 | MIROC | CFMIP | amip-4xCO2 | Ogura, Tomoo et al. (2019). MIROC MIROC6 model output prepared for CMIP6 CFMIP amip-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5427 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5427
MIROC6 | MIROC | CFMIP | amip-future4K | Ogura, Tomoo et al. (2019). MIROC MIROC6 model output prepared for CMIP6 CFMIP amip-future4K. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5435 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5435
MIROC6 | MIROC | CFMIP | amip-p4K | Ogura, Tomoo et al. (2019). MIROC MIROC6 model output prepared for CMIP6 CFMIP amip-p4K. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5446 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5446
MIROC6 | MIROC | CFMIP | amip-piForcing | Ogura, Tomoo et al. (2020). MIROC MIROC6 model output prepared for CMIP6 CFMIP amip-piForcing. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5450 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5450
MIROC6 | MIROC | CFMIP | aqua-4xCO2 | Ogura, Tomoo et al. (2021). MIROC MIROC6 model output prepared for CMIP6 CFMIP aqua-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5452 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5452
MIROC6 | MIROC | CFMIP | aqua-control | Ogura, Tomoo et al. (2021). MIROC MIROC6 model output prepared for CMIP6 CFMIP aqua-control. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5454 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5454
MIROC6 | MIROC | CFMIP | aqua-p4K | Ogura, Tomoo et al. (2021). MIROC MIROC6 model output prepared for CMIP6 CFMIP aqua-p4K. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5458 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5458
MIROC6 | MIROC | CMIP | 1pctCO2 | Tatebe, Hiroaki; Watanabe, Masahiro (2018). MIROC MIROC6 model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5371 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5371
MIROC6 | MIROC | CMIP | abrupt-4xCO2 | Tatebe, Hiroaki; Watanabe, Masahiro (2018). MIROC MIROC6 model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5411 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5411
MIROC6 | MIROC | CMIP | amip | Tatebe, Hiroaki; Watanabe, Masahiro (2018). MIROC MIROC6 model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5422 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5422
MIROC6 | MIROC | CMIP | historical | Tatebe, Hiroaki; Watanabe, Masahiro (2018). MIROC MIROC6 model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5603 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5603
MIROC6 | MIROC | CMIP | piControl | Tatebe, Hiroaki; Watanabe, Masahiro (2018). MIROC MIROC6 model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5711 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5711
MIROC6 | MIROC | DAMIP | hist-CO2 | Shiogama, Hideo (2019). MIROC MIROC6 model output prepared for CMIP6 DAMIP hist-CO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5577 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5577
MIROC6 | MIROC | DAMIP | hist-GHG | Shiogama, Hideo (2019). MIROC MIROC6 model output prepared for CMIP6 DAMIP hist-GHG. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5578 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5578
MIROC6 | MIROC | DAMIP | hist-aer | Shiogama, Hideo (2019). MIROC MIROC6 model output prepared for CMIP6 DAMIP hist-aer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5579 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5579
MIROC6 | MIROC | DAMIP | hist-nat | Shiogama, Hideo (2019). MIROC MIROC6 model output prepared for CMIP6 DAMIP hist-nat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5583 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5583
MIROC6 | MIROC | DAMIP | hist-sol | Shiogama, Hideo (2019). MIROC MIROC6 model output prepared for CMIP6 DAMIP hist-sol. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5589 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5589
MIROC6 | MIROC | DAMIP | hist-stratO3 | Shiogama, Hideo (2019). MIROC MIROC6 model output prepared for CMIP6 DAMIP hist-stratO3. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5592 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5592
MIROC6 | MIROC | DAMIP | hist-totalO3 | Shiogama, Hideo (2022). MIROC MIROC6 model output prepared for CMIP6 DAMIP hist-totalO3. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12408 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12408
MIROC6 | MIROC | DAMIP | hist-volc | Shiogama, Hideo (2019). MIROC MIROC6 model output prepared for CMIP6 DAMIP hist-volc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5593 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5593
MIROC6 | MIROC | DAMIP | ssp245-GHG | Shiogama, Hideo (2019). MIROC MIROC6 model output prepared for CMIP6 DAMIP ssp245-GHG. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5747 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5747
MIROC6 | MIROC | DAMIP | ssp245-aer | Shiogama, Hideo (2019). MIROC MIROC6 model output prepared for CMIP6 DAMIP ssp245-aer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5748 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5748
MIROC6 | MIROC | DAMIP | ssp245-nat | Shiogama, Hideo (2019). MIROC MIROC6 model output prepared for CMIP6 DAMIP ssp245-nat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5749 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5749
MIROC6 | MIROC | DAMIP | ssp245-stratO3 | Shiogama, Hideo (2019). MIROC MIROC6 model output prepared for CMIP6 DAMIP ssp245-stratO3. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5750 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5750
MIROC6 | MIROC | DCPP | dcppA-assim | Mochizuki, Takashi et al. (2019). MIROC MIROC6 model output prepared for CMIP6 DCPP dcppA-assim. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5467 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5467
MIROC6 | MIROC | DCPP | dcppA-hindcast | Mochizuki, Takashi et al. (2019). MIROC MIROC6 model output prepared for CMIP6 DCPP dcppA-hindcast. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5468 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5468
MIROC6 | MIROC | FAFMIP | faf-all | Suzuki, Tatsuo (2019). MIROC MIROC6 model output prepared for CMIP6 FAFMIP faf-all. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5536 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5536
MIROC6 | MIROC | FAFMIP | faf-heat | Suzuki, Tatsuo (2019). MIROC MIROC6 model output prepared for CMIP6 FAFMIP faf-heat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5537 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5537
MIROC6 | MIROC | FAFMIP | faf-heat-NA0pct | Suzuki, Tatsuo (2020). MIROC MIROC6 model output prepared for CMIP6 FAFMIP faf-heat-NA0pct. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11623 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11623
MIROC6 | MIROC | FAFMIP | faf-heat-NA50pct | Suzuki, Tatsuo (2020). MIROC MIROC6 model output prepared for CMIP6 FAFMIP faf-heat-NA50pct. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11624 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11624
MIROC6 | MIROC | FAFMIP | faf-passiveheat | Suzuki, Tatsuo (2019). MIROC MIROC6 model output prepared for CMIP6 FAFMIP faf-passiveheat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5538 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5538
MIROC6 | MIROC | FAFMIP | faf-stress | Suzuki, Tatsuo (2019). MIROC MIROC6 model output prepared for CMIP6 FAFMIP faf-stress. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5539 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5539
MIROC6 | MIROC | FAFMIP | faf-water | Suzuki, Tatsuo (2019). MIROC MIROC6 model output prepared for CMIP6 FAFMIP faf-water. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5540 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5540
MIROC6 | MIROC | GMMIP | amip-hist | Watanabe, Masahiro; Tatebe, Hiroaki (2019). MIROC MIROC6 model output prepared for CMIP6 GMMIP amip-hist. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5437 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5437
MIROC6 | MIROC | LS3MIP | amip-lfmip-pdLC | Onuma, Yukihiko; Kim, Hyungjun (2021). MIROC MIROC6 model output prepared for CMIP6 LS3MIP amip-lfmip-pdLC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5440 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5440
MIROC6 | MIROC | LS3MIP | amip-lfmip-rmLC | Onuma, Yukihiko; Kim, Hyungjun (2021). MIROC MIROC6 model output prepared for CMIP6 LS3MIP amip-lfmip-rmLC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5441 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5441
MIROC6 | MIROC | LS3MIP | land-hist | Onuma, Yukihiko; Kim, Hyungjun (2020). MIROC MIROC6 model output prepared for CMIP6 LS3MIP land-hist. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5622 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5622
MIROC6 | MIROC | LS3MIP | land-hist-cruNcep | Onuma, Yukihiko; Kim, Hyungjun (2020). MIROC MIROC6 model output prepared for CMIP6 LS3MIP land-hist-cruNcep. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5627 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5627
MIROC6 | MIROC | LS3MIP | land-hist-princeton | Onuma, Yukihiko; Kim, Hyungjun (2020). MIROC MIROC6 model output prepared for CMIP6 LS3MIP land-hist-princeton. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5628 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5628
MIROC6 | MIROC | LS3MIP | land-hist-wfdei | Onuma, Yukihiko; Kim, Hyungjun (2020). MIROC MIROC6 model output prepared for CMIP6 LS3MIP land-hist-wfdei. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5629 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5629
MIROC6 | MIROC | OMIP | omip1 | Komuro, Yoshiki (2019). MIROC MIROC6 model output prepared for CMIP6 OMIP omip1. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5651 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5651
MIROC6 | MIROC | OMIP | omip2 | Komuro, Yoshiki (2019). MIROC MIROC6 model output prepared for CMIP6 OMIP omip2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5655 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5655
MIROC6 | MIROC | PAMIP | pdSST-futAntSIC | Mori, Masato (2019). MIROC MIROC6 model output prepared for CMIP6 PAMIP pdSST-futAntSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5667 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5667
MIROC6 | MIROC | PAMIP | pdSST-futArcSIC | Mori, Masato (2019). MIROC MIROC6 model output prepared for CMIP6 PAMIP pdSST-futArcSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5668 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5668
MIROC6 | MIROC | PAMIP | pdSST-futBKSeasSIC | Mori, Masato (2019). MIROC MIROC6 model output prepared for CMIP6 PAMIP pdSST-futBKSeasSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5670 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5670
MIROC6 | MIROC | PAMIP | pdSST-futOkhotskSIC | Mori, Masato (2019). MIROC MIROC6 model output prepared for CMIP6 PAMIP pdSST-futOkhotskSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5671 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5671
MIROC6 | MIROC | PAMIP | pdSST-pdSIC | Mori, Masato (2019). MIROC MIROC6 model output prepared for CMIP6 PAMIP pdSST-pdSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5672 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5672
MIROC6 | MIROC | PAMIP | pdSST-piAntSIC | Mori, Masato (2019). MIROC MIROC6 model output prepared for CMIP6 PAMIP pdSST-piAntSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5674 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5674
MIROC6 | MIROC | PAMIP | pdSST-piArcSIC | Mori, Masato (2019). MIROC MIROC6 model output prepared for CMIP6 PAMIP pdSST-piArcSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5675 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5675
MIROC6 | MIROC | RFMIP | piClim-4xCO2 | Sekiguchi, Miho; Shiogama, Hideo (2019). MIROC MIROC6 model output prepared for CMIP6 RFMIP piClim-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5682 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5682
MIROC6 | MIROC | RFMIP | piClim-aer | Sekiguchi, Miho; Shiogama, Hideo (2019). MIROC MIROC6 model output prepared for CMIP6 RFMIP piClim-aer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5694 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5694
MIROC6 | MIROC | RFMIP | piClim-anthro | Sekiguchi, Miho; Shiogama, Hideo (2019). MIROC MIROC6 model output prepared for CMIP6 RFMIP piClim-anthro. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5696 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5696
MIROC6 | MIROC | RFMIP | piClim-control | Sekiguchi, Miho; Shiogama, Hideo (2019). MIROC MIROC6 model output prepared for CMIP6 RFMIP piClim-control. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5697 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5697
MIROC6 | MIROC | RFMIP | piClim-ghg | Sekiguchi, Miho; Shiogama, Hideo (2019). MIROC MIROC6 model output prepared for CMIP6 RFMIP piClim-ghg. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5699 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5699
MIROC6 | MIROC | RFMIP | piClim-histaer | Sekiguchi, Miho; Shiogama, Hideo (2019). MIROC MIROC6 model output prepared for CMIP6 RFMIP piClim-histaer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5700 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5700
MIROC6 | MIROC | RFMIP | piClim-histall | Sekiguchi, Miho; Shiogama, Hideo (2019). MIROC MIROC6 model output prepared for CMIP6 RFMIP piClim-histall. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5701 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5701
MIROC6 | MIROC | RFMIP | piClim-histghg | Sekiguchi, Miho; Shiogama, Hideo (2019). MIROC MIROC6 model output prepared for CMIP6 RFMIP piClim-histghg. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5702 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5702
MIROC6 | MIROC | RFMIP | piClim-histnat | Sekiguchi, Miho; Shiogama, Hideo (2019). MIROC MIROC6 model output prepared for CMIP6 RFMIP piClim-histnat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5703 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5703
MIROC6 | MIROC | RFMIP | piClim-lu | Sekiguchi, Miho; Shiogama, Hideo (2019). MIROC MIROC6 model output prepared for CMIP6 RFMIP piClim-lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5704 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5704
MIROC6 | MIROC | RFMIP | rad-irf | Sekiguchi, Miho; Shiogama, Hideo (2020). MIROC MIROC6 model output prepared for CMIP6 RFMIP rad-irf. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5735 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5735
MIROC6 | MIROC | ScenarioMIP | ssp119 | Shiogama, Hideo et al. (2019). MIROC MIROC6 model output prepared for CMIP6 ScenarioMIP ssp119. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5741 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5741
MIROC6 | MIROC | ScenarioMIP | ssp126 | Shiogama, Hideo et al. (2019). MIROC MIROC6 model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5743 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5743
MIROC6 | MIROC | ScenarioMIP | ssp245 | Shiogama, Hideo et al. (2019). MIROC MIROC6 model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5746 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5746
MIROC6 | MIROC | ScenarioMIP | ssp370 | Shiogama, Hideo et al. (2019). MIROC MIROC6 model output prepared for CMIP6 ScenarioMIP ssp370. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5752 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5752
MIROC6 | MIROC | ScenarioMIP | ssp434 | Shiogama, Hideo et al. (2019). MIROC MIROC6 model output prepared for CMIP6 ScenarioMIP ssp434. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5764 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5764
MIROC6 | MIROC | ScenarioMIP | ssp460 | Shiogama, Hideo et al. (2019). MIROC MIROC6 model output prepared for CMIP6 ScenarioMIP ssp460. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5766 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5766
MIROC6 | MIROC | ScenarioMIP | ssp534-over | Shiogama, Hideo et al. (2019). MIROC MIROC6 model output prepared for CMIP6 ScenarioMIP ssp534-over. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5768 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5768
MIROC6 | MIROC | ScenarioMIP | ssp585 | Shiogama, Hideo et al. (2019). MIROC MIROC6 model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5771 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5771
MPI-ESM-1-2-HAM | HAMMOZ-Consortium | AerChemMIP | hist-piAer | Neubauer, David et al. (2019). HAMMOZ-Consortium MPI-ESM1.2-HAM model output prepared for CMIP6 AerChemMIP hist-piAer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5007 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5007
MPI-ESM-1-2-HAM | HAMMOZ-Consortium | AerChemMIP | histSST | Neubauer, David et al. (2019). HAMMOZ-Consortium MPI-ESM1.2-HAM model output prepared for CMIP6 AerChemMIP histSST. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5009 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5009
MPI-ESM-1-2-HAM | HAMMOZ-Consortium | AerChemMIP | histSST-piAer | Neubauer, David et al. (2019). HAMMOZ-Consortium MPI-ESM1.2-HAM model output prepared for CMIP6 AerChemMIP histSST-piAer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5011 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5011
MPI-ESM-1-2-HAM | HAMMOZ-Consortium | AerChemMIP | piClim-2xDMS | Neubauer, David et al. (2020). HAMMOZ-Consortium MPI-ESM1.2-HAM model output prepared for CMIP6 AerChemMIP piClim-2xDMS. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5018 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5018
MPI-ESM-1-2-HAM | HAMMOZ-Consortium | AerChemMIP | piClim-2xdust | Neubauer, David et al. (2020). HAMMOZ-Consortium MPI-ESM1.2-HAM model output prepared for CMIP6 AerChemMIP piClim-2xdust. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5021 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5021
MPI-ESM-1-2-HAM | HAMMOZ-Consortium | AerChemMIP | piClim-2xfire | Neubauer, David et al. (2020). HAMMOZ-Consortium MPI-ESM1.2-HAM model output prepared for CMIP6 AerChemMIP piClim-2xfire. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5022 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5022
MPI-ESM-1-2-HAM | HAMMOZ-Consortium | AerChemMIP | piClim-2xss | Neubauer, David et al. (2020). HAMMOZ-Consortium MPI-ESM1.2-HAM model output prepared for CMIP6 AerChemMIP piClim-2xss. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5023 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5023
MPI-ESM-1-2-HAM | HAMMOZ-Consortium | AerChemMIP | piClim-BC | Neubauer, David et al. (2020). HAMMOZ-Consortium MPI-ESM1.2-HAM model output prepared for CMIP6 AerChemMIP piClim-BC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5024 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5024
MPI-ESM-1-2-HAM | HAMMOZ-Consortium | AerChemMIP | piClim-OC | Neubauer, David et al. (2020). HAMMOZ-Consortium MPI-ESM1.2-HAM model output prepared for CMIP6 AerChemMIP piClim-OC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5032 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5032
MPI-ESM-1-2-HAM | HAMMOZ-Consortium | AerChemMIP | piClim-SO2 | Neubauer, David et al. (2020). HAMMOZ-Consortium MPI-ESM1.2-HAM model output prepared for CMIP6 AerChemMIP piClim-SO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5033 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5033
MPI-ESM-1-2-HAM | HAMMOZ-Consortium | AerChemMIP | ssp370-lowNTCF | Neubauer, David et al. (2019). HAMMOZ-Consortium MPI-ESM1.2-HAM model output prepared for CMIP6 AerChemMIP ssp370-lowNTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5040 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5040
MPI-ESM-1-2-HAM | HAMMOZ-Consortium | AerChemMIP | ssp370SST | Neubauer, David et al. (2019). HAMMOZ-Consortium MPI-ESM1.2-HAM model output prepared for CMIP6 AerChemMIP ssp370SST. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5041 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5041
MPI-ESM-1-2-HAM | HAMMOZ-Consortium | AerChemMIP | ssp370SST-lowAer | Neubauer, David et al. (2019). HAMMOZ-Consortium MPI-ESM1.2-HAM model output prepared for CMIP6 AerChemMIP ssp370SST-lowAer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5042 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5042
MPI-ESM-1-2-HAM | HAMMOZ-Consortium | AerChemMIP | ssp370SST-lowBC | Neubauer, David et al. (2020). HAMMOZ-Consortium MPI-ESM1.2-HAM model output prepared for CMIP6 AerChemMIP ssp370SST-lowBC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5043 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5043
MPI-ESM-1-2-HAM | HAMMOZ-Consortium | AerChemMIP | ssp370SST-ssp126Lu | Neubauer, David et al. (2020). HAMMOZ-Consortium MPI-ESM1.2-HAM model output prepared for CMIP6 AerChemMIP ssp370SST-ssp126Lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5047 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5047
MPI-ESM-1-2-HAM | HAMMOZ-Consortium | CMIP | 1pctCO2 | Neubauer, David et al. (2019). HAMMOZ-Consortium MPI-ESM1.2-HAM model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4999 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4999
MPI-ESM-1-2-HAM | HAMMOZ-Consortium | CMIP | abrupt-4xCO2 | Neubauer, David et al. (2019). HAMMOZ-Consortium MPI-ESM1.2-HAM model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5000 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5000
MPI-ESM-1-2-HAM | HAMMOZ-Consortium | CMIP | amip | Neubauer, David et al. (2019). HAMMOZ-Consortium MPI-ESM1.2-HAM model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5001 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5001
MPI-ESM-1-2-HAM | HAMMOZ-Consortium | CMIP | historical | Neubauer, David et al. (2019). HAMMOZ-Consortium MPI-ESM1.2-HAM model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5016 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5016
MPI-ESM-1-2-HAM | HAMMOZ-Consortium | CMIP | piControl | Neubauer, David et al. (2019). HAMMOZ-Consortium MPI-ESM1.2-HAM model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5037 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5037
MPI-ESM-1-2-HAM | HAMMOZ-Consortium | RFMIP | piClim-aer | Neubauer, David et al. (2019). HAMMOZ-Consortium MPI-ESM1.2-HAM model output prepared for CMIP6 RFMIP piClim-aer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14728 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14728
MPI-ESM-1-2-HAM | HAMMOZ-Consortium | RFMIP | piClim-control | Neubauer, David et al. (2019). HAMMOZ-Consortium MPI-ESM1.2-HAM model output prepared for CMIP6 RFMIP piClim-control. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14730 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14730
MPI-ESM1-2-HR | DKRZ | ScenarioMIP | ssp126 | Schupfner, Martin et al. (2019). DKRZ MPI-ESM1.2-HR model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4397 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4397
MPI-ESM1-2-HR | DKRZ | ScenarioMIP | ssp245 | Schupfner, Martin et al. (2019). DKRZ MPI-ESM1.2-HR model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4398 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4398
MPI-ESM1-2-HR | DKRZ | ScenarioMIP | ssp370 | Schupfner, Martin et al. (2019). DKRZ MPI-ESM1.2-HR model output prepared for CMIP6 ScenarioMIP ssp370. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4399 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4399
MPI-ESM1-2-HR | DKRZ | ScenarioMIP | ssp585 | Schupfner, Martin et al. (2019). DKRZ MPI-ESM1.2-HR model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4403 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4403
MPI-ESM1-2-HR | DWD | ScenarioMIP | ssp126 | Steger, Christian et al. (2019). DWD MPI-ESM1.2-HR model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4473 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4473
MPI-ESM1-2-HR | DWD | ScenarioMIP | ssp585 | Steger, Christian et al. (2019). DWD MPI-ESM1.2-HR model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.4479 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.4479
MPI-ESM1-2-HR | MPI-M | CMIP | 1pctCO2 | Jungclaus, Johann et al. (2019). MPI-M MPI-ESM1.2-HR model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6434 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6434
MPI-ESM1-2-HR | MPI-M | CMIP | abrupt-4xCO2 | Jungclaus, Johann et al. (2019). MPI-M MPI-ESM1.2-HR model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6458 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6458
MPI-ESM1-2-HR | MPI-M | CMIP | amip | Jungclaus, Johann et al. (2019). MPI-M MPI-ESM1.2-HR model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6463 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6463
MPI-ESM1-2-HR | MPI-M | CMIP | historical | Jungclaus, Johann et al. (2019). MPI-M MPI-ESM1.2-HR model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6594 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6594
MPI-ESM1-2-HR | MPI-M | CMIP | piControl | Jungclaus, Johann et al. (2019). MPI-M MPI-ESM1.2-HR model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6674 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6674
MPI-ESM1-2-HR | MPI-M | DCPP | dcppA-hindcast | Pohlmann, Holger et al. (2019). MPI-M MPI-ESM1.2-HR model output prepared for CMIP6 DCPP dcppA-hindcast. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6490 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6490
MPI-ESM1-2-HR | MPI-M | FAFMIP | faf-all | Haak, Helmuth et al. (2019). MPI-M MPI-ESM1.2-HR model output prepared for CMIP6 FAFMIP faf-all. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6568 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6568
MPI-ESM1-2-HR | MPI-M | FAFMIP | faf-heat | Haak, Helmuth et al. (2019). MPI-M MPI-ESM1.2-HR model output prepared for CMIP6 FAFMIP faf-heat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6570 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6570
MPI-ESM1-2-HR | MPI-M | FAFMIP | faf-heat-NA50pct | Haak, Helmuth et al. (2019). MPI-M MPI-ESM1.2-HR model output prepared for CMIP6 FAFMIP faf-heat-NA50pct. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11651 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11651
MPI-ESM1-2-HR | MPI-M | FAFMIP | faf-passiveheat | Haak, Helmuth et al. (2019). MPI-M MPI-ESM1.2-HR model output prepared for CMIP6 FAFMIP faf-passiveheat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6572 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6572
MPI-ESM1-2-HR | MPI-M | FAFMIP | faf-stress | Haak, Helmuth et al. (2019). MPI-M MPI-ESM1.2-HR model output prepared for CMIP6 FAFMIP faf-stress. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6574 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6574
MPI-ESM1-2-HR | MPI-M | FAFMIP | faf-water | Haak, Helmuth et al. (2019). MPI-M MPI-ESM1.2-HR model output prepared for CMIP6 FAFMIP faf-water. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6576 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6576
MPI-ESM1-2-HR | MPI-M | GeoMIP | G6solar | Niemeier, Ulrike et al. (2019). MPI-M MPI-ESM1.2-HR model output prepared for CMIP6 GeoMIP G6solar. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15299 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15299
MPI-ESM1-2-HR | MPI-M | GeoMIP | G6sulfur | Niemeier, Ulrike et al. (2019). MPI-M MPI-ESM1.2-HR model output prepared for CMIP6 GeoMIP G6sulfur. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15300 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15300
MPI-ESM1-2-HR | MPI-M | HighResMIP | control-1950 | von Storch, Jin-Song et al. (2018). MPI-M MPI-ESM1.2-HR model output prepared for CMIP6 HighResMIP control-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6485 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6485
MPI-ESM1-2-HR | MPI-M | HighResMIP | highres-future | von Storch, Jin-Song et al. (2019). MPI-M MPI-ESM1.2-HR model output prepared for CMIP6 HighResMIP highres-future. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6579 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6579
MPI-ESM1-2-HR | MPI-M | HighResMIP | highresSST-future | von Storch, Jin-Song et al. (2019). MPI-M MPI-ESM1.2-HR model output prepared for CMIP6 HighResMIP highresSST-future. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6582 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6582
MPI-ESM1-2-HR | MPI-M | HighResMIP | highresSST-present | von Storch, Jin-Song et al. (2017). MPI-M MPI-ESM1.2-HR model output prepared for CMIP6 HighResMIP highresSST-present. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6584 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6584
MPI-ESM1-2-HR | MPI-M | HighResMIP | hist-1950 | von Storch, Jin-Song et al. (2018). MPI-M MPI-ESM1.2-HR model output prepared for CMIP6 HighResMIP hist-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6586 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6586
MPI-ESM1-2-HR | MPI-M | VolMIP | volc-long-eq | Timmreck, Claudia et al. (2019). MPI-M MPI-ESM1.2-HR model output prepared for CMIP6 VolMIP volc-long-eq. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6714 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6714
MPI-ESM1-2-HR | MPI-M | VolMIP | volc-pinatubo-full | Timmreck, Claudia et al. (2019). MPI-M MPI-ESM1.2-HR model output prepared for CMIP6 VolMIP volc-pinatubo-full. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6720 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6720
MPI-ESM1-2-LR | DKRZ | ScenarioMIP | ssp119 | Schupfner, Martin et al. (2021). DKRZ MPI-ESM1.2-LR model output prepared for CMIP6 ScenarioMIP ssp119. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15575 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15575
MPI-ESM1-2-LR | DWD | DCPP | dcppA-hindcast | Steger, Christian et al. (2022). DWD MPI-ESM1.2-LR model output prepared for CMIP6 DCPP dcppA-hindcast. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16108 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16108
MPI-ESM1-2-LR | MPI-M | C4MIP | 1pctCO2-bgc | Brovkin, Victor et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 C4MIP 1pctCO2-bgc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6437 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6437
MPI-ESM1-2-LR | MPI-M | C4MIP | 1pctCO2-rad | Brovkin, Victor et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 C4MIP 1pctCO2-rad. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6439 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6439
MPI-ESM1-2-LR | MPI-M | C4MIP | 1pctCO2Ndep | Brovkin, Victor et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 C4MIP 1pctCO2Ndep. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6440 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6440
MPI-ESM1-2-LR | MPI-M | C4MIP | 1pctCO2Ndep-bgc | Brovkin, Victor et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 C4MIP 1pctCO2Ndep-bgc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6441 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6441
MPI-ESM1-2-LR | MPI-M | C4MIP | esm-1pct-brch-1000PgC | Brovkin, Victor et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 C4MIP esm-1pct-brch-1000PgC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10730 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10730
MPI-ESM1-2-LR | MPI-M | C4MIP | esm-1pctCO2 | Brovkin, Victor et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 C4MIP esm-1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10736 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10736
MPI-ESM1-2-LR | MPI-M | C4MIP | esm-ssp585 | Brovkin, Victor et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 C4MIP esm-ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6558 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6558
MPI-ESM1-2-LR | MPI-M | CDRMIP | esm-ssp534-over | Brovkin, Victor et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 CDRMIP esm-ssp534-over. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6557 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6557
MPI-ESM1-2-LR | MPI-M | CMIP | 1pctCO2 | Wieners, Karl-Hermann et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6435 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6435
MPI-ESM1-2-LR | MPI-M | CMIP | abrupt-4xCO2 | Wieners, Karl-Hermann et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6459 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6459
MPI-ESM1-2-LR | MPI-M | CMIP | amip | Wieners, Karl-Hermann et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6464 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6464
MPI-ESM1-2-LR | MPI-M | CMIP | esm-hist | Wieners, Karl-Hermann et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 CMIP esm-hist. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6545 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6545
MPI-ESM1-2-LR | MPI-M | CMIP | esm-piControl | Wieners, Karl-Hermann et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 CMIP esm-piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6553 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6553
MPI-ESM1-2-LR | MPI-M | CMIP | historical | Wieners, Karl-Hermann et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6595 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6595
MPI-ESM1-2-LR | MPI-M | CMIP | piControl | Wieners, Karl-Hermann et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6675 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6675
MPI-ESM1-2-LR | MPI-M | DAMIP | hist-GHG | Müller, Wolfgang et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 DAMIP hist-GHG. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15022 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15022
MPI-ESM1-2-LR | MPI-M | DAMIP | hist-aer | Müller, Wolfgang et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 DAMIP hist-aer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15024 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15024
MPI-ESM1-2-LR | MPI-M | DAMIP | hist-nat | Müller, Wolfgang et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 DAMIP hist-nat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15028 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15028
MPI-ESM1-2-LR | MPI-M | DAMIP | hist-sol | Müller, Wolfgang et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 DAMIP hist-sol. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15030 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15030
MPI-ESM1-2-LR | MPI-M | DAMIP | hist-totalO3 | Müller, Wolfgang et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 DAMIP hist-totalO3. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15032 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15032
MPI-ESM1-2-LR | MPI-M | DAMIP | hist-volc | Müller, Wolfgang et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 DAMIP hist-volc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15033 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15033
MPI-ESM1-2-LR | MPI-M | DAMIP | ssp245-cov-fossil | Müller, Wolfgang et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 DAMIP ssp245-cov-fossil. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15038 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15038
MPI-ESM1-2-LR | MPI-M | DAMIP | ssp245-cov-modgreen | Müller, Wolfgang et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 DAMIP ssp245-cov-modgreen. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15039 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15039
MPI-ESM1-2-LR | MPI-M | DAMIP | ssp245-cov-strgreen | Müller, Wolfgang et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 DAMIP ssp245-cov-strgreen. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15040 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15040
MPI-ESM1-2-LR | MPI-M | DAMIP | ssp245-covid | Müller, Wolfgang et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 DAMIP ssp245-covid. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15041 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15041
MPI-ESM1-2-LR | MPI-M | FAFMIP | faf-all | Haak, Helmuth et al. (2021). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 FAFMIP faf-all. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6569 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6569
MPI-ESM1-2-LR | MPI-M | FAFMIP | faf-heat | Haak, Helmuth et al. (2021). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 FAFMIP faf-heat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6571 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6571
MPI-ESM1-2-LR | MPI-M | FAFMIP | faf-heat-NA50pct | Haak, Helmuth et al. (2021). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 FAFMIP faf-heat-NA50pct. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11652 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11652
MPI-ESM1-2-LR | MPI-M | FAFMIP | faf-passiveheat | Haak, Helmuth et al. (2021). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 FAFMIP faf-passiveheat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6573 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6573
MPI-ESM1-2-LR | MPI-M | FAFMIP | faf-stress | Haak, Helmuth et al. (2021). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 FAFMIP faf-stress. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6575 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6575
MPI-ESM1-2-LR | MPI-M | FAFMIP | faf-water | Haak, Helmuth et al. (2021). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 FAFMIP faf-water. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6577 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6577
MPI-ESM1-2-LR | MPI-M | GeoMIP | G6solar | Niemeier, Ulrike et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 GeoMIP G6solar. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6447 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6447
MPI-ESM1-2-LR | MPI-M | GeoMIP | G6sulfur | Niemeier, Ulrike et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 GeoMIP G6sulfur. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6448 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6448
MPI-ESM1-2-LR | MPI-M | LS3MIP | amip-lfmip-pdLC | Stacke, Tobias et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 LS3MIP amip-lfmip-pdLC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6473 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6473
MPI-ESM1-2-LR | MPI-M | LS3MIP | amip-lfmip-rmLC | Stacke, Tobias et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 LS3MIP amip-lfmip-rmLC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6474 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6474
MPI-ESM1-2-LR | MPI-M | LS3MIP | land-hist | Stacke, Tobias et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 LS3MIP land-hist. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6620 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6620
MPI-ESM1-2-LR | MPI-M | LS3MIP | land-hist-cruNcep | Stacke, Tobias et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 LS3MIP land-hist-cruNcep. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6625 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6625
MPI-ESM1-2-LR | MPI-M | LS3MIP | land-hist-princeton | Stacke, Tobias et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 LS3MIP land-hist-princeton. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6626 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6626
MPI-ESM1-2-LR | MPI-M | LUMIP | deforest-globe | Pongratz, Julia et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 LUMIP deforest-globe. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6542 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6542
MPI-ESM1-2-LR | MPI-M | LUMIP | esm-ssp585-ssp126Lu | Pongratz, Julia et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 LUMIP esm-ssp585-ssp126Lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6561 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6561
MPI-ESM1-2-LR | MPI-M | LUMIP | hist-noLu | Pongratz, Julia et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 LUMIP hist-noLu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6588 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6588
MPI-ESM1-2-LR | MPI-M | LUMIP | land-cCO2 | Pongratz, Julia et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 LUMIP land-cCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6613 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6613
MPI-ESM1-2-LR | MPI-M | LUMIP | land-cClim | Pongratz, Julia et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 LUMIP land-cClim. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6614 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6614
MPI-ESM1-2-LR | MPI-M | LUMIP | land-hist-altLu1 | Pongratz, Julia et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 LUMIP land-hist-altLu1. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6622 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6622
MPI-ESM1-2-LR | MPI-M | LUMIP | land-hist-altLu2 | Pongratz, Julia et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 LUMIP land-hist-altLu2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6623 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6623
MPI-ESM1-2-LR | MPI-M | LUMIP | land-hist-altStartYear | Pongratz, Julia et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 LUMIP land-hist-altStartYear. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6624 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6624
MPI-ESM1-2-LR | MPI-M | LUMIP | land-noFire | Pongratz, Julia et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 LUMIP land-noFire. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6628 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6628
MPI-ESM1-2-LR | MPI-M | LUMIP | land-noLu | Pongratz, Julia et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 LUMIP land-noLu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6629 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6629
MPI-ESM1-2-LR | MPI-M | LUMIP | land-noShiftCultivate | Pongratz, Julia et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 LUMIP land-noShiftCultivate. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6631 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6631
MPI-ESM1-2-LR | MPI-M | LUMIP | land-noWoodHarv | Pongratz, Julia et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 LUMIP land-noWoodHarv. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6632 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6632
MPI-ESM1-2-LR | MPI-M | LUMIP | ssp126-ssp370Lu | Pongratz, Julia et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 LUMIP ssp126-ssp370Lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6691 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6691
MPI-ESM1-2-LR | MPI-M | LUMIP | ssp370-ssp126Lu | Pongratz, Julia et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 LUMIP ssp370-ssp126Lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6696 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6696
MPI-ESM1-2-LR | MPI-M | PMIP | lgm | Jungclaus, Johann et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 PMIP lgm. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6642 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6642
MPI-ESM1-2-LR | MPI-M | PMIP | midHolocene | Jungclaus, Johann et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 PMIP midHolocene. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6644 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6644
MPI-ESM1-2-LR | MPI-M | PMIP | past2k | Jungclaus, Johann et al. (2021). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 PMIP past2k. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14211 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14211
MPI-ESM1-2-LR | MPI-M | RFMIP | piClim-4xCO2 | Fiedler, Stephanie et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 RFMIP piClim-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6659 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6659
MPI-ESM1-2-LR | MPI-M | RFMIP | piClim-control | Fiedler, Stephanie et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 RFMIP piClim-control. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6662 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6662
MPI-ESM1-2-LR | MPI-M | RFMIP | piClim-ghg | Fiedler, Stephanie et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 RFMIP piClim-ghg. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6663 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6663
MPI-ESM1-2-LR | MPI-M | RFMIP | piClim-lu | Fiedler, Stephanie et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 RFMIP piClim-lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6668 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6668
MPI-ESM1-2-LR | MPI-M | RFMIP | piClim-spAer-aer | Fiedler, Stephanie et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 RFMIP piClim-spAer-aer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6669 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6669
MPI-ESM1-2-LR | MPI-M | RFMIP | piClim-spAer-anthro | Fiedler, Stephanie et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 RFMIP piClim-spAer-anthro. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6670 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6670
MPI-ESM1-2-LR | MPI-M | ScenarioMIP | ssp119 | Milinski, Sebastian et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 ScenarioMIP ssp119. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6688 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6688
MPI-ESM1-2-LR | MPI-M | ScenarioMIP | ssp126 | Wieners, Karl-Hermann et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6690 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6690
MPI-ESM1-2-LR | MPI-M | ScenarioMIP | ssp245 | Wieners, Karl-Hermann et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6693 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6693
MPI-ESM1-2-LR | MPI-M | ScenarioMIP | ssp370 | Wieners, Karl-Hermann et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 ScenarioMIP ssp370. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6695 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6695
MPI-ESM1-2-LR | MPI-M | ScenarioMIP | ssp585 | Wieners, Karl-Hermann et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6705 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6705
MPI-ESM1-2-LR | MPI-M | VolMIP | volc-long-eq | Timmreck, Claudia et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 VolMIP volc-long-eq. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6715 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6715
MPI-ESM1-2-LR | MPI-M | VolMIP | volc-pinatubo-full | Timmreck, Claudia et al. (2019). MPI-M MPI-ESM1.2-LR model output prepared for CMIP6 VolMIP volc-pinatubo-full. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6721 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6721
MPI-ESM1-2-XR | MPI-M | HighResMIP | control-1950 | von Storch, Jin-Song et al. (2018). MPI-M MPI-ESM1.2-XR model output prepared for CMIP6 HighResMIP control-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10295 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10295
MPI-ESM1-2-XR | MPI-M | HighResMIP | highres-future | von Storch, Jin-Song et al. (2019). MPI-M MPI-ESM1.2-XR model output prepared for CMIP6 HighResMIP highres-future. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10300 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10300
MPI-ESM1-2-XR | MPI-M | HighResMIP | highresSST-future | von Storch, Jin-Song et al. (2019). MPI-M MPI-ESM1.2-XR model output prepared for CMIP6 HighResMIP highresSST-future. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10303 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10303
MPI-ESM1-2-XR | MPI-M | HighResMIP | highresSST-present | von Storch, Jin-Song et al. (2017). MPI-M MPI-ESM1.2-XR model output prepared for CMIP6 HighResMIP highresSST-present. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10305 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10305
MPI-ESM1-2-XR | MPI-M | HighResMIP | hist-1950 | von Storch, Jin-Song et al. (2018). MPI-M MPI-ESM1.2-XR model output prepared for CMIP6 HighResMIP hist-1950. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10307 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10307
MRI-AGCM3-2-H | MRI | HighResMIP | highresSST-future | Mizuta, Ryo et al. (2019). MRI MRI-AGCM3-2-H model output prepared for CMIP6 HighResMIP highresSST-future. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10972 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10972
MRI-AGCM3-2-H | MRI | HighResMIP | highresSST-present | Mizuta, Ryo et al. (2019). MRI MRI-AGCM3-2-H model output prepared for CMIP6 HighResMIP highresSST-present. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10974 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10974
MRI-AGCM3-2-S | MRI | HighResMIP | highresSST-future | Mizuta, Ryo et al. (2019). MRI MRI-AGCM3-2-S model output prepared for CMIP6 HighResMIP highresSST-future. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6740 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6740
MRI-AGCM3-2-S | MRI | HighResMIP | highresSST-present | Mizuta, Ryo et al. (2019). MRI MRI-AGCM3-2-S model output prepared for CMIP6 HighResMIP highresSST-present. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6942 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6942
MRI-ESM2-0 | MRI | AerChemMIP | hist-1950HC | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 AerChemMIP hist-1950HC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6818 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6818
MRI-ESM2-0 | MRI | AerChemMIP | hist-piAer | Yukimoto, Seiji et al. (2020). MRI MRI-ESM2.0 model output prepared for CMIP6 AerChemMIP hist-piAer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6826 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6826
MRI-ESM2-0 | MRI | AerChemMIP | hist-piNTCF | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 AerChemMIP hist-piNTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6827 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6827
MRI-ESM2-0 | MRI | AerChemMIP | histSST | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 AerChemMIP histSST. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6835 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6835
MRI-ESM2-0 | MRI | AerChemMIP | histSST-1950HC | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 AerChemMIP histSST-1950HC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6836 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6836
MRI-ESM2-0 | MRI | AerChemMIP | histSST-noLu | Yukimoto, Seiji et al. (2020). MRI MRI-ESM2.0 model output prepared for CMIP6 AerChemMIP histSST-noLu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11150 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11150
MRI-ESM2-0 | MRI | AerChemMIP | histSST-piAer | Yukimoto, Seiji et al. (2020). MRI MRI-ESM2.0 model output prepared for CMIP6 AerChemMIP histSST-piAer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6837 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6837
MRI-ESM2-0 | MRI | AerChemMIP | histSST-piCH4 | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 AerChemMIP histSST-piCH4. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6838 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6838
MRI-ESM2-0 | MRI | AerChemMIP | histSST-piN2O | Yukimoto, Seiji et al. (2020). MRI MRI-ESM2.0 model output prepared for CMIP6 AerChemMIP histSST-piN2O. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6839 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6839
MRI-ESM2-0 | MRI | AerChemMIP | histSST-piNTCF | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 AerChemMIP histSST-piNTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6840 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6840
MRI-ESM2-0 | MRI | AerChemMIP | histSST-piO3 | Yukimoto, Seiji et al. (2020). MRI MRI-ESM2.0 model output prepared for CMIP6 AerChemMIP histSST-piO3. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6841 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6841
MRI-ESM2-0 | MRI | AerChemMIP | piClim-BC | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 AerChemMIP piClim-BC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6874 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6874
MRI-ESM2-0 | MRI | AerChemMIP | piClim-CH4 | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 AerChemMIP piClim-CH4. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6875 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6875
MRI-ESM2-0 | MRI | AerChemMIP | piClim-HC | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 AerChemMIP piClim-HC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6876 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6876
MRI-ESM2-0 | MRI | AerChemMIP | piClim-N2O | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 AerChemMIP piClim-N2O. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6877 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6877
MRI-ESM2-0 | MRI | AerChemMIP | piClim-NOx | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 AerChemMIP piClim-NOx. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6879 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6879
MRI-ESM2-0 | MRI | AerChemMIP | piClim-NTCF | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 AerChemMIP piClim-NTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6880 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6880
MRI-ESM2-0 | MRI | AerChemMIP | piClim-O3 | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 AerChemMIP piClim-O3. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6881 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6881
MRI-ESM2-0 | MRI | AerChemMIP | piClim-OC | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 AerChemMIP piClim-OC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6882 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6882
MRI-ESM2-0 | MRI | AerChemMIP | piClim-SO2 | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 AerChemMIP piClim-SO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6883 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6883
MRI-ESM2-0 | MRI | AerChemMIP | piClim-VOC | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 AerChemMIP piClim-VOC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6884 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6884
MRI-ESM2-0 | MRI | AerChemMIP | ssp370-lowNTCF | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 AerChemMIP ssp370-lowNTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6917 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6917
MRI-ESM2-0 | MRI | AerChemMIP | ssp370-lowNTCFCH4 | Yukimoto, Seiji et al. (2020). MRI MRI-ESM2.0 model output prepared for CMIP6 AerChemMIP ssp370-lowNTCFCH4. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13529 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13529
MRI-ESM2-0 | MRI | AerChemMIP | ssp370SST | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 AerChemMIP ssp370SST. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6918 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6918
MRI-ESM2-0 | MRI | AerChemMIP | ssp370SST-lowAer | Yukimoto, Seiji et al. (2020). MRI MRI-ESM2.0 model output prepared for CMIP6 AerChemMIP ssp370SST-lowAer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6919 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6919
MRI-ESM2-0 | MRI | AerChemMIP | ssp370SST-lowBC | Yukimoto, Seiji et al. (2020). MRI MRI-ESM2.0 model output prepared for CMIP6 AerChemMIP ssp370SST-lowBC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6920 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6920
MRI-ESM2-0 | MRI | AerChemMIP | ssp370SST-lowCH4 | Yukimoto, Seiji et al. (2020). MRI MRI-ESM2.0 model output prepared for CMIP6 AerChemMIP ssp370SST-lowCH4. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6921 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6921
MRI-ESM2-0 | MRI | AerChemMIP | ssp370SST-lowNTCF | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 AerChemMIP ssp370SST-lowNTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6922 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6922
MRI-ESM2-0 | MRI | AerChemMIP | ssp370SST-lowNTCFCH4 | Yukimoto, Seiji et al. (2020). MRI MRI-ESM2.0 model output prepared for CMIP6 AerChemMIP ssp370SST-lowNTCFCH4. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13530 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13530
MRI-ESM2-0 | MRI | AerChemMIP | ssp370SST-lowO3 | Yukimoto, Seiji et al. (2020). MRI MRI-ESM2.0 model output prepared for CMIP6 AerChemMIP ssp370SST-lowO3. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6923 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6923
MRI-ESM2-0 | MRI | AerChemMIP | ssp370SST-ssp126Lu | Yukimoto, Seiji et al. (2020). MRI MRI-ESM2.0 model output prepared for CMIP6 AerChemMIP ssp370SST-ssp126Lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6924 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6924
MRI-ESM2-0 | MRI | AerChemMIP | ssp370pdSST | Yukimoto, Seiji et al. (2020). MRI MRI-ESM2.0 model output prepared for CMIP6 AerChemMIP ssp370pdSST. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11409 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11409
MRI-ESM2-0 | MRI | C4MIP | 1pctCO2-bgc | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 C4MIP 1pctCO2-bgc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5357 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5357
MRI-ESM2-0 | MRI | C4MIP | 1pctCO2-rad | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 C4MIP 1pctCO2-rad. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5358 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5358
MRI-ESM2-0 | MRI | C4MIP | esm-ssp585 | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 C4MIP esm-ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6811 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6811
MRI-ESM2-0 | MRI | C4MIP | hist-bgc | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 C4MIP hist-bgc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6824 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6824
MRI-ESM2-0 | MRI | C4MIP | ssp585-bgc | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 C4MIP ssp585-bgc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6930 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6930
MRI-ESM2-0 | MRI | CFMIP | abrupt-0p5xCO2 | Yukimoto, Seiji et al. (2020). MRI MRI-ESM2.0 model output prepared for CMIP6 CFMIP abrupt-0p5xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6753 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6753
MRI-ESM2-0 | MRI | CFMIP | abrupt-2xCO2 | Yukimoto, Seiji et al. (2020). MRI MRI-ESM2.0 model output prepared for CMIP6 CFMIP abrupt-2xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6754 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6754
MRI-ESM2-0 | MRI | CFMIP | abrupt-solm4p | Yukimoto, Seiji et al. (2020). MRI MRI-ESM2.0 model output prepared for CMIP6 CFMIP abrupt-solm4p. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6756 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6756
MRI-ESM2-0 | MRI | CFMIP | abrupt-solp4p | Yukimoto, Seiji et al. (2020). MRI MRI-ESM2.0 model output prepared for CMIP6 CFMIP abrupt-solp4p. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6757 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6757
MRI-ESM2-0 | MRI | CFMIP | amip-4xCO2 | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 CFMIP amip-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6759 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6759
MRI-ESM2-0 | MRI | CFMIP | amip-future4K | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 CFMIP amip-future4K. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6763 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6763
MRI-ESM2-0 | MRI | CFMIP | amip-lwoff | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 CFMIP amip-lwoff. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6769 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6769
MRI-ESM2-0 | MRI | CFMIP | amip-m4K | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 CFMIP amip-m4K. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6770 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6770
MRI-ESM2-0 | MRI | CFMIP | amip-p4K | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 CFMIP amip-p4K. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6771 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6771
MRI-ESM2-0 | MRI | CFMIP | amip-p4K-lwoff | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 CFMIP amip-p4K-lwoff. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6772 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6772
MRI-ESM2-0 | MRI | CFMIP | amip-piForcing | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 CFMIP amip-piForcing. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6773 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6773
MRI-ESM2-0 | MRI | CFMIP | aqua-4xCO2 | Yukimoto, Seiji et al. (2021). MRI MRI-ESM2.0 model output prepared for CMIP6 CFMIP aqua-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6774 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6774
MRI-ESM2-0 | MRI | CFMIP | aqua-control | Yukimoto, Seiji et al. (2021). MRI MRI-ESM2.0 model output prepared for CMIP6 CFMIP aqua-control. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6775 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6775
MRI-ESM2-0 | MRI | CFMIP | aqua-control-lwoff | Yukimoto, Seiji et al. (2021). MRI MRI-ESM2.0 model output prepared for CMIP6 CFMIP aqua-control-lwoff. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6776 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6776
MRI-ESM2-0 | MRI | CFMIP | aqua-p4K | Yukimoto, Seiji et al. (2021). MRI MRI-ESM2.0 model output prepared for CMIP6 CFMIP aqua-p4K. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6777 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6777
MRI-ESM2-0 | MRI | CFMIP | aqua-p4K-lwoff | Yukimoto, Seiji et al. (2021). MRI MRI-ESM2.0 model output prepared for CMIP6 CFMIP aqua-p4K-lwoff. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6778 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6778
MRI-ESM2-0 | MRI | CMIP | 1pctCO2 | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5356 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5356
MRI-ESM2-0 | MRI | CMIP | abrupt-4xCO2 | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6755 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6755
MRI-ESM2-0 | MRI | CMIP | amip | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6758 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6758
MRI-ESM2-0 | MRI | CMIP | esm-hist | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 CMIP esm-hist. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6807 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6807
MRI-ESM2-0 | MRI | CMIP | esm-piControl | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 CMIP esm-piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6809 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6809
MRI-ESM2-0 | MRI | CMIP | historical | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6842 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6842
MRI-ESM2-0 | MRI | CMIP | piControl | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6900 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6900
MRI-ESM2-0 | MRI | DAMIP | hist-GHG | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 DAMIP hist-GHG. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6820 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6820
MRI-ESM2-0 | MRI | DAMIP | hist-aer | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 DAMIP hist-aer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6821 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6821
MRI-ESM2-0 | MRI | DAMIP | hist-nat | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 DAMIP hist-nat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6825 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6825
MRI-ESM2-0 | MRI | DAMIP | hist-sol | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 DAMIP hist-sol. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6830 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6830
MRI-ESM2-0 | MRI | DAMIP | hist-stratO3 | Yukimoto, Seiji et al. (2020). MRI MRI-ESM2.0 model output prepared for CMIP6 DAMIP hist-stratO3. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6833 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6833
MRI-ESM2-0 | MRI | DAMIP | hist-volc | Yukimoto, Seiji et al. (2021). MRI MRI-ESM2.0 model output prepared for CMIP6 DAMIP hist-volc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6834 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6834
MRI-ESM2-0 | MRI | DAMIP | ssp245-cov-fossil | Yukimoto, Seiji et al. (2020). MRI MRI-ESM2.0 model output prepared for CMIP6 DAMIP ssp245-cov-fossil. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17523 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17523
MRI-ESM2-0 | MRI | DAMIP | ssp245-cov-modgreen | Yukimoto, Seiji et al. (2020). MRI MRI-ESM2.0 model output prepared for CMIP6 DAMIP ssp245-cov-modgreen. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17524 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17524
MRI-ESM2-0 | MRI | DAMIP | ssp245-cov-strgreen | Yukimoto, Seiji et al. (2020). MRI MRI-ESM2.0 model output prepared for CMIP6 DAMIP ssp245-cov-strgreen. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17525 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17525
MRI-ESM2-0 | MRI | DAMIP | ssp245-covid | Yukimoto, Seiji et al. (2020). MRI MRI-ESM2.0 model output prepared for CMIP6 DAMIP ssp245-covid. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17526 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17526
MRI-ESM2-0 | MRI | DCPP | dcppA-assim | Yukimoto, Seiji et al. (2020). MRI MRI-ESM2.0 model output prepared for CMIP6 DCPP dcppA-assim. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6780 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6780
MRI-ESM2-0 | MRI | DCPP | dcppA-hindcast | Yukimoto, Seiji et al. (2020). MRI MRI-ESM2.0 model output prepared for CMIP6 DCPP dcppA-hindcast. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6781 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6781
MRI-ESM2-0 | MRI | FAFMIP | faf-all | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 FAFMIP faf-all. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6812 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6812
MRI-ESM2-0 | MRI | FAFMIP | faf-heat | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 FAFMIP faf-heat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6813 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6813
MRI-ESM2-0 | MRI | FAFMIP | faf-heat-NA0pct | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 FAFMIP faf-heat-NA0pct. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11654 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11654
MRI-ESM2-0 | MRI | FAFMIP | faf-heat-NA50pct | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 FAFMIP faf-heat-NA50pct. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11655 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11655
MRI-ESM2-0 | MRI | FAFMIP | faf-passiveheat | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 FAFMIP faf-passiveheat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6814 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6814
MRI-ESM2-0 | MRI | FAFMIP | faf-stress | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 FAFMIP faf-stress. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6815 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6815
MRI-ESM2-0 | MRI | FAFMIP | faf-water | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 FAFMIP faf-water. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6816 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6816
MRI-ESM2-0 | MRI | GMMIP | amip-hist | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 GMMIP amip-hist. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6764 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6764
MRI-ESM2-0 | MRI | GMMIP | hist-resAMO | Yukimoto, Seiji et al. (2020). MRI MRI-ESM2.0 model output prepared for CMIP6 GMMIP hist-resAMO. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6828 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6828
MRI-ESM2-0 | MRI | GMMIP | hist-resIPO | Yukimoto, Seiji et al. (2020). MRI MRI-ESM2.0 model output prepared for CMIP6 GMMIP hist-resIPO. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6829 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6829
MRI-ESM2-0 | MRI | OMIP | omip1 | Yukimoto, Seiji et al. (2020). MRI MRI-ESM2.0 model output prepared for CMIP6 OMIP omip1. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6862 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6862
MRI-ESM2-0 | MRI | OMIP | omip1-spunup | Yukimoto, Seiji et al. (2020). MRI MRI-ESM2.0 model output prepared for CMIP6 OMIP omip1-spunup. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6863 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6863
MRI-ESM2-0 | MRI | OMIP | omip2 | Yukimoto, Seiji et al. (2020). MRI MRI-ESM2.0 model output prepared for CMIP6 OMIP omip2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6864 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6864
MRI-ESM2-0 | MRI | PMIP | midHolocene | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 PMIP midHolocene. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6860 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6860
MRI-ESM2-0 | MRI | PMIP | past1000 | Yukimoto, Seiji et al. (2020). MRI MRI-ESM2.0 model output prepared for CMIP6 PMIP past1000. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6866 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6866
MRI-ESM2-0 | MRI | RFMIP | piClim-4xCO2 | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 RFMIP piClim-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6873 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6873
MRI-ESM2-0 | MRI | RFMIP | piClim-aer | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 RFMIP piClim-aer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6885 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6885
MRI-ESM2-0 | MRI | RFMIP | piClim-anthro | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 RFMIP piClim-anthro. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6887 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6887
MRI-ESM2-0 | MRI | RFMIP | piClim-control | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 RFMIP piClim-control. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6888 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6888
MRI-ESM2-0 | MRI | RFMIP | piClim-ghg | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 RFMIP piClim-ghg. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6890 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6890
MRI-ESM2-0 | MRI | RFMIP | piClim-lu | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 RFMIP piClim-lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6895 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6895
MRI-ESM2-0 | MRI | ScenarioMIP | ssp119 | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 ScenarioMIP ssp119. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6908 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6908
MRI-ESM2-0 | MRI | ScenarioMIP | ssp126 | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6909 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6909
MRI-ESM2-0 | MRI | ScenarioMIP | ssp245 | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6910 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6910
MRI-ESM2-0 | MRI | ScenarioMIP | ssp370 | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 ScenarioMIP ssp370. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6915 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6915
MRI-ESM2-0 | MRI | ScenarioMIP | ssp434 | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 ScenarioMIP ssp434. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6925 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6925
MRI-ESM2-0 | MRI | ScenarioMIP | ssp460 | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 ScenarioMIP ssp460. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6926 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6926
MRI-ESM2-0 | MRI | ScenarioMIP | ssp534-over | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 ScenarioMIP ssp534-over. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6927 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6927
MRI-ESM2-0 | MRI | ScenarioMIP | ssp585 | Yukimoto, Seiji et al. (2019). MRI MRI-ESM2.0 model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6929 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6929
NESM3 | NUIST | CMIP | 1pctCO2 | Cao, Jian; Wang, Bin (2019). NUIST NESMv3 model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8709 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8709
NESM3 | NUIST | CMIP | abrupt-4xCO2 | Cao, Jian; Wang, Bin (2019). NUIST NESMv3 model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8719 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8719
NESM3 | NUIST | CMIP | amip | Cao, Jian; Wang, Bin (2019). NUIST NESMv3 model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8720 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8720
NESM3 | NUIST | CMIP | historical | Cao, Jian; Wang, Bin (2019). NUIST NESMv3 model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8769 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8769
NESM3 | NUIST | CMIP | piControl | Cao, Jian; Wang, Bin (2019). NUIST NESMv3 model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8776 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8776
NESM3 | NUIST | PMIP | lig127k | Cao, Jian (2019). NUIST NESMv3 model output prepared for CMIP6 PMIP lig127k. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8772 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8772
NESM3 | NUIST | PMIP | midHolocene | Cao, Jian (2019). NUIST NESMv3 model output prepared for CMIP6 PMIP midHolocene. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8773 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8773
NESM3 | NUIST | ScenarioMIP | ssp126 | Cao, Jian (2019). NUIST NESMv3 model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8780 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8780
NESM3 | NUIST | ScenarioMIP | ssp245 | Cao, Jian (2019). NUIST NESMv3 model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8781 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8781
NESM3 | NUIST | ScenarioMIP | ssp585 | Cao, Jian (2019). NUIST NESMv3 model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8790 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8790
NICAM16-7S | MIROC | HighResMIP | highresSST-future | Kodama, Chihiro et al. (2021). MIROC NICAM16-7S model output prepared for CMIP6 HighResMIP highresSST-future. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5557 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5557
NICAM16-7S | MIROC | HighResMIP | highresSST-present | Kodama, Chihiro et al. (2019). MIROC NICAM16-7S model output prepared for CMIP6 HighResMIP highresSST-present. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5565 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5565
NICAM16-8S | MIROC | HighResMIP | highresSST-future | Kodama, Chihiro et al. (2021). MIROC NICAM16-8S model output prepared for CMIP6 HighResMIP highresSST-future. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5558 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5558
NICAM16-8S | MIROC | HighResMIP | highresSST-present | Kodama, Chihiro et al. (2019). MIROC NICAM16-8S model output prepared for CMIP6 HighResMIP highresSST-present. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5566 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5566
NICAM16-9S | MIROC | HighResMIP | highresSST-future | Kodama, Chihiro et al. (2021). MIROC NICAM16-9S model output prepared for CMIP6 HighResMIP highresSST-future. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5559 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5559
NICAM16-9S | MIROC | HighResMIP | highresSST-present | Kodama, Chihiro et al. (2019). MIROC NICAM16-9S model output prepared for CMIP6 HighResMIP highresSST-present. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5567 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5567
NorCPM1 | NCC | CMIP | 1pctCO2 | Bethke, Ingo et al. (2019). NCC NorCPM1 model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10861 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10861
NorCPM1 | NCC | CMIP | abrupt-4xCO2 | Bethke, Ingo et al. (2019). NCC NorCPM1 model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10862 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10862
NorCPM1 | NCC | CMIP | amip | Bethke, Ingo et al. (2019). NCC NorCPM1 model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10863 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10863
NorCPM1 | NCC | CMIP | historical | Bethke, Ingo et al. (2019). NCC NorCPM1 model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10894 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10894
NorCPM1 | NCC | CMIP | historical-ext | Bethke, Ingo et al. (2020). NCC NorCPM1 model output prepared for CMIP6 CMIP historical-ext. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10895 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10895
NorCPM1 | NCC | CMIP | piControl | Bethke, Ingo et al. (2019). NCC NorCPM1 model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10896 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10896
NorCPM1 | NCC | DCPP | dcppA-assim | Bethke, Ingo et al. (2019). NCC NorCPM1 model output prepared for CMIP6 DCPP dcppA-assim. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10864 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10864
NorCPM1 | NCC | DCPP | dcppA-hindcast | Bethke, Ingo et al. (2019). NCC NorCPM1 model output prepared for CMIP6 DCPP dcppA-hindcast. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10865 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10865
NorCPM1 | NCC | DCPP | dcppB-forecast | Bethke, Ingo et al. (2025). NCC NorCPM1 model output prepared for CMIP6 DCPP dcppB-forecast. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10868 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10868
NorESM1-F | NCC | CMIP | piControl | Guo, Chuncheng et al. (2019). NCC NorESM1-F model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11595 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11595
NorESM1-F | NCC | PMIP | lig127k | Guo, Chuncheng et al. (2019). NCC NorESM1-F model output prepared for CMIP6 PMIP lig127k. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11590 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11590
NorESM1-F | NCC | PMIP | midHolocene | Guo, Chuncheng et al. (2019). NCC NorESM1-F model output prepared for CMIP6 PMIP midHolocene. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11591 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11591
NorESM1-F | NCC | PMIP | midPliocene-eoi400 | Guo, Chuncheng et al. (2019). NCC NorESM1-F model output prepared for CMIP6 PMIP midPliocene-eoi400. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11592 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11592
NorESM2-LM | NCC | AerChemMIP | hist-piAer | Oliviè, Dirk Jan Leo et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 AerChemMIP hist-piAer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7984 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7984
NorESM2-LM | NCC | AerChemMIP | hist-piNTCF | Oliviè, Dirk Jan Leo et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 AerChemMIP hist-piNTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7988 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7988
NorESM2-LM | NCC | AerChemMIP | histSST | Oliviè, Dirk Jan Leo et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 AerChemMIP histSST. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8007 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8007
NorESM2-LM | NCC | AerChemMIP | histSST-piAer | Oliviè, Dirk Jan Leo et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 AerChemMIP histSST-piAer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8015 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8015
NorESM2-LM | NCC | AerChemMIP | histSST-piNTCF | Oliviè, Dirk Jan Leo et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 AerChemMIP histSST-piNTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8027 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8027
NorESM2-LM | NCC | AerChemMIP | piClim-2xDMS | Oliviè, Dirk Jan Leo et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 AerChemMIP piClim-2xDMS. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8098 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8098
NorESM2-LM | NCC | AerChemMIP | piClim-2xVOC | Oliviè, Dirk Jan Leo et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 AerChemMIP piClim-2xVOC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8106 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8106
NorESM2-LM | NCC | AerChemMIP | piClim-2xdust | Oliviè, Dirk Jan Leo et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 AerChemMIP piClim-2xdust. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8110 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8110
NorESM2-LM | NCC | AerChemMIP | piClim-2xss | Oliviè, Dirk Jan Leo et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 AerChemMIP piClim-2xss. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8118 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8118
NorESM2-LM | NCC | AerChemMIP | piClim-BC | Oliviè, Dirk Jan Leo et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 AerChemMIP piClim-BC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8125 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8125
NorESM2-LM | NCC | AerChemMIP | piClim-CH4 | Oliviè, Dirk Jan Leo et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 AerChemMIP piClim-CH4. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8129 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8129
NorESM2-LM | NCC | AerChemMIP | piClim-N2O | Oliviè, Dirk Jan Leo et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 AerChemMIP piClim-N2O. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8137 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8137
NorESM2-LM | NCC | AerChemMIP | piClim-NTCF | Oliviè, Dirk Jan Leo et al. (2020). NCC NorESM2-LM model output prepared for CMIP6 AerChemMIP piClim-NTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8149 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8149
NorESM2-LM | NCC | AerChemMIP | piClim-O3 | Oliviè, Dirk Jan Leo et al. (2021). NCC NorESM2-LM model output prepared for CMIP6 AerChemMIP piClim-O3. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8153 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8153
NorESM2-LM | NCC | AerChemMIP | piClim-OC | Oliviè, Dirk Jan Leo et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 AerChemMIP piClim-OC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8157 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8157
NorESM2-LM | NCC | AerChemMIP | piClim-SO2 | Oliviè, Dirk Jan Leo et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 AerChemMIP piClim-SO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8161 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8161
NorESM2-LM | NCC | AerChemMIP | ssp370-lowNTCF | Oliviè, Dirk Jan Leo et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 AerChemMIP ssp370-lowNTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8275 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8275
NorESM2-LM | NCC | AerChemMIP | ssp370SST | Oliviè, Dirk Jan Leo et al. (2020). NCC NorESM2-LM model output prepared for CMIP6 AerChemMIP ssp370SST. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8281 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8281
NorESM2-LM | NCC | AerChemMIP | ssp370SST-lowAer | Oliviè, Dirk Jan Leo et al. (2020). NCC NorESM2-LM model output prepared for CMIP6 AerChemMIP ssp370SST-lowAer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8285 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8285
NorESM2-LM | NCC | C4MIP | 1pctCO2-bgc | Schwinger, Jörg et al. (2020). NCC NorESM2-LM model output prepared for CMIP6 C4MIP 1pctCO2-bgc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13724 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13724
NorESM2-LM | NCC | C4MIP | 1pctCO2-rad | Schwinger, Jörg et al. (2020). NCC NorESM2-LM model output prepared for CMIP6 C4MIP 1pctCO2-rad. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13726 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13726
NorESM2-LM | NCC | C4MIP | esm-1pct-brch-1000PgC | Schwinger, Jörg et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 C4MIP esm-1pct-brch-1000PgC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13731 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13731
NorESM2-LM | NCC | C4MIP | esm-ssp585 | Schwinger, Jörg et al. (2020). NCC NorESM2-LM model output prepared for CMIP6 C4MIP esm-ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13748 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13748
NorESM2-LM | NCC | C4MIP | hist-bgc | Schwinger, Jörg et al. (2021). NCC NorESM2-LM model output prepared for CMIP6 C4MIP hist-bgc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13758 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13758
NorESM2-LM | NCC | C4MIP | ssp534-over-bgc | Schwinger, Jörg et al. (2021). NCC NorESM2-LM model output prepared for CMIP6 C4MIP ssp534-over-bgc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13780 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13780
NorESM2-LM | NCC | C4MIP | ssp585-bgc | Schwinger, Jörg et al. (2021). NCC NorESM2-LM model output prepared for CMIP6 C4MIP ssp585-bgc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13781 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13781
NorESM2-LM | NCC | CDRMIP | 1pctCO2-cdr | Tjiputra, Jerry et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 CDRMIP 1pctCO2-cdr. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13725 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13725
NorESM2-LM | NCC | CDRMIP | esm-pi-CO2pulse | Tjiputra, Jerry et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 CDRMIP esm-pi-CO2pulse. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13745 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13745
NorESM2-LM | NCC | CDRMIP | esm-pi-cdr-pulse | Tjiputra, Jerry et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 CDRMIP esm-pi-cdr-pulse. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13746 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13746
NorESM2-LM | NCC | CDRMIP | esm-ssp534-over | Tjiputra, Jerry et al. (2023). NCC NorESM2-LM model output prepared for CMIP6 CDRMIP esm-ssp534-over. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13747 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13747
NorESM2-LM | NCC | CDRMIP | esm-ssp585-ocn-alk | Tjiputra, Jerry et al. (2023). NCC NorESM2-LM model output prepared for CMIP6 CDRMIP esm-ssp585-ocn-alk. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13749 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13749
NorESM2-LM | NCC | CFMIP | amip-4xCO2 | Oliviè, Dirk Jan Leo et al. (2021). NCC NorESM2-LM model output prepared for CMIP6 CFMIP amip-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7853 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7853
NorESM2-LM | NCC | CFMIP | amip-p4K | Oliviè, Dirk Jan Leo et al. (2021). NCC NorESM2-LM model output prepared for CMIP6 CFMIP amip-p4K. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7868 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7868
NorESM2-LM | NCC | CMIP | 1pctCO2 | Seland, Øyvind et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7802 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7802
NorESM2-LM | NCC | CMIP | abrupt-4xCO2 | Seland, Øyvind et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7836 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7836
NorESM2-LM | NCC | CMIP | amip | Seland, Øyvind et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7848 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7848
NorESM2-LM | NCC | CMIP | esm-hist | Seland, Øyvind et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 CMIP esm-hist. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7924 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7924
NorESM2-LM | NCC | CMIP | esm-piControl | Seland, Øyvind et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 CMIP esm-piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7936 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7936
NorESM2-LM | NCC | CMIP | historical | Seland, Øyvind et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8036 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8036
NorESM2-LM | NCC | CMIP | piControl | Seland, Øyvind et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8217 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8217
NorESM2-LM | NCC | DAMIP | hist-GHG | Seland, Øyvind et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 DAMIP hist-GHG. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7966 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7966
NorESM2-LM | NCC | DAMIP | hist-aer | Seland, Øyvind et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 DAMIP hist-aer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7969 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7969
NorESM2-LM | NCC | DAMIP | hist-nat | Seland, Øyvind et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 DAMIP hist-nat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7979 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7979
NorESM2-LM | NCC | DAMIP | hist-sol | Seland, Øyvind et al. (2023). NCC NorESM2-LM model output prepared for CMIP6 DAMIP hist-sol. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7992 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7992
NorESM2-LM | NCC | DAMIP | hist-volc | Seland, Øyvind et al. (2023). NCC NorESM2-LM model output prepared for CMIP6 DAMIP hist-volc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8004 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8004
NorESM2-LM | NCC | DAMIP | ssp245-GHG | Seland, Øyvind et al. (2021). NCC NorESM2-LM model output prepared for CMIP6 DAMIP ssp245-GHG. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8256 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8256
NorESM2-LM | NCC | DAMIP | ssp245-aer | Seland, Øyvind et al. (2021). NCC NorESM2-LM model output prepared for CMIP6 DAMIP ssp245-aer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8259 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8259
NorESM2-LM | NCC | DAMIP | ssp245-covid | Seland, Øyvind et al. (2020). NCC NorESM2-LM model output prepared for CMIP6 DAMIP ssp245-covid. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14995 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14995
NorESM2-LM | NCC | DAMIP | ssp245-nat | Seland, Øyvind et al. (2021). NCC NorESM2-LM model output prepared for CMIP6 DAMIP ssp245-nat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8262 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8262
NorESM2-LM | NCC | GeoMIP | G7cirrus | Oliviè, Dirk Jan Leo et al. (2025). NCC NorESM2-LM model output prepared for CMIP6 GeoMIP G7cirrus. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.18131 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.18131
NorESM2-LM | NCC | LUMIP | deforest-globe | Cai, Lei et al. (2020). NCC NorESM2-LM model output prepared for CMIP6 LUMIP deforest-globe. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7921 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7921
NorESM2-LM | NCC | LUMIP | esm-ssp585-ssp126Lu | Cai, Lei et al. (2020). NCC NorESM2-LM model output prepared for CMIP6 LUMIP esm-ssp585-ssp126Lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7948 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7948
NorESM2-LM | NCC | LUMIP | hist-noLu | Cai, Lei et al. (2020). NCC NorESM2-LM model output prepared for CMIP6 LUMIP hist-noLu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7982 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7982
NorESM2-LM | NCC | LUMIP | ssp126-ssp370Lu | Cai, Lei et al. (2020). NCC NorESM2-LM model output prepared for CMIP6 LUMIP ssp126-ssp370Lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8251 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8251
NorESM2-LM | NCC | LUMIP | ssp370-ssp126Lu | Cai, Lei et al. (2020). NCC NorESM2-LM model output prepared for CMIP6 LUMIP ssp370-ssp126Lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8279 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8279
NorESM2-LM | NCC | OMIP | omip1 | Bentsen, Mats et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 OMIP omip1. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8081 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8081
NorESM2-LM | NCC | OMIP | omip1-spunup | Bentsen, Mats et al. (2020). NCC NorESM2-LM model output prepared for CMIP6 OMIP omip1-spunup. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8085 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8085
NorESM2-LM | NCC | OMIP | omip2 | Bentsen, Mats et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 OMIP omip2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8089 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8089
NorESM2-LM | NCC | PAMIP | modelSST-futArcSIC | Graff, Lise Seland et al. (2020). NCC NorESM2-LM model output prepared for CMIP6 PAMIP modelSST-futArcSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13759 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13759
NorESM2-LM | NCC | PAMIP | modelSST-pdSIC | Graff, Lise Seland et al. (2020). NCC NorESM2-LM model output prepared for CMIP6 PAMIP modelSST-pdSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13760 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13760
NorESM2-LM | NCC | PAMIP | pa-futArcSIC | Graff, Lise Seland et al. (2020). NCC NorESM2-LM model output prepared for CMIP6 PAMIP pa-futArcSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13763 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13763
NorESM2-LM | NCC | PAMIP | pa-futArcSIC-ext | Graff, Lise Seland et al. (2020). NCC NorESM2-LM model output prepared for CMIP6 PAMIP pa-futArcSIC-ext. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13764 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13764
NorESM2-LM | NCC | PAMIP | pa-pdSIC | Graff, Lise Seland et al. (2020). NCC NorESM2-LM model output prepared for CMIP6 PAMIP pa-pdSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13765 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13765
NorESM2-LM | NCC | PAMIP | pa-pdSIC-ext | Graff, Lise Seland et al. (2020). NCC NorESM2-LM model output prepared for CMIP6 PAMIP pa-pdSIC-ext. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13766 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13766
NorESM2-LM | NCC | PAMIP | pdSST-futAntSIC | Graff, Lise Seland et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 PAMIP pdSST-futAntSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13769 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13769
NorESM2-LM | NCC | PAMIP | pdSST-futArcSIC | Graff, Lise Seland et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 PAMIP pdSST-futArcSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13770 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13770
NorESM2-LM | NCC | PAMIP | pdSST-pdSIC | Graff, Lise Seland et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 PAMIP pdSST-pdSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13774 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13774
NorESM2-LM | NCC | PAMIP | pdSST-piAntSIC | Graff, Lise Seland et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 PAMIP pdSST-piAntSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13776 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13776
NorESM2-LM | NCC | PAMIP | pdSST-piArcSIC | Graff, Lise Seland et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 PAMIP pdSST-piArcSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13777 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13777
NorESM2-LM | NCC | PAMIP | piSST-pdSIC | Graff, Lise Seland et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 PAMIP piSST-pdSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13778 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13778
NorESM2-LM | NCC | PMIP | lig127k | Zhang, Zhongshi et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 PMIP lig127k. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8078 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8078
NorESM2-LM | NCC | PMIP | midHolocene | Zhang, Zhongshi et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 PMIP midHolocene. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8079 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8079
NorESM2-LM | NCC | RFMIP | hist-spAer-all | Oliviè, Dirk Jan Leo et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 RFMIP hist-spAer-all. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7998 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7998
NorESM2-LM | NCC | RFMIP | piClim-4xCO2 | Oliviè, Dirk Jan Leo et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 RFMIP piClim-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8122 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8122
NorESM2-LM | NCC | RFMIP | piClim-aer | Oliviè, Dirk Jan Leo et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 RFMIP piClim-aer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8169 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8169
NorESM2-LM | NCC | RFMIP | piClim-anthro | Oliviè, Dirk Jan Leo et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 RFMIP piClim-anthro. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8176 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8176
NorESM2-LM | NCC | RFMIP | piClim-control | Oliviè, Dirk Jan Leo et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 RFMIP piClim-control. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8179 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8179
NorESM2-LM | NCC | RFMIP | piClim-ghg | Oliviè, Dirk Jan Leo et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 RFMIP piClim-ghg. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8186 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8186
NorESM2-LM | NCC | RFMIP | piClim-histaer | Oliviè, Dirk Jan Leo et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 RFMIP piClim-histaer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8189 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8189
NorESM2-LM | NCC | RFMIP | piClim-histall | Oliviè, Dirk Jan Leo et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 RFMIP piClim-histall. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8192 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8192
NorESM2-LM | NCC | RFMIP | piClim-histghg | Oliviè, Dirk Jan Leo et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 RFMIP piClim-histghg. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8195 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8195
NorESM2-LM | NCC | RFMIP | piClim-histnat | Oliviè, Dirk Jan Leo et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 RFMIP piClim-histnat. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8198 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8198
NorESM2-LM | NCC | RFMIP | piClim-lu | Oliviè, Dirk Jan Leo et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 RFMIP piClim-lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8201 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8201
NorESM2-LM | NCC | RFMIP | piClim-spAer-aer | Oliviè, Dirk Jan Leo et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 RFMIP piClim-spAer-aer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8204 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8204
NorESM2-LM | NCC | RFMIP | piClim-spAer-anthro | Oliviè, Dirk Jan Leo et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 RFMIP piClim-spAer-anthro. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8207 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8207
NorESM2-LM | NCC | RFMIP | piClim-spAer-histaer | Oliviè, Dirk Jan Leo et al. (2021). NCC NorESM2-LM model output prepared for CMIP6 RFMIP piClim-spAer-histaer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8210 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8210
NorESM2-LM | NCC | ScenarioMIP | ssp126 | Seland, Øyvind et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8248 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8248
NorESM2-LM | NCC | ScenarioMIP | ssp245 | Seland, Øyvind et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8253 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8253
NorESM2-LM | NCC | ScenarioMIP | ssp370 | Seland, Øyvind et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 ScenarioMIP ssp370. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8268 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8268
NorESM2-LM | NCC | ScenarioMIP | ssp534-over | Seland, Øyvind et al. (2021). NCC NorESM2-LM model output prepared for CMIP6 ScenarioMIP ssp534-over. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8315 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8315
NorESM2-LM | NCC | ScenarioMIP | ssp585 | Seland, Øyvind et al. (2019). NCC NorESM2-LM model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8319 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8319
NorESM2-MM | NCC | CMIP | 1pctCO2 | Bentsen, Mats et al. (2019). NCC NorESM2-MM model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7806 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7806
NorESM2-MM | NCC | CMIP | abrupt-4xCO2 | Bentsen, Mats et al. (2019). NCC NorESM2-MM model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7840 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7840
NorESM2-MM | NCC | CMIP | amip | Bentsen, Mats et al. (2019). NCC NorESM2-MM model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7852 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7852
NorESM2-MM | NCC | CMIP | historical | Bentsen, Mats et al. (2019). NCC NorESM2-MM model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8040 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8040
NorESM2-MM | NCC | CMIP | piControl | Bentsen, Mats et al. (2019). NCC NorESM2-MM model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8221 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8221
NorESM2-MM | NCC | RFMIP | piClim-4xCO2 | Oliviè, Dirk Jan Leo et al. (2020). NCC NorESM2-MM model output prepared for CMIP6 RFMIP piClim-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8124 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8124
NorESM2-MM | NCC | RFMIP | piClim-aer | Oliviè, Dirk Jan Leo et al. (2020). NCC NorESM2-MM model output prepared for CMIP6 RFMIP piClim-aer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8171 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8171
NorESM2-MM | NCC | RFMIP | piClim-control | Oliviè, Dirk Jan Leo et al. (2020). NCC NorESM2-MM model output prepared for CMIP6 RFMIP piClim-control. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8181 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8181
NorESM2-MM | NCC | ScenarioMIP | ssp126 | Bentsen, Mats et al. (2019). NCC NorESM2-MM model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8250 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8250
NorESM2-MM | NCC | ScenarioMIP | ssp245 | Bentsen, Mats et al. (2019). NCC NorESM2-MM model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8255 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8255
NorESM2-MM | NCC | ScenarioMIP | ssp370 | Bentsen, Mats et al. (2019). NCC NorESM2-MM model output prepared for CMIP6 ScenarioMIP ssp370. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8270 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8270
NorESM2-MM | NCC | ScenarioMIP | ssp585 | Bentsen, Mats et al. (2019). NCC NorESM2-MM model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8321 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8321
RRTMG-LW-4-91 | AER | RFMIP | rad-irf | Mlawer, Eli; Pernak, Richard (2020). AER RRTMG-LW4.91 model output prepared for CMIP6 RFMIP rad-irf. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10019 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10019
RRTMG-SW-4-02 | AER | RFMIP | rad-irf | Mlawer, Eli; Pernak, Richard (2020). AER RRTMG-SW4.02 model output prepared for CMIP6 RFMIP rad-irf. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10020 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10020
RTE-RRTMGP-181204 | RTE-RRTMGP-Consortium | RFMIP | rad-irf | Pincus, Robert (2019). RTE-RRTMGP-Consortium RTE+RRTMGP (2018-12-04full-resolution) model output prepared for CMIP6 RFMIP rad-irf. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10173 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10173
SAM0-UNICON | SNU | CMIP | 1pctCO2 | Park, Sungsu; Shin, Jihoon (2019). SNU SAM0-UNICON model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7782 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7782
SAM0-UNICON | SNU | CMIP | abrupt-4xCO2 | Park, Sungsu; Shin, Jihoon (2019). SNU SAM0-UNICON model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7783 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7783
SAM0-UNICON | SNU | CMIP | amip | Park, Sungsu; Shin, Jihoon (2019). SNU SAM0-UNICON model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7784 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7784
SAM0-UNICON | SNU | CMIP | historical | Park, Sungsu; Shin, Jihoon (2019). SNU SAM0-UNICON model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7789 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7789
SAM0-UNICON | SNU | CMIP | piControl | Park, Sungsu; Shin, Jihoon (2019). SNU SAM0-UNICON model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.7791 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.7791
TaiESM1 | AS-RCEC | AerChemMIP | hist-piNTCF | Tsai, I-Chun et al. (2021). AS-RCEC TaiESM1.0 model output prepared for CMIP6 AerChemMIP hist-piNTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9744 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9744
TaiESM1 | AS-RCEC | AerChemMIP | histSST | Tsai, I-Chun et al. (2020). AS-RCEC TaiESM1.0 model output prepared for CMIP6 AerChemMIP histSST. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9747 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9747
TaiESM1 | AS-RCEC | AerChemMIP | histSST-piNTCF | Tsai, I-Chun et al. (2020). AS-RCEC TaiESM1.0 model output prepared for CMIP6 AerChemMIP histSST-piNTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9752 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9752
TaiESM1 | AS-RCEC | AerChemMIP | piClim-NTCF | Tsai, I-Chun et al. (2021). AS-RCEC TaiESM1.0 model output prepared for CMIP6 AerChemMIP piClim-NTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9790 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9790
TaiESM1 | AS-RCEC | CFMIP | abrupt-0p5xCO2 | Shiu, Chein-Jung et al. (2021). AS-RCEC TaiESM1.0 model output prepared for CMIP6 CFMIP abrupt-0p5xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9706 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9706
TaiESM1 | AS-RCEC | CFMIP | abrupt-2xCO2 | Shiu, Chein-Jung et al. (2021). AS-RCEC TaiESM1.0 model output prepared for CMIP6 CFMIP abrupt-2xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9707 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9707
TaiESM1 | AS-RCEC | CFMIP | amip-4xCO2 | Shiu, Chein-Jung et al. (2021). AS-RCEC TaiESM1.0 model output prepared for CMIP6 CFMIP amip-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9714 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9714
TaiESM1 | AS-RCEC | CFMIP | amip-future4K | Shiu, Chein-Jung et al. (2021). AS-RCEC TaiESM1.0 model output prepared for CMIP6 CFMIP amip-future4K. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9718 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9718
TaiESM1 | AS-RCEC | CFMIP | amip-lwoff | Shiu, Chein-Jung et al. (2021). AS-RCEC TaiESM1.0 model output prepared for CMIP6 CFMIP amip-lwoff. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9721 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9721
TaiESM1 | AS-RCEC | CFMIP | amip-m4K | Shiu, Chein-Jung et al. (2020). AS-RCEC TaiESM1.0 model output prepared for CMIP6 CFMIP amip-m4K. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9722 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9722
TaiESM1 | AS-RCEC | CFMIP | amip-p4K | Shiu, Chein-Jung et al. (2021). AS-RCEC TaiESM1.0 model output prepared for CMIP6 CFMIP amip-p4K. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9723 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9723
TaiESM1 | AS-RCEC | CFMIP | amip-p4K-lwoff | Shiu, Chein-Jung et al. (2021). AS-RCEC TaiESM1.0 model output prepared for CMIP6 CFMIP amip-p4K-lwoff. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9724 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9724
TaiESM1 | AS-RCEC | CFMIP | amip-piForcing | Shiu, Chein-Jung et al. (2021). AS-RCEC TaiESM1.0 model output prepared for CMIP6 CFMIP amip-piForcing. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9725 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9725
TaiESM1 | AS-RCEC | CFMIP | aqua-4xCO2 | Shiu, Chein-Jung et al. (2021). AS-RCEC TaiESM1.0 model output prepared for CMIP6 CFMIP aqua-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9726 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9726
TaiESM1 | AS-RCEC | CFMIP | aqua-control | Shiu, Chein-Jung et al. (2021). AS-RCEC TaiESM1.0 model output prepared for CMIP6 CFMIP aqua-control. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9727 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9727
TaiESM1 | AS-RCEC | CFMIP | aqua-control-lwoff | Shiu, Chein-Jung et al. (2021). AS-RCEC TaiESM1.0 model output prepared for CMIP6 CFMIP aqua-control-lwoff. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9728 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9728
TaiESM1 | AS-RCEC | CFMIP | aqua-p4K | Shiu, Chein-Jung et al. (2021). AS-RCEC TaiESM1.0 model output prepared for CMIP6 CFMIP aqua-p4K. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9729 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9729
TaiESM1 | AS-RCEC | CFMIP | aqua-p4K-lwoff | Shiu, Chein-Jung et al. (2021). AS-RCEC TaiESM1.0 model output prepared for CMIP6 CFMIP aqua-p4K-lwoff. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9730 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9730
TaiESM1 | AS-RCEC | CMIP | 1pctCO2 | Lee, Wei-Liang; Liang, Hsin-Chien (2020). AS-RCEC TaiESM1.0 model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9702 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9702
TaiESM1 | AS-RCEC | CMIP | abrupt-4xCO2 | Lee, Wei-Liang; Liang, Hsin-Chien (2020). AS-RCEC TaiESM1.0 model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9709 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9709
TaiESM1 | AS-RCEC | CMIP | amip | Lee, Wei-Liang; Liang, Hsin-Chien (2019). AS-RCEC TaiESM1.0 model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9713 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9713
TaiESM1 | AS-RCEC | CMIP | historical | Lee, Wei-Liang; Liang, Hsin-Chien (2020). AS-RCEC TaiESM1.0 model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9755 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9755
TaiESM1 | AS-RCEC | CMIP | piControl | Lee, Wei-Liang; Liang, Hsin-Chien (2020). AS-RCEC TaiESM1.0 model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9798 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9798
TaiESM1 | AS-RCEC | GMMIP | amip-hist | Wang, Yi-Chi et al. (2020). AS-RCEC TaiESM1.0 model output prepared for CMIP6 GMMIP amip-hist. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9719 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9719
TaiESM1 | AS-RCEC | PAMIP | pdSST-futArcSIC | Hong, Hao-Jhe et al. (2020). AS-RCEC TaiESM1.0 model output prepared for CMIP6 PAMIP pdSST-futArcSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15229 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15229
TaiESM1 | AS-RCEC | PAMIP | pdSST-pdSIC | Hong, Hao-Jhe et al. (2020). AS-RCEC TaiESM1.0 model output prepared for CMIP6 PAMIP pdSST-pdSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15233 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15233
TaiESM1 | AS-RCEC | PAMIP | pdSST-piArcSIC | Hong, Hao-Jhe et al. (2020). AS-RCEC TaiESM1.0 model output prepared for CMIP6 PAMIP pdSST-piArcSIC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.15236 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.15236
TaiESM1 | AS-RCEC | RFMIP | piClim-control | Lee, Wei-Liang; Liang, Hsin-Chien (2021). AS-RCEC TaiESM1.0 model output prepared for CMIP6 RFMIP piClim-control. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.17707 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.17707
TaiESM1 | AS-RCEC | ScenarioMIP | ssp126 | Lee, Wei-Liang; Liang, Hsin-Chien (2020). AS-RCEC TaiESM1.0 model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9806 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9806
TaiESM1 | AS-RCEC | ScenarioMIP | ssp245 | Lee, Wei-Liang; Liang, Hsin-Chien (2020). AS-RCEC TaiESM1.0 model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9808 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9808
TaiESM1 | AS-RCEC | ScenarioMIP | ssp370 | Lee, Wei-Liang; Liang, Hsin-Chien (2020). AS-RCEC TaiESM1.0 model output prepared for CMIP6 ScenarioMIP ssp370. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9809 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9809
TaiESM1 | AS-RCEC | ScenarioMIP | ssp585 | Lee, Wei-Liang; Liang, Hsin-Chien (2020). AS-RCEC TaiESM1.0 model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9823 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9823
TaiESM1-TIMCOM | NTU | OMIP | omip1 | Tseng, Yu-Heng et al. (2020). NTU TaiESM1-TIMCOM model output prepared for CMIP6 OMIP omip1. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14334 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14334
TaiESM1-TIMCOM | NTU | OMIP | omip2 | Tseng, Yu-Heng et al. (2020). NTU TaiESM1-TIMCOM model output prepared for CMIP6 OMIP omip2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14336 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14336
TaiESM1-TIMCOM2 | NTU | OMIP | omip1 | Tseng, Yu-Heng et al. (2021). NTU TaiESM1-TIMCOM2 model output prepared for CMIP6 OMIP omip1. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16334 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16334
TaiESM1-TIMCOM2 | NTU | OMIP | omip2 | Tseng, Yu-Heng et al. (2021). NTU TaiESM1-TIMCOM2 model output prepared for CMIP6 OMIP omip2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16336 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16336
UKESM1-0-LL | MOHC | AerChemMIP | hist-piAer | O'Connor, Fiona (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 AerChemMIP hist-piAer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6062 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6062
UKESM1-0-LL | MOHC | AerChemMIP | histSST | O'Connor, Fiona (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 AerChemMIP histSST. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6077 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6077
UKESM1-0-LL | MOHC | AerChemMIP | histSST-piAer | O'Connor, Fiona (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 AerChemMIP histSST-piAer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6085 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6085
UKESM1-0-LL | MOHC | AerChemMIP | piClim-2xDMS | O'Connor, Fiona (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 AerChemMIP piClim-2xDMS. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6200 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6200
UKESM1-0-LL | MOHC | AerChemMIP | piClim-2xNOx | O'Connor, Fiona (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 AerChemMIP piClim-2xNOx. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6204 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6204
UKESM1-0-LL | MOHC | AerChemMIP | piClim-2xVOC | O'Connor, Fiona (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 AerChemMIP piClim-2xVOC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6208 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6208
UKESM1-0-LL | MOHC | AerChemMIP | piClim-2xdust | O'Connor, Fiona (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 AerChemMIP piClim-2xdust. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6212 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6212
UKESM1-0-LL | MOHC | AerChemMIP | piClim-2xfire | O'Connor, Fiona (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 AerChemMIP piClim-2xfire. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6216 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6216
UKESM1-0-LL | MOHC | AerChemMIP | piClim-2xss | O'Connor, Fiona (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 AerChemMIP piClim-2xss. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6220 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6220
UKESM1-0-LL | MOHC | AerChemMIP | piClim-BC | O'Connor, Fiona (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 AerChemMIP piClim-BC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6225 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6225
UKESM1-0-LL | MOHC | AerChemMIP | piClim-CH4 | O'Connor, Fiona (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 AerChemMIP piClim-CH4. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6229 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6229
UKESM1-0-LL | MOHC | AerChemMIP | piClim-HC | O'Connor, Fiona (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 AerChemMIP piClim-HC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6233 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6233
UKESM1-0-LL | MOHC | AerChemMIP | piClim-NTCF | O'Connor, Fiona (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 AerChemMIP piClim-NTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6249 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6249
UKESM1-0-LL | MOHC | AerChemMIP | piClim-OC | O'Connor, Fiona (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 AerChemMIP piClim-OC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6257 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6257
UKESM1-0-LL | MOHC | AerChemMIP | piClim-SO2 | O'Connor, Fiona (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 AerChemMIP piClim-SO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6261 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6261
UKESM1-0-LL | MOHC | AerChemMIP | piClim-aer | O'Connor, Fiona (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 AerChemMIP piClim-aer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6270 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6270
UKESM1-0-LL | MOHC | AerChemMIP | piClim-control | O'Connor, Fiona (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 AerChemMIP piClim-control. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6276 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6276
UKESM1-0-LL | MOHC | AerChemMIP | ssp370-lowNTCFCH4 | O'Connor, Fiona (2020). MOHC UKESM1.0-LL model output prepared for CMIP6 AerChemMIP ssp370-lowNTCFCH4. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13521 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13521
UKESM1-0-LL | MOHC | AerChemMIP | ssp370SST-lowAer | O'Connor, Fiona (2020). MOHC UKESM1.0-LL model output prepared for CMIP6 AerChemMIP ssp370SST-lowAer. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6365 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6365
UKESM1-0-LL | MOHC | AerChemMIP | ssp370SST-lowBC | O'Connor, Fiona (2020). MOHC UKESM1.0-LL model output prepared for CMIP6 AerChemMIP ssp370SST-lowBC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6369 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6369
UKESM1-0-LL | MOHC | AerChemMIP | ssp370SST-lowCH4 | O'Connor, Fiona (2020). MOHC UKESM1.0-LL model output prepared for CMIP6 AerChemMIP ssp370SST-lowCH4. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6373 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6373
UKESM1-0-LL | MOHC | AerChemMIP | ssp370SST-lowNTCF | O'Connor, Fiona (2020). MOHC UKESM1.0-LL model output prepared for CMIP6 AerChemMIP ssp370SST-lowNTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6377 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6377
UKESM1-0-LL | MOHC | AerChemMIP | ssp370SST-lowNTCFCH4 | O'Connor, Fiona (2020). MOHC UKESM1.0-LL model output prepared for CMIP6 AerChemMIP ssp370SST-lowNTCFCH4. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13525 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13525
UKESM1-0-LL | MOHC | AerChemMIP | ssp370SST-ssp126Lu | O'Connor, Fiona (2021). MOHC UKESM1.0-LL model output prepared for CMIP6 AerChemMIP ssp370SST-ssp126Lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6385 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6385
UKESM1-0-LL | MOHC | AerChemMIP | ssp370pdSST | O'Connor, Fiona (2020). MOHC UKESM1.0-LL model output prepared for CMIP6 AerChemMIP ssp370pdSST. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11405 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11405
UKESM1-0-LL | MOHC | C4MIP | 1pctCO2-bgc | Jones, Chris (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 C4MIP 1pctCO2-bgc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5796 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5796
UKESM1-0-LL | MOHC | C4MIP | 1pctCO2-rad | Jones, Chris (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 C4MIP 1pctCO2-rad. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5800 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5800
UKESM1-0-LL | MOHC | C4MIP | 1pctCO2Ndep | Jones, Chris (2020). MOHC UKESM1.0-LL model output prepared for CMIP6 C4MIP 1pctCO2Ndep. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5804 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5804
UKESM1-0-LL | MOHC | C4MIP | 1pctCO2Ndep-bgc | Jones, Chris (2020). MOHC UKESM1.0-LL model output prepared for CMIP6 C4MIP 1pctCO2Ndep-bgc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5808 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5808
UKESM1-0-LL | MOHC | C4MIP | esm-1pct-brch-1000PgC | Jones, Chris (2020). MOHC UKESM1.0-LL model output prepared for CMIP6 C4MIP esm-1pct-brch-1000PgC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10785 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10785
UKESM1-0-LL | MOHC | C4MIP | esm-1pct-brch-2000PgC | Jones, Chris (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 C4MIP esm-1pct-brch-2000PgC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10789 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10789
UKESM1-0-LL | MOHC | C4MIP | esm-1pct-brch-750PgC | Jones, Chris (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 C4MIP esm-1pct-brch-750PgC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.10793 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.10793
UKESM1-0-LL | MOHC | C4MIP | esm-ssp585 | Jones, Chris (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 C4MIP esm-ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5969 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5969
UKESM1-0-LL | MOHC | C4MIP | hist-bgc | Jones, Chris (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 C4MIP hist-bgc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6055 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6055
UKESM1-0-LL | MOHC | C4MIP | ssp534-over-bgc | Jones, Chris (2020). MOHC UKESM1.0-LL model output prepared for CMIP6 C4MIP ssp534-over-bgc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6401 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6401
UKESM1-0-LL | MOHC | C4MIP | ssp585-bgc | Jones, Chris (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 C4MIP ssp585-bgc. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6409 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6409
UKESM1-0-LL | MOHC | CDRMIP | 1pctCO2-cdr | Jones, Chris et al. (2020). MOHC UKESM1.0-LL model output prepared for CMIP6 CDRMIP 1pctCO2-cdr. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12183 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12183
UKESM1-0-LL | MOHC | CDRMIP | esm-pi-CO2pulse | Jones, Chris et al. (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 CDRMIP esm-pi-CO2pulse. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12199 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12199
UKESM1-0-LL | MOHC | CDRMIP | esm-pi-cdr-pulse | Jones, Chris et al. (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 CDRMIP esm-pi-cdr-pulse. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12201 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12201
UKESM1-0-LL | MOHC | CDRMIP | esm-ssp534-over | Jones, Chris et al. (2020). MOHC UKESM1.0-LL model output prepared for CMIP6 CDRMIP esm-ssp534-over. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12203 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12203
UKESM1-0-LL | MOHC | CDRMIP | esm-ssp585-ocn-alk | Jones, Chris et al. (2020). MOHC UKESM1.0-LL model output prepared for CMIP6 CDRMIP esm-ssp585-ocn-alk. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12205 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12205
UKESM1-0-LL | MOHC | CDRMIP | esm-ssp585-ocn-alk-stop | Jones, Chris et al. (2021). MOHC UKESM1.0-LL model output prepared for CMIP6 CDRMIP esm-ssp585-ocn-alk-stop. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12207 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12207
UKESM1-0-LL | MOHC | CDRMIP | esm-ssp585ext | Jones, Chris et al. (2021). MOHC UKESM1.0-LL model output prepared for CMIP6 CDRMIP esm-ssp585ext. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.12211 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.12211
UKESM1-0-LL | MOHC | CMIP | 1pctCO2 | Tang, Yongming et al. (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5792 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5792
UKESM1-0-LL | MOHC | CMIP | abrupt-4xCO2 | Tang, Yongming et al. (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5843 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5843
UKESM1-0-LL | MOHC | CMIP | amip | Tang, Yongming et al. (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5857 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5857
UKESM1-0-LL | MOHC | CMIP | esm-hist | Tang, Yongming et al. (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 CMIP esm-hist. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5929 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5929
UKESM1-0-LL | MOHC | CMIP | esm-piControl | Tang, Yongming et al. (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 CMIP esm-piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5953 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5953
UKESM1-0-LL | MOHC | CMIP | historical | Tang, Yongming et al. (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6113 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6113
UKESM1-0-LL | MOHC | CMIP | piControl | Tang, Yongming et al. (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6298 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6298
UKESM1-0-LL | MOHC | DAMIP | ssp245-cov-fossil | Rumbold, Steve et al. (2020). MOHC UKESM1.0-LL model output prepared for CMIP6 DAMIP ssp245-cov-fossil. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14872 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14872
UKESM1-0-LL | MOHC | DAMIP | ssp245-cov-modgreen | Rumbold, Steve et al. (2020). MOHC UKESM1.0-LL model output prepared for CMIP6 DAMIP ssp245-cov-modgreen. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14876 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14876
UKESM1-0-LL | MOHC | DAMIP | ssp245-cov-strgreen | Rumbold, Steve et al. (2020). MOHC UKESM1.0-LL model output prepared for CMIP6 DAMIP ssp245-cov-strgreen. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14880 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14880
UKESM1-0-LL | MOHC | DAMIP | ssp245-covid | Rumbold, Steve et al. (2020). MOHC UKESM1.0-LL model output prepared for CMIP6 DAMIP ssp245-covid. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14884 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14884
UKESM1-0-LL | MOHC | GeoMIP | G1 | Jones, Andy (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 GeoMIP G1. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5812 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5812
UKESM1-0-LL | MOHC | GeoMIP | G6solar | Jones, Andy (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 GeoMIP G6solar. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5820 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5820
UKESM1-0-LL | MOHC | GeoMIP | G6sulfur | Jones, Andy (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 GeoMIP G6sulfur. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5822 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5822
UKESM1-0-LL | MOHC | GeoMIP | G7cirrus | Jones, Andy (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 GeoMIP G7cirrus. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5828 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5828
UKESM1-0-LL | MOHC | LS3MIP | land-hist-cruNcep | Wiltshire, Andy et al. (2020). MOHC UKESM1.0-LL model output prepared for CMIP6 LS3MIP land-hist-cruNcep. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.14506 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.14506
UKESM1-0-LL | MOHC | LUMIP | deforest-globe | Wiltshire, Andy (2020). MOHC UKESM1.0-LL model output prepared for CMIP6 LUMIP deforest-globe. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5919 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5919
UKESM1-0-LL | MOHC | LUMIP | esm-ssp585-ssp126Lu | Wiltshire, Andy (2020). MOHC UKESM1.0-LL model output prepared for CMIP6 LUMIP esm-ssp585-ssp126Lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.5973 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.5973
UKESM1-0-LL | MOHC | LUMIP | hist-noLu | Wiltshire, Andy (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 LUMIP hist-noLu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6060 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6060
UKESM1-0-LL | MOHC | LUMIP | land-cCO2 | Wiltshire, Andy (2020). MOHC UKESM1.0-LL model output prepared for CMIP6 LUMIP land-cCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6129 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6129
UKESM1-0-LL | MOHC | LUMIP | land-cClim | Wiltshire, Andy (2020). MOHC UKESM1.0-LL model output prepared for CMIP6 LUMIP land-cClim. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6131 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6131
UKESM1-0-LL | MOHC | LUMIP | land-hist | Wiltshire, Andy (2020). MOHC UKESM1.0-LL model output prepared for CMIP6 LUMIP land-hist. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6143 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6143
UKESM1-0-LL | MOHC | LUMIP | land-noLu | Wiltshire, Andy (2020). MOHC UKESM1.0-LL model output prepared for CMIP6 LUMIP land-noLu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6156 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6156
UKESM1-0-LL | MOHC | LUMIP | ssp126-ssp370Lu | Wiltshire, Andy (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 LUMIP ssp126-ssp370Lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6337 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6337
UKESM1-0-LL | MOHC | LUMIP | ssp370-ssp126Lu | Wiltshire, Andy (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 LUMIP ssp370-ssp126Lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6359 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6359
UKESM1-0-LL | MOHC | RFMIP | piClim-4xCO2 | Andrews, Tim (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 RFMIP piClim-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11086 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11086
UKESM1-0-LL | MOHC | RFMIP | piClim-anthro | Andrews, Tim (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 RFMIP piClim-anthro. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11090 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11090
UKESM1-0-LL | MOHC | RFMIP | piClim-ghg | Andrews, Tim (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 RFMIP piClim-ghg. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11094 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11094
UKESM1-0-LL | MOHC | RFMIP | piClim-lu | Andrews, Tim (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 RFMIP piClim-lu. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.11104 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.11104
UKESM1-0-LL | MOHC | ScenarioMIP | ssp119 | Good, Peter et al. (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 ScenarioMIP ssp119. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6329 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6329
UKESM1-0-LL | MOHC | ScenarioMIP | ssp126 | Good, Peter et al. (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6333 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6333
UKESM1-0-LL | MOHC | ScenarioMIP | ssp245 | Good, Peter et al. (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6339 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6339
UKESM1-0-LL | MOHC | ScenarioMIP | ssp370 | Good, Peter et al. (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 ScenarioMIP ssp370. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6347 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6347
UKESM1-0-LL | MOHC | ScenarioMIP | ssp434 | Good, Peter et al. (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 ScenarioMIP ssp434. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6389 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6389
UKESM1-0-LL | MOHC | ScenarioMIP | ssp534-over | Good, Peter et al. (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 ScenarioMIP ssp534-over. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6397 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6397
UKESM1-0-LL | MOHC | ScenarioMIP | ssp585 | Good, Peter et al. (2019). MOHC UKESM1.0-LL model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6405 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6405
UKESM1-0-LL | NERC | AerChemMIP | hist-1950HC | O'Connor, Fiona (2020). NERC UKESM1.0-LL model output prepared for CMIP6 AerChemMIP hist-1950HC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6047 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6047
UKESM1-0-LL | NERC | AerChemMIP | histSST-piCH4 | O'Connor, Fiona (2020). NERC UKESM1.0-LL model output prepared for CMIP6 AerChemMIP histSST-piCH4. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6090 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6090
UKESM1-0-LL | NERC | AerChemMIP | histSST-piO3 | O'Connor, Fiona (2020). NERC UKESM1.0-LL model output prepared for CMIP6 AerChemMIP histSST-piO3. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6102 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6102
UKESM1-0-LL | NERC | AerChemMIP | piClim-NOx | O'Connor, Fiona (2020). NERC UKESM1.0-LL model output prepared for CMIP6 AerChemMIP piClim-NOx. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6246 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6246
UKESM1-0-LL | NERC | AerChemMIP | piClim-O3 | O'Connor, Fiona (2020). NERC UKESM1.0-LL model output prepared for CMIP6 AerChemMIP piClim-O3. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6254 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6254
UKESM1-0-LL | NERC | AerChemMIP | piClim-VOC | O'Connor, Fiona (2020). NERC UKESM1.0-LL model output prepared for CMIP6 AerChemMIP piClim-VOC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6266 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6266
UKESM1-0-LL | NERC | AerChemMIP | ssp370SST | O'Connor, Fiona (2020). NERC UKESM1.0-LL model output prepared for CMIP6 AerChemMIP ssp370SST. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6362 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6362
UKESM1-0-LL | NERC | AerChemMIP | ssp370SST-lowO3 | O'Connor, Fiona (2020). NERC UKESM1.0-LL model output prepared for CMIP6 AerChemMIP ssp370SST-lowO3. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6382 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6382
UKESM1-0-LL | NERC | VolMIP | volc-pinatubo-full | Natural Environment Research Council (NERC) (2023). NERC UKESM1.0-LL model output prepared for CMIP6 VolMIP volc-pinatubo-full. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.6426 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.6426
UKESM1-0-LL | NIMS-KMA | AerChemMIP | hist-piNTCF | Byun, Young-Hwa (2020). NIMS-KMA UKESM1.0-LL model output prepared for CMIP6 AerChemMIP hist-piNTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8370 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8370
UKESM1-0-LL | NIMS-KMA | AerChemMIP | histSST-piNTCF | Byun, Young-Hwa (2020). NIMS-KMA UKESM1.0-LL model output prepared for CMIP6 AerChemMIP histSST-piNTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8376 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8376
UKESM1-0-LL | NIMS-KMA | AerChemMIP | piClim-NTCF | Byun, Young-Hwa (2020). NIMS-KMA UKESM1.0-LL model output prepared for CMIP6 AerChemMIP piClim-NTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8418 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8418
UKESM1-0-LL | NIMS-KMA | AerChemMIP | ssp370-lowNTCF | Byun, Young-Hwa (2020). NIMS-KMA UKESM1.0-LL model output prepared for CMIP6 AerChemMIP ssp370-lowNTCF. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8440 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8440
UKESM1-0-LL | NIMS-KMA | CMIP | historical | Byun, Young-Hwa (2020). NIMS-KMA UKESM1.0-LL model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8379 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8379
UKESM1-0-LL | NIMS-KMA | ScenarioMIP | ssp126 | Shim, Sungbo et al. (2021). NIMS-KMA UKESM1.0-LL model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8433 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8433
UKESM1-0-LL | NIMS-KMA | ScenarioMIP | ssp245 | Shim, Sungbo et al. (2020). NIMS-KMA UKESM1.0-LL model output prepared for CMIP6 ScenarioMIP ssp245. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8436 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8436
UKESM1-0-LL | NIMS-KMA | ScenarioMIP | ssp370 | Shim, Sungbo et al. (2021). NIMS-KMA UKESM1.0-LL model output prepared for CMIP6 ScenarioMIP ssp370. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8438 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8438
UKESM1-0-LL | NIMS-KMA | ScenarioMIP | ssp585 | Shim, Sungbo et al. (2021). NIMS-KMA UKESM1.0-LL model output prepared for CMIP6 ScenarioMIP ssp585. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.8457 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.8457
UKESM1-0-LL | NIWA | AerChemMIP | histSST-1950HC | Dalvi, Mohit et al. (2020). NIWA UKESM1.0-LL model output prepared for CMIP6 AerChemMIP histSST-1950HC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9393 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9393
UKESM1-0-LL | NIWA | AerChemMIP | histSST-piN2O | Dalvi, Mohit et al. (2020). NIWA UKESM1.0-LL model output prepared for CMIP6 AerChemMIP histSST-piN2O. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9396 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9396
UKESM1-0-LL | NIWA | AerChemMIP | piClim-HC | Dalvi, Mohit et al. (2019). NIWA UKESM1.0-LL model output prepared for CMIP6 AerChemMIP piClim-HC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9433 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9433
UKESM1-0-LL | NIWA | AerChemMIP | piClim-N2O | Dalvi, Mohit et al. (2020). NIWA UKESM1.0-LL model output prepared for CMIP6 AerChemMIP piClim-N2O. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9434 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9434
UKESM1-0-LL | NIWA | AerChemMIP | piClim-OC | Dalvi, Mohit et al. (2020). NIWA UKESM1.0-LL model output prepared for CMIP6 AerChemMIP piClim-OC. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9439 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9439
UKESM1-0-LL | NIWA | AerChemMIP | piClim-SO2 | Dalvi, Mohit et al. (2020). NIWA UKESM1.0-LL model output prepared for CMIP6 AerChemMIP piClim-SO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.9440 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.9440
UKESM1-1-LL | MOHC | CMIP | 1pctCO2 | Mulcahy, Jane et al. (2022). MOHC UKESM1.1-LL model output prepared for CMIP6 CMIP 1pctCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16783 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16783
UKESM1-1-LL | MOHC | CMIP | abrupt-4xCO2 | Mulcahy, Jane et al. (2022). MOHC UKESM1.1-LL model output prepared for CMIP6 CMIP abrupt-4xCO2. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16785 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16785
UKESM1-1-LL | MOHC | CMIP | amip | Mulcahy, Jane et al. (2022). MOHC UKESM1.1-LL model output prepared for CMIP6 CMIP amip. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16787 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16787
UKESM1-1-LL | MOHC | CMIP | historical | Mulcahy, Jane et al. (2022). MOHC UKESM1.1-LL model output prepared for CMIP6 CMIP historical. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16797 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16797
UKESM1-1-LL | MOHC | CMIP | piControl | Mulcahy, Jane et al. (2022). MOHC UKESM1.1-LL model output prepared for CMIP6 CMIP piControl. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16823 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16823
UKESM1-1-LL | MOHC | ScenarioMIP | ssp126 | Walton, Jeremy et al. (2022). MOHC UKESM1.1-LL model output prepared for CMIP6 ScenarioMIP ssp126. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16841 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16841
UKESM1-1-LL | MOHC | ScenarioMIP | ssp370 | Walton, Jeremy et al. (2022). MOHC UKESM1.1-LL model output prepared for CMIP6 ScenarioMIP ssp370. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.16845 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.16845
UKESM1-ice-LL | NERC | ISMIP6 | 1pctCO2to4x-withism | Smith, Robin et al. (2022). NERC UKESM1.ice-LL model output prepared for CMIP6 ISMIP6 1pctCO2to4x-withism. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13430 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13430
UKESM1-ice-LL | NERC | ISMIP6 | historical-withism | Smith, Robin et al. (2022). NERC UKESM1.ice-LL model output prepared for CMIP6 ISMIP6 historical-withism. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13450 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13450
UKESM1-ice-LL | NERC | ISMIP6 | piControl-withism | Smith, Robin et al. (2022). NERC UKESM1.ice-LL model output prepared for CMIP6 ISMIP6 piControl-withism. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13486 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13486
UKESM1-ice-LL | NERC | ISMIP6 | ssp585-withism | Smith, Robin et al. (2022). NERC UKESM1.ice-LL model output prepared for CMIP6 ISMIP6 ssp585-withism. Earth System Grid Federation. doi:https://doi.org/10.22033/ESGF/CMIP6.13488 | CC BY 4.0 | https://doi.org/10.22033/ESGF/CMIP6.13488